<?php
 declare(strict_types=1); namespace Square\Models; use stdClass; class UpdateShiftRequest implements \JsonSerializable { private $shift; public function __construct(Shift $shift) { $this->shift = $shift; } public function getShift(): Shift { return $this->shift; } public function setShift(Shift $shift): void { $this->shift = $shift; } #[\ReturnTypeWillChange] public function jsonSerialize(bool $asArrayWhenEmpty = false) { $json = []; $json['shift'] = $this->shift; $json = array_filter($json, function ($val) { return $val !== null; }); return (!$asArrayWhenEmpty && empty($json)) ? new stdClass() : $json; } } 