<?php
 declare(strict_types=1); namespace Square\Models; class CatalogDiscountModifyTaxBasis { public const MODIFY_TAX_BASIS = 'MODIFY_TAX_BASIS'; public const DO_NOT_MODIFY_TAX_BASIS = 'DO_NOT_MODIFY_TAX_BASIS'; } 