<?php
 $PHPMAILER_LANG['authenticate'] = 'Błąd SMTP: nie udało się przeprowadzić uwierzytelnienia.'; $PHPMAILER_LANG['buggy_php'] = 'Używana wersja PHP zawiera błąd, który może powodować uszkodzenie wiadomości. Aby temu zapobiec, użyj wysyłki przez SMTP, wyłącz opcję mail.add_x_header w php.ini, przejdź na macOS lub Linux, lub zaktualizuj PHP do wersji 7.0.17+ albo 7.1.3+.'; $PHPMAILER_LANG['connect_host'] = 'Błąd SMTP: nie udało się połączyć z serwerem (hostem).'; $PHPMAILER_LANG['data_not_accepted'] = 'Błąd SMTP: dane wiadomości nie zostały przyjęte przez serwer.'; $PHPMAILER_LANG['empty_message'] = 'Nie można wysłać pustej wiadomości.'; $PHPMAILER_LANG['encoding'] = 'Nieobsługiwane kodowanie znaków: '; $PHPMAILER_LANG['execute'] = 'Nie udało się uruchomić polecenia: '; $PHPMAILER_LANG['extension_missing'] = 'Brak wymaganego rozszerzenia PHP: '; $PHPMAILER_LANG['file_access'] = 'Brak dostępu do pliku: '; $PHPMAILER_LANG['file_open'] = 'Nie udało się otworzyć pliku: '; $PHPMAILER_LANG['from_failed'] = 'Nieprawidłowy adres nadawcy: '; $PHPMAILER_LANG['instantiate'] = 'Nie można zainicjować funkcji mail(). Sprawdź konfigurację serwera.'; $PHPMAILER_LANG['invalid_address'] = 'Nie można wysłać wiadomości. Nieprawidłowy adres odbiorcy: '; $PHPMAILER_LANG['invalid_header'] = 'Nieprawidłowa nazwa lub wartość nagłówka.'; $PHPMAILER_LANG['invalid_hostentry'] = 'Nieprawidłowy wpis hosta: '; $PHPMAILER_LANG['invalid_host'] = 'Nieprawidłowa nazwa hosta: '; $PHPMAILER_LANG['provide_address'] = 'Musisz podać co najmniej jeden prawidłowy adres e-mail odbiorcy.'; $PHPMAILER_LANG['mailer_not_supported'] = 'Wybrana metoda wysyłki wiadomości nie jest obsługiwana.'; $PHPMAILER_LANG['recipients_failed'] = 'Błąd SMTP: nie udało się wysłać do następujących odbiorców: '; $PHPMAILER_LANG['signing'] = 'Błąd podpisywania wiadomości cyfrowo: '; $PHPMAILER_LANG['smtp_code'] = 'Kod odpowiedzi SMTP: '; $PHPMAILER_LANG['smtp_code_ex'] = 'Dodatkowe informacje serwera SMTP: '; $PHPMAILER_LANG['smtp_connect_failed'] = 'Nie udało się nawiązać połączenia za pomocą SMTP Connect().'; $PHPMAILER_LANG['smtp_detail'] = 'Szczegóły błędu: '; $PHPMAILER_LANG['smtp_error'] = 'Błąd serwera SMTP: '; $PHPMAILER_LANG['variable_set'] = 'Nie można ustawić lub zmodyfikować zmiennej: '; 