<?php
 namespace Stripe\Service; class SetupAttemptService extends \Stripe\Service\AbstractService { public function all($params = null, $opts = null) { return $this->requestCollection('get', '/v1/setup_attempts', $params, $opts); } } 