<?php
 declare(strict_types=1); namespace Square\Models; class MeasurementUnitArea { public const IMPERIAL_ACRE = 'IMPERIAL_ACRE'; public const IMPERIAL_SQUARE_INCH = 'IMPERIAL_SQUARE_INCH'; public const IMPERIAL_SQUARE_FOOT = 'IMPERIAL_SQUARE_FOOT'; public const IMPERIAL_SQUARE_YARD = 'IMPERIAL_SQUARE_YARD'; public const IMPERIAL_SQUARE_MILE = 'IMPERIAL_SQUARE_MILE'; public const METRIC_SQUARE_CENTIMETER = 'METRIC_SQUARE_CENTIMETER'; public const METRIC_SQUARE_METER = 'METRIC_SQUARE_METER'; public const METRIC_SQUARE_KILOMETER = 'METRIC_SQUARE_KILOMETER'; } 