<?php
 namespace Eluceo\iCal\Presentation\Component\Property; final class Parameter { private string $name; private Value $value; public function __construct(string $name, Value $value) { $this->name = strtoupper($name); $this->value = $value; } public function __toString(): string { return $this->name . '=' . $this->value; } } 