<?php
 class vB_Utility_Template_ParserNode_Curly_Concat extends vB_Utility_Template_ParserNode_Curly { public function validate() : array { $errors = []; $attributecount = sizeof($this->main_node->attributes); if ($attributecount == 0) { $errors[] = 'no_variable_specified'; } if ($attributecount < 2) { $errors[] = 'too_few_attributes'; } return $errors; } public function compile() : string { $arguments = $this->getRenderedAttributes(); return implode(' . ', array_filter($arguments)); } } 