<?php if (!defined('VB_ENTRY')) die('Access denied.'); class vB_Session_Skip extends vB_Session { public function __construct(&$dBAssertor, &$datastore, &$config, $styleid = 0, $languageid = 0) { parent::__construct($dBAssertor, $datastore, $config, '', array(), $styleid, $languageid); } protected function loadExistingSession($sessionhash, $restoreSessionInfo, $deferRememberMe = false) { return false; } public function save() { return; } } 