<?php
 declare(strict_types=1); namespace Jose\Component\Core\Util\Ecc; use Brick\Math\BigInteger; final readonly class PrivateKey { private function __construct( private BigInteger $secret ) { } public static function create(BigInteger $secret): self { return new self($secret); } public function getSecret(): BigInteger { return $this->secret; } } 