<?php
 declare(strict_types=1); namespace Square\Models; class SubscriptionEventSubscriptionEventType { public const START_SUBSCRIPTION = 'START_SUBSCRIPTION'; public const PLAN_CHANGE = 'PLAN_CHANGE'; public const STOP_SUBSCRIPTION = 'STOP_SUBSCRIPTION'; public const DEACTIVATE_SUBSCRIPTION = 'DEACTIVATE_SUBSCRIPTION'; public const RESUME_SUBSCRIPTION = 'RESUME_SUBSCRIPTION'; public const PAUSE_SUBSCRIPTION = 'PAUSE_SUBSCRIPTION'; } 