<?php
 class vB_dB_ArrayResult extends ArrayIterator implements Iterator { use vB_Trait_NoSerialize; private $db; public function __construct($db, $recordset) { parent::__construct($recordset); $this->db = $db; } public function db() { return $this->db; } public function free() { } } 