<?php
 namespace Eluceo\iCal\Domain\ValueObject; final class SingleDay extends Occurrence { private Date $date; public function __construct(Date $date) { $this->date = $date; } public function getDate(): Date { return $this->date; } } 