<?php
 declare(strict_types=1); namespace Jose\Component\Signature\Algorithm; use Jose\Component\Core\Algorithm; use Jose\Component\Core\JWK; interface SignatureAlgorithm extends Algorithm { public function sign(JWK $key, string $input): string; public function verify(JWK $key, string $input, string $signature): bool; } 