<?php
 namespace Stripe\Service; class InvoiceService extends \Stripe\Service\AbstractService { public function all($params = null, $opts = null) { return $this->requestCollection('get', '/v1/invoices', $params, $opts); } public function allLines($parentId, $params = null, $opts = null) { return $this->requestCollection('get', $this->buildPath('/v1/invoices/%s/lines', $parentId), $params, $opts); } public function create($params = null, $opts = null) { return $this->request('post', '/v1/invoices', $params, $opts); } public function delete($id, $params = null, $opts = null) { return $this->request('delete', $this->buildPath('/v1/invoices/%s', $id), $params, $opts); } public function finalizeInvoice($id, $params = null, $opts = null) { return $this->request('post', $this->buildPath('/v1/invoices/%s/finalize', $id), $params, $opts); } public function markUncollectible($id, $params = null, $opts = null) { return $this->request('post', $this->buildPath('/v1/invoices/%s/mark_uncollectible', $id), $params, $opts); } public function pay($id, $params = null, $opts = null) { return $this->request('post', $this->buildPath('/v1/invoices/%s/pay', $id), $params, $opts); } public function retrieve($id, $params = null, $opts = null) { return $this->request('get', $this->buildPath('/v1/invoices/%s', $id), $params, $opts); } public function search($params = null, $opts = null) { return $this->requestSearchResult('get', '/v1/invoices/search', $params, $opts); } public function sendInvoice($id, $params = null, $opts = null) { return $this->request('post', $this->buildPath('/v1/invoices/%s/send', $id), $params, $opts); } public function upcoming($params = null, $opts = null) { return $this->request('get', '/v1/invoices/upcoming', $params, $opts); } public function upcomingLines($params = null, $opts = null) { return $this->requestCollection('get', '/v1/invoices/upcoming/lines', $params, $opts); } public function update($id, $params = null, $opts = null) { return $this->request('post', $this->buildPath('/v1/invoices/%s', $id), $params, $opts); } public function voidInvoice($id, $params = null, $opts = null) { return $this->request('post', $this->buildPath('/v1/invoices/%s/void', $id), $params, $opts); } } 