<?php
 namespace Stripe; class ShippingRate extends ApiResource { const OBJECT_NAME = 'shipping_rate'; use ApiOperations\All; use ApiOperations\Create; use ApiOperations\Retrieve; use ApiOperations\Update; const TAX_BEHAVIOR_EXCLUSIVE = 'exclusive'; const TAX_BEHAVIOR_INCLUSIVE = 'inclusive'; const TAX_BEHAVIOR_UNSPECIFIED = 'unspecified'; const TYPE_FIXED_AMOUNT = 'fixed_amount'; } 