<?php
 declare(strict_types=1); namespace Square\Models; class GiftCardActivityRedeemStatus { public const PENDING = 'PENDING'; public const COMPLETED = 'COMPLETED'; public const CANCELED = 'CANCELED'; } 