<?php
 class vB_Entity_ScheduleItem extends vB_Entity { public function __construct( protected int $startunixtime, protected int $endunixtime, protected int $priority, protected array $data ) {} public function isActiveAt(int $unixtimestamp) : bool { return ($this->startunixtime <= $unixtimestamp AND $unixtimestamp <= $this->endunixtime); } public static function createFromArray(array $data) : static { return new self($data['startunixtime'], $data['endunixtime'], $data['priority'], $data['data']); } } 