<?php
 declare(strict_types=1); namespace Square\Models; class MeasurementUnitVolume { public const GENERIC_FLUID_OUNCE = 'GENERIC_FLUID_OUNCE'; public const GENERIC_SHOT = 'GENERIC_SHOT'; public const GENERIC_CUP = 'GENERIC_CUP'; public const GENERIC_PINT = 'GENERIC_PINT'; public const GENERIC_QUART = 'GENERIC_QUART'; public const GENERIC_GALLON = 'GENERIC_GALLON'; public const IMPERIAL_CUBIC_INCH = 'IMPERIAL_CUBIC_INCH'; public const IMPERIAL_CUBIC_FOOT = 'IMPERIAL_CUBIC_FOOT'; public const IMPERIAL_CUBIC_YARD = 'IMPERIAL_CUBIC_YARD'; public const METRIC_MILLILITER = 'METRIC_MILLILITER'; public const METRIC_LITER = 'METRIC_LITER'; } 