<?php
 class vB_dB_Query_Select extends vB_dB_Query_TableQuery { protected function buildQuery(array $values) : string { $queryBuilder = self::$queryBuilders[$this->db_type]; $params = $this->extractParamsFromValues($values); $where = $this->getWhere($queryBuilder, $values); return $queryBuilder->makeSelectQuery($this->queryid, $where, $this->sortorder, $this->structure['structure'], $params); } protected function doQuery(string $querystring) : mixed { $useSlave = ($this->dbSlave AND empty($this->params[self::PRIORITY_QUERY])); $resultclass = 'vB_dB_' . $this->db_type . '_result'; $result = new $resultclass($this->db, $querystring, $useSlave); return $result; } } 