<?php
 abstract class vB_Utility_Template_ParserNode_CurlyRuntime extends vB_Utility_Template_ParserNode_Curly { protected static string $function = ''; protected static string $noparamerror = 'no_variable_specified'; protected static int $maxparams = PHP_INT_MAX; public function validate() : array { $errors = []; $attributecount = sizeof($this->main_node->attributes); if ($attributecount == 0) { $errors[] = static::$noparamerror; } if ($attributecount > static::$maxparams) { $errors[] = 'too_many_attributes'; } return $errors; } public function compile() : string { return 'vB_Template_Runtime::' . static::$function . '(' . $this->getArgumentsFromAttributes() . ')'; } } 