<?php
 namespace Stripe\Service; class SubscriptionItemService extends \Stripe\Service\AbstractService { public function all($params = null, $opts = null) { return $this->requestCollection('get', '/v1/subscription_items', $params, $opts); } public function allUsageRecordSummaries($parentId, $params = null, $opts = null) { return $this->requestCollection('get', $this->buildPath('/v1/subscription_items/%s/usage_record_summaries', $parentId), $params, $opts); } public function create($params = null, $opts = null) { return $this->request('post', '/v1/subscription_items', $params, $opts); } public function createUsageRecord($parentId, $params = null, $opts = null) { return $this->request('post', $this->buildPath('/v1/subscription_items/%s/usage_records', $parentId), $params, $opts); } public function delete($id, $params = null, $opts = null) { return $this->request('delete', $this->buildPath('/v1/subscription_items/%s', $id), $params, $opts); } public function retrieve($id, $params = null, $opts = null) { return $this->request('get', $this->buildPath('/v1/subscription_items/%s', $id), $params, $opts); } public function update($id, $params = null, $opts = null) { return $this->request('post', $this->buildPath('/v1/subscription_items/%s', $id), $params, $opts); } } 