<?php
 declare(strict_types=1); namespace Square\Models; class V1PaymentSurchargeType { public const UNKNOWN = 'UNKNOWN'; public const AUTO_GRATUITY = 'AUTO_GRATUITY'; public const CUSTOM = 'CUSTOM'; } 