<?php if (!defined('VB_ENTRY')) die('Access denied.'); class vB_Cache_Null extends vB_Cache { protected $assertor; protected $requestStart; protected $cache = array(); public function __construct($cachetype) { $this->cachetype = $cachetype; } protected function writeCache($cache){} protected function readCache($key){} protected function purgeCache($key){} protected function expireCache($key){} public function write($key, $data, $lifetime_mins = false, $events = false) { return false; } public function saveCacheInfo($cacheid) { return false; } public function restoreCacheInfo($cacheid) { return false; } public function isLoaded($key) { return false; } public function read($keys, $writeLock = false, $save_meta = false) { if(is_array($keys)) { return array_fill_keys($keys, false); } return false; } public function purge($cache_id) { return $this; } public function expire($cache_id) { return $this; } public function event($events) { return $this; } public function lock($key) { return false; } public function unlock($key) { return false; } public function clean($only_expired = true){} public function attachObserver(vB_Cache_Observer $observer){} public function removeObserver(vB_Cache_Observer $observer){} public function shutdown(){} public function cleanNow(){} } 