<?php
 class vB_DataManager_StyleVarTextDecoration extends vB_DataManager_StyleVar { protected array $childfields = [ 'none' => [vB_Cleaner::TYPE_BOOL, vB_DataManager_Constants::REQ_NO], 'underline' => [vB_Cleaner::TYPE_BOOL, vB_DataManager_Constants::REQ_NO], 'overline' => [vB_Cleaner::TYPE_BOOL, vB_DataManager_Constants::REQ_NO], 'line-through' => [vB_Cleaner::TYPE_BOOL, vB_DataManager_Constants::REQ_NO], 'stylevar_none' => [vB_Cleaner::TYPE_STR, vB_DataManager_Constants::REQ_NO, vB_DataManager_Constants::VF_METHOD, 'verify_value_stylevar'], 'stylevar_underline' => [vB_Cleaner::TYPE_STR, vB_DataManager_Constants::REQ_NO, vB_DataManager_Constants::VF_METHOD, 'verify_value_stylevar'], 'stylevar_overline' => [vB_Cleaner::TYPE_STR, vB_DataManager_Constants::REQ_NO, vB_DataManager_Constants::VF_METHOD, 'verify_value_stylevar'], 'stylevar_line-through' => [vB_Cleaner::TYPE_STR, vB_DataManager_Constants::REQ_NO, vB_DataManager_Constants::VF_METHOD, 'verify_value_stylevar'], ]; public $datatype = 'TextDecoration'; } 