<?php
 declare(strict_types=1); namespace Square\Models; class CustomerCreationSource { public const OTHER = 'OTHER'; public const APPOINTMENTS = 'APPOINTMENTS'; public const COUPON = 'COUPON'; public const DELETION_RECOVERY = 'DELETION_RECOVERY'; public const DIRECTORY = 'DIRECTORY'; public const EGIFTING = 'EGIFTING'; public const EMAIL_COLLECTION = 'EMAIL_COLLECTION'; public const FEEDBACK = 'FEEDBACK'; public const IMPORT = 'IMPORT'; public const INVOICES = 'INVOICES'; public const LOYALTY = 'LOYALTY'; public const MARKETING = 'MARKETING'; public const MERGE = 'MERGE'; public const ONLINE_STORE = 'ONLINE_STORE'; public const INSTANT_PROFILE = 'INSTANT_PROFILE'; public const TERMINAL = 'TERMINAL'; public const THIRD_PARTY = 'THIRD_PARTY'; public const THIRD_PARTY_IMPORT = 'THIRD_PARTY_IMPORT'; public const UNMERGE_RECOVERY = 'UNMERGE_RECOVERY'; } 