<?php
 declare(strict_types=1); namespace Square\Models; class SubscriptionCadence { public const DAILY = 'DAILY'; public const WEEKLY = 'WEEKLY'; public const EVERY_TWO_WEEKS = 'EVERY_TWO_WEEKS'; public const THIRTY_DAYS = 'THIRTY_DAYS'; public const SIXTY_DAYS = 'SIXTY_DAYS'; public const NINETY_DAYS = 'NINETY_DAYS'; public const MONTHLY = 'MONTHLY'; public const EVERY_TWO_MONTHS = 'EVERY_TWO_MONTHS'; public const QUARTERLY = 'QUARTERLY'; public const EVERY_FOUR_MONTHS = 'EVERY_FOUR_MONTHS'; public const EVERY_SIX_MONTHS = 'EVERY_SIX_MONTHS'; public const ANNUAL = 'ANNUAL'; public const EVERY_TWO_YEARS = 'EVERY_TWO_YEARS'; } 