<?php
 declare(strict_types=1); namespace Square\Models; use stdClass; class TeamMemberAssignedLocations implements \JsonSerializable { private $assignmentType; private $locationIds; public function getAssignmentType(): ?string { return $this->assignmentType; } public function setAssignmentType(?string $assignmentType): void { $this->assignmentType = $assignmentType; } public function getLocationIds(): ?array { return $this->locationIds; } public function setLocationIds(?array $locationIds): void { $this->locationIds = $locationIds; } #[\ReturnTypeWillChange] public function jsonSerialize(bool $asArrayWhenEmpty = false) { $json = []; if (isset($this->assignmentType)) { $json['assignment_type'] = $this->assignmentType; } if (isset($this->locationIds)) { $json['location_ids'] = $this->locationIds; } $json = array_filter($json, function ($val) { return $val !== null; }); return (!$asArrayWhenEmpty && empty($json)) ? new stdClass() : $json; } } 