<?php
 namespace Eluceo\iCal\Presentation\Component\Property\Value; use Eluceo\iCal\Presentation\Component\Property\Value; final class ListValue extends Value { private array $values = []; public function __construct(array $values) { foreach ($values as $value) { $this->addValue($value); } } public function __toString(): string { return implode(',', array_map('strval', $this->values)); } private function addValue(Value $value): void { $this->values[] = $value; } } 