<?php
 declare(strict_types=1); namespace Square\Models; use stdClass; class RetrieveSubscriptionRequest implements \JsonSerializable { private $mInclude; public function getMInclude(): ?string { return $this->mInclude; } public function setMInclude(?string $mInclude): void { $this->mInclude = $mInclude; } #[\ReturnTypeWillChange] public function jsonSerialize(bool $asArrayWhenEmpty = false) { $json = []; if (isset($this->mInclude)) { $json['include'] = $this->mInclude; } $json = array_filter($json, function ($val) { return $val !== null; }); return (!$asArrayWhenEmpty && empty($json)) ? new stdClass() : $json; } } 