<?php
 declare(strict_types=1); namespace Square\Models; class OrderLineItemItemType { public const ITEM = 'ITEM'; public const CUSTOM_AMOUNT = 'CUSTOM_AMOUNT'; public const GIFT_CARD = 'GIFT_CARD'; } 