/*
 =======================================================================*\
|| ###################################################################### ||
|| # vBulletin 6.2.3
|| # ------------------------------------------------------------------ # ||
|| # Copyright 2000-2026 MH Sub I, LLC dba vBulletin. All Rights Reserved.  # ||
|| # This file may not be redistributed in whole or significant part.   # ||
|| # ----------------- VBULLETIN IS NOT FREE SOFTWARE ----------------- # ||
|| # http://www.vbulletin.com | http://www.vbulletin.com/license.html   # ||
|| ###################################################################### ||
\*========================================================================*/
var multi_input=[];
function vB_Multi_Input(f,k,h){this.varname=f;this.count=k;this.cpstylefolder=h;this.add=function(){var a=document.createElement("div");a.id="multi_input_container_"+this.varname+"_"+this.count;a.appendChild(document.createTextNode(this.count+1+" "));a.appendChild(this.create_input(this.count+1));fetch_object("multi_input_fieldset_"+this.varname).appendChild(a);this.append_buttons(this.count++);return!1};this.create_input=function(){var a=document.createElement("input");a.type="text";a.size=40;a.className=
"bginput";a.name="setting["+this.varname+"]["+this.count+"]";a.id="multi_input_"+this.varname+"_"+this.count;a.tabIndex=1;return a};this.create_button=function(a,c,b){var d=document.createElement("a");d.varname=this.varname;d.index=a;d.moveby=b;d.href="#";d.onclick=function(){return multi_input[this.varname].move(this.index,this.moveby)};a=document.createElement("img");a.src="../cpstyles/"+this.cpstylefolder+"/move_"+c+".gif";a.alt="";a.border=0;d.appendChild(a);return d};this.append_buttons=function(a){var c=
fetch_object("multi_input_container_"+this.varname+"_"+a);c.varname=this.varname;c.index=a;c.appendChild(document.createTextNode(" "));c.appendChild(this.create_button(a,"down",1));c.appendChild(document.createTextNode(" "));c.appendChild(this.create_button(a,"up",-1))};this.fetch_input=function(a){return fetch_object("multi_input_"+this.varname+"_"+a)};this.move=function(a,c){var b,d=[];for(b=0;b<this.count;b++)d[b]=this.fetch_input(b).value;if(0==a&&0>c)for(b=0;b<this.count;b++)this.fetch_input(b).value=
b==this.count-1?d[0]:d[b+1];else if(a==this.count-1&&0<c)for(b=0;b<this.count;b++)this.fetch_input(b).value=0==b?d[this.count-1]:d[b-1];else this.fetch_input(a).value=d[a+c],this.fetch_input(a+c).value=d[a];return!1};for(f=0;f<this.count;f++)this.append_buttons(f)}
(function(f){function k(h,a=300){let c=f("#"+h),b=3,d=!0;if(c.length){c.addClass("h-highlight-optiontitle");let g=setInterval(()=>{d=!d;c.toggleClass("h-highlight-ease-off",!d);d||--b;0>=b&&(clearInterval(g),c.addClass("h-highlight-ease-off--final"))},a)}}f(function(){f("#settings-filter").trigger("focus").on("keyup",function(a){var c=f(this).val().toLowerCase();a=f("#settings-select");var b=a.find("option");if(""==c)b.show(),a.get(0).selectedIndex=0;else{var d=[];b.each(function(g,e){e=f(this);var m=
e.val().toLowerCase(),l=e.text().toLowerCase();-1==m.indexOf(c)&&-1==l.indexOf(c)&&"[all]"!=m?e.hide():(e.show(),-1!=l.indexOf(c)&&d.push({index:g,text:l,$option:e}))});0<d.length&&(d.sort(function(g,e){g=g.text.match(new RegExp("(\\b|^|/)"+c,"i"));e=e.text.match(new RegExp("(\\b|^|/)"+c,"i"));g=g&&g.length?1:0;e=e&&e.length?1:0;return g==e?0:g>e?-1:1}),b=d.shift(),a.get(0).selectedIndex=b.index)}});const h=(new URLSearchParams(window.location.search)).get("varname")||window.location.hash.substring(1);
h&&("hidden"==document.visibilityState?addEventListener("visibilitychange",()=>{"visible"==document.visibilityState&&k(h)},{once:!0}):k(h))})})(jQuery);
