<?php if (!defined('VB_ENTRY')) die('Access denied.'); class vB_Exception_404 extends vB_Exception { public function __construct($message = false, $code = false, $file = false, $line = false) { $message = $message ? $message : new vB_Phrase('error', 'page_not_found'); parent::__construct($message, $code, $file, $line); } } 