<?php
 declare(strict_types=1); namespace Square\Models; use stdClass; class ListPayoutsRequest implements \JsonSerializable { private $locationId; private $status; private $beginTime; private $endTime; private $sortOrder; private $cursor; private $limit; public function getLocationId(): ?string { return $this->locationId; } public function setLocationId(?string $locationId): void { $this->locationId = $locationId; } public function getStatus(): ?string { return $this->status; } public function setStatus(?string $status): void { $this->status = $status; } public function getBeginTime(): ?string { return $this->beginTime; } public function setBeginTime(?string $beginTime): void { $this->beginTime = $beginTime; } public function getEndTime(): ?string { return $this->endTime; } public function setEndTime(?string $endTime): void { $this->endTime = $endTime; } public function getSortOrder(): ?string { return $this->sortOrder; } public function setSortOrder(?string $sortOrder): void { $this->sortOrder = $sortOrder; } public function getCursor(): ?string { return $this->cursor; } public function setCursor(?string $cursor): void { $this->cursor = $cursor; } public function getLimit(): ?int { return $this->limit; } public function setLimit(?int $limit): void { $this->limit = $limit; } #[\ReturnTypeWillChange] public function jsonSerialize(bool $asArrayWhenEmpty = false) { $json = []; if (isset($this->locationId)) { $json['location_id'] = $this->locationId; } if (isset($this->status)) { $json['status'] = $this->status; } if (isset($this->beginTime)) { $json['begin_time'] = $this->beginTime; } if (isset($this->endTime)) { $json['end_time'] = $this->endTime; } if (isset($this->sortOrder)) { $json['sort_order'] = $this->sortOrder; } if (isset($this->cursor)) { $json['cursor'] = $this->cursor; } if (isset($this->limit)) { $json['limit'] = $this->limit; } $json = array_filter($json, function ($val) { return $val !== null; }); return (!$asArrayWhenEmpty && empty($json)) ? new stdClass() : $json; } } 