<?php
 declare(strict_types=1); namespace Square\Models; class TeamMemberAssignedLocationsAssignmentType { public const ALL_CURRENT_AND_FUTURE_LOCATIONS = 'ALL_CURRENT_AND_FUTURE_LOCATIONS'; public const EXPLICIT_LOCATIONS = 'EXPLICIT_LOCATIONS'; } 