<?php
 declare(strict_types=1); namespace Square\Models; class GiftCardStatus { public const ACTIVE = 'ACTIVE'; public const DEACTIVATED = 'DEACTIVATED'; public const BLOCKED = 'BLOCKED'; public const PENDING = 'PENDING'; } 