<?php
 declare(strict_types=1); namespace Ramsey\Uuid\Math; final class RoundingMode { public const UNNECESSARY = 0; public const UP = 1; public const DOWN = 2; public const CEILING = 3; public const FLOOR = 4; public const HALF_UP = 5; public const HALF_DOWN = 6; public const HALF_CEILING = 7; public const HALF_FLOOR = 8; public const HALF_EVEN = 9; private function __construct() { } } 