<?php
 declare(strict_types=1); namespace Shopify\Rest\Admin2024_04; use Shopify\Auth\Session; use Shopify\Rest\Base; class CancellationRequest extends Base { public static string $API_VERSION = "2024-04"; protected static array $HAS_ONE = []; protected static array $HAS_MANY = []; protected static array $PATHS = [ ["http_method" => "post", "operation" => "accept", "ids" => ["fulfillment_order_id"], "path" => "fulfillment_orders/<fulfillment_order_id>/cancellation_request/accept.json"], ["http_method" => "post", "operation" => "post", "ids" => ["fulfillment_order_id"], "path" => "fulfillment_orders/<fulfillment_order_id>/cancellation_request.json"], ["http_method" => "post", "operation" => "reject", "ids" => ["fulfillment_order_id"], "path" => "fulfillment_orders/<fulfillment_order_id>/cancellation_request/reject.json"] ]; public function accept( array $params = [], $body = [] ): ?array { $response = parent::request( "post", "accept", $this->session, ["fulfillment_order_id" => $this->fulfillment_order_id], $params, $body, $this, ); return $response->getDecodedBody(); } public function reject( array $params = [], $body = [] ): ?array { $response = parent::request( "post", "reject", $this->session, ["fulfillment_order_id" => $this->fulfillment_order_id], $params, $body, $this, ); return $response->getDecodedBody(); } } 