<?php
 declare(strict_types=1); namespace Square\Models; class DayOfWeek { public const SUN = 'SUN'; public const MON = 'MON'; public const TUE = 'TUE'; public const WED = 'WED'; public const THU = 'THU'; public const FRI = 'FRI'; public const SAT = 'SAT'; } 