<?php
 declare(strict_types=1); namespace Square\Models; class GiftCardActivityDeactivateReason { public const SUSPICIOUS_ACTIVITY = 'SUSPICIOUS_ACTIVITY'; public const UNKNOWN_REASON = 'UNKNOWN_REASON'; public const CHARGEBACK_DEACTIVATE = 'CHARGEBACK_DEACTIVATE'; } 