<?php
 declare(strict_types=1); namespace Square\Models; use stdClass; class CatalogQueryItemsForTax implements \JsonSerializable { private $taxIds; public function __construct(array $taxIds) { $this->taxIds = $taxIds; } public function getTaxIds(): array { return $this->taxIds; } public function setTaxIds(array $taxIds): void { $this->taxIds = $taxIds; } #[\ReturnTypeWillChange] public function jsonSerialize(bool $asArrayWhenEmpty = false) { $json = []; $json['tax_ids'] = $this->taxIds; $json = array_filter($json, function ($val) { return $val !== null; }); return (!$asArrayWhenEmpty && empty($json)) ? new stdClass() : $json; } } 