/*
 =======================================================================*\
|| ###################################################################### ||
|| # vBulletin 6.2.3
|| # ------------------------------------------------------------------ # ||
|| # Copyright 2000-2026 MH Sub I, LLC dba vBulletin. All Rights Reserved.  # ||
|| # This file may not be redistributed in whole or significant part.   # ||
|| # ----------------- VBULLETIN IS NOT FREE SOFTWARE ----------------- # ||
|| # http://www.vbulletin.com | http://www.vbulletin.com/license.html   # ||
|| ###################################################################### ||
\*========================================================================*/
(function(a){a(()=>{vBAdmin.initJumpControl("prod",{productdisable:"admincp/product.php?do=productdisable&productid={id}",productenable:"admincp/product.php?do=productenable&productid={id}",productedit:"admincp/product.php?do=productedit&productid={id}",productversioncheck:"admincp/product.php?do=productversioncheck&productid={id}",productexport:"admincp/product.php?do=productexport&productid={id}",productdelete:"admincp/product.php?do=productdelete&productid={id}"})})})(jQuery);
