<?php
 declare(strict_types=1); namespace SpomkyLabs\Pki\X501\StringPrep; use Normalizer; final class NormalizeStep implements PrepareStep { public function apply(string $string): string { return normalizer_normalize($string, Normalizer::NFKC); } } 