<?php
 declare(strict_types=1); namespace Square\Models; use stdClass; class TeamMember implements \JsonSerializable { private $id; private $referenceId; private $isOwner; private $status; private $givenName; private $familyName; private $emailAddress; private $phoneNumber; private $createdAt; private $updatedAt; private $assignedLocations; public function getId(): ?string { return $this->id; } public function setId(?string $id): void { $this->id = $id; } public function getReferenceId(): ?string { return $this->referenceId; } public function setReferenceId(?string $referenceId): void { $this->referenceId = $referenceId; } public function getIsOwner(): ?bool { return $this->isOwner; } public function setIsOwner(?bool $isOwner): void { $this->isOwner = $isOwner; } public function getStatus(): ?string { return $this->status; } public function setStatus(?string $status): void { $this->status = $status; } public function getGivenName(): ?string { return $this->givenName; } public function setGivenName(?string $givenName): void { $this->givenName = $givenName; } public function getFamilyName(): ?string { return $this->familyName; } public function setFamilyName(?string $familyName): void { $this->familyName = $familyName; } public function getEmailAddress(): ?string { return $this->emailAddress; } public function setEmailAddress(?string $emailAddress): void { $this->emailAddress = $emailAddress; } public function getPhoneNumber(): ?string { return $this->phoneNumber; } public function setPhoneNumber(?string $phoneNumber): void { $this->phoneNumber = $phoneNumber; } public function getCreatedAt(): ?string { return $this->createdAt; } public function setCreatedAt(?string $createdAt): void { $this->createdAt = $createdAt; } public function getUpdatedAt(): ?string { return $this->updatedAt; } public function setUpdatedAt(?string $updatedAt): void { $this->updatedAt = $updatedAt; } public function getAssignedLocations(): ?TeamMemberAssignedLocations { return $this->assignedLocations; } public function setAssignedLocations(?TeamMemberAssignedLocations $assignedLocations): void { $this->assignedLocations = $assignedLocations; } #[\ReturnTypeWillChange] public function jsonSerialize(bool $asArrayWhenEmpty = false) { $json = []; if (isset($this->id)) { $json['id'] = $this->id; } if (isset($this->referenceId)) { $json['reference_id'] = $this->referenceId; } if (isset($this->isOwner)) { $json['is_owner'] = $this->isOwner; } if (isset($this->status)) { $json['status'] = $this->status; } if (isset($this->givenName)) { $json['given_name'] = $this->givenName; } if (isset($this->familyName)) { $json['family_name'] = $this->familyName; } if (isset($this->emailAddress)) { $json['email_address'] = $this->emailAddress; } if (isset($this->phoneNumber)) { $json['phone_number'] = $this->phoneNumber; } if (isset($this->createdAt)) { $json['created_at'] = $this->createdAt; } if (isset($this->updatedAt)) { $json['updated_at'] = $this->updatedAt; } if (isset($this->assignedLocations)) { $json['assigned_locations'] = $this->assignedLocations; } $json = array_filter($json, function ($val) { return $val !== null; }); return (!$asArrayWhenEmpty && empty($json)) ? new stdClass() : $json; } } 