vBulletin.precache(
	[
		// phrases
		'googlelogin_connect_to_google',
		'googlelogin_disconnect_complete_revoke_access',
		'googlelogin_disconnect_from_google',
	],
	[
	]
);
{
	const vB = vBulletin,
		phrases = {
			connect_to_provider: 'googlelogin_connect_to_google',
			disconnect_from_provider: 'googlelogin_disconnect_from_google',
			after_unlink_title: 'googlelogin_disconnect_from_google',
			after_unlink_body: 'googlelogin_disconnect_complete_revoke_access',
		};
	vB.ready('oauth').then(() => {
		vB.oauth.init('googlelogin', phrases);
	});
}