<?php
 declare(strict_types=1); namespace Square\Models; class V1SettlementEntryType { public const ADJUSTMENT = 'ADJUSTMENT'; public const BALANCE_CHARGE = 'BALANCE_CHARGE'; public const CHARGE = 'CHARGE'; public const FREE_PROCESSING = 'FREE_PROCESSING'; public const HOLD_ADJUSTMENT = 'HOLD_ADJUSTMENT'; public const PAID_SERVICE_FEE = 'PAID_SERVICE_FEE'; public const PAID_SERVICE_FEE_REFUND = 'PAID_SERVICE_FEE_REFUND'; public const REDEMPTION_CODE = 'REDEMPTION_CODE'; public const REFUND = 'REFUND'; public const RETURNED_PAYOUT = 'RETURNED_PAYOUT'; public const SQUARE_CAPITAL_ADVANCE = 'SQUARE_CAPITAL_ADVANCE'; public const SQUARE_CAPITAL_PAYMENT = 'SQUARE_CAPITAL_PAYMENT'; public const SQUARE_CAPITAL_REVERSED_PAYMENT = 'SQUARE_CAPITAL_REVERSED_PAYMENT'; public const SUBSCRIPTION_FEE = 'SUBSCRIPTION_FEE'; public const SUBSCRIPTION_FEE_REFUND = 'SUBSCRIPTION_FEE_REFUND'; public const OTHER = 'OTHER'; public const INCENTED_PAYMENT = 'INCENTED_PAYMENT'; public const RETURNED_ACH_ENTRY = 'RETURNED_ACH_ENTRY'; public const RETURNED_SQUARE_275 = 'RETURNED_SQUARE_275'; public const SQUARE_275 = 'SQUARE_275'; public const SQUARE_CARD = 'SQUARE_CARD'; } 