<?php
 declare(strict_types=1); namespace Square\Models; class TeamMemberInvitationStatus { public const UNINVITED = 'UNINVITED'; public const PENDING = 'PENDING'; public const ACCEPTED = 'ACCEPTED'; } 