<?php
 declare(strict_types=1); namespace Square\Models; class CardPrepaidType { public const UNKNOWN_PREPAID_TYPE = 'UNKNOWN_PREPAID_TYPE'; public const NOT_PREPAID = 'NOT_PREPAID'; public const PREPAID = 'PREPAID'; } 