<?php
 declare(strict_types=1); namespace Square\Models; class CatalogItemProductType { public const REGULAR = 'REGULAR'; public const GIFT_CARD = 'GIFT_CARD'; public const APPOINTMENTS_SERVICE = 'APPOINTMENTS_SERVICE'; } 