<?php
 class vB_Utility_Template_ParserNode_Curly_Debugtimer extends vB_Utility_Template_ParserNode_Curly { public function validate() : array { return []; } public function compile() : string { if (count($this->main_node->attributes)) { $timerName = $this->attributeToString($this->main_node->attributes[0]); } else { $timerName = "''"; } return '\'\'; $final_rendered .= vB_Template_Runtime::debugTimer(' . $timerName . '); $final_rendered .= \'\''; } } 