<?php
 declare(strict_types=1); namespace Jose\Component\Encryption\Algorithm; use Jose\Component\Core\Algorithm; interface ContentEncryptionAlgorithm extends Algorithm { public function encryptContent( string $data, string $cek, string $iv, ?string $aad, string $encoded_protected_header, ?string &$tag = null ): string; public function decryptContent( string $data, string $cek, string $iv, ?string $aad, string $encoded_protected_header, string $tag ): string; public function getIVSize(): int; public function getCEKSize(): int; } 