<?php
 namespace Stripe\Service\Identity; class VerificationSessionService extends \Stripe\Service\AbstractService { public function all($params = null, $opts = null) { return $this->requestCollection('get', '/v1/identity/verification_sessions', $params, $opts); } public function cancel($id, $params = null, $opts = null) { return $this->request('post', $this->buildPath('/v1/identity/verification_sessions/%s/cancel', $id), $params, $opts); } public function create($params = null, $opts = null) { return $this->request('post', '/v1/identity/verification_sessions', $params, $opts); } public function redact($id, $params = null, $opts = null) { return $this->request('post', $this->buildPath('/v1/identity/verification_sessions/%s/redact', $id), $params, $opts); } public function retrieve($id, $params = null, $opts = null) { return $this->request('get', $this->buildPath('/v1/identity/verification_sessions/%s', $id), $params, $opts); } public function update($id, $params = null, $opts = null) { return $this->request('post', $this->buildPath('/v1/identity/verification_sessions/%s', $id), $params, $opts); } } 