<?php
 namespace Stripe\Service\Checkout; class SessionService extends \Stripe\Service\AbstractService { public function all($params = null, $opts = null) { return $this->requestCollection('get', '/v1/checkout/sessions', $params, $opts); } public function allLineItems($parentId, $params = null, $opts = null) { return $this->requestCollection('get', $this->buildPath('/v1/checkout/sessions/%s/line_items', $parentId), $params, $opts); } public function create($params = null, $opts = null) { return $this->request('post', '/v1/checkout/sessions', $params, $opts); } public function expire($id, $params = null, $opts = null) { return $this->request('post', $this->buildPath('/v1/checkout/sessions/%s/expire', $id), $params, $opts); } public function retrieve($id, $params = null, $opts = null) { return $this->request('get', $this->buildPath('/v1/checkout/sessions/%s', $id), $params, $opts); } } 