<?php if (!defined('VB_ENTRY')) die('Access denied.');
/*========================================================================*\
|| ###################################################################### ||
|| # vBulletin 6.2.3 - Licence Number L3138846
|| # ------------------------------------------------------------------ # ||
|| # Copyright 2000-2026 MH Sub I, LLC dba vBulletin. All Rights Reserved.  # ||
|| # This file may not be redistributed in whole or significant part.   # ||
|| # ----------------- VBULLETIN IS NOT FREE SOFTWARE ----------------- # ||
|| # http://www.vbulletin.com | http://www.vbulletin.com/license.html   # ||
|| ###################################################################### ||
\*========================================================================*/

// display the credits table for use in admin/mod control panels

//not sure why this is a form -- we don't have any way to submit it however removing the form header destroys the formatting (which
//may be why) so we'll "fix" it and leave it.
print_form_header2('admincp/index', 'home');
print_table_start2();
print_table_header($vbphrase['vbulletin_developers_and_contributors']);
print_column_style_code(array('white-space: nowrap', ''));

function print_credit_section($header, $members)
{
	print_label_row('<b>' . $header . '</b>', implode(', ', $members), '', 'top', null, false);
}

print_credit_section($vbphrase['project_management'], [
	'Thong Nguyen',
]);

print_credit_section($vbphrase['development_lead'], [
	'Kevin Sours',
]);

print_credit_section($vbphrase['development'], [
	'Jin-Soo Jo',
	'Nicolas Acerenza',
]);

print_credit_section($vbphrase['product_management_user_experience_visual_design'], [
	'Diego Ibanez',
	'Joe Rosenblum',
	'Rajesh Muniraju',
	'Robert Ames',
]);

print_credit_section($vbphrase['qa'], [
	'Allen H. Lin',
	'Jasmine Khan',
	'Nishant Dey',
	'Yves Rigaud',
]);

print_credit_section($vbphrase['documentation'], [
	'Wayne Luke',
]);

print_credit_section($vbphrase['bussines_operations_management_and_customer_support'], [
	'Christine Tran',
	'Mark Bowland',
	'Michael Berlind',
	'Wayne Luke',
	'Yves Rigaud',
]);

print_credit_section($vbphrase['special_thanks_and_contributions'], [
	'Aakif Nazir',
	'Abel Lawal',
	'Alan Ordu&ntilde;o',
	'Chen Xu',
	'Christian Rosch',
	'Danco Dimovski',
	'Daniel Lee',
	'Darren Gordon',
	'David Grove',
	'Dominic Schlatter',
	'Edwin Brown',
	'Fabian Schonholz',
	'Fernando Varesi',
	'Francisco Aceves',
	'Freddie Bingham',
	'George Liu',
	'Glenn Vergara',
	'Gorgi Gichevski',
	'Gregg Hartling',
	'Jes&uacute;s Figueroa',
	'Joe Dibiasi',
	'John McGanty',
	'Jorge Tiznado',
	'Joshua Gonzales',
	'Kyle Furlong',
	'Lynne Sands',
	'Marjo Mercado',
	'Mark Jean',
	'Meghan Sensenbach',
	'Michael Lavaveshkul',
	'Miguel Montano',
	'Neal Sainani',
	'Olga Mandrosov',
	'Paul Marsden',
	'Pawel Grzesiecki',
	'Rishi Basu',
	'Sebastiano Vassellatti',
	'Tadeo Valencia',
	'Thao Pham',
	'Tuan Nguyen',
	'Trevor Hannant',
	'Xiaoyu Huang',
	'Zachery Woods',
	'Zafer Bahadir',
	'Zoltan Szalay',
]);

print_table_footer();

/*=========================================================================*\
|| #######################################################################
|| # Downloaded: 13:27, Sun Aug 30th 2026
|| # CVS: $RCSfile$ - $Revision: 122409 $
|| #######################################################################
\*=========================================================================*/
