<?php
 namespace Eluceo\iCal\Domain\ValueObject\Alarm; use Eluceo\iCal\Domain\ValueObject\Timestamp; final class AbsoluteDateTimeTrigger extends Trigger { private Timestamp $dateTime; public function __construct(Timestamp $dateTime) { $this->dateTime = $dateTime; } public function getDateTime(): Timestamp { return $this->dateTime; } } 