<?php
 declare(strict_types=1); namespace Square\Models; class CheckoutOptionsPaymentType { public const CARD_PRESENT = 'CARD_PRESENT'; public const MANUAL_CARD_ENTRY = 'MANUAL_CARD_ENTRY'; public const FELICA_ID = 'FELICA_ID'; public const FELICA_QUICPAY = 'FELICA_QUICPAY'; public const FELICA_TRANSPORTATION_GROUP = 'FELICA_TRANSPORTATION_GROUP'; public const FELICA_ALL = 'FELICA_ALL'; } 