<?php
 declare(strict_types=1); namespace Square\Models; use stdClass; class ResumeSubscriptionRequest implements \JsonSerializable { private $resumeEffectiveDate; private $resumeChangeTiming; public function getResumeEffectiveDate(): ?string { return $this->resumeEffectiveDate; } public function setResumeEffectiveDate(?string $resumeEffectiveDate): void { $this->resumeEffectiveDate = $resumeEffectiveDate; } public function getResumeChangeTiming(): ?string { return $this->resumeChangeTiming; } public function setResumeChangeTiming(?string $resumeChangeTiming): void { $this->resumeChangeTiming = $resumeChangeTiming; } #[\ReturnTypeWillChange] public function jsonSerialize(bool $asArrayWhenEmpty = false) { $json = []; if (isset($this->resumeEffectiveDate)) { $json['resume_effective_date'] = $this->resumeEffectiveDate; } if (isset($this->resumeChangeTiming)) { $json['resume_change_timing'] = $this->resumeChangeTiming; } $json = array_filter($json, function ($val) { return $val !== null; }); return (!$asArrayWhenEmpty && empty($json)) ? new stdClass() : $json; } } 