<?php
 declare(strict_types=1); namespace Jose\Component\Checker; use Override; use function sprintf; final readonly class IsEqualChecker implements ClaimChecker, HeaderChecker { public function __construct( private string $key, private mixed $value, private bool $protectedHeaderOnly = true ) { } #[Override] public function checkClaim(mixed $value): void { if ($value !== $this->value) { throw new InvalidClaimException(sprintf('The "%s" claim is invalid.', $this->key), $this->key, $value); } } #[Override] public function supportedClaim(): string { return $this->key; } #[Override] public function checkHeader(mixed $value): void { if ($value !== $this->value) { throw new InvalidHeaderException(sprintf('The "%s" header is invalid.', $this->key), $this->key, $value); } } #[Override] public function supportedHeader(): string { return $this->key; } #[Override] public function protectedHeaderOnly(): bool { return $this->protectedHeaderOnly; } } 