<?php
 declare(strict_types=1); namespace Square\Models; class RiskEvaluationRiskLevel { public const PENDING = 'PENDING'; public const NORMAL = 'NORMAL'; public const MODERATE = 'MODERATE'; public const HIGH = 'HIGH'; } 