<?php
 declare(strict_types=1); namespace Square\Http; class HttpRequest { private $httpMethod; private $headers; private $queryUrl; private $parameters; public function __construct( string $httpMethod, array $headers = [], string $queryUrl = "", array $parameters = [] ) { $this->httpMethod = $httpMethod; $this->headers = $headers; $this->queryUrl = $queryUrl; $this->parameters = $parameters; } public function getHttpMethod(): string { return $this->httpMethod; } public function setHttpMethod(string $httpMethod): void { $this->httpMethod = $httpMethod; } public function getHeaders(): array { return $this->headers; } public function setHeaders(array $headers): void { $this->headers = $headers; } public function addHeader(string $key, string $value): void { $this->headers[$key] = $value; } public function getQueryUrl(): string { return $this->queryUrl; } public function setQueryUrl(string $queryUrl): void { $this->queryUrl = $queryUrl; } public function getParameters(): array { return $this->parameters; } public function setParameters(array $parameters): void { $this->parameters = $parameters; } } 