<?php
 declare(strict_types=1); namespace Square\Models; class InvoiceStatus { public const DRAFT = 'DRAFT'; public const UNPAID = 'UNPAID'; public const SCHEDULED = 'SCHEDULED'; public const PARTIALLY_PAID = 'PARTIALLY_PAID'; public const PAID = 'PAID'; public const PARTIALLY_REFUNDED = 'PARTIALLY_REFUNDED'; public const REFUNDED = 'REFUNDED'; public const CANCELED = 'CANCELED'; public const FAILED = 'FAILED'; public const PAYMENT_PENDING = 'PAYMENT_PENDING'; } 