<?php
 namespace Stripe\Service\TestHelpers; class CustomerService extends \Stripe\Service\AbstractService { public function fundCashBalance($id, $params = null, $opts = null) { return $this->request('post', $this->buildPath('/v1/test_helpers/customers/%s/fund_cash_balance', $id), $params, $opts); } } 