<?php
 declare(strict_types=1); namespace Jose\Component\Encryption\Algorithm\KeyEncryption; use Jose\Component\Core\JWK; use Jose\Component\Encryption\Algorithm\KeyEncryptionAlgorithm; interface KeyWrapping extends KeyEncryptionAlgorithm { public function wrapKey(JWK $key, string $cek, array $completeHeader, array &$additionalHeader): string; public function unwrapKey(JWK $key, string $encrypted_cek, array $completeHeader): string; } 