<?php
 class vB_Utility_Template_ParserNode_Curly_Var extends vB_Utility_Template_ParserNode_Curly_Raw { public function compile() : string { return 'vB_Template_Runtime::vBVar(' . parent::compile() . ')'; } } 