<?php
 namespace Stripe\FinancialConnections; class Session extends \Stripe\ApiResource { const OBJECT_NAME = 'financial_connections.session'; use \Stripe\ApiOperations\Create; use \Stripe\ApiOperations\Retrieve; } 