<?php
 declare(strict_types=1); namespace Square\Models; use stdClass; class DisputeEvidenceCreatedWebhookObject implements \JsonSerializable { private $object; public function getObject(): ?Dispute { return $this->object; } public function setObject(?Dispute $object): void { $this->object = $object; } #[\ReturnTypeWillChange] public function jsonSerialize(bool $asArrayWhenEmpty = false) { $json = []; if (isset($this->object)) { $json['object'] = $this->object; } $json = array_filter($json, function ($val) { return $val !== null; }); return (!$asArrayWhenEmpty && empty($json)) ? new stdClass() : $json; } } 