<?php
 namespace Stripe\Service\TestHelpers\Treasury; class OutboundTransferService extends \Stripe\Service\AbstractService { public function fail($id, $params = null, $opts = null) { return $this->request('post', $this->buildPath('/v1/test_helpers/treasury/outbound_transfers/%s/fail', $id), $params, $opts); } public function post($id, $params = null, $opts = null) { return $this->request('post', $this->buildPath('/v1/test_helpers/treasury/outbound_transfers/%s/post', $id), $params, $opts); } public function returnOutboundTransfer($id, $params = null, $opts = null) { return $this->request('post', $this->buildPath('/v1/test_helpers/treasury/outbound_transfers/%s/return', $id), $params, $opts); } } 