<?php
 declare(strict_types=1); namespace Square\Models; class InventoryChangeType { public const PHYSICAL_COUNT = 'PHYSICAL_COUNT'; public const ADJUSTMENT = 'ADJUSTMENT'; public const TRANSFER = 'TRANSFER'; } 