<?php
 $PHPMAILER_LANG['authenticate'] = 'Hadisoana SMTP: Tsy nahomby ny fanamarinana.'; $PHPMAILER_LANG['connect_host'] = 'SMTP Error: Tsy afaka mampifandray amin\'ny mpampiantrano SMTP.'; $PHPMAILER_LANG['data_not_accepted'] = 'SMTP diso: tsy voarakitra ny angona.'; $PHPMAILER_LANG['empty_message'] = 'Tsy misy ny votoaty mailaka.'; $PHPMAILER_LANG['encoding'] = 'Tsy fantatra encoding: '; $PHPMAILER_LANG['execute'] = 'Tsy afaka manatanteraka ity baiko manaraka ity: '; $PHPMAILER_LANG['file_access'] = 'Tsy nahomby ny fidirana amin\'ity rakitra ity: '; $PHPMAILER_LANG['file_open'] = 'Hadisoana diso: Tsy afaka nanokatra ity file manaraka ity: '; $PHPMAILER_LANG['from_failed'] = 'Ny adiresy iraka manaraka dia diso: '; $PHPMAILER_LANG['instantiate'] = 'Tsy afaka nanomboka ny hetsika mail.'; $PHPMAILER_LANG['invalid_address'] = 'Tsy mety ny adiresy: '; $PHPMAILER_LANG['mailer_not_supported'] = ' mailer tsy manohana.'; $PHPMAILER_LANG['provide_address'] = 'Alefaso azafady iray adiresy iray farafahakeliny.'; $PHPMAILER_LANG['recipients_failed'] = 'SMTP Error: Tsy mety ireo mpanaraka ireto: '; $PHPMAILER_LANG['signing'] = 'Error nandritra ny sonia:'; $PHPMAILER_LANG['smtp_connect_failed'] = 'Tsy nahomby ny fifandraisana tamin\'ny server SMTP.'; $PHPMAILER_LANG['smtp_error'] = 'Fahadisoana tamin\'ny server SMTP: '; $PHPMAILER_LANG['variable_set'] = 'Tsy azo atao ny mametraka na mamerina ny variable: '; $PHPMAILER_LANG['extension_missing'] = 'Tsy hita ny ampahany: '; 