<?php
 declare(strict_types=1); namespace Square\Models; class OrderFulfillmentState { public const PROPOSED = 'PROPOSED'; public const RESERVED = 'RESERVED'; public const PREPARED = 'PREPARED'; public const COMPLETED = 'COMPLETED'; public const CANCELED = 'CANCELED'; public const FAILED = 'FAILED'; } 