<?php
 declare(strict_types=1); namespace Square\Models; use stdClass; class CustomerTextFilter implements \JsonSerializable { private $exact; private $fuzzy; public function getExact(): ?string { return $this->exact; } public function setExact(?string $exact): void { $this->exact = $exact; } public function getFuzzy(): ?string { return $this->fuzzy; } public function setFuzzy(?string $fuzzy): void { $this->fuzzy = $fuzzy; } #[\ReturnTypeWillChange] public function jsonSerialize(bool $asArrayWhenEmpty = false) { $json = []; if (isset($this->exact)) { $json['exact'] = $this->exact; } if (isset($this->fuzzy)) { $json['fuzzy'] = $this->fuzzy; } $json = array_filter($json, function ($val) { return $val !== null; }); return (!$asArrayWhenEmpty && empty($json)) ? new stdClass() : $json; } } 