<?php
 namespace Eluceo\iCal\Domain\ValueObject; final class BinaryContent { private string $content; public function __construct(string $content) { $this->content = $content; } public function getContent(): string { return $this->content; } } 