<?php
 declare(strict_types=1); namespace Square\Models; class RefundStatus { public const PENDING = 'PENDING'; public const APPROVED = 'APPROVED'; public const REJECTED = 'REJECTED'; public const FAILED = 'FAILED'; } 