<?php
 class vB_Options_Option_Currencysymbols extends vB_Options_Option { protected function validateCustom(array $validation, mixed $rawvalue) : bool|string|array { $rawvalue = trim($rawvalue); if ($rawvalue) { $lines = preg_split("#(\r\n|\n|\r)#", $rawvalue); foreach($lines AS $key => $line) { $fields = explode('|', $line); if (count($fields) != 2 OR !trim($fields[0]) OR !trim($fields[1])) { return ['error_invalid_currency_symbols', $key + 1, $line]; } } } return true; } } 