/*
 =======================================================================*\
|| ###################################################################### ||
|| # vBulletin 6.2.3
|| # ------------------------------------------------------------------ # ||
|| # Copyright 2000-2026 MH Sub I, LLC dba vBulletin. All Rights Reserved.  # ||
|| # This file may not be redistributed in whole or significant part.   # ||
|| # ----------------- VBULLETIN IS NOT FREE SOFTWARE ----------------- # ||
|| # http://www.vbulletin.com | http://www.vbulletin.com/license.html   # ||
|| ###################################################################### ||
\*========================================================================*/
var BBURL="undefined"==typeof BBURL?"":BBURL,SESSIONURL="undefined"==typeof SESSIONURL?"":SESSIONURL,SECURITYTOKEN="undefined"==typeof SECURITYTOKEN?"":SECURITYTOKEN,vbphrase="undefined"==typeof vbphrase?[]:vbphrase,vB_Default_Timeout=15E3,is_saf=0<YAHOO.env.ua.webkit,is_moz=0<YAHOO.env.ua.gecko;function fetch_object(a){return document.getElementById(a)}function fetch_tags(a,b){return null==a?[]:a.getElementsByTagName(b)}function fetch_tag_count(a,b){return fetch_tags(a,b).length}
function vBulletin_AJAX_Error_Handler(a){console.warn("AJAX Error: Status = %s: %s",a.status,a.statusText)}function getBaseUrl(){try{var a=document.getElementsByTagName("base");return 0==a.length?"":(a=a[a.length-1].href)?a.match(/.*[\/\\]/):""}catch(b){return""}}
function js_toggle_all(a,b,c,d,f){for(var g=0;g<a.elements.length;g++){var e=a.elements[g];if(e.type==b&&!d.includes(e.name))switch(b){case "radio":e.value==c&&(e.checked=f);break;case "select-one":e.selectedIndex=f;break;default:e.checked=f}}}function js_select_all(a){exclude=["selectall"];js_toggle_all(a,"select-one","",exclude,a.selectall.selectedIndex)}function js_check_all(a){exclude=["keepattachments","allbox","removeall"];js_toggle_all(a,"checkbox","",exclude,a.allbox.checked)}
function js_check_all_option(a,b){exclude=["inherit"];js_toggle_all(a,"radio",b,exclude,!0)}function do_securitytoken_replacement(a){if(""!=a){for(var b=0;b<document.forms.length;b++)document.forms[b].elements.securitytoken&&document.forms[b].elements.securitytoken.value==SECURITYTOKEN&&(document.forms[b].elements.securitytoken.value=a);SECURITYTOKEN=a;console.log("Securitytoken updated")}}
function handle_securitytoken_response(a){console.log("Processing securitytoken update");var b=JSON.parse(a.responseText);b&&b.newtoken.length?(do_securitytoken_replacement(b.newtoken),securitytoken_errors=0):handle_securitytoken_error(a)}function handle_securitytoken_error(a){console.log("Securitytoken Error");3==++securitytoken_errors&&do_securitytoken_replacement("guest")}var timeout=36E5,securitytoken_timeout=window.setTimeout("replace_securitytoken()",timeout),securitytoken_errors=0;
function replace_securitytoken(){window.clearTimeout(securitytoken_timeout);""!=SECURITYTOKEN&&"guest"!=SECURITYTOKEN&&(securitytoken_timeout=window.setTimeout("replace_securitytoken()",timeout),YAHOO.util.Connect.asyncRequest("POST","ajax/replacesecuritytoken",{success:handle_securitytoken_response,failure:handle_securitytoken_error,timeout:vB_Default_Timeout},SESSIONURL+"securitytoken="+SECURITYTOKEN+"&do=securitytoken"))}
function vBulletin_Framework(){this.elements=[];this.ajaxurls=[];this.events=[];this.time=new Date;this.add_event("systemInit")}vBulletin_Framework.prototype.init=function(){console.info("Firing System Init");this.events.systemInit.fire()};vBulletin_Framework.prototype.extend=function(a,b){function c(){}c.prototype=b.prototype;a.prototype=new c;a.prototype.constructor=a;a.baseConstructor=b;a.superClass=b.prototype};
vBulletin_Framework.prototype.register_control=function(a,b){for(var c=[],d=1;d<arguments.length;d++)c.push(arguments[d]);this.elements[a]||(console.info('Creating array vBulletin.elements["%s"]',a),this.elements[a]=[]);d=this.elements[a].push(c);console.log('vBulletin.elements["%s"][%d] = %s',a,d-1,c.join(", "))};
vBulletin_Framework.prototype.register_ajax_urls=function(a,b,c){a=a.split("?");a[1]=SESSIONURL+"securitytoken="+SECURITYTOKEN+"&ajax=1&"+a[1].replace(/\{(\d+)(:\w+)?\}/gi,"%$1$s");b=b.split("?");b[1]=SESSIONURL+"securitytoken="+SECURITYTOKEN+"&ajax=1&"+b[1].replace(/\{(\d+)(:\w+)?\}/gi,"%$1$s");console.log("Register AJAX URLs for %s",c);for(var d=0;d<c.length;d++)this.ajaxurls[c[d]]=[a,b]};vBulletin_Framework.prototype.add_event=function(a){this.events[a]=new YAHOO.util.CustomEvent(a)};
vBulletin_Framework.prototype.console=function(){if(window.console||console.firebug){for(var a=[],b=0;b<arguments.length;b++)a[a.length]=arguments[b];try{eval("console.log('"+a.join("','")+"');")}catch(c){}}};var vBulletin=new vBulletin_Framework;YAHOO.namespace("vBulletin");
