<?php
 declare(strict_types=1); namespace Square\Models; class CatalogCustomAttributeDefinitionAppVisibility { public const APP_VISIBILITY_HIDDEN = 'APP_VISIBILITY_HIDDEN'; public const APP_VISIBILITY_READ_ONLY = 'APP_VISIBILITY_READ_ONLY'; public const APP_VISIBILITY_READ_WRITE_VALUES = 'APP_VISIBILITY_READ_WRITE_VALUES'; } 