<?php
 declare(strict_types=1); namespace Square\Models; class CashDrawerEventType { public const NO_SALE = 'NO_SALE'; public const CASH_TENDER_PAYMENT = 'CASH_TENDER_PAYMENT'; public const OTHER_TENDER_PAYMENT = 'OTHER_TENDER_PAYMENT'; public const CASH_TENDER_CANCELLED_PAYMENT = 'CASH_TENDER_CANCELLED_PAYMENT'; public const OTHER_TENDER_CANCELLED_PAYMENT = 'OTHER_TENDER_CANCELLED_PAYMENT'; public const CASH_TENDER_REFUND = 'CASH_TENDER_REFUND'; public const OTHER_TENDER_REFUND = 'OTHER_TENDER_REFUND'; public const PAID_IN = 'PAID_IN'; public const PAID_OUT = 'PAID_OUT'; } 