<?php
 namespace Stripe; interface BaseStripeClientInterface { public function getApiKey(); public function getClientId(); public function getApiBase(); public function getConnectBase(); public function getFilesBase(); } 