<?php
 class vB_Utility_Template_ParserNode_Curly_Escapejs extends vB_Utility_Template_ParserNode_CurlyRuntime { protected static string $function = 'escapeJS'; protected static int $maxparams = 1; } 