/*
 =======================================================================*\
|| ###################################################################### ||
|| # vBulletin 6.2.3
|| # ------------------------------------------------------------------ # ||
|| # Copyright 2000-2026 MH Sub I, LLC dba vBulletin. All Rights Reserved.  # ||
|| # This file may not be redistributed in whole or significant part.   # ||
|| # ----------------- VBULLETIN IS NOT FREE SOFTWARE ----------------- # ||
|| # http://www.vbulletin.com | http://www.vbulletin.com/license.html   # ||
|| ###################################################################### ||
\*========================================================================*/
function crc32(c){for(var n=-1,p,m=0;m<c.length;m++)p=(n^c.charCodeAt(m))&255,p="0x"+"00000000 77073096 EE0E612C 990951BA 076DC419 706AF48F E963A535 9E6495A3 0EDB8832 79DCB8A4 E0D5E91E 97D2D988 09B64C2B 7EB17CBD E7B82D07 90BF1D91 1DB71064 6AB020F2 F3B97148 84BE41DE 1ADAD47D 6DDDE4EB F4D4B551 83D385C7 136C9856 646BA8C0 FD62F97A 8A65C9EC 14015C4F 63066CD9 FA0F3D63 8D080DF5 3B6E20C8 4C69105E D56041E4 A2677172 3C03E4D1 4B04D447 D20D85FD A50AB56B 35B5A8FA 42B2986C DBBBC9D6 ACBCF940 32D86CE3 45DF5C75 DCD60DCF ABD13D59 26D930AC 51DE003A C8D75180 BFD06116 21B4F4B5 56B3C423 CFBA9599 B8BDA50F 2802B89E 5F058808 C60CD9B2 B10BE924 2F6F7C87 58684C11 C1611DAB B6662D3D 76DC4190 01DB7106 98D220BC EFD5102A 71B18589 06B6B51F 9FBFE4A5 E8B8D433 7807C9A2 0F00F934 9609A88E E10E9818 7F6A0DBB 086D3D2D 91646C97 E6635C01 6B6B51F4 1C6C6162 856530D8 F262004E 6C0695ED 1B01A57B 8208F4C1 F50FC457 65B0D9C6 12B7E950 8BBEB8EA FCB9887C 62DD1DDF 15DA2D49 8CD37CF3 FBD44C65 4DB26158 3AB551CE A3BC0074 D4BB30E2 4ADFA541 3DD895D7 A4D1C46D D3D6F4FB 4369E96A 346ED9FC AD678846 DA60B8D0 44042D73 33031DE5 AA0A4C5F DD0D7CC9 5005713C 270241AA BE0B1010 C90C2086 5768B525 206F85B3 B966D409 CE61E49F 5EDEF90E 29D9C998 B0D09822 C7D7A8B4 59B33D17 2EB40D81 B7BD5C3B C0BA6CAD EDB88320 9ABFB3B6 03B6E20C 74B1D29A EAD54739 9DD277AF 04DB2615 73DC1683 E3630B12 94643B84 0D6D6A3E 7A6A5AA8 E40ECF0B 9309FF9D 0A00AE27 7D079EB1 F00F9344 8708A3D2 1E01F268 6906C2FE F762575D 806567CB 196C3671 6E6B06E7 FED41B76 89D32BE0 10DA7A5A 67DD4ACC F9B9DF6F 8EBEEFF9 17B7BE43 60B08ED5 D6D6A3E8 A1D1937E 38D8C2C4 4FDFF252 D1BB67F1 A6BC5767 3FB506DD 48B2364B D80D2BDA AF0A1B4C 36034AF6 41047A60 DF60EFC3 A867DF55 316E8EEF 4669BE79 CB61B38C BC66831A 256FD2A0 5268E236 CC0C7795 BB0B4703 220216B9 5505262F C5BA3BBE B2BD0B28 2BB45A92 5CB36A04 C2D7FFA7 B5D0CF31 2CD99E8B 5BDEAE1D 9B64C2B0 EC63F226 756AA39C 026D930A 9C0906A9 EB0E363F 72076785 05005713 95BF4A82 E2B87A14 7BB12BAE 0CB61B38 92D28E9B E5D5BE0D 7CDCEFB7 0BDBDF21 86D3D2D4 F1D4E242 68DDB3F8 1FDA836E 81BE16CD F6B9265B 6FB077E1 18B74777 88085AE6 FF0F6A70 66063BCA 11010B5C 8F659EFF F862AE69 616BFFD3 166CCF45 A00AE278 D70DD2EE 4E048354 3903B3C2 A7672661 D06016F7 4969474D 3E6E77DB AED16A4A D9D65ADC 40DF0B66 37D83BF0 A9BCAE53 DEBB9EC5 47B2CF7F 30B5FFE9 BDBDF21C CABAC28A 53B39330 24B4A3A6 BAD03605 CDD70693 54DE5729 23D967BF B3667A2E C4614AB8 5D681B02 2A6F2B94 B40BBE37 C30C8EA1 5A05DF1B 2D02EF8D".substr(9*
p,8),n=n>>>8^p;return n^-1}
(c=>{function n(){var d=c(this),h=c(window).scrollTop(),q=d.find(".CodeMirror-scroll").scrollTop();if(0<h||0<q)c('<input type="hidden" name="windowScrollTop" value="'+h+'" />').appendTo(d),c('<input type="hidden" name="textareaScrollTop" value="'+q+'" />').appendTo(d)}function p(){c(".js-reload-to-position").closest("form").off("submit",n).on("submit",n);var d=(new URL(location.href)).searchParams,h=d.get("windowScrollTop");d=d.get("textareaScrollTop");0<h&&c(window).scrollTop(h);0<d&&c(".CodeMirror-scroll").scrollTop(d)}
function m(d){vBRedirect("admincp/template.php?do="+d+"&searchstring="+u+"&expandset="+t)}function w(d,h){if(null==d)return!1;switch(d.action){case "expand":h={"do":"modify",group:d.value};d=t?"styleheader"+t:"";h.searchstring=u;h.expandset=t;h="admincp/template.php?"+c.param(h);d&&(h+="#"+d);vBRedirect(h);break;case "customize":m("add&dostyleid="+d.styleid+"&title="+d.value+"&group="+r);break;case "edit":switch(h){case "vieworiginal":window.open("admincp/template.php?do=view&title="+d.selectedtext);
break;case "killtemplate":m("delete&templateid="+d.value+"&dostyleid="+d.styleid+"&group="+r);break;default:m("edit&templateid="+d.value+"&group="+r)}break;case "editinherited":"vieworiginal"==h?window.open("admincp/template.php?do=view&title="+d.selectedtext):m("add&dostyleid="+d.styleid+"&templateid="+d.value+"&group="+r)}}var r,t,u;c(()=>{0<c(".js-reload-to-position").length&&0<c(".CodeMirror-scroll").length&&p();r=c("[name=group]").val();t=c("[name=expandset]").val();u=c("[name=searchstring]").val();
var d=(a,b)=>{var g=a.find(":selected");if(0<g.length){a:{g=g.get(0);var f=a.data("styleid");if(g){var k=g.value,l=document.forms.tform;a={};if(b){for(var e of["edit","cust","kill","expa","orig"])a[e]=l[e+f],a[e].disabled="disabled";textbox=c("#helparea"+f).get(0)}if(""!=k)if(l=l["tl"+f],e={},e.selectedtext=l.options[l.selectedIndex].text.replace(/^-- /,""),"~"==k&&(k=e.selectedtext),e.styleid=f,e.original=k,-1!=k.search(/^\[(\w*)\]$/)?(e.value=k.replace(/^\[(\w*)\]$/,"$1"),isNaN(e.value)||""==e.value?
(e.action="expand",e.text=vBAdmin.renderPhrase("click_the_expand_collapse_button",e.selectedtext.replace(/Templates/,"").bold()),f=["expa"]):(e.action="editinherited",tsid=l.options[l.selectedIndex].getAttribute("tsid"),k="admincp/template.php?do=edit&amp;templateid="+e.value+"&amp;group="+r,e.text=vBAdmin.renderPhrase("this_template_has_been_customized_in_a_parent_style",STYLETITLE[tsid].bold(),STYLETITLE[f].bold(),e.selectedtext.bold(),k),f=["orig","cust"])):(e.value=k,isNaN(e.value)?(e.action=
"customize",e.text=vBAdmin.renderPhrase("this_template_has_not_been_customized"),f=["cust"]):(e.action="edit",e.text=vBAdmin.renderPhrase("this_template_has_been_customized_in_this_style"),f=["edit","orig","kill"])),b){for(var v of f)a[v].disabled="";textbox.innerHTML=e.selectedtext.bold()+":<br /><br />"+e.text;g.getAttribute("i")&&(b=g.getAttribute("i").split(";"),b[1]=new Date(1E3*b[1]),v=b[1].getDate(),g=b[1].getMonth(),a=b[1].getFullYear(),f=b[1].getHours(),10>f&&(f="0"+f),k=b[1].getMinutes(),
10>k&&(k="0"+k),textbox.innerHTML+="<br /><br />"+vBAdmin.renderPhrase("template_last_edited_js",MONTH[g],v,a,f,k,b[0].bold()))}else{b=e;break a}else textbox.innerHTML="<center>"+vBAdmin.renderPhrase("x_templates",STYLETITLE[f].bold())+"</center>";b=void 0}else b=null}return b}return null},h=a=>{var b=a.val();a=a.data("styleid");b=b.split("_");if("template"==b[0]){var g=null,f="dostyleid";anchorvar="";switch(b[1]){case "templates":g="modify";f="expandset";anchorvar="styleheader"+a;break;case "addtemplate":g=
"add";break;case "editstyle":g="editstyle";break;case "addstyle":g="addstyle";f="parentid";break;case "delete":g="deletestyle";break;case "download":g="files";break;case "revertall":g="revertall"}g&&(b="admincp/template.php?group="+document.forms.tform.group.value+"&do="+g+"&"+f+"="+a,anchorvar&&(b+="#"+anchorvar),vBRedirect(b))}else"css"==b[0]?vBRedirect("admincp/replacement.php?do=editlist&dowhat="+b[1]+"&dostyleid="+a):"stylevar"==b[0]&&("revertall"==b[1]?vBRedirect("admincp/stylevar.php?do=revertall&dostyleid="+
a):vBRedirect("admincp/stylevar.php?dostyleid="+a))},q=c(".js-templatelist");q.off("change").on("change",a=>{d(c(a.currentTarget),1)});q.off("dblclick").on("dblclick",a=>{w(d(c(a.currentTarget),0))});q.each((a,b)=>{d(c(b),1)});c(".js-template-userselect").off("click").on("click",a=>{a=c(a.currentTarget);var b=(g,f)=>{c("[data-parentid="+g.data("styleid")+"]").each((k,l)=>{k=c(l);k.prop("checked",f);b(k,f)})};b(a,a.prop("checked"))});c(".js-button-template-expand").off("click").on("click",a=>{var b=
c(a.currentTarget);a=b.data("styleid");b="admincp/template.php?do=modify&expandset="+a+"&group="+b.data("group");a&&(b+="#styleheader"+a);vBRedirect(b)});c(".js-template-menu").off("change").on("change",a=>{h(c(a.currentTarget))});c(".js-button-template-go").off("click").on("click",a=>{h(c("[name="+c(a.currentTarget).data("menu")+"]"))});c(".js-button-template-action").off("click").on("click",a=>{a=c(a.currentTarget);w(d(c("[name=tl"+a.data("styleid")+"]"),0),a.data("request"))})})})(jQuery);
