<?php
 namespace Stripe\Treasury; class ReceivedDebit extends \Stripe\ApiResource { const OBJECT_NAME = 'treasury.received_debit'; use \Stripe\ApiOperations\All; use \Stripe\ApiOperations\Retrieve; const FAILURE_CODE_ACCOUNT_CLOSED = 'account_closed'; const FAILURE_CODE_ACCOUNT_FROZEN = 'account_frozen'; const FAILURE_CODE_INSUFFICIENT_FUNDS = 'insufficient_funds'; const FAILURE_CODE_OTHER = 'other'; const NETWORK_ACH = 'ach'; const NETWORK_CARD = 'card'; const NETWORK_STRIPE = 'stripe'; const STATUS_FAILED = 'failed'; const STATUS_SUCCEEDED = 'succeeded'; } 