<?php
 abstract class vB_Utility_Geoip { use vB_Utility_Trait_NoSerialize; public function getLocation($ipaddress) { return $this->getCountryCode($ipaddress); } protected function getCountryCode($ipaddress) { return 'UNKNOWN'; } public function getIpData($address) { return "Raw data not available"; } } 