<?php
 declare(strict_types=1); namespace Square\Models; class MeasurementUnitUnitType { public const TYPE_CUSTOM = 'TYPE_CUSTOM'; public const TYPE_AREA = 'TYPE_AREA'; public const TYPE_LENGTH = 'TYPE_LENGTH'; public const TYPE_VOLUME = 'TYPE_VOLUME'; public const TYPE_WEIGHT = 'TYPE_WEIGHT'; public const TYPE_GENERIC = 'TYPE_GENERIC'; } 