<?php
 declare(strict_types=1); namespace SpomkyLabs\Pki\CryptoTypes\AlgorithmIdentifier; use SpomkyLabs\Pki\ASN1\Type\UnspecifiedType; abstract class SpecificAlgorithmIdentifier extends AlgorithmIdentifier { abstract public static function fromASN1Params(?UnspecifiedType $params = null): self; } 