<?php
 class vB_Utility_Template_ParserNode_Tag_Null extends vB_Utility_Template_ParserNode_Tag { private bool $invalid; public function __construct(vB_Xml_Node $main_node, array|bool $allowedTags, array|bool $allowedCurlies, vB_Utility_Template_Parser $parser, bool $invalid) { vB_Utility_Template_ParserNode::__construct($main_node, $allowedTags, $allowedCurlies, $parser); $this->invalid = $invalid; } public function validate() : array { return [[($this->invalid ? 'parser_element_invalid' : 'parser_element_not_allowed'), htmlspecialchars('<vb:' . $this->main_node->value . '>')]]; } public function compile() : string { return $this->parser->_parse_nodes($this->main_node->childNodes()); } } 