<?php

class googlelogin_Product
{
	public $vbMinVersion = '5.4.2 Alpha 1';
	public $vbMaxVersion = '6.9.9';

	public static $AutoInstall = true;

	public $hookClasses = [
		'googlelogin_Hooks'
	];
}
