<?php
 namespace Stripe\Service\Treasury; class TreasuryServiceFactory extends \Stripe\Service\AbstractServiceFactory { private static $classMap = [ 'creditReversals' => CreditReversalService::class, 'debitReversals' => DebitReversalService::class, 'financialAccounts' => FinancialAccountService::class, 'inboundTransfers' => InboundTransferService::class, 'outboundPayments' => OutboundPaymentService::class, 'outboundTransfers' => OutboundTransferService::class, 'receivedCredits' => ReceivedCreditService::class, 'receivedDebits' => ReceivedDebitService::class, 'transactionEntries' => TransactionEntryService::class, 'transactions' => TransactionService::class, ]; protected function getServiceClass($name) { return \array_key_exists($name, self::$classMap) ? self::$classMap[$name] : null; } } 