<?php
 declare(strict_types=1); namespace Square\Models; use stdClass; class CatalogCustomAttributeDefinitionSelectionConfigCustomAttributeSelection implements \JsonSerializable { private $uid; private $name; public function __construct(string $name) { $this->name = $name; } public function getUid(): ?string { return $this->uid; } public function setUid(?string $uid): void { $this->uid = $uid; } public function getName(): string { return $this->name; } public function setName(string $name): void { $this->name = $name; } #[\ReturnTypeWillChange] public function jsonSerialize(bool $asArrayWhenEmpty = false) { $json = []; if (isset($this->uid)) { $json['uid'] = $this->uid; } $json['name'] = $this->name; $json = array_filter($json, function ($val) { return $val !== null; }); return (!$asArrayWhenEmpty && empty($json)) ? new stdClass() : $json; } } 