<?php
 declare(strict_types=1); namespace Square\Models; class TransactionProduct { public const REGISTER = 'REGISTER'; public const EXTERNAL_API = 'EXTERNAL_API'; public const BILLING = 'BILLING'; public const APPOINTMENTS = 'APPOINTMENTS'; public const INVOICES = 'INVOICES'; public const ONLINE_STORE = 'ONLINE_STORE'; public const PAYROLL = 'PAYROLL'; public const OTHER = 'OTHER'; } 