<?php
 declare(strict_types=1); namespace SpomkyLabs\Pki\CryptoTypes\AlgorithmIdentifier\Signature; use SpomkyLabs\Pki\ASN1\Element; abstract class RFC4055RSASignatureAlgorithmIdentifier extends RSASignatureAlgorithmIdentifier { protected function __construct( string $oid, protected null|Element $params ) { parent::__construct($oid); } protected function paramsASN1(): ?Element { return $this->params; } } 