<?php
 $PHPMAILER_LANG['authenticate'] = 'Lỗi SMTP: Không thể xác thực.'; $PHPMAILER_LANG['connect_host'] = 'Lỗi SMTP: Không thể kết nối máy chủ SMTP.'; $PHPMAILER_LANG['data_not_accepted'] = 'Lỗi SMTP: Dữ liệu không được chấp nhận.'; $PHPMAILER_LANG['empty_message'] = 'Không có nội dung'; $PHPMAILER_LANG['encoding'] = 'Mã hóa không xác định: '; $PHPMAILER_LANG['execute'] = 'Không thực hiện được: '; $PHPMAILER_LANG['file_access'] = 'Không thể truy cập tệp tin '; $PHPMAILER_LANG['file_open'] = 'Lỗi Tập tin: Không thể mở tệp tin: '; $PHPMAILER_LANG['from_failed'] = 'Lỗi địa chỉ gửi đi: '; $PHPMAILER_LANG['instantiate'] = 'Không dùng được các hàm gửi thư.'; $PHPMAILER_LANG['invalid_address'] = 'Đại chỉ emai không đúng: '; $PHPMAILER_LANG['mailer_not_supported'] = ' trình gửi thư không được hỗ trợ.'; $PHPMAILER_LANG['provide_address'] = 'Bạn phải cung cấp ít nhất một địa chỉ người nhận.'; $PHPMAILER_LANG['recipients_failed'] = 'Lỗi SMTP: lỗi địa chỉ người nhận: '; $PHPMAILER_LANG['signing'] = 'Lỗi đăng nhập: '; $PHPMAILER_LANG['smtp_connect_failed'] = 'Lỗi kết nối với SMTP'; $PHPMAILER_LANG['smtp_error'] = 'Lỗi máy chủ smtp '; $PHPMAILER_LANG['variable_set'] = 'Không thể thiết lập hoặc thiết lập lại biến: '; 