<?php
 declare(strict_types=1); namespace Jose\Component\Core\Util\Ecc; final readonly class PublicKey { public function __construct( private Point $point ) { } public function getPoint(): Point { return $this->point; } } 