<?php
 declare(strict_types=1); namespace Square\Models; use stdClass; class SearchTeamMembersFilter implements \JsonSerializable { private $locationIds; private $status; private $isOwner; public function getLocationIds(): ?array { return $this->locationIds; } public function setLocationIds(?array $locationIds): void { $this->locationIds = $locationIds; } public function getStatus(): ?string { return $this->status; } public function setStatus(?string $status): void { $this->status = $status; } public function getIsOwner(): ?bool { return $this->isOwner; } public function setIsOwner(?bool $isOwner): void { $this->isOwner = $isOwner; } #[\ReturnTypeWillChange] public function jsonSerialize(bool $asArrayWhenEmpty = false) { $json = []; if (isset($this->locationIds)) { $json['location_ids'] = $this->locationIds; } if (isset($this->status)) { $json['status'] = $this->status; } if (isset($this->isOwner)) { $json['is_owner'] = $this->isOwner; } $json = array_filter($json, function ($val) { return $val !== null; }); return (!$asArrayWhenEmpty && empty($json)) ? new stdClass() : $json; } } 