<?php
 $PHPMAILER_LANG['authenticate'] = 'SMTP xətası: Giriş uğursuz oldu.'; $PHPMAILER_LANG['connect_host'] = 'SMTP xətası: SMTP serverinə qoşulma uğursuz oldu.'; $PHPMAILER_LANG['data_not_accepted'] = 'SMTP xətası: Verilənlər qəbul edilməyib.'; $PHPMAILER_LANG['empty_message'] = 'Boş mesaj göndərilə bilməz.'; $PHPMAILER_LANG['encoding'] = 'Qeyri-müəyyən kodlaşdırma: '; $PHPMAILER_LANG['execute'] = 'Əmr yerinə yetirilmədi: '; $PHPMAILER_LANG['file_access'] = 'Fayla giriş yoxdur: '; $PHPMAILER_LANG['file_open'] = 'Fayl xətası: Fayl açıla bilmədi: '; $PHPMAILER_LANG['from_failed'] = 'Göstərilən poçtlara göndərmə uğursuz oldu: '; $PHPMAILER_LANG['instantiate'] = 'Mail funksiyası işə salına bilmədi.'; $PHPMAILER_LANG['invalid_address'] = 'Düzgün olmayan e-mail adresi: '; $PHPMAILER_LANG['mailer_not_supported'] = ' - e-mail kitabxanası dəstəklənmir.'; $PHPMAILER_LANG['provide_address'] = 'Ən azı bir e-mail adresi daxil edilməlidir.'; $PHPMAILER_LANG['recipients_failed'] = 'SMTP xətası: Aşağıdakı ünvanlar üzrə alıcılara göndərmə uğursuzdur: '; $PHPMAILER_LANG['signing'] = 'İmzalama xətası: '; $PHPMAILER_LANG['smtp_connect_failed'] = 'SMTP serverinə qoşulma uğursuz oldu.'; $PHPMAILER_LANG['smtp_error'] = 'SMTP serveri xətası: '; $PHPMAILER_LANG['variable_set'] = 'Dəyişənin quraşdırılması uğursuz oldu: '; 