<?php
 class vB_Options_Option_Useemoji extends vB_Options_Option { protected function validateCustom(array $validation, mixed $rawvalue) : bool|string|array { if ($rawvalue == 1) { $charsets = vB::getDbAssertor()->getDbCharsets('text', 'rawtext'); if ($charsets['effectiveCharset'] != 'utf8mb4') { return 'setting_validation_error_useemoj'; } } return true; } } 