<?php
 declare(strict_types=1); namespace Shopify\Rest\Admin2022_10; use Shopify\Auth\Session; use Shopify\Rest\Base; class DisputeEvidence extends Base { public static string $API_VERSION = "2022-10"; protected static array $HAS_ONE = []; protected static array $HAS_MANY = [ "fulfillments" => Fulfillment::class ]; protected static array $PATHS = [ ["http_method" => "get", "operation" => "get", "ids" => ["dispute_id"], "path" => "shopify_payments/disputes/<dispute_id>/dispute_evidences.json"], ["http_method" => "put", "operation" => "put", "ids" => ["dispute_id"], "path" => "shopify_payments/disputes/<dispute_id>/dispute_evidences.json"] ]; protected static string $PRIMARY_KEY = "dispute_id"; public static function find( Session $session, $dispute_id, array $urlIds = [], array $params = [] ): ?DisputeEvidence { $result = parent::baseFind( $session, array_merge(["dispute_id" => $dispute_id], $urlIds), $params, ); return !empty($result) ? $result[0] : null; } } 