<?php
 declare(strict_types=1); namespace Square\Models; use stdClass; class V1ListOrdersRequest implements \JsonSerializable { private $order; private $limit; private $batchToken; public function getOrder(): ?string { return $this->order; } public function setOrder(?string $order): void { $this->order = $order; } public function getLimit(): ?int { return $this->limit; } public function setLimit(?int $limit): void { $this->limit = $limit; } public function getBatchToken(): ?string { return $this->batchToken; } public function setBatchToken(?string $batchToken): void { $this->batchToken = $batchToken; } #[\ReturnTypeWillChange] public function jsonSerialize(bool $asArrayWhenEmpty = false) { $json = []; if (isset($this->order)) { $json['order'] = $this->order; } if (isset($this->limit)) { $json['limit'] = $this->limit; } if (isset($this->batchToken)) { $json['batch_token'] = $this->batchToken; } $json = array_filter($json, function ($val) { return $val !== null; }); return (!$asArrayWhenEmpty && empty($json)) ? new stdClass() : $json; } } 