<?php
 declare(strict_types=1); namespace Square\Models; class SearchOrdersSortField { public const CREATED_AT = 'CREATED_AT'; public const UPDATED_AT = 'UPDATED_AT'; public const CLOSED_AT = 'CLOSED_AT'; } 