<?php
 declare(strict_types=1); namespace Square\Models; use stdClass; class LoyaltyProgramAccrualRuleItemVariationData implements \JsonSerializable { private $itemVariationId; public function __construct(string $itemVariationId) { $this->itemVariationId = $itemVariationId; } public function getItemVariationId(): string { return $this->itemVariationId; } public function setItemVariationId(string $itemVariationId): void { $this->itemVariationId = $itemVariationId; } #[\ReturnTypeWillChange] public function jsonSerialize(bool $asArrayWhenEmpty = false) { $json = []; $json['item_variation_id'] = $this->itemVariationId; $json = array_filter($json, function ($val) { return $val !== null; }); return (!$asArrayWhenEmpty && empty($json)) ? new stdClass() : $json; } } 