<?php
 declare(strict_types=1); namespace Square\Models; class SubscriptionActionType { public const CANCEL = 'CANCEL'; public const PAUSE = 'PAUSE'; public const RESUME = 'RESUME'; public const SWAP_PLAN = 'SWAP_PLAN'; } 