<?php
 namespace Stripe; class StripeClient extends BaseStripeClient { private $coreServiceFactory; public function __get($name) { if (null === $this->coreServiceFactory) { $this->coreServiceFactory = new \Stripe\Service\CoreServiceFactory($this); } return $this->coreServiceFactory->__get($name); } } 