<?php
 declare(strict_types=1); namespace Square\Models; use stdClass; class RiskEvaluation implements \JsonSerializable { private $createdAt; private $riskLevel; public function getCreatedAt(): ?string { return $this->createdAt; } public function setCreatedAt(?string $createdAt): void { $this->createdAt = $createdAt; } public function getRiskLevel(): ?string { return $this->riskLevel; } public function setRiskLevel(?string $riskLevel): void { $this->riskLevel = $riskLevel; } #[\ReturnTypeWillChange] public function jsonSerialize(bool $asArrayWhenEmpty = false) { $json = []; if (isset($this->createdAt)) { $json['created_at'] = $this->createdAt; } if (isset($this->riskLevel)) { $json['risk_level'] = $this->riskLevel; } $json = array_filter($json, function ($val) { return $val !== null; }); return (!$asArrayWhenEmpty && empty($json)) ? new stdClass() : $json; } } 