/*
 =======================================================================*\
|| ###################################################################### ||
|| # vBulletin 6.2.3
|| # ------------------------------------------------------------------ # ||
|| # Copyright 2000-2026 MH Sub I, LLC dba vBulletin. All Rights Reserved.  # ||
|| # This file may not be redistributed in whole or significant part.   # ||
|| # ----------------- VBULLETIN IS NOT FREE SOFTWARE ----------------- # ||
|| # http://www.vbulletin.com | http://www.vbulletin.com/license.html   # ||
|| ###################################################################### ||
\*========================================================================*/
vBulletin.precache("lostpw_email_sent forgot_password_title invalid_email_address please_enter_your_email_address please_enter_a_username requiredfieldmissing activation_code activate_your_account".split(" "),[]);
(function(c,e,k,g){function h(){location.href=pageData.baseurl}function l(a,b,d){a="";b=c(".email",b);d=b.val();""==c.trim(d)?a="please_enter_your_email_address":isValidEmailAddress(d)||(a="invalid_email_address");a&&e.error("error",a,b);return!a}function m(){k.initForm(c("#frmActivateuser"),{beforeSubmit:function(a,b,d){a="";d=c(".activateid",b);if(""==c.trim(d.val())){a=["requiredfieldmissing",e.phrase.get("activation_code")];var f=d}b=c(".username",b);""==c.trim(b.val())&&(a="please_enter_a_username",
f=b);a&&e.warning("error",a,f);return!a},success:function(a,b,d,f){e.alert("activate_your_account",a.msg,null,h)}})}function n(){k.initForm(c("#frmActivateemail"),{beforeSubmit:l,success:function(a,b,d,f){e.alert("email_activation_codes",a.msg,null,h)}})}function p(){g.reset();g.initAjaxForm(c("#frmLostpw"),{beforeSubmit:l,success:function(a){e.alert("forgot_password_title","lostpw_email_sent",null,h)},api_error:g.resetOnError})}c(function(){p();m();n()})})(jQuery,vBulletin,vBulletin.ajaxtools,vBulletin.hv);
