<?php
 declare(strict_types=1); namespace Square\Models; class ShiftSortField { public const START_AT = 'START_AT'; public const END_AT = 'END_AT'; public const CREATED_AT = 'CREATED_AT'; public const UPDATED_AT = 'UPDATED_AT'; } 