<?php
 class vB_dB_Query_Replace extends vB_dB_Query_TableQuery { protected function buildQuery(array $values) : string { $queryBuilder = self::$queryBuilders[$this->db_type]; $params = $this->extractParamsFromValues($values); return $queryBuilder->makeReplaceQuery($this->queryid, $values, $this->structure['forcetext'] ?? []); } protected function doQuery(string $querystring) : mixed { $this->db->query_write($querystring); $this->error = $this->db->error(); return $this->db->insert_id(); } } 