<?php
 declare(strict_types=1); namespace SpomkyLabs\Pki\X501\ASN1\AttributeValue; use SpomkyLabs\Pki\ASN1\Type\UnspecifiedType; use SpomkyLabs\Pki\X501\ASN1\AttributeType; use SpomkyLabs\Pki\X501\ASN1\AttributeValue\Feature\PrintableStringValue; final class SerialNumberValue extends PrintableStringValue { protected function __construct(string $value) { parent::__construct(AttributeType::OID_SERIAL_NUMBER, $value); } public static function create(string $value): self { return new self($value); } public static function fromASN1(UnspecifiedType $el): self { return self::create($el->asPrintableString()->string()); } } 