<?php
 namespace GuzzleHttp; use Psr\Http\Message\RequestInterface; use Psr\Http\Message\ResponseInterface; interface MessageFormatterInterface { public function format(RequestInterface $request, ?ResponseInterface $response = null, ?\Throwable $error = null): string; } 