<?php
 declare(strict_types=1); namespace Square\Models; use stdClass; class CatalogQueryItemsForItemOptions implements \JsonSerializable { private $itemOptionIds; public function getItemOptionIds(): ?array { return $this->itemOptionIds; } public function setItemOptionIds(?array $itemOptionIds): void { $this->itemOptionIds = $itemOptionIds; } #[\ReturnTypeWillChange] public function jsonSerialize(bool $asArrayWhenEmpty = false) { $json = []; if (isset($this->itemOptionIds)) { $json['item_option_ids'] = $this->itemOptionIds; } $json = array_filter($json, function ($val) { return $val !== null; }); return (!$asArrayWhenEmpty && empty($json)) ? new stdClass() : $json; } } 