<?php
 class vB_Utility_Template_ParserNode_Curly_Headlink extends vB_Utility_Template_ParserNode_Curly { public function validate() : array { $errors = []; $attributecount = sizeof($this->main_node->attributes); if ($attributecount == 0) { $errors[] = 'no_variable_specified'; } return $errors; } public function compile() : string { $arguments = $this->getRenderedNamedAttributes(0); $arguments = '[' . implode(', ', $arguments) . ']'; return '\'\' . vB_Template_Runtime::includeHeadLink(' . $arguments . '); $final_rendered .= \'\''; } } 