<?php
 class vB_Session_WebApi extends vB_Session_Web { public static function getSession($userId, $sessionHash = '', $dBAssertor = null, $datastore = null, $config = null) { $dBAssertor = $dBAssertor ?: vB::getDbAssertor(); $datastore = $datastore ?: vB::getDatastore(); $config = $config ?: vB::getConfig(); $restoreSessionInfo = ['userid' => $userId]; $session = new vB_Session_WebApi($dBAssertor, $datastore, $config, $sessionHash, $restoreSessionInfo); $session->set('userid', $userId); $session->fetch_userinfo(); return $session; } public static function createSessionNew($sessionhash, $restoreSessionInfo = [], $deferRememberMe = false) { $assertor = vB::getDbAssertor(); $datastore = vB::getDatastore(); $config = vB::getConfig(); $styleid = 0; $languageid = 0; $session = new vB_Session_WebApi( $assertor, $datastore, $config, $sessionhash, $restoreSessionInfo, $styleid, $languageid, $deferRememberMe ); return $session; } } 