<?php
 declare(strict_types=1); namespace Square\Models; use stdClass; class V1ListSettlementsResponse implements \JsonSerializable { private $items; public function getItems(): ?array { return $this->items; } public function setItems(?array $items): void { $this->items = $items; } #[\ReturnTypeWillChange] public function jsonSerialize(bool $asArrayWhenEmpty = false) { $json = []; if (isset($this->items)) { $json['items'] = $this->items; } $json = array_filter($json, function ($val) { return $val !== null; }); return (!$asArrayWhenEmpty && empty($json)) ? new stdClass() : $json; } } 