<?php
 namespace Stripe\Issuing; class Card extends \Stripe\ApiResource { const OBJECT_NAME = 'issuing.card'; use \Stripe\ApiOperations\All; use \Stripe\ApiOperations\Create; use \Stripe\ApiOperations\Retrieve; use \Stripe\ApiOperations\Update; public function details($params = null, $opts = null) { $url = $this->instanceUrl() . '/details'; list($response, $opts) = $this->_request('get', $url, $params, $opts); $obj = \Stripe\Util\Util::convertToStripeObject($response, $opts); $obj->setLastResponse($response); return $obj; } } 