<?php
 declare(strict_types=1); namespace Shopify\Rest\Admin2024_04; use Shopify\Auth\Session; use Shopify\Rest\Base; class Asset extends Base { public static string $API_VERSION = "2024-04"; protected static array $HAS_ONE = []; protected static array $HAS_MANY = []; protected static array $PATHS = [ ["http_method" => "delete", "operation" => "delete", "ids" => ["theme_id"], "path" => "themes/<theme_id>/assets.json"], ["http_method" => "get", "operation" => "get", "ids" => ["theme_id"], "path" => "themes/<theme_id>/assets.json"], ["http_method" => "get", "operation" => "get", "ids" => ["theme_id"], "path" => "themes/<theme_id>/assets.json"], ["http_method" => "put", "operation" => "put", "ids" => ["theme_id"], "path" => "themes/<theme_id>/assets.json"] ]; protected static string $PRIMARY_KEY = "key"; public static function delete( Session $session, array $urlIds = [], array $params = [] ): ?array { $response = parent::request( "delete", "delete", $session, $urlIds, $params, ); return $response->getDecodedBody(); } public static function all( Session $session, array $urlIds = [], array $params = [] ): array { return parent::baseFind( $session, $urlIds, $params, ); } } 