<?php
 class vB_Options_Option_Imagickpdfthumbnail extends vB_Options_Option { protected function validateCustom(array $validation, mixed $rawvalue) : bool|string|array { if ($rawvalue) { $vboptions = vB::getDatastore()->getValue('options'); $pdfThumbOkay = false; try { $image = new vB_Image_Imagick($vboptions); $pdfThumbOkay = $image->canThumbnailPdf(); } catch (Exception) { } if (!$pdfThumbOkay) { return 'imagick_pdf_thumbnail_check_failed'; } } return true; } } 