<?php
 declare(strict_types=1); namespace Jose\Component\KeyManagement\Analyzer; use Jose\Component\Core\JWKSet; final class KeysetAnalyzerManager { private array $analyzers = []; public function add(KeysetAnalyzer $analyzer): void { $this->analyzers[] = $analyzer; } public function analyze(JWKSet $jwkset): MessageBag { $bag = new MessageBag(); foreach ($this->analyzers as $analyzer) { $analyzer->analyze($jwkset, $bag); } return $bag; } } 