<?php
 declare(strict_types=1); namespace Jose\Component\Core\Util\Ecc; use Brick\Math\BigInteger; final readonly class EcDH { public static function computeSharedKey(Curve $curve, PublicKey $publicKey, PrivateKey $privateKey): BigInteger { return $curve->mul($publicKey->getPoint(), $privateKey->getSecret()) ->getX(); } } 