<?php
 declare(strict_types=1); namespace Square\Models; use stdClass; class UpdateWorkweekConfigRequest implements \JsonSerializable { private $workweekConfig; public function __construct(WorkweekConfig $workweekConfig) { $this->workweekConfig = $workweekConfig; } public function getWorkweekConfig(): WorkweekConfig { return $this->workweekConfig; } public function setWorkweekConfig(WorkweekConfig $workweekConfig): void { $this->workweekConfig = $workweekConfig; } #[\ReturnTypeWillChange] public function jsonSerialize(bool $asArrayWhenEmpty = false) { $json = []; $json['workweek_config'] = $this->workweekConfig; $json = array_filter($json, function ($val) { return $val !== null; }); return (!$asArrayWhenEmpty && empty($json)) ? new stdClass() : $json; } } 