<?php
 abstract class vB_dB_Type { use vB_Trait_NoSerialize; protected static function getInstance($type, ...$values) : static { $dbType = vB::getDbAssertor()->getDbType(); $className = "vB_dB_{$dbType}_Type_" . $type; return new $className(...$values); } public abstract function escapeFieldValue(); } 