<?php if (!defined('VB_ENTRY')) die('Access denied.'); class vB_Api_FCMessaging extends vB_Api { protected $assertor; protected $library; protected function __construct() { parent::__construct(); $this->assertor = vB::getDbAssertor(); $this->library = vB_Library::instance('FCMessaging'); } public function sendFCM($messageHashes) { if (!is_array($messageHashes)) { $messageHashes = array($messageHashes); } $strHashes = array(); foreach ($messageHashes AS $__hash) { if (is_string($__hash)) { $strHashes[] = $__hash; } } return $this->library->handleOffloadedTask($strHashes); } } 