<?php
 declare(strict_types=1); namespace Square\Models; use stdClass; class BulkRetrieveVendorsRequest implements \JsonSerializable { private $vendorIds; public function getVendorIds(): ?array { return $this->vendorIds; } public function setVendorIds(?array $vendorIds): void { $this->vendorIds = $vendorIds; } #[\ReturnTypeWillChange] public function jsonSerialize(bool $asArrayWhenEmpty = false) { $json = []; if (isset($this->vendorIds)) { $json['vendor_ids'] = $this->vendorIds; } $json = array_filter($json, function ($val) { return $val !== null; }); return (!$asArrayWhenEmpty && empty($json)) ? new stdClass() : $json; } } 