<?php
 declare(strict_types=1); namespace Square\Models; class CatalogCustomAttributeDefinitionSellerVisibility { public const SELLER_VISIBILITY_HIDDEN = 'SELLER_VISIBILITY_HIDDEN'; public const SELLER_VISIBILITY_READ_WRITE_VALUES = 'SELLER_VISIBILITY_READ_WRITE_VALUES'; } 