/*
 =======================================================================*\
|| ###################################################################### ||
|| # vBulletin 6.2.3
|| # ------------------------------------------------------------------ # ||
|| # Copyright 2000-2026 MH Sub I, LLC dba vBulletin. All Rights Reserved.  # ||
|| # This file may not be redistributed in whole or significant part.   # ||
|| # ----------------- VBULLETIN IS NOT FREE SOFTWARE ----------------- # ||
|| # http://www.vbulletin.com | http://www.vbulletin.com/license.html   # ||
|| ###################################################################### ||
\*========================================================================*/
// ***************************
// js.compressed/infraction.js
// ***************************
vBulletin.precache("error_adding_infraction error_adding_warning error_reversing_infraction give_infraction_ginfraction infraction_added infraction_reversed please_check_the_box_to_reverse_infraction please_specify_reason_to_reverse_infraction received_infraction received_warning warning_added".split(" "),[]);vBulletin.ensureObj("infraction");vBulletin.ensureObj("privateMessage");
(function(a,d){function F(c){const b=getSelectedMessages();0<b.length&&"0"!=pageData.userid&&d.AJAX({call:"/ajax/api/node/"+(c?"markReadMultiple":"markUnreadMultiple"),data:{nodeids:b},success(h){for(const t in b)a("[data-node-id={0}]".format(b[t]),".infractions-list").toggleClass("read",c).find(".privateMessageActionCheck").prop("checked",!1)}})}function z(c,b,h,t){if(!c&&(c=a("#private-message-toolbar .infractions-paginator .infractionsPageTo"),0==c.length))return!1;updateCounter=h||0;t=t||!1;var m=
c.closest(".infractions-paginator"),q=a("#privateMessageContainer .main-pane .pending-posts-container"),l=m.find("#maxPageNum").filter(":input[type=hidden]").val();c=parseInt(m.find(":input[type=hidden][name=pagenum]").val(),10);var f=parseInt(m.find(":input[type=hidden][name=per-page]").val(),10);b=parseInt(b,10);if(isNaN(b)||isNaN(l)||isNaN(c))return!1;if(1>b||b>l)return d.error("error","please_enter_a_valid_page_number"),!1;if(b==c&&!h)return!1;var u={};a("#infractionFilters input:checked").each(function(){u[this.name]=
this.value});u.time&&(u.time={from:u.time});var y={setCurrentPage:b,setPerPage:f,getPagingInfo:h,options:u,isAjaxTemplateRenderWithData:!0};d.AJAX({call:"/ajax/render/privatemessage_infraction_main",data:y,success:function(r){q.html(r.template);var x=r=0;b<l?(x=b+1,1<b&&(r=b-1)):r=b-1;m.find(":input[type=hidden][name=pagenum]").val(b);m.find(":input[type=hidden][name=next-page]").val(x);m.find(":input[type=hidden][name=prev-page]").val(r);m.find(".infractionsNext").toggleClass("h-disabled",!x);m.find(".infractionsPrev").toggleClass("h-disabled",
!r);m.find(".infractionsPageTo").val(b);h&&(r=a("#privateMessageContainer .main-pane .pending-posts-container .pending-posts-pageinfo"),r=parseInt(r.find(".totalpages").val(),10),m.find("#maxPageNum").filter(":input[type=hidden]").val(r),l=r,m.find(".infractionsPageCount").text(r));D&&d.privateMessage.updatePaginationLinks(G,b,l);D&&!t&&d.privateMessage.pmFilterHistory.isEnabled()&&(y.maxPage=l,r=d.privateMessage.getPrivateMessageUrl(b),d.privateMessage.pmFilterHistory.pushState({infractionFilterParams:y},
document.title,r.url))}})}var p=a("#infractions-tab"),D=d.privateMessage&&d.privateMessage.jsReady||!1,G=a("#privateMessageContainer");d.infraction.infractUser=function(c,b){var h=a(this);if(h.data("ajaxstarted"))return!1;var t=h.hasClass("js-infraction-received");if(t){c="received_infraction_form";var m="received_infraction";var q="receive-infraction-dialog"}else c="give_infraction_form",m="give_infraction_ginfraction",q="give-infraction-dialog";h.data("ajaxstarted",!0);d.AJAX({call:"/ajax/render/"+
c,data:{userid:h.data("userid"),nodeid:h.closest(".js-post-controls").data("node-id")||h.data("nodeid"),userInfraction:h.data("userinfraction"),isAjaxTemplateRenderWithData:!0},complete:function(){h.data("ajaxstarted",null)},success:function(l){a("."+q).length?a("."+q).replaceWith(l.template):a(l.template).appendTo(document.body).hide();l=a("."+q);l.dialog({title:d.phrase.get(m),autoOpen:!0,modal:!0,resizable:!1,closeOnEscape:!1,showCloseButton:!1,width:l.hasClass("error-infraction-dialog")?500:t?
600:700,dialogClass:"dialog-container infraction-dialog-container dialog-box",close:function(){var f=a(".js-editor",this);f.length&&d.ckeditor.editorExists(f)&&d.ckeditor.destroyEditor(f);a(this).dialog("destroy").remove()},open:function(){var f=this;if(t)d.ajaxForm.apply(a(".infraction-reverse-form",f),[{error_phrase:"error_reversing_infraction",success:function(e,g,k,n){d.alert("reverse_this_infraction","infraction_reversed");"function"==typeof b&&b.apply(h.get(0),[e]);a(f).dialog("close")},beforeSubmit:function(e,
g,k){if(a(".infraction-nodeid",g).is(":checked"))a.trim(a(".infraction-reason",g).val())||(n="please_specify_reason_to_reverse_infraction",v=a(".infraction-reason",g));else{var n="please_check_the_box_to_reverse_infraction";var v=a(".infraction-nodeid",g)}return n?(d.warning("reverse_this_infraction",n,function(){v.trigger("focus")}),!1):!0}}]),a(".reverse-infraction",f).on("click",function(){a(".infraction-reverse-form",f).submit()});else{var u=a(".infraction-send-pm",f);d.ajaxForm.apply(a(f),[{dataType:"json",
error_phrase:"error_adding_infraction",success:function(e,g,k,n){g=e.infractionNodeid&&!e.infractionNodeid.errors;n="warning";g?(k=e.isWarning?"warning_added":"infraction_added",n=""):k=e.isWarning?"error_adding_warning":"error_adding_infraction";d.alert("give_infraction_ginfraction",k,n);g&&("function"==typeof b&&b.apply(h.get(0),[e]),a(f).dialog("close"))},beforeSubmit:function(e,g,k){if("0"==a(".infraction-level-control option:selected",g).val()){e=function(J,K){x(a(".infraction-level",f));d.warning("give_infraction_ginfraction",
J,function(){K.trigger("focus")})};if(""==a.trim(a(".custom-reason",g).val()))return e("please_specify_custom_reason",a(".custom-reason",g)),!1;k=Number(a(".custom-points",g).val());if(isNaN(k)||0>k)return e("please_specify_custom_points",a(".custom-points",g)),!1;k=a(".custom-period option:selected",g).val();var n=Number(a(".custom-expires",g).val());if("N"!=k&&(isNaN(n)||0>=n))return e("please_specify_custom_expires",a(".custom-expires",g)),!1}e=a(".infraction-ban-reason .ban-reason",f);if(e.is(":visible")&&
!a.trim(e.val()))return x(a(".infraction-ban",f)),a(".ban-reason-desc",f).removeClass("h-hide"),e.trigger("focus"),a(".dialog-content",f).scrollTop(0).scrollTop(a(".infraction-ban-reason",f).position().top),!1;if(Number(u.data("required"))){var v=a(".js-editor",g),A=d.ckeditor.getEditor(v);g=A?A.getData():A.val();if(!a.trim(g))return d.warning("give_infraction_ginfraction","please_specify_infraction_pm",function(){x(u);A?A.focus():v.trigger("focus")}),!1}}}]);var y=function(e){r.toggleClass("h-hide",
!e).find("input, select").prop("disabled",!1).end().find(".selectBox").toggleClass("selectBox-disabled",!e)};a(".infraction-level-control",f).on("change",function(e,g,k){e=a(this.options[this.selectedIndex]);k&&1==k.length||(k=a(this).closest(".infraction-level").find(".infraction-warning-control input"));g||(e.data("allow-warning")?(k.prop("disabled",!1).val(this.value).parent().removeClass("h-hide"),y(!1)):(k.prop("disabled",!0).parent().addClass("h-hide"),"0"==this.value&&(y(!0),a(".textbox",r).first().trigger("focus"))));
var n=g=0;k.prop("checked")||"0"==this.value?"0"==this.value&&(g=Number(a(".custom-infraction-info .custom-points",f).val())||0)&&(n=1):(g=Number(e.data("points"))||0,n=1);k=a(".infraction-dashboard-stats").data();k=g&&L(Number(k.points)+g,Number(k.infractions)+n);H(k);B()});a(".infraction-warning-control input",f).on("click",function(){this.checked?H(!1):a(".infraction-level-control",f).trigger("change",[!0,this])});a(".custom-points",f).on("change",function(){a(".infraction-level-control",f).trigger("change",
[!0])});var r=a(".custom-infraction-info",f).removeClass("h-hide");a("select",f).selectBox();r.addClass("h-hide");a(".js-content-entry-panel, .js-editor",u).data("callback",function(){B()});d.ckeditor.initEditorComponents(u,!0);a(".toggle-button",f).on("click",function(e){e=a(this);var g=e.closest(".blockrow-head"),k=g.next(".blockrow-body"),n=e.hasClass("expand");k.toggle(n);g.toggleClass("collapsed",!n);B();e.toggleClass("collapse expand");g=e.attr("title");e.attr("title",e.data("toggle-title")).data("toggle-title",
g);return!1});var x=function(e){a(".toggle-button.expand",e).trigger("click")},L=function(e,g){if(0==e&&0==g)return!1;var k=!1;a(".infraction-ban-list tbody tr",f).each(function(n,v){if(v=a(this).data())if(n=Number(v.points),v=Number(v.infractions),n&&e>=n||v&&g>=v)return k=!0,!1});return k},H=function(e){var g=a(".infraction-ban-reason",f);e?(g.removeClass("h-hide"),x(a(".infraction-ban",f))):g.addClass("h-hide")},C=a(".dialog-content",f),B=function(){C[0]||(C[0]=f);var e=C[0].scrollHeight>parseFloat(C.css("max-height"));
C.toggleClass("has-scrollbar",e)};B();a(".infraction-level-control",f).trigger("change")}a(".close-infraction",f).on("click",function(){a(f).dialog("close")});a(".ckeditor-bare-box.ckeditor-load-on-focus",f).on("focus",function(){d.ckeditor.initEditor(this.id,{complete:function(e){B()},error:function(e){a("#"+e).prop("disabled",!1).removeClass("ckeditor-load-on-focus")}})})}})}})};d.infraction.loadUserInfractions=function(c){a.post(d.getAjaxBaseurl()+"/ajax/render/user_infractions",{userid:c.userid,
pagenum:c.pageNumber},function(b,h,t){c.container.html(b);a(".pagenav-form",p).length&&new d.pagination({context:p,tabParamAsQueryString:!1,allowHistory:1==p.find(".conversation-toolbar-wrapper").data("allow-history"),onPageChanged:function(m,q){d.infraction.loadUserInfractions({container:p,userid:p.data("userid"),pageNumber:m,replaceState:!0})}});"function"==typeof c.callback&&c.callback(b);if(c.pushState||c.replaceState)b=d.makePaginatedUrl(location.href,c.pageNumber),w||(E="1"==p.find(".conversation-toolbar-wrapper").data("allow-history"),
w=new d.history.instance(E)),w.isEnabled()&&(h={from:"infraction_filter",page:c.pageNumber,tab:p.data("url-path")?p.data("url-path"):"#"+p.attr("id")},w[c.pushState?"pushState":"setDefaultState"](h,document.title,b))},"json")};var w,E;d.infraction.setHistoryStateChange=function(){w||(E="1"==p.find(".conversation-toolbar-wrapper").data("allow-history"),w=new d.history.instance(E));w.isEnabled()&&w.setStateChange(function(c){var b=w.getState();if("infraction_filter"==b.data.from){w.log(b.data,b.title,
b.url);c=p.closest(".ui-tabs");var h=c.find(".ui-tabs-nav > li").filter('li:has(a[href*="#{0}"])'.format(p.attr("id")));h.hasClass("ui-tabs-active")?d.infraction.loadUserInfractions({container:p,userid:p.data("userid"),pageNumber:b.data.page,pushState:!1}):(b=h.index(),d.selectTabByIndex.call(c,b))}},"infraction_filter")};a(document).off("click",".js-post-control__infraction").on("click",".js-post-control__infraction",function(c){d.infraction.infractUser.apply(this,[c,function(b){let h=a(this),t=
h.find(".b-post-control__icon"),m=h.hasClass("js-infraction-received"),q;t.removeClass("infraction--neutral infraction--warned infraction--infracted");m?(b="give_infraction_ginfraction",q="infraction--neutral"):b.isWarning?(b="received_warning",q="infraction--warned"):(b="received_infraction",q="infraction--infracted");h.toggleClass("js-infraction-received",!m);h.attr("title",d.phrase.get(b));t.addClass(q)}])});p.off("click",".infractionCtrl").on("click",".infractionCtrl",function(c){d.infraction.infractUser.apply(this,
[c,function(b){d.infraction.loadUserInfractions({container:p,userid:a(this).data("userid"),pageNumber:1,pushState:1!=Number(a('.pagenav-form input[name="page"]',p).val())})}])});p.on("click",".view-infraction",function(c){d.infraction.infractUser.apply(this,[c,function(b){b=Number(a('.pagenav-form input[name="page"]',p).val())||1;d.infraction.loadUserInfractions({container:p,userid:a(this).data("userid"),pageNumber:b,pushState:1!=b})}])});a(document).off("click","#privateMessageContainer .js-button-group .view-infraction").on("click",
"#privateMessageContainer .js-button-group .view-infraction",function(c){d.infraction.infractUser.apply(this,[c,function(b){}])});a(".infraction-delete").off("click").on("click",function(c){$button=a(this);var b=!1;if($button.parents("#pmFloatingBarContent").hasClass("infractions-paginator"))var h=getSelectedMessages();else h=[a("#privateMessageContainer .js-conversation-starter").data("nodeId")],b=!0;0<h.length&&openConfirmDialog({title:d.phrase.get("messages_header"),message:d.phrase.get("are_you_sure_delete_infractions"),
iconType:"warning",onClickYes:function(){d.AJAX({url:d.getAjaxBaseurl()+"/ajax/api/node/deleteNodes",data:{nodeids:h,hard:0},success:function(t){b?location.href=a("#pmBtnBackToInfractions").prop("href"):location.reload()}})}})});a(".infraction-mark_as_read").offon("click",function(c){F(!0)});a(".infraction-mark_as_unread").offon("click",function(c){F(!1)});a(document).ready(function(){if(0<a("#pmBtnBackToInfractions").length){const c=a("#privateMessageContainer .conversation-list .b-post--infraction").data("nodeId");
d.markTopicAsRead(c)}});a("#infractionFilters").trigger("reset").find(".filter-options input").off("click").on("click",function(c){M.apply(this)});a(document).off("click","#privatemessagePaging .infractionsPrev").on("click","#privatemessagePaging .infractionsPrev",function(c){c.preventDefault();c=a(this).closest("#privatemessagePaging").find(':input[type=hidden][name="prev-page"]').val();z(a(this),c)});a(document).off("click","#privatemessagePaging .infractionsNext").on("click","#privatemessagePaging .infractionsNext",
function(c){c.preventDefault();c=a(this).closest("#privatemessagePaging").find(':input[type=hidden][name="next-page"]').val();z(a(this),c)});var I=function(c){var b=a("#privatemessagePaging"),h=b.find("input[name='pagenum']");c=h.val();var t=b.find("#maxPageNum");b=t.val();var m=a("#infractionFilters"),q={};d.privateMessage.updatePaginationLinks(G,c,b);d.privateMessage.getPageFiltersForUrl=function(l){m.find("input:checked").each(function(){l["filter_"+this.name]=this.value});return l};a("#infractionsFilter").length&&
a("#infractionFilters input:checked").each(function(){queryParams["filter_"+this.name]=this.value});d.privateMessage.pmFilterHistory.isEnabled()&&(q={infractionFilterParams:{setCurrentPage:c,options:{},maxPage:b}},m.find("input:checked").each(function(){q.infractionFilterParams.options[this.name]=this.value}),q.infractionFilterParams.options.time&&(q.infractionFilterParams.options.time={from:q.infractionFilterParams.options.time}),d.privateMessage.pmFilterHistory.setDefaultState(q,document.title,
window.location.href),d.privateMessage.pmFilterHistory.setStateChange(function(l){l=d.privateMessage.pmFilterHistory.getState();l.data.hasOwnProperty("infractionFilterParams")&&(l=l.data.infractionFilterParams,a.each(l.options,function(f,u){f="input[name='{0}'][value='{1}']".format(f,u);m.find(f).prop("checked",!0)}),t.val(l.maxPage),h.val(l.setCurrentPage),z(null,l.setCurrentPage,!0,!0))},"privatemessage"));D=!0};if(D)I();else a(document).one("vb-privatemessage-js-ready",I);a(document).off("keypress",
"#privatemessagePaging .infractionsPageTo").on("keypress","#privatemessagePaging .infractionsPageTo",function(c){if(13==c.keyCode){c.preventDefault();c=a(this);var b=parseInt(c.val(),10);if(isNaN(b))return d.error("error","please_enter_a_valid_page_number"),!1;z(c,b)}});var M=function(c){$paginateButton=a("#private-message-toolbar .infractions-paginator .infractionsPageTo");if($paginateButton.length)z($paginateButton,1,!0);else{var b={};a(this).closest(".filter-options-list").find("input:checked").each(function(){b[this.name]=
a(this).val()});b.time&&(b.time={from:b.time});a(this).prop("checked",!0);b.page=1;b.perpage=pmPerPage;d.AJAX({call:"/ajax/render/privatemessage_infraction_main",data:{options:b,isAjaxTemplateRenderWithData:!0},success:function(h){a("#privateMessageContainer .pending-posts-container").html(h.template);pmPageNum=1}})}}})(jQuery,vBulletin);
;

// ***************************
// js.compressed/conversation.js
// ***************************
vBulletin.precache("cancel_new_with_quote create_new_conversation_with_quote error_fetching_comments error_fetching_quotes error_x existing_message_will_be_deleted invalid_server_response_please_try_again new_with_quote please_click_on_the_quote_icon_of_the_post_you_want_to_quote post_reply share_post_link_help visitor_message x_comment x_comments_lower your_post_is_now_being_reviewed_and_waiting_for_moderators_approval add_bookmark remove_bookmark".split(" "),[]);vBulletin.ensureObj("conversation");
$.extend(vBulletin.conversation,function(b,f,L){function E(d,g){g&&(d=y(),0<d.length?f.AJAX({call:"/createcontent/fetch-quotes",data:{nodeid:d},success:h=>{let q=Object.values(h).join("<br/><br/>")+"<br/><br/>";g.setData("",()=>{g.insertHtml(q.replace(/(\n)/gi,"<br />"));g.focus()})},title_phrase:"conversation",error_phrase:"error_fetching_quotes"}):g.focus())}function z(){let d=b(".post-reply-btn .js-button__text-secondary"),g=y().length;d.text(0<g?"("+g+")":"");return g}function F(){let d=y();b(".js-post-control__quote").filter((g,
h)=>d.includes(b(h).parent().data("node-id"))).addClass("b-post-control__quote--selected")}function M(){b(".b-post-control__quote--selected").removeClass("b-post-control__quote--selected");t.unsetAll();z()}function N(d){f.qtip.apply(d,"qtip-sharepostlink",{content:{title:{text:f.phrase.get("share_post_link_help"),button:!0},text:'<input type="text" class="textbox stretch" value="'+d.attr("href")+'" />'},show:{event:"click",solo:!0,ready:!0},events:{visible:function(g,h){h.elements.content.find("input.textbox").trigger("select").trigger("focus")}},
hide:{event:"unfocus",fixed:!0}})}function O(d){return 1==b(".conversation-media-view",d).length?2:1==b(".conversation-stream-view",d).length?1:0}if(!f.pageHasSelectors([".forum-conversation-content-widget",".group-conversation-content-widget",".blog-conversation-content-widget",".profile-widget","#privateMessageContainer .infractions"]))return!1;const u=f.ckeditor;let v=()=>b(".js-content-entry").has("form[data-message-type=reply]"),t=f.storagetools.createStorage("quotes"),y=()=>Object.keys(t.getAll()).map(d=>
parseInt(d));b(()=>{var d=b(".conversation-content-widget"),g="1"==b(".conversation-toolbar-wrapper",d).data("allow-history"),h=d.filter(".widget-tabs").tabs({active:O(d)});h.trigger("vb-tabinit");h.find(".widget-header .widget-tabs-nav li.ui-state-default:not(.ui-tabs-active) a").off("click").on("click",function(){location.href=b(this).attr("data-href");return!1});var q=new f.pagination({context:d,allowHistory:g,onPageChanged:function(a,c,e){w.updatePageNumber(a);if(!c){if(c=w.getOption("customFilter"))c.pagenum=
a,delete w.lastFilters,e&&delete c[b(".toolbar-search-form .js-filter-search",d).attr("name")];w.applyFilters(!1,!1,!1,!0)}f.Responsive.checkForVideoSignature();F()}});f.conversation.pagination=q;var G=b(".conversation-toolbar-wrapper.scrolltofixed-floating",d),H=function(){return 0<d.length?d.offset().top+(d.outerHeight()-parseFloat(d.css("border-bottom-width")))-G.height():0};try{var P=new f.scrollToFixed({element:G,limit:H()})}catch(a){}var w=new f.conversation.filter({context:d,scrollToTop:d,
pagination:q,allowHistory:g,hash:d.find(".js-module-top-anchor").attr("id"),onContentLoad:function(){P.updateLimit(H())}});g=b(document);g.offon("click",".js-show-post-link",function(a){a.preventDefault();N(b(a.currentTarget))});g.offon("click","a.js-scroll-if-on-page",a=>{a=b(a.currentTarget);a=parseInt(a.data("nodeid"),10);$anchor=b(".js-post[data-node-id='"+a+"']:not(.pinned-answer)");if($anchor.length)return vBulletin.animateScrollTop($anchor.offset().top),!1});b(".conversation-toolbar .post-reply-btn").offon("click",
function(a){var c=v();if(1==c.length){a=c.find(".js-editor");var e=u.getEditor(a),l=b(".conversation-toolbar-wrapper"),k=l.hasClass("scrolltofixed");l=l.length&&l.outerHeight(!0)||0;c=c.offset().top;k||(c+=l);e?E(d,e):u.initEditor(a,{success:()=>{e=u.getEditor(v($container).find(".js-editor"));E(d,e)}});f.animateScrollTop(c,{duration:500,complete:()=>{e&&e.focus()}})}});F();z();g.offon("mouseover",".js-userinfo__signature",function(){var a=b(this);"1"!=a.data("qtip-initialized")&&(a.data("qtip-initialized",
"1"),a.find(".user-signature"),f.qtip.apply(a,"qtip-signature",{content:a.find(".user-signature"),hide:{event:"unfocus"},show:{solo:!0}}),b(this).trigger("mouseover"))});h=b(".conversation-list",d);b(".js-post-controls",h).disableSelection();h.offon("click",".js-post-control__quote",function(){var a=b(this);a.toggleClass("b-post-control__quote--selected");var c=a.parent().data("node-id");(a=a.hasClass("b-post-control__quote--selected"))?t.set(c,1):t.unset(c);c=z();a&&1==c&&b(".post-reply-btn:visible").trigger("click");
0==c&&(c=u.getEditor(v($container).find(".js-editor")))&&c.setData("")});vBulletin.conversation.initContentEvents(h);"inlinemod"in f&&f.ensureFun(f.inlinemod.init)(d);h.offon("click",".js-comment-entry__post",function(a){vBulletin.conversation.postComment.apply(this,[a,function(c){if(c)if(c.redirecturl)location.replace(c.redirecturl);else{var e=b(this).closest(".js-post"),l=c.totalcomments,k=e.find(".js-comments").removeClass("h-hide"),A=e.find(".js-comments__comments");b(this).closest(".js-comment-entry").addClass("b-comment-entry--has-comments").find(".js-comment-entry__textbox").val("").trigger("input");
var m=b(c.template),n=m.find(".js-comment");m.appendTo(A);k.find(".js-comments__footer").addClass("h-hide");k.find(".js-comments__page--prev").show().data("page-num",1).prev("label").hide();k.find(".js-comments__header").removeClass("h-hide").find(".js-comments__pagination").removeClass(function(){return 1<l?"h-hide":""}).end().find(".js-comments__total-text").text(function(){return f.phrase.get(1<l?"x_comments_lower":"x_comment",l)});e=e.closest(".ui-tabs-panel").find(".conversation-toolbar-wrapper");
e.hasClass("scrolltofixed-floating")&&(e=e.data("object-instance"))&&e.addLimit(n.outerHeight(!0));f.scrollToAnchor("#post"+c.nodeId)}}])});h.offon("click",".js-comments__page--prev, .js-comments__page--next",function(){b("body").css("cursor","wait");var a=b(this),c=a.closest(".js-post"),e=c.find(".js-comments"),l=e.find(".js-comments__comments"),k=Number(a.data("page-num"))||0,A=a.closest(".canvas-widget").attr("data-widget-instance-id");f.AJAX({call:"/ajax/fetch-comments",data:{page:k,parentid:c.attr("data-node-id"),
postindex:c.find(".js-post__content .js-show-post-link").text().replace("#",""),widgetInstanceId:A,isblogcomment:1==a.closest(".blog-list").length?1:0,isarticlecomment:1==a.closest(".article-list").length?1:0},complete:function(m,n){b("body").css("cursor","auto")},success:function(m,n,p){if(m.templates){var x=b("<ul />").attr("class",l.attr("class")),B=m.totalcomments;b.each(m.templates,function(I,r){x.append(r)});l.replaceWith(x);n=Number(x.find(".js-comment:first-child .js-show-post-link span").text().replace(/\D/g,
""));p=Number(x.find(".js-comment:last-child .js-show-post-link span").text().replace(/\D/g,""));var Q=Math.ceil(B/vBulletin.conversation.COMMENTS_PER_PAGE);if(a.hasClass("js-comments__page--prev")){var C=a;var D=e.find(".js-comments__page--next")}else C=e.find(".js-comments__page--prev"),D=a;var K=function(I,r,J){I.find(".js-comments__pagination > label").show().text(r==J?r:"{0} - {1}".format(r,J))};k=m.page;K(e.find(".js-comments__header"),n,p);1==k?e.find(".js-comments__footer").addClass("h-hide"):
(n=p+1,p=n+vBulletin.conversation.COMMENTS_PER_PAGE-1,p=p>B?B:p,m=e.find(".js-comments__footer"),m.removeClass("h-hide"),K(m,n,p));C.data("page-num",k+1);D.data("page-num",k-1||1);C.removeClass("h-hide-imp")[Q>k?"show":"hide"]().prev("label").show();D[1<k?"show":"hide"]()}},title_phrase:"conversation",error_phrase:"error_fetching_comments"})});vBulletin.conversation.bindEditFormEventHandlers("all");if(h=parseInt(pageData.nodeid))f.markTopicAsRead(h),f.AJAX({call:"/ajax/api/node/incrementNodeview",
data:{nodeid:h},error:f.ajaxtools.logAjaxError,api_error:f.ajaxtools.logApiError});-1!=location.href.indexOf("edit=1")&&pageData.nodeid&&0<pageData.nodeid&&b("#edit-"+pageData.nodeid).trigger("click");g.offon("change",".js-article-content-pagenav",function(){location.href=b(this).val()});0<pageData.userid&&(b(" .js-goto-first-unread-page").offon("click",a=>{a=b(a.currentTarget).data("unread-page");let c=b(".pagenav-controls .pagenav-form",d);q.updatePageNavigation(c,a,!1);return!1}),g.on("vb-postpagination",
(a,c)=>{$goToUnreadBtn=b(" .js-goto-first-unread-page");if($goToUnreadBtn.length){({ajaxResult:a}=c);const {first_unread_page:e,pageinfo:l,page_sort:k}=a;a=l.pagenumber||l.currentpage||1;c=l.totalpages;a="ASC"==k&&1==e||a==c||0>=e||e>c||"DESC"==k||("ASC"==k?e<a:e>a);$goToUnreadBtn.data("unread-page",e);$goToUnreadBtn.attr("data-unread-page",e);$goToUnreadBtn.toggleClass("h-hide-imp",a)}}));g=v();g.length&&L.entryBoxEvent(g,"afterCancel afterSave",M)});return{}}(jQuery,vBulletin,vBulletin.contentEntryBox));
;

// ***************************
// js.compressed/subscribe.js
// ***************************
vBulletin.precache(["follow","following","following_pending","social_group_count_members_x","unsubscribe_overlay_error"],[]);
(function(){function h(a,b){a=$(".js-replace-member-count-"+a);a.length&&a.each(function(){var c=$(this),d=c.data("replace-phrase-varname"),k=parseInt(c.data("member-count"),10)+b;c.text(vBulletin.phrase.get(d,k));c.data("member-count",k)})}function l(a){a=$(this);if(a.hasClass("isSubscribed")&&!a.hasClass("is-owner")){let b=a.outerWidth();a.css("width",b+"px");e(a,"following_remove","b-button--unfollow")}}function m(a){a=$(this);a.hasClass("b-button--unfollow")&&f(a,"following","","b-button--unfollow");
a.css("width","")}vBulletin.subscribe={};var g=function(a,b){a.children(".js-button__text-primary").text(vBulletin.phrase.get(b))},f=function(a,b,c,d){g(a,b);a.addClass((c||"")+" b-button--special").removeClass((d||"")+" b-button--secondary")},e=function(a,b,c,d){g(a,b);a.addClass((c||"")+" b-button--secondary").removeClass((d||"")+" b-button--special")},n=function(a,b,c){vBulletin.AJAX({call:b,data:c,success:function(d){!isNaN(d)&&1<=d?1==d?f(a,"following","isSubscribed"):f(a,"following_pending",
"is-pending"):vBulletin.error("follow","follow_error")},title_phrase:"follow",error_phrase:"follow_error"})},p=function(a){var b=$(a),c=parseInt(b.attr("data-node-id"),10);a=parseInt(b.attr("data-owner-id"),10);vBulletin.AJAX({call:"/ajax/api/node/requestChannel",data:{channelid:c,recipient:a,requestType:"sg_member"},success:function(d){!0===d?(f(b,"joined","has-joined"),h(c,1),(b.hasClass("join-to-post-btn")||b.hasClass("js-refresh"))&&window.location.reload()):isNaN(d)||f(b,"following_pending",
"is-pending")},title_phrase:"join",error_phrase:"join_error"})},q=function(a){var b=$(a),c=parseInt($(a).attr("data-node-id"),10);vBulletin.AJAX({call:"/ajax/api/blog/leaveChannel",data:{channelId:c},success:function(d){!0===d?(b.hasClass("js-button--follow")?(g(b,"follow"),b.addClass("b-button--special").removeClass("isSubscribed b-button--unfollow")):(g(b,"join"),b.removeClass("has-joined b-button--special leave-btn")),h(c,-1),b.is(".js-no-refresh")||location.reload()):vBulletin.error("leave","invalid_server_response_please_try_again")},
title_phrase:"leave",error_phrase:"invalid_server_response_please_try_again"})},r=function(a){var b=$(a);a=$(a).attr("data-node-id");vBulletin.AJAX({call:"/ajax/api/follow/delete",data:{follow_item:a,type:"follow_contents"},success:function(c){1==c?e(b,"follow","","isSubscribed b-button--unfollow"):vBulletin.error("follow","unfollow_error")},title_phrase:"follow",error_phrase:"unfollow_error"})};vBulletin.subscribe.updateSubscribeButton=function(a){if("undefined"!=typeof a){var b=$(".js-button--follow").filter(function(){return $(this).data("node-id")==
pageData.nodeid&&pageData.nodeid!=pageData.channelid});switch(a){case 0:e(b,"follow","","isSubscribed b-button--unfollow");break;case 1:e(b,"following","isSubscribed");break;case 2:e(b,"following_pending","is-pending")}}};$(".js-button--follow").on("click",function(a){a=$(this);if(a.hasClass("isSubscribed"))a.hasClass("b-button--unfollow")&&(a.hasClass("is-blog-channel")?q(this):r(this));else if(a=$(this),!a.hasClass("isSubscribed")&&!a.hasClass("is-pending")){var b=parseInt(a.attr("data-node-id"),
10),c={};a.hasClass("is-topic")?(c.follow_item=b,c.type="follow_contents",n(a,"/ajax/api/follow/add",c)):(c={},c.channelid=b,c.recipient=parseInt(a.attr("data-owner-id"),10),a.hasClass("is-blog-channel")?c.requestType="member":a.hasClass("is-sg-channel")?c.requestType="sg_subscriber":c.requestType="subscriber",n(a,"/ajax/api/node/requestChannel",c))}});$(".js-button--follow").on("mouseover",l);$(".js-button--follow, .js-subscription__follow").on("mouseout",m);$(".subscriptionsContainer").on("mouseover",
".js-subscription__follow",l);$(".subscriptionsContainer").on("mouseout",".js-subscription__follow",m);$(".join-to-post-btn").on("click",function(a){$(this).hasClass("has-joined")||$(this).hasClass("is-pending")||p(this)});$(document).on("click",".join-btn",function(a){$(this).hasClass("has-joined")||$(this).hasClass("is-pending")?$(this).hasClass("leave-btn")&&!$(this).hasClass("is-owner")&&q(this):p(this)});$(document).on("mouseover",".join-btn",function(a){a=$(this);a.hasClass("has-joined")&&!a.hasClass("is-owner")&&
e(a,"leave","leave-btn")});$(document).on("mouseout",".join-btn",function(a){a=$(this);a.hasClass("leave-btn")&&!a.hasClass("is-owner")&&f(a,"joined","","leave-btn")})})();
;

// ***************************
// js.compressed/tag-editor.js
// ***************************
var $jscomp=$jscomp||{};$jscomp.scope={};$jscomp.ASSUME_ES5=!1;$jscomp.ASSUME_NO_NATIVE_MAP=!1;$jscomp.ASSUME_NO_NATIVE_SET=!1;$jscomp.SIMPLE_FROUND_POLYFILL=!1;$jscomp.ISOLATE_POLYFILLS=!1;$jscomp.FORCE_POLYFILL_PROMISE=!1;$jscomp.FORCE_POLYFILL_PROMISE_WHEN_NO_UNHANDLED_REJECTION=!1;$jscomp.defineProperty=$jscomp.ASSUME_ES5||"function"==typeof Object.defineProperties?Object.defineProperty:function(a,c,e){if(a==Array.prototype||a==Object.prototype)return a;a[c]=e.value;return a};
$jscomp.getGlobal=function(a){a=["object"==typeof globalThis&&globalThis,a,"object"==typeof window&&window,"object"==typeof self&&self,"object"==typeof global&&global];for(var c=0;c<a.length;++c){var e=a[c];if(e&&e.Math==Math)return e}throw Error("Cannot find global object");};$jscomp.global=$jscomp.getGlobal(this);$jscomp.IS_SYMBOL_NATIVE="function"===typeof Symbol&&"symbol"===typeof Symbol("x");$jscomp.TRUST_ES6_POLYFILLS=!$jscomp.ISOLATE_POLYFILLS||$jscomp.IS_SYMBOL_NATIVE;$jscomp.polyfills={};
$jscomp.propertyToPolyfillSymbol={};$jscomp.POLYFILL_PREFIX="$jscp$";var $jscomp$lookupPolyfilledValue=function(a,c){var e=$jscomp.propertyToPolyfillSymbol[c];if(null==e)return a[c];e=a[e];return void 0!==e?e:a[c]};$jscomp.polyfill=function(a,c,e,h){c&&($jscomp.ISOLATE_POLYFILLS?$jscomp.polyfillIsolated(a,c,e,h):$jscomp.polyfillUnisolated(a,c,e,h))};
$jscomp.polyfillUnisolated=function(a,c,e,h){e=$jscomp.global;a=a.split(".");for(h=0;h<a.length-1;h++){var p=a[h];if(!(p in e))return;e=e[p]}a=a[a.length-1];h=e[a];c=c(h);c!=h&&null!=c&&$jscomp.defineProperty(e,a,{configurable:!0,writable:!0,value:c})};
$jscomp.polyfillIsolated=function(a,c,e,h){var p=a.split(".");a=1===p.length;h=p[0];h=!a&&h in $jscomp.polyfills?$jscomp.polyfills:$jscomp.global;for(var w=0;w<p.length-1;w++){var y=p[w];if(!(y in h))return;h=h[y]}p=p[p.length-1];e=$jscomp.IS_SYMBOL_NATIVE&&"es6"===e?h[p]:null;c=c(e);null!=c&&(a?$jscomp.defineProperty($jscomp.polyfills,p,{configurable:!0,writable:!0,value:c}):c!==e&&(void 0===$jscomp.propertyToPolyfillSymbol[p]&&(e=1E9*Math.random()>>>0,$jscomp.propertyToPolyfillSymbol[p]=$jscomp.IS_SYMBOL_NATIVE?
$jscomp.global.Symbol(p):$jscomp.POLYFILL_PREFIX+e+"$"+p),$jscomp.defineProperty(h,$jscomp.propertyToPolyfillSymbol[p],{configurable:!0,writable:!0,value:c})))};$jscomp.arrayIteratorImpl=function(a){var c=0;return function(){return c<a.length?{done:!1,value:a[c++]}:{done:!0}}};$jscomp.arrayIterator=function(a){return{next:$jscomp.arrayIteratorImpl(a)}};$jscomp.makeIterator=function(a){var c="undefined"!=typeof Symbol&&Symbol.iterator&&a[Symbol.iterator];return c?c.call(a):$jscomp.arrayIterator(a)};
$jscomp.polyfill("Promise.allSettled",function(a){function c(h){return{status:"fulfilled",value:h}}function e(h){return{status:"rejected",reason:h}}return a?a:function(h){var p=this;h=Array.from(h,function(w){return p.resolve(w).then(c,e)});return p.all(h)}},"es_2020","es3");
vBulletin.precache("add_tags edit_tags error error_adding_search_tips_code_x error_adding_tags_code_x error_fetching_tags invalid_server_response_please_try_again invalid_x_tag_length loading none popular_tags_cloud tag_cloud unable_to_load_tag_editor unable_to_save_tags you_may_add_one_more_tag you_may_add_x_more_tags you_may_not_add_any_more_tags save post".split(" "),["tagforcelower","tagmaxlen","tagminlen"]);
(function(a,c,e,h,p){function w(f,g=!1){function m(b){b=a(this);var d=b.parent();!d.hasClass("added")&&F(b.text())&&(d.addClass("added"),n.is(":visible")&&n[0].focus());return!1}function k(b,d,q,G={}){let Q=b.data("node-id"),R=p.getContainingEditor(b),S=H(x.data("type")||"nodes"),I;I=d.suggested?Promise.resolve(d.suggested):R?T(R.getData()):X(Q);Promise.allSettled([I,S]).then(()=>{h.openModalDialog(q,{title:"add_tags",dialogClass:"tag-editor-dialog-container",onOpen:function(){t.clearElements();var U=
x.find(".tag-input").val();U?J(U.split(",").map(Y=>Y.trim())):B&&!n.attr("placeholder")&&n.attr("placeholder",B);q.find(".save-tag-btn").text(e.get(G.saveButtonPhrase||"save"));C();Z(Q);K(S,u,"popular");K(I,u,"suggested")},onAfterClose:()=>{x.data("autocomplete-instance").close()}})});b.data("tag-dialog",q);q.data("parent",b.closest("form, .search-controls-tags, .form_row"));q.off("vb-tag-dialog-save vb-tag-dialog-cancel")}var l=this,r=!1,v=!1,z=c.options.get("tagmaxlen")||25,aa=c.options.get("tagminlen")||
3,D=0,A=0,L=!1,n=a(f),u=n.closest(".tag-editor-container"),x=n.closest(".tag-editor-wrapper"),t=!1,B=n.attr("placeholder")?n.attr("placeholder"):"",M=B?B.length:10,F=function(b,d){if(!t)return!1;if("undefined"==typeof d||1>d)d=pageData.userid;let q=t.getMinLength();if(b.length<q)return h.error("error",["invalid_x_tag_length",q]),!1;1==c.options.get("tagforcelower")&&(b=b.toLowerCase());b.length>z&&(b=b.substr(0,z));d=t.addElement(b,d);n.val("");C();return d},J=function(b){b.map(d=>F(d))},O=function(){n.attr("size",
M);var b=JShtmlEncode(a.trim(n.val()));if(""==b)return!1;0<N()&&setTimeout(function(){F(b)},10)},N=function(){if(g||0==D&&0==A)return!0;var b=t.countElements(),d=a(t.getElements()).filter(function(q,G){return 0==pageData.userid||G.value==pageData.userid}).length;b=0<D?D-b:A-b;return Math.min(0==A?b:A-d,b)},C=function(){var b=u.find(".you-may-add-text"),d=N();if(!0===d)return!0;if(1<d)var q=["you_may_add_x_more_tags",d];else 1==d?q="you_may_add_one_more_tag":(q="you_may_not_add_any_more_tags",d=0);
b.toggleClass("warning",0==d).html(e.get(q));b=!!d;n.toggle(b);b&&n[0].focus();return d},Z=function(b){g?n[0].focus():E[b]?(D=E[b].maxTags,A=E[b].maxUserTags,L=E[b].canManageTags,C()):(E[b]={},c.AJAX({call:"/ajax/api/tags/getNodeTags",data:{nodeid:b},success:function(d){a.isArray(d.tags)&&(D=parseInt(d.maxtags,10),A=parseInt(d.maxusertags,10),L=d.canmanagetags,E[b]={maxTags:D,maxUserTags:A,canManageTags:L},C())},api_error:a.noop,error:a.noop}))};this.addTag=function(b,d){F(b,d)};this.addTags=function(b){J(b)};
this.setTags=function(b){t&&(t.clearElements(),J(b))};this.removeAllTags=function(){t.clearElements()};this.getTags=function(){return t?t.getLabels():!1};this.getTagEditor=function(){return n};this.getWrapper=function(){return x};this.setSuggested=function(b){this.suggested=b};this.openTagDialog=function(b,d={}){k(b,this,u,d);return u};x.data("initialized")?console.log("Tag Editor is already initialized."):(x.attr("data-initialized",!0),function(){if(0==n.length)return!1;n.attr("maxlength",z);t=new vBulletin_Autocomplete(n,
{apiClass:"Tags",containerClass:" entry-field h-clearfix",placeholderText:B,editorContext:{type:"tags",context:l},minLength:aa,beforeAdd:function(b,d){r=v?!0:!1;return 0==N()?!1:!0},afterAdd:function(b,d){C();n.attr("placeholder","");y(u.find(".tagcloudlink"),u)},afterDelete:function(b,d){r=v?!0:!1;C();n.attr("placeholder",function(){var q=t?t.getLabels():!1;return q&&0!=q.length?"":B});b=u.find(".js-popular-tags .tagcloudlink");0==b.length&&(b=u.find(".popular-tags-link"),b.length&&b.qtip&&(b=b.qtip("api").elements.tooltip.find(".tagcloudlink")));
y(u.find(".tagcloudlink"),u)}});n=t.getInputField();x.data("autocomplete-instance",t)}(),n.offon("keydown",function(b){var d=a(b.target).val().length;a(b.target).attr("size",d>M?d:M);if(13==b.which)return r=v?!0:!1,O(),b.preventDefault(),!1}),n.offon("blur",function(b){v=setTimeout(function(){r||O();v=r=!1},0)}),n.offon("click",function(b){a(b.target).hasClass("tag-input")||(a(".tag-input",a(this)).trigger("focus"),r=v?!0:!1);return!1}),n.each(function(){a(this).closest("form").on("submit",O)}),a(".js-popular-tag-text.inline-tag-cloud .popular-tags-link",
u).offon("click",function(){K(H("nodes"),u,"popular")}),vBulletin.qtip.apply(a(".js-popular-tag-text:not(.inline-tag-cloud) .popular-tags-link",u),"qtip-populartags",{content:{title:{text:e.get("tag_cloud"),button:!1},text:function(b,d){H("nodes").then(q=>{d.set("content.text",'<div class="tag-cloud js-popular-tags">{0}</div>'.format(q||e.get("no_tags_yet")));q=d.elements.tooltip;q.on("click",".js-popular-tags .tagcloudlink label",m);y(q.find(".tagcloudlink"),x)},q=>{d.set("content.text",q.message)});
return e.get("working_ellipsis")}},position:{at:"bottom center",my:"top center",viewport:a(window),effect:!1},show:{event:"click",solo:!0},hide:"unfocus"}),u.on("click",".tagcloudlink label",m))}function y(f,g){if(0<f.length){let m=(g.find(".tag-input").val()||"").split(",").map(k=>k.trim());f.each((k,l)=>{k=a(l);k.toggleClass("added",m.includes(k.data("tag")))})}}function K(f,g,m){let k=g.find(".js-"+m+"-tags");f.then(l=>{let r=g.find(".js-"+m+"-tags-text");!l&&r.is(".inline-tag-cloud")&&(l=e.get("no_tags_yet"));
k.html(l);l&&y(k.find(".tagcloudlink"),g);r.toggle(!!l)},l=>{k.html(l.message)})}async function H(f){return P("tags/fetchTagsForCloud",{type:f,taglevels:5,limit:20,tagsonly:!0})}async function X(f){return P("tags/getSuggestedTagsForNode",{nodeid:f})}async function T(f){return P("editor/getSuggestedTagsForEditorText",{text:f})}async function P(f,g){let m,k,l=(r="")=>{k='<span class="error">{0} {1}</span>'.format(e.get("error_fetching_tags"),r)};await c.AJAX({call:"/ajax/api/"+f,data:g,success:function(r){m=
r.tags.map(v=>'<span class="tagcloudlink" data-tag="{0}"><label class="b-link js-link" tabindex="0">{0}</label></span>'.format(v)).join(", ")},api_error:r=>l(e.get(r[0])),error:()=>l()});if(k)throw Error(k);return m}function ba(f,g){c.AJAX({call:"/ajax/api/tags/updateUserTags",data:{nodeid:f,taglist:g.split(",").filter(m=>m)},success:function(m){let k=a("#content-tags-"+f);k.find(".js-content-tag, .js-content-tag-none").remove();let l=m.tags;l&&0<l.length?a.each(l,function(r,v){var z=a("<span />").addClass("js-content-tag");
a("<a />").attr("href",v.searchurl).html(v.tagtext).appendTo(z);r<l.length-1&&z.append(document.createTextNode(", "));z.appendTo(k)}):a("<span />").addClass("js-content-tag-none").html(e.get("none")).appendTo(k)},error_phrase:"unable_to_save_tags",title_phrase:"edit_tags"})}function ca(f){let g=f.data("node-id");c.AJAX({call:"/ajax/render/tag_editor",data:{nodeid:g,dialogOnly:!0,editPost:!0,editorClass:"js-topic-tag-editor",isAjaxTemplateRenderWithData:!0},success:function(m){function k(){l.dialog("destroy").closest(".tag-editor-wrapper").remove()}
a("body").append(m.template);let l=(new w(".js-topic-tag-editor",!1)).openTagDialog(f);l.on("vb-tag-dialog-cancel",k);l.on("vb-tag-dialog-save",function(r,v){ba(g,v.tagList);k()})},error_phrase:"unable_to_load_tag_editor",title_phrase:"edit_tags"})}function V(f){if(0<a(f).length){let g=new w(f);f=g.getWrapper().find(".add-tag-link");f.data("tageditor",g);f.offon("click",m=>{m.stopPropagation();g.openTagDialog(a(m.currentTarget));return!1})}}let W=c.ensureObj("jsexec.tag_editor",{exec:0});W.exec++;
if(!(1<W.exec)){var E={};c.ensureObj("tagEditor");a(()=>{a(document).offon("click.tage",".tag-editor-container .cancel-tag-btn",function(){a(".tag-editor-container").dialog("close").trigger("vb-tag-dialog-cancel")});a(document).offon("click.tage",".tag-editor-container .save-tag-btn",function(){var f=a(this).closest(".tag-editor-container"),g=f.find(".tag-input").val(),m=g.replace(/,/g,", "),k=f.data("parent");k.find(".tag-list span").text(m);k.find(".tag-input").val(g);k.find(".tag-list").toggleClass("h-hide",
!g);f.dialog("close").trigger("vb-tag-dialog-save",{tagList:g})});a(document).offon("mousedown.tage",".tag-editor-container .autocomplete-container",function(){var f=this;setTimeout(function(){var g=a(".autocompleteHelper:visible",f);0<g.length&&g[0].focus()},10);return!1});V(".js-content-entry-tag-editor");a(document).offon("click.tage",".js-edit-tags",f=>ca(a(f.currentTarget)))});c.tagEditor=a.extend(c.tagEditor,{initEditTagsContent:V,instance:w,promptForTags:function(f){let g=f.find(".add-tag-link"),
m=g.data("tageditor"),k=p.getContainingEditor(g),l=()=>{f.data("tagsdone",!0);f.submit()};if(!m||!k)return!1;T(k.getData()).then(r=>{r?(m.setSuggested(r),m.openTagDialog(g,{saveButtonPhrase:"post"}).on("vb-tag-dialog-save",()=>{l()})):l()},()=>l);return!0}})}})(jQuery,vBulletin,vBulletin.phrase,vBulletin.dialogtools,vBulletin.ckeditor);
;

