<?php
 declare(strict_types=1); namespace SpomkyLabs\Pki\ASN1\Type; use SpomkyLabs\Pki\ASN1\Component\Identifier; trait UniversalClass { public function typeClass(): int { return Identifier::CLASS_UNIVERSAL; } } 