<?php
 declare(strict_types=1); namespace SpomkyLabs\Pki\CryptoTypes\AlgorithmIdentifier\Asymmetric; use SpomkyLabs\Pki\ASN1\Type\UnspecifiedType; use SpomkyLabs\Pki\CryptoTypes\AlgorithmIdentifier\AlgorithmIdentifier; use SpomkyLabs\Pki\CryptoTypes\AlgorithmIdentifier\SpecificAlgorithmIdentifier; use UnexpectedValueException; final class Ed448AlgorithmIdentifier extends RFC8410EdAlgorithmIdentifier { protected function __construct() { parent::__construct(self::OID_ED448); } public static function create(): self { return new self(); } public static function fromASN1Params(?UnspecifiedType $params = null): SpecificAlgorithmIdentifier { if ($params !== null) { throw new UnexpectedValueException('Parameters must be absent.'); } return self::create(); } public function name(): string { return 'id-Ed448'; } public function supportsKeyAlgorithm(AlgorithmIdentifier $algo): bool { return $algo->oid() === self::OID_ED448; } } 