<?php
 declare(strict_types=1); namespace Square\Models; class CardSquareProduct { public const UNKNOWN_SQUARE_PRODUCT = 'UNKNOWN_SQUARE_PRODUCT'; public const CONNECT_API = 'CONNECT_API'; public const DASHBOARD = 'DASHBOARD'; public const REGISTER_CLIENT = 'REGISTER_CLIENT'; public const BUYER_DASHBOARD = 'BUYER_DASHBOARD'; public const WEB = 'WEB'; public const INVOICES = 'INVOICES'; public const GIFT_CARD = 'GIFT_CARD'; public const VIRTUAL_TERMINAL = 'VIRTUAL_TERMINAL'; public const READER_SDK = 'READER_SDK'; public const SQUARE_PROFILE = 'SQUARE_PROFILE'; } 