<?php
 declare(strict_types=1); namespace SpomkyLabs\Pki\X509\Certificate\Extension; use SpomkyLabs\Pki\X509\Certificate\Extension\DistributionPoint\DistributionPoint; final class FreshestCRLExtension extends CRLDistributionPointsExtension { public static function create(bool $critical, DistributionPoint ...$distribution_points): self { return new self(self::OID_FRESHEST_CRL, $critical, ...$distribution_points); } } 