<?php
 declare(strict_types=1); namespace Square\Models; use stdClass; class ResumeSubscriptionResponse implements \JsonSerializable { private $errors; private $subscription; private $actions; public function getErrors(): ?array { return $this->errors; } public function setErrors(?array $errors): void { $this->errors = $errors; } public function getSubscription(): ?Subscription { return $this->subscription; } public function setSubscription(?Subscription $subscription): void { $this->subscription = $subscription; } public function getActions(): ?array { return $this->actions; } public function setActions(?array $actions): void { $this->actions = $actions; } #[\ReturnTypeWillChange] public function jsonSerialize(bool $asArrayWhenEmpty = false) { $json = []; if (isset($this->errors)) { $json['errors'] = $this->errors; } if (isset($this->subscription)) { $json['subscription'] = $this->subscription; } if (isset($this->actions)) { $json['actions'] = $this->actions; } $json = array_filter($json, function ($val) { return $val !== null; }); return (!$asArrayWhenEmpty && empty($json)) ? new stdClass() : $json; } } 