<?php
 namespace Eluceo\iCal\Presentation\Component\Property\Value; final class AppleLocationGeoValue extends GeoValue { public function __toString(): string { return sprintf('geo:%1.6F,%1.6F', number_format($this->geographicPosition->getLatitude(), 6), number_format($this->geographicPosition->getLongitude(), 6), ); } } 