<?php
 declare(strict_types=1); namespace Square\Models; class CatalogObjectType { public const ITEM = 'ITEM'; public const IMAGE = 'IMAGE'; public const CATEGORY = 'CATEGORY'; public const ITEM_VARIATION = 'ITEM_VARIATION'; public const TAX = 'TAX'; public const DISCOUNT = 'DISCOUNT'; public const MODIFIER_LIST = 'MODIFIER_LIST'; public const MODIFIER = 'MODIFIER'; public const PRICING_RULE = 'PRICING_RULE'; public const PRODUCT_SET = 'PRODUCT_SET'; public const TIME_PERIOD = 'TIME_PERIOD'; public const MEASUREMENT_UNIT = 'MEASUREMENT_UNIT'; public const SUBSCRIPTION_PLAN = 'SUBSCRIPTION_PLAN'; public const ITEM_OPTION = 'ITEM_OPTION'; public const ITEM_OPTION_VAL = 'ITEM_OPTION_VAL'; public const CUSTOM_ATTRIBUTE_DEFINITION = 'CUSTOM_ATTRIBUTE_DEFINITION'; public const QUICK_AMOUNTS_SETTINGS = 'QUICK_AMOUNTS_SETTINGS'; } 