<?php
 declare(strict_types=1); namespace Square\Models; class LoyaltyEventType { public const ACCUMULATE_POINTS = 'ACCUMULATE_POINTS'; public const CREATE_REWARD = 'CREATE_REWARD'; public const REDEEM_REWARD = 'REDEEM_REWARD'; public const DELETE_REWARD = 'DELETE_REWARD'; public const ADJUST_POINTS = 'ADJUST_POINTS'; public const EXPIRE_POINTS = 'EXPIRE_POINTS'; public const OTHER = 'OTHER'; } 