/*
Copyright (c) 2003-2013, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.html or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'smiley', 'en', {
	options: 'Smiley Options',
	title: 'Insert a Smiley',
	toolbar: 'Smiley'
});
