<?php
 namespace Facebook; class GraphPage extends GraphObject { public function getId() { return $this->getProperty('id'); } public function getCategory() { return $this->getProperty('category'); } public function getName() { return $this->getProperty('name'); } }