<?php
 declare(strict_types=1); namespace Square\Models; use stdClass; class CustomerTaxIds implements \JsonSerializable { private $euVat; public function getEuVat(): ?string { return $this->euVat; } public function setEuVat(?string $euVat): void { $this->euVat = $euVat; } #[\ReturnTypeWillChange] public function jsonSerialize(bool $asArrayWhenEmpty = false) { $json = []; if (isset($this->euVat)) { $json['eu_vat'] = $this->euVat; } $json = array_filter($json, function ($val) { return $val !== null; }); return (!$asArrayWhenEmpty && empty($json)) ? new stdClass() : $json; } } 