<?php
 declare(strict_types=1); namespace Square; interface ConfigurationInterface { public function getTimeout(): int; public function shouldEnableRetries(): bool; public function getNumberOfRetries(): int; public function getRetryInterval(): float; public function getBackOffFactor(): float; public function getMaximumRetryWaitTime(): int; public function shouldRetryOnTimeout(): bool; public function getHttpStatusCodesToRetry(): array; public function getHttpMethodsToRetry(): array; public function getSquareVersion(): string; public function getAdditionalHeaders(): array; public function getUserAgentDetail(): string; public function getEnvironment(): string; public function getCustomUrl(): string; public function getBearerAuthCredentials(): ?BearerAuthCredentials; public function getBaseUri(string $server = Server::DEFAULT_): string; } 