<?php
 declare(strict_types=1); namespace SpomkyLabs\Pki\X509\Certificate; use SpomkyLabs\Pki\ASN1\Type\Primitive\BitString; final class UniqueIdentifier { private function __construct( private readonly BitString $uid ) { } public static function create(BitString $uid): self { return new self($uid); } public static function fromASN1(BitString $bs): self { return self::create($bs); } public static function fromString(string $str): self { return self::create(BitString::create($str)); } public function string(): string { return $this->uid->string(); } public function bitString(): BitString { return $this->uid; } public function toASN1(): BitString { return $this->uid; } } 