<?php
 declare(strict_types=1); namespace SpomkyLabs\Pki\CryptoTypes\Signature; use SpomkyLabs\Pki\ASN1\Type\Primitive\BitString; use function strval; final class RSASignature extends Signature { private ?string $_signature = null; public static function fromSignatureString(string $signature): Signature { $obj = new self(); $obj->_signature = strval($signature); return $obj; } public function bitString(): BitString { return BitString::create($this->_signature); } } 