<?php if (!defined('VB_ENTRY')) die('Access denied.'); abstract class vB_Notification_Content_GroupByParentid extends vB_Notification_Content { const GROUP_CHILDREN = true; const TYPENAME = 'GroupByParentid'; final protected static function defineUnique($notificationData, $skipValidation) { $nodeid = $notificationData['sentbynodeid']; if ($skipValidation) { $node = array(); $node['parentid'] = (int) $notificationData['parentid']; } else { $node = vB_Library::instance('node')->getNodeBare($nodeid); if (!isset($node['parentid'])) { throw new Exception("Missing data! node.parentid"); } } return array('parentid' => (int) $node['parentid']); } } 