<?php
 $PHPMAILER_LANG['authenticate'] = 'خطای SMTP: احراز هویت با شکست مواجه شد.'; $PHPMAILER_LANG['connect_host'] = 'خطای SMTP: اتصال به سرور SMTP برقرار نشد.'; $PHPMAILER_LANG['data_not_accepted'] = 'خطای SMTP: داده‌ها نا‌درست هستند.'; $PHPMAILER_LANG['empty_message'] = 'بخش متن پیام خالی است.'; $PHPMAILER_LANG['encoding'] = 'کد‌گذاری نا‌شناخته: '; $PHPMAILER_LANG['execute'] = 'امکان اجرا وجود ندارد: '; $PHPMAILER_LANG['file_access'] = 'امکان دسترسی به فایل وجود ندارد: '; $PHPMAILER_LANG['file_open'] = 'خطای File: امکان بازکردن فایل وجود ندارد: '; $PHPMAILER_LANG['from_failed'] = 'آدرس فرستنده اشتباه است: '; $PHPMAILER_LANG['instantiate'] = 'امکان معرفی تابع ایمیل وجود ندارد.'; $PHPMAILER_LANG['invalid_address'] = 'آدرس ایمیل معتبر نیست: '; $PHPMAILER_LANG['mailer_not_supported'] = ' mailer پشتیبانی نمی‌شود.'; $PHPMAILER_LANG['provide_address'] = 'باید حداقل یک آدرس گیرنده وارد کنید.'; $PHPMAILER_LANG['recipients_failed'] = 'خطای SMTP: ارسال به آدرس گیرنده با خطا مواجه شد: '; $PHPMAILER_LANG['signing'] = 'خطا در امضا: '; $PHPMAILER_LANG['smtp_connect_failed'] = 'خطا در اتصال به SMTP.'; $PHPMAILER_LANG['smtp_error'] = 'خطا در SMTP Server: '; $PHPMAILER_LANG['variable_set'] = 'امکان ارسال یا ارسال مجدد متغیر‌ها وجود ندارد: '; $PHPMAILER_LANG['extension_missing'] = 'افزونه موجود نیست: '; 