<?php
 declare(strict_types=1); namespace Square\Models; use stdClass; class OrderFulfillmentPickupDetailsCurbsidePickupDetails implements \JsonSerializable { private $curbsideDetails; private $buyerArrivedAt; public function getCurbsideDetails(): ?string { return $this->curbsideDetails; } public function setCurbsideDetails(?string $curbsideDetails): void { $this->curbsideDetails = $curbsideDetails; } public function getBuyerArrivedAt(): ?string { return $this->buyerArrivedAt; } public function setBuyerArrivedAt(?string $buyerArrivedAt): void { $this->buyerArrivedAt = $buyerArrivedAt; } #[\ReturnTypeWillChange] public function jsonSerialize(bool $asArrayWhenEmpty = false) { $json = []; if (isset($this->curbsideDetails)) { $json['curbside_details'] = $this->curbsideDetails; } if (isset($this->buyerArrivedAt)) { $json['buyer_arrived_at'] = $this->buyerArrivedAt; } $json = array_filter($json, function ($val) { return $val !== null; }); return (!$asArrayWhenEmpty && empty($json)) ? new stdClass() : $json; } } 