<?php
 declare(strict_types=1); namespace Square\Models; class LocationCapability { public const CREDIT_CARD_PROCESSING = 'CREDIT_CARD_PROCESSING'; public const AUTOMATIC_TRANSFERS = 'AUTOMATIC_TRANSFERS'; } 