<?php
 declare(strict_types=1); namespace Square\Models; class CatalogQuickAmountType { public const QUICK_AMOUNT_TYPE_MANUAL = 'QUICK_AMOUNT_TYPE_MANUAL'; public const QUICK_AMOUNT_TYPE_AUTO = 'QUICK_AMOUNT_TYPE_AUTO'; } 