<?php
 declare(strict_types=1); namespace Jose\Component\Checker; interface HeaderChecker { public function checkHeader(mixed $value): void; public function supportedHeader(): string; public function protectedHeaderOnly(): bool; } 