<?php
 namespace Stripe\Checkout; class Session extends \Stripe\ApiResource { const OBJECT_NAME = 'checkout.session'; use \Stripe\ApiOperations\All; use \Stripe\ApiOperations\Create; use \Stripe\ApiOperations\NestedResource; use \Stripe\ApiOperations\Retrieve; const BILLING_ADDRESS_COLLECTION_AUTO = 'auto'; const BILLING_ADDRESS_COLLECTION_REQUIRED = 'required'; const CUSTOMER_CREATION_ALWAYS = 'always'; const CUSTOMER_CREATION_IF_REQUIRED = 'if_required'; const MODE_PAYMENT = 'payment'; const MODE_SETUP = 'setup'; const MODE_SUBSCRIPTION = 'subscription'; const PAYMENT_STATUS_NO_PAYMENT_REQUIRED = 'no_payment_required'; const PAYMENT_STATUS_PAID = 'paid'; const PAYMENT_STATUS_UNPAID = 'unpaid'; const STATUS_COMPLETE = 'complete'; const STATUS_EXPIRED = 'expired'; const STATUS_OPEN = 'open'; const SUBMIT_TYPE_AUTO = 'auto'; const SUBMIT_TYPE_BOOK = 'book'; const SUBMIT_TYPE_DONATE = 'donate'; const SUBMIT_TYPE_PAY = 'pay'; public function expire($params = null, $opts = null) { $url = $this->instanceUrl() . '/expire'; list($response, $opts) = $this->_request('post', $url, $params, $opts); $this->refreshFrom($response, $opts); return $this; } const PATH_LINE_ITEMS = '/line_items'; public static function allLineItems($id, $params = null, $opts = null) { return self::_allNestedResources($id, static::PATH_LINE_ITEMS, $params, $opts); } } 