<?php
 declare(strict_types=1); namespace Square\Models; use stdClass; class RetrieveCashDrawerShiftRequest implements \JsonSerializable { private $locationId; public function __construct(string $locationId) { $this->locationId = $locationId; } public function getLocationId(): string { return $this->locationId; } public function setLocationId(string $locationId): void { $this->locationId = $locationId; } #[\ReturnTypeWillChange] public function jsonSerialize(bool $asArrayWhenEmpty = false) { $json = []; $json['location_id'] = $this->locationId; $json = array_filter($json, function ($val) { return $val !== null; }); return (!$asArrayWhenEmpty && empty($json)) ? new stdClass() : $json; } } 