<?php
 declare(strict_types=1); namespace Square\Models; use stdClass; class Employee implements \JsonSerializable { private $id; private $firstName; private $lastName; private $email; private $phoneNumber; private $locationIds; private $status; private $isOwner; private $createdAt; private $updatedAt; public function getId(): ?string { return $this->id; } public function setId(?string $id): void { $this->id = $id; } public function getFirstName(): ?string { return $this->firstName; } public function setFirstName(?string $firstName): void { $this->firstName = $firstName; } public function getLastName(): ?string { return $this->lastName; } public function setLastName(?string $lastName): void { $this->lastName = $lastName; } public function getEmail(): ?string { return $this->email; } public function setEmail(?string $email): void { $this->email = $email; } public function getPhoneNumber(): ?string { return $this->phoneNumber; } public function setPhoneNumber(?string $phoneNumber): void { $this->phoneNumber = $phoneNumber; } public function getLocationIds(): ?array { return $this->locationIds; } public function setLocationIds(?array $locationIds): void { $this->locationIds = $locationIds; } public function getStatus(): ?string { return $this->status; } public function setStatus(?string $status): void { $this->status = $status; } public function getIsOwner(): ?bool { return $this->isOwner; } public function setIsOwner(?bool $isOwner): void { $this->isOwner = $isOwner; } public function getCreatedAt(): ?string { return $this->createdAt; } public function setCreatedAt(?string $createdAt): void { $this->createdAt = $createdAt; } public function getUpdatedAt(): ?string { return $this->updatedAt; } public function setUpdatedAt(?string $updatedAt): void { $this->updatedAt = $updatedAt; } #[\ReturnTypeWillChange] public function jsonSerialize(bool $asArrayWhenEmpty = false) { $json = []; if (isset($this->id)) { $json['id'] = $this->id; } if (isset($this->firstName)) { $json['first_name'] = $this->firstName; } if (isset($this->lastName)) { $json['last_name'] = $this->lastName; } if (isset($this->email)) { $json['email'] = $this->email; } if (isset($this->phoneNumber)) { $json['phone_number'] = $this->phoneNumber; } if (isset($this->locationIds)) { $json['location_ids'] = $this->locationIds; } if (isset($this->status)) { $json['status'] = $this->status; } if (isset($this->isOwner)) { $json['is_owner'] = $this->isOwner; } if (isset($this->createdAt)) { $json['created_at'] = $this->createdAt; } if (isset($this->updatedAt)) { $json['updated_at'] = $this->updatedAt; } $json = array_filter($json, function ($val) { return $val !== null; }); return (!$asArrayWhenEmpty && empty($json)) ? new stdClass() : $json; } } 