/*
Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'image2', 'et', {
	alt: 'Alternatiivne tekst',
	btnUpload: 'Saada serverisse',
	captioned: 'Pealkirjaga pilt',
	captionPlaceholder: 'Pealkiri',
	infoTab: 'Pildi info',
	lockRatio: 'Lukusta kuvasuhe',
	menu: 'Pildi omadused',
	pathName: 'pilt',
	pathNameCaption: 'pealkiri',
	resetSize: 'Lähtesta suurus',
	resizer: 'Suuruse muutmiseks klõpsa ja lohista',
	title: 'Pildi omadused',
	uploadTab: 'Lae üles',
	urlMissing: 'Pildi lähte-URL on puudu.',
	altMissing: 'Alternatiivtekst puudub.'
} );
