<?php
 declare(strict_types=1); namespace Square\Http; class HttpMethod { public const GET = "Get"; public const POST = "Post"; public const PUT = "Put"; public const PATCH = "Patch"; public const DELETE = "Delete"; public const HEAD = "Head"; } 