<?php
 declare(strict_types=1); namespace Jose\Component\Checker; use Jose\Component\Core\JWT; interface TokenTypeSupport { public function retrieveTokenHeaders( JWT $jwt, int $index, array &$protectedHeader, array &$unprotectedHeader ): void; public function supports(JWT $jwt): bool; } 