<?php
 namespace Facebook; class FacebookJavaScriptLoginHelper extends FacebookSignedRequestFromInputHelper { public function getRawSignedRequest() { return $this->getRawSignedRequestFromCookie(); } } 