<?php
 declare(strict_types=1); namespace SpomkyLabs\Pki\CryptoTypes\AlgorithmIdentifier\Feature; use SpomkyLabs\Pki\CryptoTypes\AlgorithmIdentifier\AlgorithmIdentifier; interface SignatureAlgorithmIdentifier extends AlgorithmIdentifierType { public function supportsKeyAlgorithm(AlgorithmIdentifier $algo): bool; } 