<?php
 class vB_dB_Query_InsertIgnore extends vB_dB_Query_TableQuery { public function execSQL() : mixed { if (!$this->data_loaded) { return false; } $querystring = $this->buildQuery($this->params); if (!$querystring) { return [false]; } $this->logQuery($querystring); return $this->doQuery($querystring); } protected function buildQuery(array $values) : string { $queryBuilder = self::$queryBuilders[$this->db_type]; $params = $this->extractParamsFromValues($values); return $queryBuilder->makeInsertQuery($this->queryid, true, $values, $this->structure['forcetext'] ?? []); } protected function doQuery(string $querystring) : mixed { $results = []; try { $this->db->query_write($querystring); $this->error = $this->db->error(); $results[] = $this->db->insert_id(); } catch (Exception $e) { $results[] = false; } return $results; } } 