<?php
 declare(strict_types=1); namespace Square\Models; class DisputeReason { public const AMOUNT_DIFFERS = 'AMOUNT_DIFFERS'; public const CANCELLED = 'CANCELLED'; public const DUPLICATE = 'DUPLICATE'; public const NO_KNOWLEDGE = 'NO_KNOWLEDGE'; public const NOT_AS_DESCRIBED = 'NOT_AS_DESCRIBED'; public const NOT_RECEIVED = 'NOT_RECEIVED'; public const PAID_BY_OTHER_MEANS = 'PAID_BY_OTHER_MEANS'; public const CUSTOMER_REQUESTS_CREDIT = 'CUSTOMER_REQUESTS_CREDIT'; public const EMV_LIABILITY_SHIFT = 'EMV_LIABILITY_SHIFT'; } 