<?php
 declare(strict_types=1); namespace Shopify\Webhooks; final class RegisterResponse { private readonly bool $success; private $body; public function __construct(bool $success, $body) { $this->success = $success; $this->body = $body; } public function isSuccess(): bool { return $this->success; } public function getBody() { return $this->body; } } 