<?php
 declare(strict_types=1); namespace Square\Models; use stdClass; class SearchVendorsRequestFilter implements \JsonSerializable { private $name; private $status; public function getName(): ?array { return $this->name; } public function setName(?array $name): void { $this->name = $name; } public function getStatus(): ?array { return $this->status; } public function setStatus(?array $status): void { $this->status = $status; } #[\ReturnTypeWillChange] public function jsonSerialize(bool $asArrayWhenEmpty = false) { $json = []; if (isset($this->name)) { $json['name'] = $this->name; } if (isset($this->status)) { $json['status'] = $this->status; } $json = array_filter($json, function ($val) { return $val !== null; }); return (!$asArrayWhenEmpty && empty($json)) ? new stdClass() : $json; } } 