<?php
 declare(strict_types=1); namespace Square\Models; class SubscriptionEventInfoCode { public const LOCATION_NOT_ACTIVE = 'LOCATION_NOT_ACTIVE'; public const LOCATION_CANNOT_ACCEPT_PAYMENT = 'LOCATION_CANNOT_ACCEPT_PAYMENT'; public const CUSTOMER_DELETED = 'CUSTOMER_DELETED'; public const CUSTOMER_NO_EMAIL = 'CUSTOMER_NO_EMAIL'; public const CUSTOMER_NO_NAME = 'CUSTOMER_NO_NAME'; public const USER_PROVIDED = 'USER_PROVIDED'; } 