<?php
 declare(strict_types=1); namespace Square\Models; class DestinationType { public const BANK_ACCOUNT = 'BANK_ACCOUNT'; public const CARD = 'CARD'; public const SQUARE_BALANCE = 'SQUARE_BALANCE'; public const SQUARE_STORED_BALANCE = 'SQUARE_STORED_BALANCE'; } 