<?php
 declare(strict_types=1); namespace Square\Models; use stdClass; class LoyaltyEventLoyaltyAccountFilter implements \JsonSerializable { private $loyaltyAccountId; public function __construct(string $loyaltyAccountId) { $this->loyaltyAccountId = $loyaltyAccountId; } public function getLoyaltyAccountId(): string { return $this->loyaltyAccountId; } public function setLoyaltyAccountId(string $loyaltyAccountId): void { $this->loyaltyAccountId = $loyaltyAccountId; } #[\ReturnTypeWillChange] public function jsonSerialize(bool $asArrayWhenEmpty = false) { $json = []; $json['loyalty_account_id'] = $this->loyaltyAccountId; $json = array_filter($json, function ($val) { return $val !== null; }); return (!$asArrayWhenEmpty && empty($json)) ? new stdClass() : $json; } } 