<?php
 declare(strict_types=1); namespace Square\Models; class SubscriptionStatus { public const PENDING = 'PENDING'; public const ACTIVE = 'ACTIVE'; public const CANCELED = 'CANCELED'; public const DEACTIVATED = 'DEACTIVATED'; public const PAUSED = 'PAUSED'; } 