<?php
 declare(strict_types=1); namespace Jose\Component\Checker; use Exception; class InvalidHeaderException extends Exception { public function __construct( string $message, private readonly string $header, private readonly mixed $value ) { parent::__construct($message); } public function getHeader(): string { return $this->header; } public function getValue(): mixed { return $this->value; } } 