<?php
 declare(strict_types=1); namespace Square\Models; class BankAccountStatus { public const VERIFICATION_IN_PROGRESS = 'VERIFICATION_IN_PROGRESS'; public const VERIFIED = 'VERIFIED'; public const DISABLED = 'DISABLED'; } 