<?php if (!defined('VB_ENTRY')) die('Access denied.'); class vB_Exception_NodePermission extends vB_Exception_Api { private $nodeid; public function __construct($nodeid, $nodetype = "", $user = "") { if (is_numeric($nodeid)) { $this->nodeid = $nodeid; if (!$nodetype) { $nodetype = 'node'; } if ($user) { parent::__construct('node_permission_user', array($nodeid, $nodetype, $user)); } else { parent::__construct('node_permission', array($nodeid, $nodetype)); } } else { $this->nodeid = 0; parent::__construct('node_permission_section', array($nodeid)); } } public function getNodeId() { return $this->nodeid; } } 