<?php
 declare(strict_types=1); namespace Square\Models; use stdClass; class WageSetting implements \JsonSerializable { private $teamMemberId; private $jobAssignments; private $isOvertimeExempt; private $version; private $createdAt; private $updatedAt; public function getTeamMemberId(): ?string { return $this->teamMemberId; } public function setTeamMemberId(?string $teamMemberId): void { $this->teamMemberId = $teamMemberId; } public function getJobAssignments(): ?array { return $this->jobAssignments; } public function setJobAssignments(?array $jobAssignments): void { $this->jobAssignments = $jobAssignments; } public function getIsOvertimeExempt(): ?bool { return $this->isOvertimeExempt; } public function setIsOvertimeExempt(?bool $isOvertimeExempt): void { $this->isOvertimeExempt = $isOvertimeExempt; } public function getVersion(): ?int { return $this->version; } public function setVersion(?int $version): void { $this->version = $version; } public function getCreatedAt(): ?string { return $this->createdAt; } public function setCreatedAt(?string $createdAt): void { $this->createdAt = $createdAt; } public function getUpdatedAt(): ?string { return $this->updatedAt; } public function setUpdatedAt(?string $updatedAt): void { $this->updatedAt = $updatedAt; } #[\ReturnTypeWillChange] public function jsonSerialize(bool $asArrayWhenEmpty = false) { $json = []; if (isset($this->teamMemberId)) { $json['team_member_id'] = $this->teamMemberId; } if (isset($this->jobAssignments)) { $json['job_assignments'] = $this->jobAssignments; } if (isset($this->isOvertimeExempt)) { $json['is_overtime_exempt'] = $this->isOvertimeExempt; } if (isset($this->version)) { $json['version'] = $this->version; } if (isset($this->createdAt)) { $json['created_at'] = $this->createdAt; } if (isset($this->updatedAt)) { $json['updated_at'] = $this->updatedAt; } $json = array_filter($json, function ($val) { return $val !== null; }); return (!$asArrayWhenEmpty && empty($json)) ? new stdClass() : $json; } } 