<?php
 declare(strict_types=1); namespace Square\Models; class BusinessAppointmentSettingsBookingLocationType { public const BUSINESS_LOCATION = 'BUSINESS_LOCATION'; public const CUSTOMER_LOCATION = 'CUSTOMER_LOCATION'; public const PHONE = 'PHONE'; } 