<?php
 declare(strict_types=1); namespace SpomkyLabs\Pki\ASN1\Type\Tagged; use SpomkyLabs\Pki\ASN1\Component\Identifier; use SpomkyLabs\Pki\ASN1\Feature\ElementBase; use SpomkyLabs\Pki\ASN1\Type\UnspecifiedType; interface ImplicitTagging extends ElementBase { public function implicit(int $tag, int $class = Identifier::CLASS_UNIVERSAL): UnspecifiedType; } 