<?php
 class vB_dB_Query_Delete extends vB_dB_Query_TableQuery { protected function buildQuery(array $values) : string { $queryBuilder = self::$queryBuilders[$this->db_type]; $params = $this->extractParamsFromValues($values); $where = $this->getWhere($queryBuilder, $values); return $queryBuilder->makeDeleteQuery($this->queryid, $where, $this->sortorder, $this->structure['structure'], $params); } protected function doQuery(string $querystring) : mixed { $this->db->query_write($querystring); $this->error = $this->db->error(); return empty($this->error); } } 