<?php
 $vendorDir = dirname(__DIR__); $baseDir = dirname($vendorDir); return array( 'voku\\' => array($vendorDir . '/voku/portable-ascii/src/voku'), 'SpomkyLabs\\Pki\\' => array($vendorDir . '/spomky-labs/pki-framework/src'), 'Shopify\\' => array($vendorDir . '/shopify/shopify-api/src'), 'Ramsey\\Uuid\\' => array($vendorDir . '/ramsey/uuid/src'), 'Ramsey\\Collection\\' => array($vendorDir . '/ramsey/collection/src'), 'Psr\\Log\\' => array($vendorDir . '/psr/log/src'), 'Psr\\Http\\Message\\' => array($vendorDir . '/psr/http-factory/src', $vendorDir . '/psr/http-message/src'), 'Psr\\Http\\Client\\' => array($vendorDir . '/psr/http-client/src'), 'Psr\\Clock\\' => array($vendorDir . '/psr/clock/src'), 'PHPMailer\\PHPMailer\\' => array($vendorDir . '/phpmailer/phpmailer/src'), 'Minishlink\\WebPush\\' => array($vendorDir . '/minishlink/web-push/src'), 'League\\OAuth2\\Client\\' => array($vendorDir . '/league/oauth2-google/src', $vendorDir . '/league/oauth2-client/src'), 'Krombox\\OAuth2\\Client\\' => array($vendorDir . '/krombox/oauth2-wordpress/src'), 'Jose\\Component\\' => array($vendorDir . '/web-token/jwt-library'), 'GuzzleHttp\\Psr7\\' => array($vendorDir . '/guzzlehttp/psr7/src'), 'GuzzleHttp\\Promise\\' => array($vendorDir . '/guzzlehttp/promises/src'), 'GuzzleHttp\\' => array($vendorDir . '/guzzlehttp/guzzle/src'), 'Greew\\OAuth2\\Client\\Provider\\' => array($vendorDir . '/greew/oauth2-azure-provider/src/Provider'), 'Firebase\\JWT\\' => array($vendorDir . '/firebase/php-jwt/src'), 'Eluceo\\iCal\\' => array($vendorDir . '/eluceo/ical/src'), 'Doctrine\\Inflector\\' => array($vendorDir . '/doctrine/inflector/src'), 'Brick\\Math\\' => array($vendorDir . '/brick/math/src'), 'Base64Url\\' => array($vendorDir . '/spomky-labs/base64url/src'), ); 