<?php
 class vB_Options_Option_Enabledscanner extends vB_Options_Option { protected function validateCustom(array $validation, mixed $rawvalue) : bool|string|array { if (count($rawvalue) == 0) { return true; } $errors = vB_Library::instance('filescan')->validateEnabledScanners($rawvalue); if (!empty($errors)) { $rendered = vB_Library::instance('phrase')->renderPhrases($errors); return ['enabled_filescanners_error_preface', implode("<br/>", $rendered)]; } return true; } } 