<?php
 trait vB_Utility_Trait_NoSerialize { public function __serialize() : array { throw new Exception('Serialization not supported'); } public function __unserialize($serialized) : void { throw new Exception('Serialization not supported'); } } 