<?php
 class vB_Utility_Template_ParserNode_Curly_Urladmincptemp extends vB_Utility_Template_ParserNode_CurlyRuntime { protected static string $function = 'buildUrlAdmincpTemp'; protected static string $noparamerror = 'no_route_specified'; protected static int $maxparams = 1; } 