<?php
 class vB_DataManager_StyleVarColor extends vB_DataManager_StyleVar { protected array $childfields = [ 'color' => [vB_Cleaner::TYPE_STR, vB_DataManager_Constants::REQ_NO, vB_DataManager_Constants::VF_METHOD], 'stylevar_color' => [vB_Cleaner::TYPE_STR, vB_DataManager_Constants::REQ_NO, vB_DataManager_Constants::VF_METHOD, 'verify_value_stylevar'], 'inherit_param_color' => [vB_Cleaner::TYPE_STR, vB_DataManager_Constants::REQ_NO, vB_DataManager_Constants::VF_METHOD, 'verify_value_inherit_param_color'], ]; public $datatype = 'Color'; } 