<?php
 namespace Stripe\Treasury; class Transaction extends \Stripe\ApiResource { const OBJECT_NAME = 'treasury.transaction'; use \Stripe\ApiOperations\All; use \Stripe\ApiOperations\Retrieve; const FLOW_TYPE_CREDIT_REVERSAL = 'credit_reversal'; const FLOW_TYPE_DEBIT_REVERSAL = 'debit_reversal'; const FLOW_TYPE_INBOUND_TRANSFER = 'inbound_transfer'; const FLOW_TYPE_ISSUING_AUTHORIZATION = 'issuing_authorization'; const FLOW_TYPE_OTHER = 'other'; const FLOW_TYPE_OUTBOUND_PAYMENT = 'outbound_payment'; const FLOW_TYPE_OUTBOUND_TRANSFER = 'outbound_transfer'; const FLOW_TYPE_RECEIVED_CREDIT = 'received_credit'; const FLOW_TYPE_RECEIVED_DEBIT = 'received_debit'; const STATUS_OPEN = 'open'; const STATUS_POSTED = 'posted'; const STATUS_VOID = 'void'; } 