<?php
 class vB_DataManager_StyleVarDimension extends vB_DataManager_StyleVar { protected array $childfields = [ 'width' => [vB_Cleaner::TYPE_NUM, vB_DataManager_Constants::REQ_NO], 'height' => [vB_Cleaner::TYPE_NUM, vB_DataManager_Constants::REQ_NO], 'units' => [vB_Cleaner::TYPE_STR, vB_DataManager_Constants::REQ_NO, vB_DataManager_Constants::VF_METHOD, 'verify_units'], 'stylevar_width' => [vB_Cleaner::TYPE_STR, vB_DataManager_Constants::REQ_NO, vB_DataManager_Constants::VF_METHOD, 'verify_value_stylevar'], 'stylevar_height' => [vB_Cleaner::TYPE_STR, vB_DataManager_Constants::REQ_NO, vB_DataManager_Constants::VF_METHOD, 'verify_value_stylevar'], 'stylevar_units' => [vB_Cleaner::TYPE_STR, vB_DataManager_Constants::REQ_NO, vB_DataManager_Constants::VF_METHOD, 'verify_value_stylevar'], ]; public $datatype = 'Dimension'; } 