<?php
 namespace Facebook\HttpClients; interface FacebookHttpable { public function addRequestHeader($key, $value); public function getResponseHeaders(); public function getResponseHttpStatusCode(); public function send($url, $method = 'GET', $parameters = array()); } 