<?php
 declare(strict_types=1); namespace Ramsey\Uuid\Codec; use Ramsey\Uuid\UuidInterface; interface CodecInterface { public function encode(UuidInterface $uuid): string; public function encodeBinary(UuidInterface $uuid): string; public function decode(string $encodedUuid): UuidInterface; public function decodeBytes(string $bytes): UuidInterface; } 