/*
Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'image2', 'lv', {
	alt: 'Alternatīvais teksts',
	btnUpload: 'Nosūtīt serverim',
	captioned: 'Attēls ar parakstu',
	captionPlaceholder: 'Paraksts',
	infoTab: 'Informācija par attēlu',
	lockRatio: 'Nemainīga Augstuma/Platuma attiecība',
	menu: 'Attēla īpašības',
	pathName: 'Attēls',
	pathNameCaption: 'paraksts',
	resetSize: 'Atjaunot sākotnējo izmēru',
	resizer: 'Noklikšķini un pavelc lai mērogotu',
	title: 'Attēla īpašības',
	uploadTab: 'Augšupielādēt',
	urlMissing: 'Trūkst attēla atrašanās adrese.',
	altMissing: 'Trūkst alternatīvais teksts'
} );
