/*
 =======================================================================*\
|| ###################################################################### ||
|| # vBulletin 6.2.3
|| # ------------------------------------------------------------------ # ||
|| # Copyright 2000-2026 MH Sub I, LLC dba vBulletin. All Rights Reserved.  # ||
|| # This file may not be redistributed in whole or significant part.   # ||
|| # ----------------- VBULLETIN IS NOT FREE SOFTWARE ----------------- # ||
|| # http://www.vbulletin.com | http://www.vbulletin.com/license.html   # ||
|| ###################################################################### ||
\*========================================================================*/
(function(a){a(()=>{vBAdmin.initJumpControl("inf",{editlevel:"admincp/admininfraction.php?do=editlevel&infractionlevelid={id}",killlevel:"admincp/admininfraction.php?do=removelevel&infractionlevelid={id}"});vBAdmin.initJumpControl("infg",{editgroup:"admincp/admininfraction.php?do=editgroup&infractiongroupid={id}",killgroup:"admincp/admininfraction.php?do=removegroup&infractiongroupid={id}"});vBAdmin.initJumpControl("ban",{editban:"admincp/admininfraction.php?do=editbangroup&infractionbanid={id}",
killban:"admincp/admininfraction.php?do=removebangroup&infractionbanid={id}"})})})(jQuery);
