<?php
 declare(strict_types=1); namespace Square\Models; class BookingStatus { public const PENDING = 'PENDING'; public const CANCELLED_BY_CUSTOMER = 'CANCELLED_BY_CUSTOMER'; public const CANCELLED_BY_SELLER = 'CANCELLED_BY_SELLER'; public const DECLINED = 'DECLINED'; public const ACCEPTED = 'ACCEPTED'; public const NO_SHOW = 'NO_SHOW'; } 