<?php
 declare(strict_types=1); namespace Square\Models; class BusinessBookingProfileCustomerTimezoneChoice { public const BUSINESS_LOCATION_TIMEZONE = 'BUSINESS_LOCATION_TIMEZONE'; public const CUSTOMER_CHOICE = 'CUSTOMER_CHOICE'; } 