<?php
 declare(strict_types=1); namespace Square\Models; class OrderLineItemDiscountType { public const UNKNOWN_DISCOUNT = 'UNKNOWN_DISCOUNT'; public const FIXED_PERCENTAGE = 'FIXED_PERCENTAGE'; public const FIXED_AMOUNT = 'FIXED_AMOUNT'; public const VARIABLE_PERCENTAGE = 'VARIABLE_PERCENTAGE'; public const VARIABLE_AMOUNT = 'VARIABLE_AMOUNT'; } 