<?php
 namespace Stripe\Util; class CaseInsensitiveArray implements \ArrayAccess, \Countable, \IteratorAggregate { private $container = []; public function __construct($initial_array = []) { $this->container = \array_change_key_case($initial_array, \CASE_LOWER); } #[\ReturnTypeWillChange] public function count() { return \count($this->container); } #[\ReturnTypeWillChange] public function getIterator() { return new \ArrayIterator($this->container); } #[\ReturnTypeWillChange] public function offsetSet($offset, $value) { $offset = static::maybeLowercase($offset); if (null === $offset) { $this->container[] = $value; } else { $this->container[$offset] = $value; } } #[\ReturnTypeWillChange] public function offsetExists($offset) { $offset = static::maybeLowercase($offset); return isset($this->container[$offset]); } #[\ReturnTypeWillChange] public function offsetUnset($offset) { $offset = static::maybeLowercase($offset); unset($this->container[$offset]); } #[\ReturnTypeWillChange] public function offsetGet($offset) { $offset = static::maybeLowercase($offset); return isset($this->container[$offset]) ? $this->container[$offset] : null; } private static function maybeLowercase($v) { if (\is_string($v)) { return \strtolower($v); } return $v; } } 