<?php
 declare(strict_types=1); namespace Square\Models; use stdClass; class BatchDeleteCatalogObjectsRequest implements \JsonSerializable { private $objectIds; public function getObjectIds(): ?array { return $this->objectIds; } public function setObjectIds(?array $objectIds): void { $this->objectIds = $objectIds; } #[\ReturnTypeWillChange] public function jsonSerialize(bool $asArrayWhenEmpty = false) { $json = []; if (isset($this->objectIds)) { $json['object_ids'] = $this->objectIds; } $json = array_filter($json, function ($val) { return $val !== null; }); return (!$asArrayWhenEmpty && empty($json)) ? new stdClass() : $json; } } 