<?php
 declare(strict_types=1); namespace GuzzleHttp\Promise; class AggregateException extends RejectionException { public function __construct(string $msg, array $reasons) { parent::__construct( $reasons, sprintf('%s; %d rejected promises', $msg, count($reasons)) ); } } 