<?php
 declare(strict_types=1); namespace Square\Http; class HttpContext { private $request = null; private $response = null; public function __construct(HttpRequest $request, HttpResponse $response) { $this->request = $request; $this->response = $response; } public function getRequest(): HttpRequest { return $this->request; } public function getResponse(): HttpResponse { return $this->response; } } 