<?php
 class vB_DataManager_StyleVarNumeric extends vB_DataManager_StyleVar { protected array $childfields = [ 'numeric' => [vB_Cleaner::TYPE_NUM, vB_DataManager_Constants::REQ_NO], 'stylevar_numeric' => [vB_Cleaner::TYPE_STR, vB_DataManager_Constants::REQ_NO, vB_DataManager_Constants::VF_METHOD, 'verify_value_stylevar'], ]; public $datatype = 'Numeric'; } 