<?php
 namespace League\OAuth2\Client\Token; use JsonSerializable; use ReturnTypeWillChange; use RuntimeException; interface AccessTokenInterface extends JsonSerializable { public function getToken(); public function getRefreshToken(); public function getExpires(); public function hasExpired(); public function getValues(); public function __toString(); #[ReturnTypeWillChange] public function jsonSerialize(); } 