<?php
 namespace Stripe\Terminal; class Reader extends \Stripe\ApiResource { const OBJECT_NAME = 'terminal.reader'; use \Stripe\ApiOperations\All; use \Stripe\ApiOperations\Create; use \Stripe\ApiOperations\Delete; use \Stripe\ApiOperations\Retrieve; use \Stripe\ApiOperations\Update; public function cancelAction($params = null, $opts = null) { $url = $this->instanceUrl() . '/cancel_action'; list($response, $opts) = $this->_request('post', $url, $params, $opts); $this->refreshFrom($response, $opts); return $this; } public function processPaymentIntent($params = null, $opts = null) { $url = $this->instanceUrl() . '/process_payment_intent'; list($response, $opts) = $this->_request('post', $url, $params, $opts); $this->refreshFrom($response, $opts); return $this; } public function processSetupIntent($params = null, $opts = null) { $url = $this->instanceUrl() . '/process_setup_intent'; list($response, $opts) = $this->_request('post', $url, $params, $opts); $this->refreshFrom($response, $opts); return $this; } public function setReaderDisplay($params = null, $opts = null) { $url = $this->instanceUrl() . '/set_reader_display'; list($response, $opts) = $this->_request('post', $url, $params, $opts); $this->refreshFrom($response, $opts); return $this; } } 