<?php
 declare(strict_types=1); namespace Square\Models; use stdClass; class BulkUpsertCustomerCustomAttributesRequest implements \JsonSerializable { private $values; public function __construct(array $values) { $this->values = $values; } public function getValues(): array { return $this->values; } public function setValues(array $values): void { $this->values = $values; } #[\ReturnTypeWillChange] public function jsonSerialize(bool $asArrayWhenEmpty = false) { $json = []; $json['values'] = $this->values; $json = array_filter($json, function ($val) { return $val !== null; }); return (!$asArrayWhenEmpty && empty($json)) ? new stdClass() : $json; } } 