<?php
 declare(strict_types=1); namespace Square\Models; use stdClass; class CashDrawerShiftEvent implements \JsonSerializable { private $id; private $employeeId; private $eventType; private $eventMoney; private $createdAt; private $description; public function getId(): ?string { return $this->id; } public function setId(?string $id): void { $this->id = $id; } public function getEmployeeId(): ?string { return $this->employeeId; } public function setEmployeeId(?string $employeeId): void { $this->employeeId = $employeeId; } public function getEventType(): ?string { return $this->eventType; } public function setEventType(?string $eventType): void { $this->eventType = $eventType; } public function getEventMoney(): ?Money { return $this->eventMoney; } public function setEventMoney(?Money $eventMoney): void { $this->eventMoney = $eventMoney; } public function getCreatedAt(): ?string { return $this->createdAt; } public function setCreatedAt(?string $createdAt): void { $this->createdAt = $createdAt; } public function getDescription(): ?string { return $this->description; } public function setDescription(?string $description): void { $this->description = $description; } #[\ReturnTypeWillChange] public function jsonSerialize(bool $asArrayWhenEmpty = false) { $json = []; if (isset($this->id)) { $json['id'] = $this->id; } if (isset($this->employeeId)) { $json['employee_id'] = $this->employeeId; } if (isset($this->eventType)) { $json['event_type'] = $this->eventType; } if (isset($this->eventMoney)) { $json['event_money'] = $this->eventMoney; } if (isset($this->createdAt)) { $json['created_at'] = $this->createdAt; } if (isset($this->description)) { $json['description'] = $this->description; } $json = array_filter($json, function ($val) { return $val !== null; }); return (!$asArrayWhenEmpty && empty($json)) ? new stdClass() : $json; } } 