<?php
 declare(strict_types=1); namespace Square\Models; class MeasurementUnitTime { public const GENERIC_MILLISECOND = 'GENERIC_MILLISECOND'; public const GENERIC_SECOND = 'GENERIC_SECOND'; public const GENERIC_MINUTE = 'GENERIC_MINUTE'; public const GENERIC_HOUR = 'GENERIC_HOUR'; public const GENERIC_DAY = 'GENERIC_DAY'; } 