<?php
 declare(strict_types=1); namespace Jose\Component\Encryption\Algorithm\KeyEncryption; use Jose\Component\Core\JWK; use Jose\Component\Encryption\Algorithm\KeyEncryptionAlgorithm; interface KeyAgreementWithKeyWrapping extends KeyEncryptionAlgorithm { public function wrapAgreementKey( JWK $recipientKey, ?JWK $senderKey, string $cek, int $encryption_key_length, array $complete_header, array &$additional_header_values ): string; public function unwrapAgreementKey( JWK $recipientKey, ?JWK $senderKey, string $encrypted_cek, int $encryption_key_length, array $complete_header ): string; } 