<?php
 declare(strict_types=1); namespace Jose\Component\Encryption\Serializer; use Jose\Component\Encryption\JWE; interface JWESerializer { public function name(): string; public function displayName(): string; public function serialize(JWE $jws, ?int $recipientIndex = null): string; public function unserialize(string $input): JWE; } 