<?php
 declare(strict_types=1); namespace Square\Models; class InvoiceAutomaticPaymentSource { public const NONE = 'NONE'; public const CARD_ON_FILE = 'CARD_ON_FILE'; public const BANK_ON_FILE = 'BANK_ON_FILE'; } 