<?php
 namespace Stripe\Service; class EphemeralKeyService extends \Stripe\Service\AbstractService { public function delete($id, $params = null, $opts = null) { return $this->request('delete', $this->buildPath('/v1/ephemeral_keys/%s', $id), $params, $opts); } public function create($params = null, $opts = null) { if (!$opts || !isset($opts['stripe_version'])) { throw new \Stripe\Exception\InvalidArgumentException('stripe_version must be specified to create an ephemeral key'); } return $this->request('post', '/v1/ephemeral_keys', $params, $opts); } } 