<?php
 declare(strict_types=1); namespace Shopify; class ApiVersion { public const UNSTABLE = "unstable"; public const APRIL_2022 = "2022-04"; public const JULY_2022 = "2022-07"; public const OCTOBER_2022 = "2022-10"; public const JANUARY_2023 = "2023-01"; public const APRIL_2023 = "2023-04"; public const JULY_2023 = "2023-07"; public const OCTOBER_2023 = "2023-10"; public const JANUARY_2024 = "2024-01"; public const APRIL_2024 = "2024-04"; public const JULY_2024 = "2024-07"; public const OCTOBER_2024 = "2024-10"; public const JANUARY_2025 = "2025-01"; public const APRIL_2025 = "2025-04"; public const JULY_2025 = "2025-07"; public const OCTOBER_2025 = "2025-10"; } 