<?php
 declare(strict_types=1); namespace Square\Models; class GiftCardActivityClearBalanceReason { public const SUSPICIOUS_ACTIVITY = 'SUSPICIOUS_ACTIVITY'; public const REUSE_GIFTCARD = 'REUSE_GIFTCARD'; public const UNKNOWN_REASON = 'UNKNOWN_REASON'; } 