<?php
 declare(strict_types=1); namespace SpomkyLabs\Pki\CryptoTypes\AlgorithmIdentifier\Cipher; abstract class BlockCipherAlgorithmIdentifier extends CipherAlgorithmIdentifier { abstract public function blockSize(): int; } 