<?php
 namespace Eluceo\iCal\Domain\Collection; use Eluceo\iCal\Domain\Entity\Event; use Iterator; use IteratorAggregate; abstract class Events implements IteratorAggregate { abstract public function getIterator(): Iterator; abstract public function addEvent(Event $event): void; } 