/*
 =======================================================================*\
|| ###################################################################### ||
|| # vBulletin 6.2.3
|| # ------------------------------------------------------------------ # ||
|| # Copyright 2000-2026 MH Sub I, LLC dba vBulletin. All Rights Reserved.  # ||
|| # This file may not be redistributed in whole or significant part.   # ||
|| # ----------------- VBULLETIN IS NOT FREE SOFTWARE ----------------- # ||
|| # http://www.vbulletin.com | http://www.vbulletin.com/license.html   # ||
|| ###################################################################### ||
\*========================================================================*/
var $jscomp=$jscomp||{};$jscomp.scope={};$jscomp.ASSUME_ES5=!1;$jscomp.ASSUME_NO_NATIVE_MAP=!1;$jscomp.ASSUME_NO_NATIVE_SET=!1;$jscomp.SIMPLE_FROUND_POLYFILL=!1;$jscomp.ISOLATE_POLYFILLS=!1;$jscomp.FORCE_POLYFILL_PROMISE=!1;$jscomp.FORCE_POLYFILL_PROMISE_WHEN_NO_UNHANDLED_REJECTION=!1;$jscomp.defineProperty=$jscomp.ASSUME_ES5||"function"==typeof Object.defineProperties?Object.defineProperty:function(a,f,e){if(a==Array.prototype||a==Object.prototype)return a;a[f]=e.value;return a};
$jscomp.getGlobal=function(a){a=["object"==typeof globalThis&&globalThis,a,"object"==typeof window&&window,"object"==typeof self&&self,"object"==typeof global&&global];for(var f=0;f<a.length;++f){var e=a[f];if(e&&e.Math==Math)return e}throw Error("Cannot find global object");};$jscomp.global=$jscomp.getGlobal(this);$jscomp.IS_SYMBOL_NATIVE="function"===typeof Symbol&&"symbol"===typeof Symbol("x");$jscomp.TRUST_ES6_POLYFILLS=!$jscomp.ISOLATE_POLYFILLS||$jscomp.IS_SYMBOL_NATIVE;$jscomp.polyfills={};
$jscomp.propertyToPolyfillSymbol={};$jscomp.POLYFILL_PREFIX="$jscp$";var $jscomp$lookupPolyfilledValue=function(a,f){var e=$jscomp.propertyToPolyfillSymbol[f];if(null==e)return a[f];e=a[e];return void 0!==e?e:a[f]};$jscomp.polyfill=function(a,f,e,l){f&&($jscomp.ISOLATE_POLYFILLS?$jscomp.polyfillIsolated(a,f,e,l):$jscomp.polyfillUnisolated(a,f,e,l))};
$jscomp.polyfillUnisolated=function(a,f,e,l){e=$jscomp.global;a=a.split(".");for(l=0;l<a.length-1;l++){var k=a[l];if(!(k in e))return;e=e[k]}a=a[a.length-1];l=e[a];f=f(l);f!=l&&null!=f&&$jscomp.defineProperty(e,a,{configurable:!0,writable:!0,value:f})};
$jscomp.polyfillIsolated=function(a,f,e,l){var k=a.split(".");a=1===k.length;l=k[0];l=!a&&l in $jscomp.polyfills?$jscomp.polyfills:$jscomp.global;for(var q=0;q<k.length-1;q++){var m=k[q];if(!(m in l))return;l=l[m]}k=k[k.length-1];e=$jscomp.IS_SYMBOL_NATIVE&&"es6"===e?l[k]:null;f=f(e);null!=f&&(a?$jscomp.defineProperty($jscomp.polyfills,k,{configurable:!0,writable:!0,value:f}):f!==e&&(void 0===$jscomp.propertyToPolyfillSymbol[k]&&(e=1E9*Math.random()>>>0,$jscomp.propertyToPolyfillSymbol[k]=$jscomp.IS_SYMBOL_NATIVE?
$jscomp.global.Symbol(k):$jscomp.POLYFILL_PREFIX+e+"$"+k),$jscomp.defineProperty(l,$jscomp.propertyToPolyfillSymbol[k],{configurable:!0,writable:!0,value:f})))};
$jscomp.polyfill("String.prototype.replaceAll",function(a){return a?a:function(f,e){if(f instanceof RegExp&&!f.global)throw new TypeError("String.prototype.replaceAll called with a non-global RegExp argument.");return f instanceof RegExp?this.replace(f,e):this.replace(new RegExp(String(f).replace(/([-()\[\]{}+?*.$\^|,:#<!\\])/g,"\\$1").replace(/\x08/g,"\\x08"),"g"),e)}},"es_2021","es3");
function construct_phrase(a,...f){for(var e=1;e<=f.length;e++)a=a.replace(new RegExp("%"+e+"\\$s","gi"),f[e-1]);return a}function isFullScreen(a){return/\bCodeMirror-fullscreen\b/.test(a.getWrapperElement().className)}function winHeight(){return window.innerHeight||(document.documentElement||document.body).clientHeight}
function setFullScreen(a,f){var e=a.getWrapperElement();f?(e.className+=" CodeMirror-fullscreen",e.style.height=winHeight()+"px",document.documentElement.style.overflow="hidden"):(e.className=e.className.replace(" CodeMirror-fullscreen",""),e.style.height="",document.documentElement.style.overflow="");updateCodeMirrorWidth();f=$(e).find("textarea");window.scrollTo(0,f.offset().top);f.focus();a.refresh()}
function updateCodeMirrorWidth(){var a=$(".CodeMirror-wrap"),f=a.closest("#ctrl_template"),e=0<$(".CodeMirror-fullscreen").length;1>a.length||1>f.length||(e?a.css("width",""):(e=$("<div />").text(Array(5E3).join("a ")).appendTo(f),a.hide(),a.width(f.innerWidth()),a.show(),e.remove()))}
function setUpCodeMirror(a){CodeMirror.on(window,"resize",function(){updateCodeMirrorWidth();var m=document.body.getElementsByClassName("CodeMirror-fullscreen")[0];m&&(m.CodeMirror.getWrapperElement().style.height=winHeight()+"px")});var f=CodeMirror.newFoldFunction(CodeMirror.tagRangeFinder),e=$("#"+a.textarea_id),l=$('<div class="smallfont sizetools"><a class="fullscreen" href="#"></div>'+a.phrase_fullscreen+"</a>");e.after(l);var k=CodeMirror.fromTextArea(e.get(0),{mode:a.mode,lineNumbers:!0,matchBrackets:!0,
autoCloseBrackets:!0,autoCloseTags:!0,tabMode:"indent",indentUnit:4,tabSize:4,electricChars:!1,smartIndent:!0,indentWithTabs:!0,autoClearEmptyLines:!0,lineWrapping:!0,highlightSelectionMatches:!0,styleActiveLine:!0,extraKeys:{"Ctrl-Q":function(m){f(m,m.getCursor().line)},"Ctrl-Space":"autocomplete",F11:function(m){setFullScreen(m,!isFullScreen(m))},Esc:function(m){isFullScreen(m)&&setFullScreen(m,!1)}}});l.on("click",()=>{setFullScreen(k,!0);return!1});(a=e.attr("dir"))&&$(k.display.wrapper).attr("dir",
a);updateCodeMirrorWidth();k.on("gutterClick",f);var q=e.parents("form");q.find("input.searchstring").val(q.find('input[name="searchstring"]').val());q.find("input.findbutton").on("click",function(){var m=k.getSearchCursor(q.find("input.searchstring").val(),k.getCursor(),!0);m.find();m.atOccurrence&&(k.setCursor(m.to()),k.setSelection(m.from(),m.to()))})}
$.extend(window,(a=>{function f(c,b=!1){c=new URL(c,document.baseURI);if(b)return!!window.open(c);location=c;return!0}function e(c,...b){var d=a(".js-phrase-data").data(c);return d?b.length?construct_phrase(d,...b):d:c}function l(){function c(){return!a(".js-adminmessage-dismissmultiple:not(:checked)").length}function b(){var h=!a(".js-adminmessage-dismissmultiple:checked").length;a(".js-adminmessage-dismissmultiple-submit").prop("disabled",h)}function d(){a(".js-adminmessage-dismissmultiple").prop("checked",
!c());b()}function g(){a(".js-adminmessage-dismissmultiple-toggle").prop("checked",c());b()}a(".js-adminmessage-dismissmultiple-toggle").off("change",d).on("change",d);a(".js-adminmessage-dismissmultiple").off("change",g).on("change",g)}function k(){function c(d,g){var h=d.closest("js-dependant-trigger-group");let n=h.data("hide")||1;var p=h.data("name")||"js-dependant-child";h="."+p;d="."+p+"-"+d.val();p=(r,t)=>{r=g.find(r);hiderow=t&&!!n;r.prop("disabled",t).toggleClass("hide-row",hiderow);r.closest(".main-table-row").toggleClass("h-hide-imp",
hiderow)};p(h+":not("+d+")",!0);p(d,!1)}a(".js-autocheck-master").each(function(){var d=a(this);d.on("focus",function(){a(document).find(d.data("on")).prop("checked",!0)})});a(".js-checkbox-container").on("click",".js-checkbox-master",d=>{var g=a(d.currentTarget);let h=g.data("child")||"js-checkbox-child";g=g.prop("checked")?":not(:checked)":":checked";a(d.delegateTarget).find("."+h+g).trigger("click")});let b=a(".js-dependant-container");b.on("change",".js-dependant-trigger-group :radio",d=>{c(a(d.currentTarget),
a(d.delegateTarget))});b.each((d,g)=>{c(a(".js-dependant-trigger-group :radio:checked",g),a(g))});a(".js-link").on("click",d=>{f(a(d.currentTarget).data("href"))});a(".js-link-newwindow").on("click",d=>{window.open(a(d.currentTarget).data("href"))});a(".js-link-popup").on("click",d=>{d=a(d.currentTarget);let g=parseInt(d.data("height")||600),h=parseFloat(d.data("width")||.9);0<h&&1>=h&&(h*=screen.width);window.open(d.data("href"),"popup","resizable=yes,scrollbars=yes,width="+h+",height="+g)});a(".js-alternate-submit").on("click",
d=>{d=a(d.currentTarget);data=d.data();action=data.action||"";newDo=data["do"]||"";target=data.target||"";$form=d.closest("form");$do=$form.find('input[name="do"]');action&&$form.attr("action",action);target&&$form.attr("target",target);newDo&&$do.val(newDo)})}function q(){a(".js-image-upload-update-preview").on("change vb-init",function(c){c=a(this).attr("name");var b=a('.js-channel-icon-preview-wrapper[data-for="'+c+'"]'),d=a('img[data-for="'+c+'"]'),g=a('.js-image-upload-remove[data-for="'+c+'"]'),
h=a('.js-image-upload-revert[data-for="'+c+'"]');"undefined"!=typeof FileReader&&(c=new FileReader,c.onload=function(n){d.attr("src",n.target.result);b.toggleClass("hide",!1);g.prop("disabled",!1);h.length&&h.prop("disabled",!1)},0<this.files.length&&c.readAsDataURL(this.files[0]))});a(".js-image-upload-update-preview").trigger("vb-init");a(".js-image-upload-remove").on("click",function(){var c=a(this),b=c.data("for"),d=b&&a('.js-image-upload-revert[data-for="'+b+'"]'),g=b&&a('input[name="'+b+'"]'),
h=b&&a('.js-image-upload-filedataid[data-for="'+b+'"]'),n=a('.js-channel-icon-preview-wrapper[data-for="'+b+'"]');b=b&&a('img[data-for="'+b+'"]');g.val("");h.val("0");b.attr("src","");n.toggleClass("hide",!0);d.length&&d.prop("disabled",!1);c.prop("disabled",!0)});a(".js-image-upload-revert").on("click",function(){var c=a(this),b=c.data("for"),d=b&&a('.js-image-upload-remove[data-for="'+b+'"]'),g=b&&a('input[name="'+b+'"]'),h=b&&a('.js-image-upload-filedataid[data-for="'+b+'"]'),n=a('.js-channel-icon-preview-wrapper[data-for="'+
b+'"]');b=b&&a('img[data-for="'+b+'"]');g.val("");h.val(h.data("orig-value"));b.attr("src",b.data("orig-src"));n.toggleClass("hide",!1);c.prop("disabled",!0);d.prop("disabled",!1)})}function m(){a("[autofocus]:not(:focus)").eq(0).trigger("focus");a(".js-page-redirect").each((c,b)=>{let d=a(b);c=d.data("timeout");setTimeout(()=>{d.is("a")?location=d.prop("href"):d.is("form")&&b.submit()},1E3*c);return!1});a(".js-copy-default").on("click",c=>{c=a(c.currentTarget);let b=a("#"+c.data("sourceid")).val();
""==b?alert(e("default_text_is_empty")):a("#"+c.data("targetid")).val(b)})}function u(){var c=(b,d)=>{var g=a(`[data-groupid="${b}"]`),h=a(`.js-collapse-group[data-groupid="${b}"]:not(.no-collapse) > *:not(.no-collapse)`),n=`.js-acp-collapse[for="${b}"][data-action='expand']`,p=a(n),r=a(`.js-acp-collapse[for="${b}"]:not([data-action='expand'])`);n=h.has(n).first();d&&(b=g.find(`[data-groupid!="${b}"].js-local-closed *:not(.collapse-toggle)`),h=h.not(b));h.toggle(d);g.toggleClass("js-local-closed",
!d);n.toggle(!0);p.toggleClass("h-hide-imp",d);r.toggleClass("h-hide-imp",!d)};a(".js-collapsed").each((b,d)=>{b=a(d);b=b.attr("for")||b.data("groupid");c(b,!1)});a(".js-acp-collapse").on("click",b=>{var d=a(b.currentTarget);b=d.attr("for");d="expand"==d.data("action");c(b,d)})}a(()=>{a:{var c=window;for(var b=0;2>b&&c.parent;++b)if(c=c.parent,c.frames&&c.frames.length&&c.frames.head){c=c.frames.head;break a}c=!1}c&&(c.parent.document.title=""!=document.title?document.title:"vBulletin",b=a(".js-admincp-data"),
c=c.document,a(".js-debug-warning-message",c).toggleClass("hide",!b.data("debug")),a(".js-siteoff-warning-message",c).toggleClass("hide",!b.data("siteoff")));k();m();q();l();u()});return{copy_default_text:function(c){var b=a("#default_phrase, [name=deftext]").val();""==b?alert(e("default_text_is_empty")):a("#text_"+c).val(b)},vBRedirect:f,vBAdmin:{ensureFun:function(c){return"function"==typeof c?c:()=>{}},renderPhrase:e,vBRedirect:f,htmlspecialchars:function(c){let b=[RegExp("&(?!#[0-9]+;)","g"),
RegExp("<","g"),RegExp(">","g"),RegExp('"',"g")],d=["&amp;","&lt;","&gt;","&quot;"];for(let g=0;g<b.length;g++)c=c.replace(b[g],d[g]);return c},initJumpControl:function(c,b){function d(g){let h=g.val(),n=g.data(c+"id"),p="";h in b?p=b[h].replaceAll("{id}",n):"default"in b?p=b["default"].replace("{id}",n).replace("{value}",h):alert(vBAdmin.renderPhrase("invalid_action_specified_gcpglobal"));""!=p&&vBAdmin.vBRedirect(p,!p.match(/^(?:mailto:|modcp\/|admincp\/)/))&&(g.get(0).selectedIndex=0);return!1}
a(".js-"+c+"-select").off("change").on("change",g=>d(a(g.delegateTarget)));a(".js-"+c+"-go").off("click").on("click",g=>d(a("#"+c+a(g.currentTarget).data(c+"id"))))}}}})(jQuery));
