<?php
 declare(strict_types=1); namespace Square\Models; class ActivityType { public const ADJUSTMENT = 'ADJUSTMENT'; public const APP_FEE_REFUND = 'APP_FEE_REFUND'; public const APP_FEE_REVENUE = 'APP_FEE_REVENUE'; public const AUTOMATIC_SAVINGS = 'AUTOMATIC_SAVINGS'; public const AUTOMATIC_SAVINGS_REVERSED = 'AUTOMATIC_SAVINGS_REVERSED'; public const CHARGE = 'CHARGE'; public const DEPOSIT_FEE = 'DEPOSIT_FEE'; public const DISPUTE = 'DISPUTE'; public const ESCHEATMENT = 'ESCHEATMENT'; public const FEE = 'FEE'; public const FREE_PROCESSING = 'FREE_PROCESSING'; public const HOLD_ADJUSTMENT = 'HOLD_ADJUSTMENT'; public const INITIAL_BALANCE_CHANGE = 'INITIAL_BALANCE_CHANGE'; public const MONEY_TRANSFER = 'MONEY_TRANSFER'; public const MONEY_TRANSFER_REVERSAL = 'MONEY_TRANSFER_REVERSAL'; public const OPEN_DISPUTE = 'OPEN_DISPUTE'; public const OTHER = 'OTHER'; public const OTHER_ADJUSTMENT = 'OTHER_ADJUSTMENT'; public const PAID_SERVICE_FEE = 'PAID_SERVICE_FEE'; public const PAID_SERVICE_FEE_REFUND = 'PAID_SERVICE_FEE_REFUND'; public const REDEMPTION_CODE = 'REDEMPTION_CODE'; public const REFUND = 'REFUND'; public const RELEASE_ADJUSTMENT = 'RELEASE_ADJUSTMENT'; public const RESERVE_HOLD = 'RESERVE_HOLD'; public const RESERVE_RELEASE = 'RESERVE_RELEASE'; public const RETURNED_PAYOUT = 'RETURNED_PAYOUT'; public const SQUARE_CAPITAL_PAYMENT = 'SQUARE_CAPITAL_PAYMENT'; public const SQUARE_CAPITAL_REVERSED_PAYMENT = 'SQUARE_CAPITAL_REVERSED_PAYMENT'; public const SUBSCRIPTION_FEE = 'SUBSCRIPTION_FEE'; public const SUBSCRIPTION_FEE_PAID_REFUND = 'SUBSCRIPTION_FEE_PAID_REFUND'; public const SUBSCRIPTION_FEE_REFUND = 'SUBSCRIPTION_FEE_REFUND'; public const TAX_ON_FEE = 'TAX_ON_FEE'; public const THIRD_PARTY_FEE = 'THIRD_PARTY_FEE'; public const THIRD_PARTY_FEE_REFUND = 'THIRD_PARTY_FEE_REFUND'; } 