<?php
 declare(strict_types=1); namespace Jose\Component\KeyManagement\Analyzer; use Jose\Component\Core\JWKSet; interface KeysetAnalyzer { public function analyze(JWKSet $JWKSet, MessageBag $bag): void; } 