<?php
 class vB_Utility_Template_ParserNode_Curly_Datetime extends vB_Utility_Template_ParserNode_CurlyRuntime { protected static string $function = 'datetime'; protected static string $noparamerror = 'no_timestamp_specified'; protected static int $maxparams = 3; } 