<?php
 declare(strict_types=1); namespace Square\Models; use stdClass; class DisputeEvidenceCreatedWebhook implements \JsonSerializable { private $merchantId; private $locationId; private $type; private $eventId; private $createdAt; private $data; public function getMerchantId(): ?string { return $this->merchantId; } public function setMerchantId(?string $merchantId): void { $this->merchantId = $merchantId; } public function getLocationId(): ?string { return $this->locationId; } public function setLocationId(?string $locationId): void { $this->locationId = $locationId; } public function getType(): ?string { return $this->type; } public function setType(?string $type): void { $this->type = $type; } public function getEventId(): ?string { return $this->eventId; } public function setEventId(?string $eventId): void { $this->eventId = $eventId; } public function getCreatedAt(): ?string { return $this->createdAt; } public function setCreatedAt(?string $createdAt): void { $this->createdAt = $createdAt; } public function getData(): ?DisputeEvidenceCreatedWebhookData { return $this->data; } public function setData(?DisputeEvidenceCreatedWebhookData $data): void { $this->data = $data; } #[\ReturnTypeWillChange] public function jsonSerialize(bool $asArrayWhenEmpty = false) { $json = []; if (isset($this->merchantId)) { $json['merchant_id'] = $this->merchantId; } if (isset($this->locationId)) { $json['location_id'] = $this->locationId; } if (isset($this->type)) { $json['type'] = $this->type; } if (isset($this->eventId)) { $json['event_id'] = $this->eventId; } if (isset($this->createdAt)) { $json['created_at'] = $this->createdAt; } if (isset($this->data)) { $json['data'] = $this->data; } $json = array_filter($json, function ($val) { return $val !== null; }); return (!$asArrayWhenEmpty && empty($json)) ? new stdClass() : $json; } } 