<?php
 class vB_Utility_Template_ParserNode_Tag_Literal extends vB_Utility_Template_ParserNode_Tag { public function validate() : array { return []; } public function compile() : string { return $this->parser->_parse_nodes($this->main_node->childNodes()); } } 