<?php
 class vB_Utility_Template_ParserNode_Curly_Urlencode extends vB_Utility_Template_ParserNode_CurlyRuntime { protected static string $function = 'urlEncode'; protected static int $maxparams = 1; } 