<?php
 class vB_Utility_Template_ParserNode_Curly_Rawdata extends vB_Utility_Template_ParserNode_Curly { public function validate() : array { $errors = []; $attributecount = sizeof($this->main_node->attributes); if ($attributecount == 0) { $errors[] = 'no_variable_specified'; } else if ($attributecount == 1 OR $attributecount == 2) { } return $errors; } public function compile() : string { $string = $this->compileVar($this->main_node->attributes[0]); $arguments = $this->getArgumentsFromAttributes(1); return '\'\'; ' . $string . ' = vB_Template_Runtime::parseDataWithErrors(' . $arguments . '); $final_rendered .= \'\''; } } 