<?php
 declare(strict_types=1); namespace Square\Models; use stdClass; class DisputeEvidenceCreatedWebhookData implements \JsonSerializable { private $type; private $id; private $object; public function getType(): ?string { return $this->type; } public function setType(?string $type): void { $this->type = $type; } public function getId(): ?string { return $this->id; } public function setId(?string $id): void { $this->id = $id; } public function getObject(): ?DisputeEvidenceCreatedWebhookObject { return $this->object; } public function setObject(?DisputeEvidenceCreatedWebhookObject $object): void { $this->object = $object; } #[\ReturnTypeWillChange] public function jsonSerialize(bool $asArrayWhenEmpty = false) { $json = []; if (isset($this->type)) { $json['type'] = $this->type; } if (isset($this->id)) { $json['id'] = $this->id; } if (isset($this->object)) { $json['object'] = $this->object; } $json = array_filter($json, function ($val) { return $val !== null; }); return (!$asArrayWhenEmpty && empty($json)) ? new stdClass() : $json; } } 