/*
Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'image2', 'es-mx', {
	alt: 'Texto alternativo',
	btnUpload: 'Enviar al servidor',
	captioned: 'Imagen subtitulada',
	captionPlaceholder: 'Subtítulo',
	infoTab: 'Información de la imagen',
	lockRatio: 'Bloquear aspecto',
	menu: 'Propiedades de la imagen',
	pathName: 'imagen',
	pathNameCaption: 'subtítulo',
	resetSize: 'Reiniciar tamaño',
	resizer: 'Presiona y arrastra para redimensionar',
	title: 'Propiedades de imagen',
	uploadTab: 'Cargar',
	urlMissing: 'Falta la URL de origen de la imagen.',
	altMissing: 'Falta texto alternativo.'
} );
