<?php
 declare(strict_types=1); namespace SpomkyLabs\Pki\CryptoTypes\AlgorithmIdentifier; interface AlgorithmIdentifierProvider { public function supportsOID(string $oid): bool; public function getClassByOID(string $oid): string; } 