<?php
 declare(strict_types=1); namespace SpomkyLabs\Pki\CryptoTypes\Asymmetric; use SpomkyLabs\Pki\ASN1\Type\Primitive\BitString; use SpomkyLabs\Pki\CryptoTypes\AlgorithmIdentifier\Feature\AlgorithmIdentifierType; use SpomkyLabs\Pki\CryptoTypes\Asymmetric\Attribute\OneAsymmetricKeyAttributes; final class PrivateKeyInfo extends OneAsymmetricKey { public static function create( AlgorithmIdentifierType $algo, string $key, ?OneAsymmetricKeyAttributes $attributes = null, ?BitString $public_key = null, ): self { return new self($algo, $key, $attributes, $public_key, parent::VERSION_1); } } 