<?php if (!defined('VB_ENTRY')) die('Access denied.'); class vB_Api_ContentType extends vB_Api { const OLDTYPE_BLOGCHANNEL = 9973; const OLDTYPE_BLOGSTARTER = 9972; const OLDTYPE_BLOGRESPONSE = 9984; const OLDTYPE_BLOGRESPONSE_502a2 = 9971; const OLDTYPE_BLOGCHANNEL_PRE502a2 = 9999; const OLDTYPE_BLOGSTARTER_PRE502a2 = 9985; const OLDTYPE_BLOGRESPONSE_PRE502a2 = 9984; const OLDTYPE_ORPHAN_INFRACTION_THREAD = 9979; const OLDTYPE_ORPHAN_INFRACTION_POST = 9978; const OLDTYPE_ORPHAN_INFRACTION_PROFILE = 9977; const OLDTYPE_SGPHOTO = 9987; const OLDTYPE_PHOTO = 9986; const OLDTYPE_SGGALLERY = 9983; const OLDTYPE_THREADATTACHMENT = 9982; const OLDTYPE_POSTATTACHMENT = 9990; const OLDTYPE_BLOGATTACHMENT = 9974; const OLDTYPE_ARTICLEATTACHMENT = 9968; const OLDTYPE_PMSTARTER = 9989; const OLDTYPE_PMRESPONSE = 9981; const OLDTYPE_POLL = 9011; const OLDTYPE_CMS_SECTION = 9970; const OLDTYPE_CMS_ARTICLE = 9969; const OLDTYPE_CMS_COMMENT = 9967; const OLDTYPE_CMS_STATICPAGE = 9966; protected function __construct() { parent::__construct(); } public function fetchContentTypeIdFromClass($class, $package = 'vBForum') { $contenttypeid = vB_Types::instance()->getContentTypeId($package . '_' . $class); return $contenttypeid ? $contenttypeid : 0; } public function fetchContentTypeClassFromId($contenttypeid) { return vB_Types::instance()->getContentTypeClass($contenttypeid); } } 