<?php
 namespace Eluceo\iCal\Domain\Enum; final class TimeZoneTransitionType { private static ?self $daylight = null; private static ?self $standard = null; public static function DAYLIGHT(): self { return self::$daylight ??= new TimeZoneTransitionType(); } public static function STANDARD(): self { return self::$standard ??= new TimeZoneTransitionType(); } } 