<?php
 declare(strict_types=1); namespace Square\Models; use stdClass; class TerminalRefundQueryFilter implements \JsonSerializable { private $deviceId; private $createdAt; private $status; public function getDeviceId(): ?string { return $this->deviceId; } public function setDeviceId(?string $deviceId): void { $this->deviceId = $deviceId; } public function getCreatedAt(): ?TimeRange { return $this->createdAt; } public function setCreatedAt(?TimeRange $createdAt): void { $this->createdAt = $createdAt; } public function getStatus(): ?string { return $this->status; } public function setStatus(?string $status): void { $this->status = $status; } #[\ReturnTypeWillChange] public function jsonSerialize(bool $asArrayWhenEmpty = false) { $json = []; if (isset($this->deviceId)) { $json['device_id'] = $this->deviceId; } if (isset($this->createdAt)) { $json['created_at'] = $this->createdAt; } if (isset($this->status)) { $json['status'] = $this->status; } $json = array_filter($json, function ($val) { return $val !== null; }); return (!$asArrayWhenEmpty && empty($json)) ? new stdClass() : $json; } } 