<?php
 class vB_Options_Option_Sharingtwitterusername extends vB_Options_Option { protected function validateCustom(array $validation, mixed $rawvalue) : bool|string|array { $rawvalue = trim($rawvalue); if ($rawvalue AND substr($rawvalue, 0, 1) == '@') { return 'you_did_not_enter_a_valid_value'; } return true; } } 