/*
 =======================================================================*\
|| ###################################################################### ||
|| # vBulletin 6.2.3
|| # ------------------------------------------------------------------ # ||
|| # Copyright 2000-2026 MH Sub I, LLC dba vBulletin. All Rights Reserved.  # ||
|| # This file may not be redistributed in whole or significant part.   # ||
|| # ----------------- VBULLETIN IS NOT FREE SOFTWARE ----------------- # ||
|| # http://www.vbulletin.com | http://www.vbulletin.com/license.html   # ||
|| ###################################################################### ||
\*========================================================================*/
// ***************************
// js.compressed/memberchannel.js
// ***************************
vBulletin.memberChannel=function(d){function n(a,b,e){a=a.filter(b).toggleClass("h-disabled",!e);e?a.attr("href",e):a.removeAttr("href")}function p(a,b){function e(c){var g=c.innerWidth(),h=parseInt(c.css("paddingLeft"),10);c=parseInt(c.css("paddingRight"),10);return Math.floor(g-h-c)}function f(c,g){var h=!!g;c.width(g);c.toggleClass("b-groupgrid__item-inner--expanded",h);g=d(".js-groupgrid-item-icon",l).outerWidth();l=d(".js-groupgrid-item-icon-link",l).outerWidth();h&&l>g&&c.removeClass("b-groupgrid__item-inner--expanded");
var l=c.first();h=e(l)-1;c.find(".js-groupgrid-item-icon-link").width(h).height(h)}if(a.length&&(f(a,""),b)){b=a.first();var k=e(b.closest(".b-groupgrid__item")),m=Math.ceil(b.outerWidth(!0))-e(b);b.closest(".b-groupgrid__item").is(".b-flexgrid__item--lastrow")||(a.each(function(){var c=d(this).closest(".b-groupgrid__item");if(c.is(".b-flexgrid__item--lastrow"))return!0;k=Math.min(k,e(c))}),f(a,k-m-1))}}function q(a,b){a=d(".b-groupgrid__item-inner");b&&b.isResize&&a.css({opacity:"0"});p(a,!1)}function r(a,
b){a=d(".b-groupgrid__item-inner");p(a,!0);b&&b.isResize&&a.removeClass("h-tranparent").animate({opacity:"1"},400)}return{updateToolbarButtonPressState:function(a){function b(f){var k=f.data("js-movable-button-clone-id");return d(".js-movable-toolbar-button-clone").filter(function(){return d(this).data("js-movable-button-clone-id")==k})}if(!a.find(".js-button-filter-display-blogs.js-checked").length){var e=a.find(".js-display-blogs-state").data("display-blogs-state");a.find(".js-button-filter-display-blogs").filter('[data-filter-value="{0}"]'.format(e)).addClass("js-checked")}a.find(".js-button-filters .js-button-filter").removeClass("b-button--pressed").each(function(){b(d(this)).removeClass("b-button--pressed")}).filter(".js-checked").addClass("b-button--pressed").each(function(){b(d(this)).addClass("b-button--pressed")})},
updateToolbarPagination:function(a){var b=d(".conversation-toolbar-wrapper .pagenav-controls .pagenav-form",a),e=d(".arrow",b).removeClass("h-disabled"),f=a.find(".js-membergroup-pagination-info"),k=f.find(".js-prevpage").val(),m=f.find(".js-nextpage").val(),c=f.find(".js-pagenum").val()||1;f=f.find(".js-totalpages").val()||1;var g=a.find(".js-under-toolbar-pagenav .js-pagenav");a=a.find(".js-pagenav").not(g);d(".js-pagenum",b).val(c);d(".pagetotal",b).text(f);n(e,"[rel=prev]",k);n(e,"[rel=next]",
m);0==a.length?g.html(""):g.html(a.clone().html())},initFlexGridAdjustments:function(a){a.on("vbulletin:flexgridstart",".js-flexgrid",q).on("vbulletin:flexgridready",".js-flexgrid",r)}}}(jQuery);
;

// ***************************
// js.compressed/sb_blogs.js
// ***************************
vBulletin.precache(["create_a_blog","error_creating_user_blog_channel","select_a_blog"],[]);
(function(a,d,h){function p(q){let g=f=>location.href="{0}/new-content/{1}".format(pageData.baseurl,f),k=a(this).closest(".canvas-widget").data("blog-channel-id");d.AJAX({call:"/ajax/api/user/getGitCanStart",data:{parentNodeId:k},success:function(f){let l=f.length;if(1<l){let e=a("#user-blogs-dialog"),b=a("select.custom-dropdown",e);for(let c of f)a("<option />").val(c.nodeid).html(c.title).appendTo(b);h.openModalDialog(e,{title:"select_a_blog",onOpen:()=>{b.removeClass("h-hide").selectBox();a(".btnContinue",
e).offon("click",()=>{g(b.val())});a(".btnCancel",e).offon("click",()=>{e.dialog("close")})},onAfterClose:()=>{b.selectBox("destroy").find("option").remove()}})}else 1==l?g(f[0].nodeid):d.AJAX({call:"/ajax/api/blog/canCreateBlog",data:{parentid:k},success:function(e){let b=a("#create-blog-dialog");$form=a("form",b);h.openModalDialog(b,{title:"create_a_blog",onOpen:()=>{$form.trigger("reset");a(".btnContinue",b).offon("click",()=>{d.AJAX({call:"/create-content/blog",data:d.getFormData($form,0),success:c=>
g(c.nodeid),error_phrase:"error_creating_user_blog_channel"});return!1});a(".btnCancel",b).offon("click",()=>{b.dialog("close")});a(".blog-adv-settings",b).offon("click",c=>{let m=d.getFormData($form,0);c=new URL(c.currentTarget);let n=c.searchParams;n.append("blogtitle",a.trim(m.title));n.append("blogdesc",a.trim(m.description));location.href=c;return!1})}})},title_phrase:"create_a_blog"})},error_phrase:"error_fetching_user_blog_channels"})}if(!d.pageHasSelectors([".bloghome-widget"]))return!1;a(function(){a(".bloghome-widget").offon("click",
".conversation-toolbar .new-conversation-btn",p);d.memberChannel.initFlexGridAdjustments(a(".bloghome-widget"))})})(jQuery,vBulletin,vBulletin.dialogtools);
;

// ***************************
// js.compressed/blog_summary.js
// ***************************
vBulletin.precache(["blog_subscribers_list","blog_subscribers","unable_to_contact_server_please_try_again"],[]);
(function(c){if(!vBulletin.pageHasSelectors([".summary-widget",".blogadmin-widget"]))return!1;var q=function(){c("#blogSubscribersSeeAll").off("click").on("click",function(e){l(c(this).attr("data-node-id"));e.stopPropagation();return!1})},b,l=function(e,g,h){b=c("#blogSubscribersAll").dialog({title:vBulletin.phrase.get("blog_subscribers_list"),autoOpen:!1,modal:!0,resizable:!1,closeOnEscape:!1,showCloseButton:!1,width:450,dialogClass:"dialog-container dialog-box blog-subscribers-dialog"});vBulletin.pagination({context:b,
onPageChanged:function(a,k){l(e,a)}});b.off("click",".blog-subscribers-close").on("click",".blog-subscribers-close",function(){b.dialog("close")});b.off("click",".action_button").on("click",".action_button",function(){if(!c(this).hasClass("subscribepending_button")){var a=c(this),k=parseInt(a.attr("data-userid"),10),d="";a.hasClass("subscribe_button")?d="add":a.hasClass("unsubscribe_button")&&(d="delete");"number"==typeof k&&d&&vBulletin.AJAX({call:"/profile/follow-button",data:{"do":d,follower:k,
type:"follow_members"},success:function(f){if(1==f||2==f){if("add"==d){var m="subscribe_button b-button b-button--special";var n=(1==f?"subscribed":"subscribepending")+"_button b-button b-button--secondary";var p=1==f?"following":"following_pending";a.attr("disabled","disabled")}else"delete"==d&&(m="subscribed_button unsubscribe_button b-button b-button--special",n="subscribe_button b-button b-button--secondary",p="follow");a.removeClass(m).addClass(n).text(vBulletin.phrase.get(p))}},title_phrase:"profile_guser",
error_phrase:"unable_to_contact_server_please_try_again"})}});g||(g=1);h||(h=10);vBulletin.AJAX({call:"/ajax/render/subscribers_list",data:{nodeid:e,page:g,perpage:h},success:function(a){b.dialog("close");c(".blog-subscribers-content",b).html(a);b.dialog("open")},title_phrase:"blog_subscribers",error_phrase:"unable_to_contact_server_please_try_again"})};c(document).ready(function(){q()})})(jQuery);
;

