<?php
 declare(strict_types=1); namespace Square\Models; class OrderLineItemTaxType { public const UNKNOWN_TAX = 'UNKNOWN_TAX'; public const ADDITIVE = 'ADDITIVE'; public const INCLUSIVE = 'INCLUSIVE'; } 