<?php
 namespace Eluceo\iCal\Domain\ValueObject\Alarm; final class DisplayAction extends Action { private string $description; public function __construct(string $description) { $this->description = $description; } public function getDescription(): string { return $this->description; } } 