<?php
 declare(strict_types=1); namespace SpomkyLabs\Pki\ASN1\Type; use SpomkyLabs\Pki\ASN1\Feature\ElementBase; use SpomkyLabs\Pki\ASN1\Feature\Stringable; interface StringType extends ElementBase, Stringable { } 