<?php
 declare(strict_types=1); namespace Jose\Component\Encryption\Algorithm\KeyEncryption; use Jose\Component\Core\JWK; use Jose\Component\Encryption\Algorithm\KeyEncryptionAlgorithm; interface DirectEncryption extends KeyEncryptionAlgorithm { public function getCEK(JWK $key): string; } 