/*
 =======================================================================*\
|| ###################################################################### ||
|| # vBulletin 6.2.3
|| # ------------------------------------------------------------------ # ||
|| # Copyright 2000-2026 MH Sub I, LLC dba vBulletin. All Rights Reserved.  # ||
|| # This file may not be redistributed in whole or significant part.   # ||
|| # ----------------- VBULLETIN IS NOT FREE SOFTWARE ----------------- # ||
|| # http://www.vbulletin.com | http://www.vbulletin.com/license.html   # ||
|| ###################################################################### ||
\*========================================================================*/
(function(l){l(()=>{dismissed_news=dismissed_news.split(",");if("undefined"!=typeof vb_version&&isNewerVersion(current_version,vb_version)){let a="https://www.vbulletin.com/forum/forum/vbulletin-announcements/"+vb_announcementid;var m=l("#news_table").get(0);let b=l(m.insertRow(1));m=l(m.insertRow(2));b.append('<td class="thead"><b>'+vBAdmin.renderPhrase("there_is_a_newer_vbulletin_version")+"</b></td>");m.append('<td class="alt1"><p class="smallfont"><a href="'+a+'" target="_blank"><b>'+vBAdmin.renderPhrase("latest_version_available_x",
vb_version)+"</b></a> "+vBAdmin.renderPhrase("you_are_running_vbulletin_version_x",current_version.bold())+'</p><p class="smallfont"><a href="https://members.vbulletin.com/" target="_blank">'+vBAdmin.renderPhrase("download_vbulletin_x_from_members_area",vb_version.bold())+"</a></p></td>")}l.post("admincp/newsproxy.php",{},null,"xml").done(a=>{var b=done_table,f=!1,h=a.getElementsByTagName("item");if(done_table)g=fetch_object("news_table"),f=!0;else{var g=fetch_object("news_table");h.length&&(fetch_object("admin_news").style.display=
"",cell=g.insertRow(0).insertCell(0),cell.className="tcat",cell.align="center",cell.innerHTML=news_header_string.bold(),f=!0)}for(a=0;a<h.length;a++){var e=h[a].getElementsByTagName("guid")[0].firstChild.nodeValue;if(!dismissed_news.includes(e)){b=!0;var k=h[a].getElementsByTagName("title")[0].firstChild.nodeValue;let n=h[a].getElementsByTagName("description")[0].firstChild.nodeValue,p=h[a].getElementsByTagName("link")[0].firstChild.nodeValue;var d=n.match(/\[local\]((?!\[\/local\]).)*\[\/local\]/g);
if(null!=d){var c;for(c=0;c<d.length;c++)n=n.replace(d[c],d[c].replace(/^\[local\](.*)\.php(\??)(.*)\[\/local\]$/,"$1"+local_extension+"?$3"))}d=g.insertRow(g.rows.length);d.id="r1_"+e;d=d.insertCell(0);d.className="thead";c=document.createElement("input");c.type="submit";c.name="acpnews["+e+"]";c.className="button";c.style.cssFloat=stylevar_right;c.title="id="+e;c.value=dismiss_string;d.appendChild(c);k=document.createTextNode(construct_phrase(vbulletin_news_string,k));d.appendChild(k);k=g.insertRow(g.rows.length);
k.id="r2_"+e;e=k.insertCell(0);e.className="alt2 smallfont";e.innerHTML=n+" ";p&&"http://"!=p&&(link_elem=document.createElement("a"),link_elem.href=p,link_elem.target="_blank",link_elem.innerHTML=view_string.bold(),e.appendChild(link_elem))}}if(f)for(h.length&&(a=g.insertRow(g.rows.length).insertCell(0),a.className=b?"tfoot":"alt1",a.align="center",b=document.createElement("a"),b.href=show_all_news_link,b.innerHTML=show_all_news_string,a.currentStyle?b.style.color=a.currentStyle.color:window.getComputedStyle&&
window.getComputedStyle(a,null)&&(b.style.color=window.getComputedStyle(a,null).color),a.appendChild(b)),b=fetch_tags(fetch_object("news_table"),"td"),f="alt1",a=0;a<b.length;a++)"alt1"==b[a].className||"alt2"==b[a].className?f=b[a].className:"alt2 smallfont"==b[a].className&&("alt1"==f?f="alt2":(b[a].className="alt1 smallfont",f="alt1"))})})})(jQuery);
