<?php
 declare(strict_types=1); namespace Square\Models; use stdClass; class CatalogQueryItemVariationsForItemOptionValues implements \JsonSerializable { private $itemOptionValueIds; public function getItemOptionValueIds(): ?array { return $this->itemOptionValueIds; } public function setItemOptionValueIds(?array $itemOptionValueIds): void { $this->itemOptionValueIds = $itemOptionValueIds; } #[\ReturnTypeWillChange] public function jsonSerialize(bool $asArrayWhenEmpty = false) { $json = []; if (isset($this->itemOptionValueIds)) { $json['item_option_value_ids'] = $this->itemOptionValueIds; } $json = array_filter($json, function ($val) { return $val !== null; }); return (!$asArrayWhenEmpty && empty($json)) ? new stdClass() : $json; } } 