<?php
 declare(strict_types=1); namespace Square\Models; class MeasurementUnitWeight { public const IMPERIAL_WEIGHT_OUNCE = 'IMPERIAL_WEIGHT_OUNCE'; public const IMPERIAL_POUND = 'IMPERIAL_POUND'; public const IMPERIAL_STONE = 'IMPERIAL_STONE'; public const METRIC_MILLIGRAM = 'METRIC_MILLIGRAM'; public const METRIC_GRAM = 'METRIC_GRAM'; public const METRIC_KILOGRAM = 'METRIC_KILOGRAM'; } 