<?php
 declare(strict_types=1); namespace SpomkyLabs\Pki\CryptoTypes\AlgorithmIdentifier\Feature; use SpomkyLabs\Pki\ASN1\Type\Constructed\Sequence; interface AlgorithmIdentifierType { public function oid(): string; public function name(): string; public function toASN1(): Sequence; } 