<?php
 class vB_Options_Option_Cmspreviewimagesize extends vB_Options_Option { protected function validateCustom(array $validation, mixed $rawvalue) : bool|string|array { if (!in_array($rawvalue, ['icon', 'thumb', 'small', 'medium', 'large'], true)) { return 'you_did_not_enter_a_valid_value'; } return true; } } 