<?php
 declare(strict_types=1); namespace SpomkyLabs\Pki\CryptoTypes\AlgorithmIdentifier\Hash; use SpomkyLabs\Pki\ASN1\Type\UnspecifiedType; use SpomkyLabs\Pki\CryptoTypes\AlgorithmIdentifier\SpecificAlgorithmIdentifier; final class SHA512AlgorithmIdentifier extends SHA2AlgorithmIdentifier { private function __construct() { parent::__construct(self::OID_SHA512); } public static function create(): self { return new self(); } public static function fromASN1Params(?UnspecifiedType $params = null): SpecificAlgorithmIdentifier { $obj = new static(); if (isset($params)) { $obj->_params = $params->asNull(); } return $obj; } public function name(): string { return 'sha512'; } } 