<?php
 declare(strict_types=1); namespace Square\Models; use stdClass; class UnlinkCustomerFromGiftCardRequest implements \JsonSerializable { private $customerId; public function __construct(string $customerId) { $this->customerId = $customerId; } public function getCustomerId(): string { return $this->customerId; } public function setCustomerId(string $customerId): void { $this->customerId = $customerId; } #[\ReturnTypeWillChange] public function jsonSerialize(bool $asArrayWhenEmpty = false) { $json = []; $json['customer_id'] = $this->customerId; $json = array_filter($json, function ($val) { return $val !== null; }); return (!$asArrayWhenEmpty && empty($json)) ? new stdClass() : $json; } } 