<?php
 class vB_Options_Option_Globalignore extends vB_Options_Option { protected function validateCustom(array $validation, mixed $rawvalue) : bool|string|array { if (preg_match('#^(\d+ *)*$#', $rawvalue)) { return true; } return 'setting_validation_error_globalignore'; } } 