<?php
 declare(strict_types=1); namespace Square\Models; class BusinessBookingProfileBookingPolicy { public const ACCEPT_ALL = 'ACCEPT_ALL'; public const REQUIRES_ACCEPTANCE = 'REQUIRES_ACCEPTANCE'; } 