<?php
 declare(strict_types=1); namespace Square\Http; class HttpResponse { private $statusCode; private $headers; private $rawBody; public function __construct(int $statusCode, array $headers, string $rawBody) { $this->statusCode = $statusCode; $this->headers = $headers; $this->rawBody = $rawBody; } public function getStatusCode(): int { return $this->statusCode; } public function getHeaders(): array { return $this->headers; } public function getRawBody(): string { return $this->rawBody; } } 