<?php
 declare(strict_types=1); namespace Square\Models; class EcomVisibility { public const UNINDEXED = 'UNINDEXED'; public const UNAVAILABLE = 'UNAVAILABLE'; public const HIDDEN = 'HIDDEN'; public const VISIBLE = 'VISIBLE'; } 