<?php
 interface vB_Interface_BBCode { const TYPE = 'NONE'; public function setRenderOptionsAndContext(array $renderOptions, array $renderContext) : void; public function setUserContext(?vB_UserContext $usercontext) : void; public function canHandleBbCode(string $data, ?string $option) : bool; public function renderBbCode(string $data, ?string $option) : string; const RENDER_META_URL_LOADED = 0; public function getRenderMetaData() : array; } 