<?php
 class vB_Utility_Template_ParserNode_Curly_Number extends vB_Utility_Template_ParserNode_CurlyRuntime { protected static string $function = 'numberFormat'; protected static string $noparamerror = 'no_number_specified'; protected static int $maxparams = 2; } 