<?php
 $PHPMAILER_LANG['authenticate'] = 'Erro SMTP: Falha na autenticação.'; $PHPMAILER_LANG['buggy_php'] = 'A sua versão do PHP tem um bug que pode causar mensagens corrompidas. Para resolver, utilize o envio por SMTP, desative a opção mail.add_x_header no ficheiro php.ini, mude para MacOS ou Linux, ou atualize o PHP para a versão 7.0.17+ ou 7.1.3+.'; $PHPMAILER_LANG['connect_host'] = 'Erro SMTP: Não foi possível ligar ao servidor SMTP.'; $PHPMAILER_LANG['data_not_accepted'] = 'Erro SMTP: Dados não aceites.'; $PHPMAILER_LANG['empty_message'] = 'A mensagem de e-mail está vazia.'; $PHPMAILER_LANG['encoding'] = 'Codificação desconhecida: '; $PHPMAILER_LANG['execute'] = 'Não foi possível executar: '; $PHPMAILER_LANG['extension_missing'] = 'Extensão em falta: '; $PHPMAILER_LANG['file_access'] = 'Não foi possível aceder ao ficheiro: '; $PHPMAILER_LANG['file_open'] = 'Erro ao abrir o ficheiro: '; $PHPMAILER_LANG['from_failed'] = 'O envio falhou para o seguinte endereço do remetente: '; $PHPMAILER_LANG['instantiate'] = 'Não foi possível instanciar a função mail.'; $PHPMAILER_LANG['invalid_address'] = 'Endereço de e-mail inválido: '; $PHPMAILER_LANG['invalid_header'] = 'Nome ou valor do cabeçalho inválido.'; $PHPMAILER_LANG['invalid_hostentry'] = 'Entrada de host inválida: '; $PHPMAILER_LANG['invalid_host'] = 'Host inválido: '; $PHPMAILER_LANG['mailer_not_supported'] = 'O cliente de e-mail não é suportado.'; $PHPMAILER_LANG['provide_address'] = 'Deve fornecer pelo menos um endereço de destinatário.'; $PHPMAILER_LANG['recipients_failed'] = 'Erro SMTP: Falha no envio para os seguintes destinatários: '; $PHPMAILER_LANG['signing'] = 'Erro ao assinar: '; $PHPMAILER_LANG['smtp_code'] = 'Código SMTP: '; $PHPMAILER_LANG['smtp_code_ex'] = 'Informações adicionais SMTP: '; $PHPMAILER_LANG['smtp_connect_failed'] = 'Falha na função SMTP connect().'; $PHPMAILER_LANG['smtp_detail'] = 'Detalhes: '; $PHPMAILER_LANG['smtp_error'] = 'Erro do servidor SMTP: '; $PHPMAILER_LANG['variable_set'] = 'Não foi possível definir ou redefinir a variável: '; 