<?php
 $PHPMAILER_LANG['authenticate'] = 'SMTP -ի սխալ: չհաջողվեց ստուգել իսկությունը.'; $PHPMAILER_LANG['connect_host'] = 'SMTP -ի սխալ: չհաջողվեց կապ հաստատել SMTP սերվերի հետ.'; $PHPMAILER_LANG['data_not_accepted'] = 'SMTP -ի սխալ: տվյալները ընդունված չեն.'; $PHPMAILER_LANG['empty_message'] = 'Հաղորդագրությունը դատարկ է'; $PHPMAILER_LANG['encoding'] = 'Կոդավորման անհայտ տեսակ: '; $PHPMAILER_LANG['execute'] = 'Չհաջողվեց իրականացնել հրամանը: '; $PHPMAILER_LANG['file_access'] = 'Ֆայլը հասանելի չէ: '; $PHPMAILER_LANG['file_open'] = 'Ֆայլի սխալ: ֆայլը չհաջողվեց բացել: '; $PHPMAILER_LANG['from_failed'] = 'Ուղարկողի հետևյալ հասցեն սխալ է: '; $PHPMAILER_LANG['instantiate'] = 'Հնարավոր չէ կանչել mail ֆունկցիան.'; $PHPMAILER_LANG['invalid_address'] = 'Հասցեն սխալ է: '; $PHPMAILER_LANG['mailer_not_supported'] = ' փոստային սերվերի հետ չի աշխատում.'; $PHPMAILER_LANG['provide_address'] = 'Անհրաժեշտ է տրամադրել գոնե մեկ ստացողի e-mail հասցե.'; $PHPMAILER_LANG['recipients_failed'] = 'SMTP -ի սխալ: չի հաջողվել ուղարկել հետևյալ ստացողների հասցեներին: '; $PHPMAILER_LANG['signing'] = 'Ստորագրման սխալ: '; $PHPMAILER_LANG['smtp_connect_failed'] = 'SMTP -ի connect() ֆունկցիան չի հաջողվել'; $PHPMAILER_LANG['smtp_error'] = 'SMTP սերվերի սխալ: '; $PHPMAILER_LANG['variable_set'] = 'Չի հաջողվում ստեղծել կամ վերափոխել փոփոխականը: '; $PHPMAILER_LANG['extension_missing'] = 'Հավելվածը բացակայում է: '; 