<?php
 declare(strict_types=1); namespace Square\Models; class LoyaltyProgramRewardDefinitionScope { public const ORDER = 'ORDER'; public const ITEM_VARIATION = 'ITEM_VARIATION'; public const CATEGORY = 'CATEGORY'; } 