<?php if (!defined('VB_ENTRY')) die('Access denied.'); class vB_Api_Vb4_ajax extends vB_Api { public function dismissnotice($noticeid) { $success = vB_Api::instanceInternal('notice')->dismiss($noticeid); return array('response' => array('dismissed' => $success)); } } 