<?php
 declare(strict_types=1); namespace Jose\Component\Checker; use Exception; class InvalidClaimException extends Exception implements ClaimExceptionInterface { public function __construct( string $message, private readonly string $claim, private readonly mixed $value ) { parent::__construct($message); } public function getClaim(): string { return $this->claim; } public function getValue(): mixed { return $this->value; } } 