<?php if (!defined('VB_ENTRY')) die('Access denied.'); class vB_DataManager_Userpic_Avatar extends vB_DataManager_Userpic { function __construct($registry = NULL, $errtype = NULL) { parent::__construct($registry, $errtype); $this->setStorageOptions('avatar'); } } 