<?php
 declare(strict_types=1); namespace Square\Models; use stdClass; class DigitalWalletDetails implements \JsonSerializable { private $status; private $brand; private $cashAppDetails; public function getStatus(): ?string { return $this->status; } public function setStatus(?string $status): void { $this->status = $status; } public function getBrand(): ?string { return $this->brand; } public function setBrand(?string $brand): void { $this->brand = $brand; } public function getCashAppDetails(): ?CashAppDetails { return $this->cashAppDetails; } public function setCashAppDetails(?CashAppDetails $cashAppDetails): void { $this->cashAppDetails = $cashAppDetails; } #[\ReturnTypeWillChange] public function jsonSerialize(bool $asArrayWhenEmpty = false) { $json = []; if (isset($this->status)) { $json['status'] = $this->status; } if (isset($this->brand)) { $json['brand'] = $this->brand; } if (isset($this->cashAppDetails)) { $json['cash_app_details'] = $this->cashAppDetails; } $json = array_filter($json, function ($val) { return $val !== null; }); return (!$asArrayWhenEmpty && empty($json)) ? new stdClass() : $json; } } 