<?php
 declare(strict_types=1); namespace Square\Models; class CatalogCustomAttributeDefinitionType { public const STRING = 'STRING'; public const BOOLEAN = 'BOOLEAN'; public const NUMBER = 'NUMBER'; public const SELECTION = 'SELECTION'; } 