<?php
 declare(strict_types=1); namespace Square\Models; use stdClass; class SearchLoyaltyAccountsRequestLoyaltyAccountQuery implements \JsonSerializable { private $mappings; private $customerIds; public function getMappings(): ?array { return $this->mappings; } public function setMappings(?array $mappings): void { $this->mappings = $mappings; } public function getCustomerIds(): ?array { return $this->customerIds; } public function setCustomerIds(?array $customerIds): void { $this->customerIds = $customerIds; } #[\ReturnTypeWillChange] public function jsonSerialize(bool $asArrayWhenEmpty = false) { $json = []; if (isset($this->mappings)) { $json['mappings'] = $this->mappings; } if (isset($this->customerIds)) { $json['customer_ids'] = $this->customerIds; } $json = array_filter($json, function ($val) { return $val !== null; }); return (!$asArrayWhenEmpty && empty($json)) ? new stdClass() : $json; } } 