<?php
 class vB_Utility_Template_ParserNode_Text extends vB_Utility_Template_ParserNode { public function validate() : array { return []; } public function compile() : string { return var_export($this->main_node->value, true); } protected function nodename() : string { return '{textnode}'; } } 