<?php
 declare(strict_types=1); namespace Square\Models; use stdClass; class RetrieveInventoryChangesRequest implements \JsonSerializable { private $locationIds; private $cursor; public function getLocationIds(): ?string { return $this->locationIds; } public function setLocationIds(?string $locationIds): void { $this->locationIds = $locationIds; } public function getCursor(): ?string { return $this->cursor; } public function setCursor(?string $cursor): void { $this->cursor = $cursor; } #[\ReturnTypeWillChange] public function jsonSerialize(bool $asArrayWhenEmpty = false) { $json = []; if (isset($this->locationIds)) { $json['location_ids'] = $this->locationIds; } if (isset($this->cursor)) { $json['cursor'] = $this->cursor; } $json = array_filter($json, function ($val) { return $val !== null; }); return (!$asArrayWhenEmpty && empty($json)) ? new stdClass() : $json; } } 