<?php
 declare(strict_types=1); namespace Square\Models; class InvoicePaymentReminderStatus { public const PENDING = 'PENDING'; public const NOT_APPLICABLE = 'NOT_APPLICABLE'; public const SENT = 'SENT'; } 