<?php
 namespace Eluceo\iCal\Presentation\Component\Property\Value; use Eluceo\iCal\Domain\ValueObject\Uri; class QuotedUriValue extends UriValue { private string $uri; public function __construct(Uri $url) { $this->uri = $url->getUri(); } public function __toString(): string { return '"' . $this->uri . '"'; } } 