<?php
 $PHPMAILER_LANG['authenticate'] = 'Ralat SMTP: Tidak dapat pengesahan.'; $PHPMAILER_LANG['connect_host'] = 'Ralat SMTP: Tidak dapat menghubungi hos pelayan SMTP.'; $PHPMAILER_LANG['data_not_accepted'] = 'Ralat SMTP: Data tidak diterima oleh pelayan.'; $PHPMAILER_LANG['empty_message'] = 'Tiada isi untuk mesej'; $PHPMAILER_LANG['encoding'] = 'Pengekodan tidak diketahui: '; $PHPMAILER_LANG['execute'] = 'Tidak dapat melaksanakan: '; $PHPMAILER_LANG['file_access'] = 'Tidak dapat mengakses fail: '; $PHPMAILER_LANG['file_open'] = 'Ralat Fail: Tidak dapat membuka fail: '; $PHPMAILER_LANG['from_failed'] = 'Berikut merupakan ralat dari alamat e-mel: '; $PHPMAILER_LANG['instantiate'] = 'Tidak dapat memberi contoh fungsi e-mel.'; $PHPMAILER_LANG['invalid_address'] = 'Alamat emel tidak sah: '; $PHPMAILER_LANG['mailer_not_supported'] = ' jenis penghantar emel tidak disokong.'; $PHPMAILER_LANG['provide_address'] = 'Anda perlu menyediakan sekurang-kurangnya satu alamat e-mel penerima.'; $PHPMAILER_LANG['recipients_failed'] = 'Ralat SMTP: Penerima e-mel berikut telah gagal: '; $PHPMAILER_LANG['signing'] = 'Ralat pada tanda tangan: '; $PHPMAILER_LANG['smtp_connect_failed'] = 'SMTP Connect() telah gagal.'; $PHPMAILER_LANG['smtp_error'] = 'Ralat pada pelayan SMTP: '; $PHPMAILER_LANG['variable_set'] = 'Tidak boleh menetapkan atau menetapkan semula pembolehubah: '; $PHPMAILER_LANG['extension_missing'] = 'Sambungan hilang: '; 