<?php
 class vB_Utility_Geoip_None extends vB_Utility_Geoip { public function getLocation($address) { return 'UNKNOWN'; } public function getIpData($address) { return 'No Geoip Provider has been configured'; } } 