<?php
 declare(strict_types=1); namespace Square\Models; class DisputeEvidenceType { public const GENERIC_EVIDENCE = 'GENERIC_EVIDENCE'; public const ONLINE_OR_APP_ACCESS_LOG = 'ONLINE_OR_APP_ACCESS_LOG'; public const AUTHORIZATION_DOCUMENTATION = 'AUTHORIZATION_DOCUMENTATION'; public const CANCELLATION_OR_REFUND_DOCUMENTATION = 'CANCELLATION_OR_REFUND_DOCUMENTATION'; public const CARDHOLDER_COMMUNICATION = 'CARDHOLDER_COMMUNICATION'; public const CARDHOLDER_INFORMATION = 'CARDHOLDER_INFORMATION'; public const PURCHASE_ACKNOWLEDGEMENT = 'PURCHASE_ACKNOWLEDGEMENT'; public const DUPLICATE_CHARGE_DOCUMENTATION = 'DUPLICATE_CHARGE_DOCUMENTATION'; public const PRODUCT_OR_SERVICE_DESCRIPTION = 'PRODUCT_OR_SERVICE_DESCRIPTION'; public const RECEIPT = 'RECEIPT'; public const SERVICE_RECEIVED_DOCUMENTATION = 'SERVICE_RECEIVED_DOCUMENTATION'; public const PROOF_OF_DELIVERY_DOCUMENTATION = 'PROOF_OF_DELIVERY_DOCUMENTATION'; public const RELATED_TRANSACTION_DOCUMENTATION = 'RELATED_TRANSACTION_DOCUMENTATION'; public const REBUTTAL_EXPLANATION = 'REBUTTAL_EXPLANATION'; public const TRACKING_NUMBER = 'TRACKING_NUMBER'; } 