<?php
 declare(strict_types=1); namespace Jose\Component\Signature\Serializer; use Jose\Component\Signature\JWS; interface JWSSerializer { public function name(): string; public function displayName(): string; public function serialize(JWS $jws, ?int $signatureIndex = null): string; public function unserialize(string $input): JWS; } 