<?php
 class vB_Utility_Template_ParserNode_Curly_Debugexit extends vB_Utility_Template_ParserNode_Curly { public function validate() : array { return []; } public function compile() : string { return '\'\'; vB_Template_Runtime::debugExit(); $final_rendered .= \'\''; } } 