<?php
 declare(strict_types=1); namespace Square\Models; use stdClass; class BatchDeleteCatalogObjectsResponse implements \JsonSerializable { private $errors; private $deletedObjectIds; private $deletedAt; public function getErrors(): ?array { return $this->errors; } public function setErrors(?array $errors): void { $this->errors = $errors; } public function getDeletedObjectIds(): ?array { return $this->deletedObjectIds; } public function setDeletedObjectIds(?array $deletedObjectIds): void { $this->deletedObjectIds = $deletedObjectIds; } public function getDeletedAt(): ?string { return $this->deletedAt; } public function setDeletedAt(?string $deletedAt): void { $this->deletedAt = $deletedAt; } #[\ReturnTypeWillChange] public function jsonSerialize(bool $asArrayWhenEmpty = false) { $json = []; if (isset($this->errors)) { $json['errors'] = $this->errors; } if (isset($this->deletedObjectIds)) { $json['deleted_object_ids'] = $this->deletedObjectIds; } if (isset($this->deletedAt)) { $json['deleted_at'] = $this->deletedAt; } $json = array_filter($json, function ($val) { return $val !== null; }); return (!$asArrayWhenEmpty && empty($json)) ? new stdClass() : $json; } } 