<?php
 declare(strict_types=1); namespace Square\Models; use stdClass; class UpdateCustomerRequest implements \JsonSerializable { private $givenName; private $familyName; private $companyName; private $nickname; private $emailAddress; private $address; private $phoneNumber; private $referenceId; private $note; private $birthday; private $version; private $taxIds; public function getGivenName(): ?string { return $this->givenName; } public function setGivenName(?string $givenName): void { $this->givenName = $givenName; } public function getFamilyName(): ?string { return $this->familyName; } public function setFamilyName(?string $familyName): void { $this->familyName = $familyName; } public function getCompanyName(): ?string { return $this->companyName; } public function setCompanyName(?string $companyName): void { $this->companyName = $companyName; } public function getNickname(): ?string { return $this->nickname; } public function setNickname(?string $nickname): void { $this->nickname = $nickname; } public function getEmailAddress(): ?string { return $this->emailAddress; } public function setEmailAddress(?string $emailAddress): void { $this->emailAddress = $emailAddress; } public function getAddress(): ?Address { return $this->address; } public function setAddress(?Address $address): void { $this->address = $address; } public function getPhoneNumber(): ?string { return $this->phoneNumber; } public function setPhoneNumber(?string $phoneNumber): void { $this->phoneNumber = $phoneNumber; } public function getReferenceId(): ?string { return $this->referenceId; } public function setReferenceId(?string $referenceId): void { $this->referenceId = $referenceId; } public function getNote(): ?string { return $this->note; } public function setNote(?string $note): void { $this->note = $note; } public function getBirthday(): ?string { return $this->birthday; } public function setBirthday(?string $birthday): void { $this->birthday = $birthday; } public function getVersion(): ?int { return $this->version; } public function setVersion(?int $version): void { $this->version = $version; } public function getTaxIds(): ?CustomerTaxIds { return $this->taxIds; } public function setTaxIds(?CustomerTaxIds $taxIds): void { $this->taxIds = $taxIds; } #[\ReturnTypeWillChange] public function jsonSerialize(bool $asArrayWhenEmpty = false) { $json = []; if (isset($this->givenName)) { $json['given_name'] = $this->givenName; } if (isset($this->familyName)) { $json['family_name'] = $this->familyName; } if (isset($this->companyName)) { $json['company_name'] = $this->companyName; } if (isset($this->nickname)) { $json['nickname'] = $this->nickname; } if (isset($this->emailAddress)) { $json['email_address'] = $this->emailAddress; } if (isset($this->address)) { $json['address'] = $this->address; } if (isset($this->phoneNumber)) { $json['phone_number'] = $this->phoneNumber; } if (isset($this->referenceId)) { $json['reference_id'] = $this->referenceId; } if (isset($this->note)) { $json['note'] = $this->note; } if (isset($this->birthday)) { $json['birthday'] = $this->birthday; } if (isset($this->version)) { $json['version'] = $this->version; } if (isset($this->taxIds)) { $json['tax_ids'] = $this->taxIds; } $json = array_filter($json, function ($val) { return $val !== null; }); return (!$asArrayWhenEmpty && empty($json)) ? new stdClass() : $json; } } 