<?php
 class vB_DataManager_StyleVarCustom extends vB_DataManager_StyleVar { protected array $childfields = []; public function add_child($key, $descriptor) { $this->childfields[$key] = $descriptor; } public $datatype = 'Custom'; } 