<?php
 declare(strict_types=1); namespace Ramsey\Uuid\Converter; use Ramsey\Uuid\Type\Hexadecimal; use Ramsey\Uuid\Type\Time; interface TimeConverterInterface { public function calculateTime(string $seconds, string $microseconds): Hexadecimal; public function convertTime(Hexadecimal $uuidTimestamp): Time; } 