<?php
 declare(strict_types=1); namespace Square\Models; class MeasurementUnitLength { public const IMPERIAL_INCH = 'IMPERIAL_INCH'; public const IMPERIAL_FOOT = 'IMPERIAL_FOOT'; public const IMPERIAL_YARD = 'IMPERIAL_YARD'; public const IMPERIAL_MILE = 'IMPERIAL_MILE'; public const METRIC_MILLIMETER = 'METRIC_MILLIMETER'; public const METRIC_CENTIMETER = 'METRIC_CENTIMETER'; public const METRIC_METER = 'METRIC_METER'; public const METRIC_KILOMETER = 'METRIC_KILOMETER'; } 