<?php
 $PHPMAILER_LANG['authenticate'] = 'SMTP greška: autentifikacija nije uspela.'; $PHPMAILER_LANG['connect_host'] = 'SMTP greška: povezivanje sa SMTP serverom nije uspelo.'; $PHPMAILER_LANG['data_not_accepted'] = 'SMTP greška: podaci nisu prihvaćeni.'; $PHPMAILER_LANG['empty_message'] = 'Sadržaj poruke je prazan.'; $PHPMAILER_LANG['encoding'] = 'Nepoznato kodiranje: '; $PHPMAILER_LANG['execute'] = 'Nije moguće izvršiti naredbu: '; $PHPMAILER_LANG['file_access'] = 'Nije moguće pristupiti datoteci: '; $PHPMAILER_LANG['file_open'] = 'Nije moguće otvoriti datoteku: '; $PHPMAILER_LANG['from_failed'] = 'SMTP greška: slanje sa sledećih adresa nije uspelo: '; $PHPMAILER_LANG['recipients_failed'] = 'SMTP greška: slanje na sledeće adrese nije uspelo: '; $PHPMAILER_LANG['instantiate'] = 'Nije moguće pokrenuti mail funkciju.'; $PHPMAILER_LANG['invalid_address'] = 'Poruka nije poslata. Neispravna adresa: '; $PHPMAILER_LANG['mailer_not_supported'] = ' majler nije podržan.'; $PHPMAILER_LANG['provide_address'] = 'Definišite bar jednu adresu primaoca.'; $PHPMAILER_LANG['signing'] = 'Greška prilikom prijave: '; $PHPMAILER_LANG['smtp_connect_failed'] = 'Povezivanje sa SMTP serverom nije uspelo.'; $PHPMAILER_LANG['smtp_error'] = 'Greška SMTP servera: '; $PHPMAILER_LANG['variable_set'] = 'Nije moguće zadati niti resetovati promenljivu: '; $PHPMAILER_LANG['extension_missing'] = 'Nedostaje proširenje: '; 