<?php
 class vB_DataManager_StyleVarSize extends vB_DataManager_StyleVar { protected array $childfields = [ 'size' => [vB_Cleaner::TYPE_STR, vB_DataManager_Constants::REQ_NO], 'units' => [vB_Cleaner::TYPE_STR, vB_DataManager_Constants::REQ_NO, vB_DataManager_Constants::VF_METHOD, 'verify_units'], 'stylevar_size' => [vB_Cleaner::TYPE_STR, vB_DataManager_Constants::REQ_NO, vB_DataManager_Constants::VF_METHOD, 'verify_value_stylevar'], 'stylevar_units' => [vB_Cleaner::TYPE_STR, vB_DataManager_Constants::REQ_NO, vB_DataManager_Constants::VF_METHOD, 'verify_value_stylevar'], ]; public $datatype = 'size'; } 