<?php if (!defined('VB_ENTRY')) die('Access denied.'); class vB_DataManager_Constants { use vB_Trait_NoSerialize; const ERRTYPE_ARRAY = 0; const ERRTYPE_STANDARD = 1; const ERRTYPE_CP = 2; const ERRTYPE_SILENT = 3; const ERRTYPE_ARRAY_UNPROCESSED = 4; const ERRTYPE_UPGRADE = 5; const VF_TYPE = 0; const VF_REQ = 1; const VF_CODE = 2; const VF_METHODNAME = 3; const VF_METHOD = '_-_mEtHoD_-_'; const REQ_NO = 0; const REQ_YES = 1; const REQ_AUTO = 2; const REQ_INCR = 3; } 