<?php
 declare(strict_types=1); namespace Square\Models; class OrderState { public const OPEN = 'OPEN'; public const COMPLETED = 'COMPLETED'; public const CANCELED = 'CANCELED'; public const DRAFT = 'DRAFT'; } 