<?php
 class vB_Systemevent_Item_ChannelTask_Delete extends vB_Systemevent_Item_ChannelTask { public function run() : void { $topics = $this->getTopics(); if (count($topics) > 0) { vB_Library::instance('node')->deleteNodes($topics, true, ''); } } } 