<?php
 declare(strict_types=1); namespace Square\Models; class DeviceCodeStatus { public const UNKNOWN = 'UNKNOWN'; public const UNPAIRED = 'UNPAIRED'; public const PAIRED = 'PAIRED'; public const EXPIRED = 'EXPIRED'; } 