<?php
 class vB_DataManager_StyleVarImage extends vB_DataManager_StyleVar { protected array $childfields = [ 'image' => [vB_Cleaner::TYPE_STR, vB_DataManager_Constants::REQ_NO, vB_DataManager_Constants::VF_METHOD, 'verify_image'], ]; public $datatype = 'Image'; } 