<?php
 declare(strict_types=1); namespace Square\Models; class OrderLineItemTaxScope { public const OTHER_TAX_SCOPE = 'OTHER_TAX_SCOPE'; public const LINE_ITEM = 'LINE_ITEM'; public const ORDER = 'ORDER'; } 