<?php
 declare(strict_types=1); namespace Shopify\Rest\Admin2024_01; use Shopify\Auth\Session; use Shopify\Rest\Base; class Collection extends Base { public static string $API_VERSION = "2024-01"; protected static array $HAS_ONE = [ "image" => Image::class ]; protected static array $HAS_MANY = []; protected static array $PATHS = [ ["http_method" => "get", "operation" => "get", "ids" => ["id"], "path" => "collections/<id>.json"], ["http_method" => "get", "operation" => "products", "ids" => ["id"], "path" => "collections/<id>/products.json"] ]; public static function find( Session $session, $id, array $urlIds = [], array $params = [] ): ?Collection { $result = parent::baseFind( $session, array_merge(["id" => $id], $urlIds), $params, ); return !empty($result) ? $result[0] : null; } public static function products( Session $session, $id, array $urlIds = [], array $params = [] ): ?array { $response = parent::request( "get", "products", $session, array_merge(["id" => $id], $urlIds), $params, [], ); return $response->getDecodedBody(); } } 