<?php
 class vB_Utility_Template_ParserNode_Curly_Action extends vB_Utility_Template_ParserNode_Curly { public function validate() : array { $errors = []; $attributecount = sizeof($this->main_node->attributes); if ($attributecount == 0) { $errors[] = 'no_variable_specified'; } return $errors; } public function compile() : string { $arguments = $this->getRenderedAttributes(1); $string = $this->main_node->attributes[0]; $string = ($string[0] !== '$' ? '$' : '') . $string; return '\'\'; ' . $string . ' = vB_Template_Runtime::parseAction(' . implode(', ', $arguments) . '); $final_rendered .= \'\''; } } 