<?php
 declare(strict_types=1); namespace Shopify\Auth; interface SessionStorage { public function storeSession(Session $session): bool; public function loadSession(string $sessionId); public function deleteSession(string $sessionId): bool; } 