/*
 =======================================================================*\
|| ###################################################################### ||
|| # vBulletin 6.2.3
|| # ------------------------------------------------------------------ # ||
|| # Copyright 2000-2026 MH Sub I, LLC dba vBulletin. All Rights Reserved.  # ||
|| # This file may not be redistributed in whole or significant part.   # ||
|| # ----------------- VBULLETIN IS NOT FREE SOFTWARE ----------------- # ||
|| # http://www.vbulletin.com | http://www.vbulletin.com/license.html   # ||
|| ###################################################################### ||
\*========================================================================*/
(function(f){function l(a,b){a=a.data();b.sortfield=a.sortby;b.sortorder=a.sortorder}function q(a){g(this,(b,d,c)=>c.pagenumber=a)}function r(a){g(a,(b,d,c)=>c.pagenumber=d.data("page"));return!1}function t(a){g(a,(b,d,c)=>{c.username="";c.startswith=m(d)})}function u(a){g(a,(b,d,c)=>{b=d.val().toLowerCase();c.username="";c.startswith="empty"==b?"":b})}function v(a){g(a,(b,d,c)=>{c.usergroups=d.val()})}function w(a){g(a,(b,d,c)=>{l(d,c)});return!1}function x(a){g(a,(b,d,c)=>{b=d.closest(".js-sort-by");
b.hasClass("selected")&&b.data("sortorder","asc"==b.data("sortorder")?"desc":"asc");l(b,c)})}function y(a){g(a,(b,d,c)=>{b=d.val();c.startswith=b?null:"";c.username=b})}function g(a,b){var d=f(a.currentTarget||a);a=d.closest(".js-memberlist-widget");let c={perpage:a.find(".js-per-page").data("perpage"),pagenumber:a.find(".toolbar-pagenav .js-pagenum").val(),startswith:m(a.find(".js-letter.selected")),username:a.find(".js-memberlist__usernamesearch").val(),usergroups:a.find(".js-drop-down-usergroup").val()};
l(a.find(".js-sort-by.selected"),c);c.pagenumber=1;b(a,d,c);z(c.startswith,a);b=c.sortfield;d=c.sortorder;let e=a.find(".js-sort-by");n(e);n(e.filter("[data-sortby="+b+"]"),b,d);b=a.find(".js-memberlist-sortby-option").closest(".b-comp-menu-dropdown__content-item").removeClass("b-comp-menu-dropdown__content-item--current").end().filter("[data-sortby={0}][data-sortorder={1}]".format(b,d)).closest(".b-comp-menu-dropdown__content-item").addClass("b-comp-menu-dropdown__content-item--current");b.closest(".js-comp-menu-dropdown").find(".js-comp-menu-dropdown__trigger-text").text(b.text());
p(a.find(".js-drop-down-usergroup"),c.usergroups);a.find(".js-memberlist__usernamesearch").val(c.username);A(a,c)}function n(a,b="",d=""){b=!!b;asc="asc"==d;a.toggleClass("selected",b).find(".js-sort-arrow").toggleClass("h-hide-imp",!b).toggleClass("fa-caret-up",b&&asc).toggleClass("fa-caret-down",b&&!asc)}function p(a,b){a.val(b).filter(".selectBox").selectBox("value",b)}function z(a,b){let d=b.find(".js-memberlist__letterfilter .letter"),c=e=>p(b.find(".js-drop-down-startswith"),e);d.removeClass("selected");
c("empty");if(null!==a){let e;d.filter(".js-letter-"+(null!=(e={"":"all","#":"numbers"}[a])?e:a)).addClass("selected");c(a)}}function A(a,b){let d=a.find(".js-memberlist-route-info").data("routeinfojson");vBulletin.ajaxtools.render({template:"memberlist_items",data:{criteria:b,routeInfoJson:d},success:function(c){a.find(".js-memberlist-table-body").replaceWith(c.template);c=a.find(".js-memberlist-table-body");var e=c.data("totalPages");let h=c.find(".js-pagenav-current-button").data("page")||1;var k=
a.find(".js-toolbar-pagenav"),B=k.find(".js-pagenum").val(),C=k.find(".right-arrow");k.find(".pagetotal").text(e);C.addClass("h-disabled");B<e&&k.find(".right-arrow").removeClass("h-disabled");e=a.find(".js-toolbar-pagenav");e.find(".js-pagenum").val(h);e.find(".left-arrow, .right-arrow").removeClass("h-disabled");1>=h&&e.find(".left-arrow").addClass("h-disabled");k=e.find(".pagetotal").text();h>=k&&e.find(".right-arrow").addClass("h-disabled");c=c.find(".js-pagenav").clone();a.find(".js-under-toolbar-pagenav .js-pagenav").replaceWith(c);
vBulletin.Responsive.Debounce.checkShrinkEvent(f(".js-pagenav"))}})}let m=a=>(a.is(".js-letter-all")?"":a.html()||"").toLowerCase();f(function(){vBulletin.pagination({context:".memberlist-widget .conversation-toolbar",onPageChanged:q});var a=f(".js-drop-down-startswith");let b=f(".js-drop-down-usergroup"),d=a.add(b).filter(":not(:visible)").toArray();a.selectBox().change(u);b.selectBox().change(v);d.length&&(new MutationObserver((c,e)=>{for(c=d.length-1;0<=c;c--){let h=f(d[c]);h.is(":visible")&&(h.selectBox(),
d.splice(c,1))}d.length||e.disconnect()})).observe(document.body,{attributes:!0,attributeFilter:["class"]});a=f(".memberlist-widget");a.offon("click.memberlist",".js-memberlist__letterfilter .letter",t);a.offon("click.memberlist",".js-sort-label",x);a.offon("click.memberlist",".js-memberlist-sortby-option",w);a.offon("click.memberlist",".js-pagenav .js-pagenav-button",r);f(".js-memberlist__usernamesearch").offon("keyup.memberlist",f.debounce(400,y))})})(jQuery);
