<?php
 declare(strict_types=1); namespace Shopify\Rest\Admin2024_04; use Shopify\Auth\Session; use Shopify\Rest\Base; class GiftCardAdjustment extends Base { public static string $API_VERSION = "2024-04"; protected static array $HAS_ONE = []; protected static array $HAS_MANY = []; protected static array $PATHS = [ ["http_method" => "get", "operation" => "get", "ids" => ["gift_card_id"], "path" => "gift_cards/<gift_card_id>/adjustments.json"], ["http_method" => "get", "operation" => "get", "ids" => ["gift_card_id", "id"], "path" => "gift_cards/<gift_card_id>/adjustments/<id>.json"], ["http_method" => "post", "operation" => "post", "ids" => ["gift_card_id"], "path" => "gift_cards/<gift_card_id>/adjustments.json"] ]; protected static function getJsonBodyName(): string { return "adjustment"; } public static function find( Session $session, $id, array $urlIds = [], array $params = [] ): ?GiftCardAdjustment { $result = parent::baseFind( $session, array_merge(["id" => $id], $urlIds), $params, ); return !empty($result) ? $result[0] : null; } public static function all( Session $session, array $urlIds = [], array $params = [] ): array { return parent::baseFind( $session, $urlIds, $params, ); } } 