<?php
 declare(strict_types=1); namespace Ramsey\Collection; use Ramsey\Collection\Exception\NoSuchElementException; use RuntimeException; interface DoubleEndedQueueInterface extends QueueInterface { public function addFirst(mixed $element): bool; public function addLast(mixed $element): bool; public function offerFirst(mixed $element): bool; public function offerLast(mixed $element): bool; public function removeFirst(): mixed; public function removeLast(): mixed; public function pollFirst(): mixed; public function pollLast(): mixed; public function firstElement(): mixed; public function lastElement(): mixed; public function peekFirst(): mixed; public function peekLast(): mixed; } 