<?php
 namespace League\OAuth2\Client\Tool; use League\OAuth2\Client\Token\AccessTokenInterface; trait BearerAuthorizationTrait { protected function getAuthorizationHeaders($token = null) { return ['Authorization' => 'Bearer ' . $token]; } } 