/*
 =======================================================================*\
|| ###################################################################### ||
|| # vBulletin 6.2.3
|| # ------------------------------------------------------------------ # ||
|| # Copyright 2000-2026 MH Sub I, LLC dba vBulletin. All Rights Reserved.  # ||
|| # This file may not be redistributed in whole or significant part.   # ||
|| # ----------------- VBULLETIN IS NOT FREE SOFTWARE ----------------- # ||
|| # http://www.vbulletin.com | http://www.vbulletin.com/license.html   # ||
|| ###################################################################### ||
\*========================================================================*/
(function(a){function c(b){b.originalEvent.getModifierState&&a("#cap_lock_alert").toggle(b.originalEvent.getModifierState("CapsLock"))}a(function(){let b=document.forms.loginform;a(document).one("mousemove",c);a(document).on("keydown",c);a(b).on("submit",function(){md5hash(this.vb_login_password,this.vb_login_md5password,this.vb_login_md5password_utf);if(this.nojs&&this.nojs.checked){let d=-1!=this.url.value.search(/\?/)?"&":"?";this.url.value+=d+"nojs=1"}});a("#cplogin_options_button").on("click",
function(){a("#loginoptions").show();this.disabled=!0});""==b.vb_login_username.value?b.vb_login_username.focus():b.vb_login_password.focus()})})(jQuery);
