<?php
 declare(strict_types=1); namespace Square\Models; class GiftCardActivityAdjustDecrementReason { public const SUSPICIOUS_ACTIVITY = 'SUSPICIOUS_ACTIVITY'; public const BALANCE_ACCIDENTALLY_INCREASED = 'BALANCE_ACCIDENTALLY_INCREASED'; public const SUPPORT_ISSUE = 'SUPPORT_ISSUE'; } 