<?php
 use PHPMailer\PHPMailer\PHPMailer; use PHPMailer\PHPMailer\SMTP; class vB_Mail_Transport_PhpMailer_PhpMail extends vB_Mail_Transport_PhpMailer { protected function createPhpMailer() : PHPMailer { $mailer = parent::createPhpMailer(); $mailer->isMail(); return $mailer; } } 