<?php
 declare(strict_types=1); namespace Square\Models; use stdClass; class StandardUnitDescriptionGroup implements \JsonSerializable { private $standardUnitDescriptions; private $languageCode; public function getStandardUnitDescriptions(): ?array { return $this->standardUnitDescriptions; } public function setStandardUnitDescriptions(?array $standardUnitDescriptions): void { $this->standardUnitDescriptions = $standardUnitDescriptions; } public function getLanguageCode(): ?string { return $this->languageCode; } public function setLanguageCode(?string $languageCode): void { $this->languageCode = $languageCode; } #[\ReturnTypeWillChange] public function jsonSerialize(bool $asArrayWhenEmpty = false) { $json = []; if (isset($this->standardUnitDescriptions)) { $json['standard_unit_descriptions'] = $this->standardUnitDescriptions; } if (isset($this->languageCode)) { $json['language_code'] = $this->languageCode; } $json = array_filter($json, function ($val) { return $val !== null; }); return (!$asArrayWhenEmpty && empty($json)) ? new stdClass() : $json; } } 