<?php
 declare(strict_types=1); namespace Shopify\Rest\Admin2024_07; use Shopify\Auth\Session; use Shopify\Rest\Base; class ApplicationCredit extends Base { public static string $API_VERSION = "2024-07"; protected static array $HAS_ONE = [ "currency" => Currency::class ]; protected static array $HAS_MANY = []; protected static array $PATHS = [ ["http_method" => "get", "operation" => "get", "ids" => [], "path" => "application_credits.json"], ["http_method" => "get", "operation" => "get", "ids" => ["id"], "path" => "application_credits/<id>.json"] ]; public static function find( Session $session, $id, array $urlIds = [], array $params = [] ): ?ApplicationCredit { $result = parent::baseFind( $session, array_merge(["id" => $id], $urlIds), $params, ); return !empty($result) ? $result[0] : null; } public static function all( Session $session, array $urlIds = [], array $params = [] ): array { return parent::baseFind( $session, [], $params, ); } } 