<?php
 declare(strict_types=1); namespace Square\Models; use stdClass; class InvoicePaymentReminder implements \JsonSerializable { private $uid; private $relativeScheduledDays; private $message; private $status; private $sentAt; public function getUid(): ?string { return $this->uid; } public function setUid(?string $uid): void { $this->uid = $uid; } public function getRelativeScheduledDays(): ?int { return $this->relativeScheduledDays; } public function setRelativeScheduledDays(?int $relativeScheduledDays): void { $this->relativeScheduledDays = $relativeScheduledDays; } public function getMessage(): ?string { return $this->message; } public function setMessage(?string $message): void { $this->message = $message; } public function getStatus(): ?string { return $this->status; } public function setStatus(?string $status): void { $this->status = $status; } public function getSentAt(): ?string { return $this->sentAt; } public function setSentAt(?string $sentAt): void { $this->sentAt = $sentAt; } #[\ReturnTypeWillChange] public function jsonSerialize(bool $asArrayWhenEmpty = false) { $json = []; if (isset($this->uid)) { $json['uid'] = $this->uid; } if (isset($this->relativeScheduledDays)) { $json['relative_scheduled_days'] = $this->relativeScheduledDays; } if (isset($this->message)) { $json['message'] = $this->message; } if (isset($this->status)) { $json['status'] = $this->status; } if (isset($this->sentAt)) { $json['sent_at'] = $this->sentAt; } $json = array_filter($json, function ($val) { return $val !== null; }); return (!$asArrayWhenEmpty && empty($json)) ? new stdClass() : $json; } } 