<?php
 declare(strict_types=1); namespace Square\Models; use stdClass; class BookingCreatorDetails implements \JsonSerializable { private $creatorType; private $teamMemberId; private $customerId; public function getCreatorType(): ?string { return $this->creatorType; } public function setCreatorType(?string $creatorType): void { $this->creatorType = $creatorType; } public function getTeamMemberId(): ?string { return $this->teamMemberId; } public function setTeamMemberId(?string $teamMemberId): void { $this->teamMemberId = $teamMemberId; } public function getCustomerId(): ?string { return $this->customerId; } public function setCustomerId(?string $customerId): void { $this->customerId = $customerId; } #[\ReturnTypeWillChange] public function jsonSerialize(bool $asArrayWhenEmpty = false) { $json = []; if (isset($this->creatorType)) { $json['creator_type'] = $this->creatorType; } if (isset($this->teamMemberId)) { $json['team_member_id'] = $this->teamMemberId; } if (isset($this->customerId)) { $json['customer_id'] = $this->customerId; } $json = array_filter($json, function ($val) { return $val !== null; }); return (!$asArrayWhenEmpty && empty($json)) ? new stdClass() : $json; } } 