<?php
 declare(strict_types=1); namespace Square\Models; use stdClass; class DisputeEvidence implements \JsonSerializable { private $evidenceId; private $id; private $disputeId; private $evidenceFile; private $evidenceText; private $uploadedAt; private $evidenceType; public function getEvidenceId(): ?string { return $this->evidenceId; } public function setEvidenceId(?string $evidenceId): void { $this->evidenceId = $evidenceId; } public function getId(): ?string { return $this->id; } public function setId(?string $id): void { $this->id = $id; } public function getDisputeId(): ?string { return $this->disputeId; } public function setDisputeId(?string $disputeId): void { $this->disputeId = $disputeId; } public function getEvidenceFile(): ?DisputeEvidenceFile { return $this->evidenceFile; } public function setEvidenceFile(?DisputeEvidenceFile $evidenceFile): void { $this->evidenceFile = $evidenceFile; } public function getEvidenceText(): ?string { return $this->evidenceText; } public function setEvidenceText(?string $evidenceText): void { $this->evidenceText = $evidenceText; } public function getUploadedAt(): ?string { return $this->uploadedAt; } public function setUploadedAt(?string $uploadedAt): void { $this->uploadedAt = $uploadedAt; } public function getEvidenceType(): ?string { return $this->evidenceType; } public function setEvidenceType(?string $evidenceType): void { $this->evidenceType = $evidenceType; } #[\ReturnTypeWillChange] public function jsonSerialize(bool $asArrayWhenEmpty = false) { $json = []; if (isset($this->evidenceId)) { $json['evidence_id'] = $this->evidenceId; } if (isset($this->id)) { $json['id'] = $this->id; } if (isset($this->disputeId)) { $json['dispute_id'] = $this->disputeId; } if (isset($this->evidenceFile)) { $json['evidence_file'] = $this->evidenceFile; } if (isset($this->evidenceText)) { $json['evidence_text'] = $this->evidenceText; } if (isset($this->uploadedAt)) { $json['uploaded_at'] = $this->uploadedAt; } if (isset($this->evidenceType)) { $json['evidence_type'] = $this->evidenceType; } $json = array_filter($json, function ($val) { return $val !== null; }); return (!$asArrayWhenEmpty && empty($json)) ? new stdClass() : $json; } } 