<?php
 declare(strict_types=1); namespace Shopify\Rest\Admin2023_07; use Shopify\Auth\Session; use Shopify\Rest\Base; class DisputeFileUpload extends Base { public static string $API_VERSION = "2023-07"; protected static array $HAS_ONE = []; protected static array $HAS_MANY = []; protected static array $PATHS = [ ["http_method" => "delete", "operation" => "delete", "ids" => ["dispute_id", "id"], "path" => "shopify_payments/disputes/<dispute_id>/dispute_file_uploads/<id>.json"], ["http_method" => "post", "operation" => "post", "ids" => ["dispute_id"], "path" => "shopify_payments/disputes/<dispute_id>/dispute_file_uploads.json"] ]; public static function delete( Session $session, $id, array $urlIds = [], array $params = [] ): ?array { $response = parent::request( "delete", "delete", $session, array_merge(["id" => $id], $urlIds), $params, ); return $response->getDecodedBody(); } } 