<?php
 declare(strict_types=1); namespace Shopify\Rest\Admin2023_04; use Shopify\Auth\Session; use Shopify\Rest\Base; class ProductResourceFeedback extends Base { public static string $API_VERSION = "2023-04"; protected static array $HAS_ONE = []; protected static array $HAS_MANY = []; protected static array $PATHS = [ ["http_method" => "get", "operation" => "get", "ids" => ["product_id"], "path" => "products/<product_id>/resource_feedback.json"], ["http_method" => "post", "operation" => "post", "ids" => ["product_id"], "path" => "products/<product_id>/resource_feedback.json"] ]; protected static function getJsonBodyName(): string { return "resource_feedback"; } public static function all( Session $session, array $urlIds = [], array $params = [] ): array { return parent::baseFind( $session, $urlIds, $params, ); } } 