<?php
 declare(strict_types=1); namespace Square\Models; use stdClass; class TeamMemberBookingProfile implements \JsonSerializable { private $teamMemberId; private $description; private $displayName; private $isBookable; private $profileImageUrl; public function getTeamMemberId(): ?string { return $this->teamMemberId; } public function setTeamMemberId(?string $teamMemberId): void { $this->teamMemberId = $teamMemberId; } public function getDescription(): ?string { return $this->description; } public function setDescription(?string $description): void { $this->description = $description; } public function getDisplayName(): ?string { return $this->displayName; } public function setDisplayName(?string $displayName): void { $this->displayName = $displayName; } public function getIsBookable(): ?bool { return $this->isBookable; } public function setIsBookable(?bool $isBookable): void { $this->isBookable = $isBookable; } public function getProfileImageUrl(): ?string { return $this->profileImageUrl; } public function setProfileImageUrl(?string $profileImageUrl): void { $this->profileImageUrl = $profileImageUrl; } #[\ReturnTypeWillChange] public function jsonSerialize(bool $asArrayWhenEmpty = false) { $json = []; if (isset($this->teamMemberId)) { $json['team_member_id'] = $this->teamMemberId; } if (isset($this->description)) { $json['description'] = $this->description; } if (isset($this->displayName)) { $json['display_name'] = $this->displayName; } if (isset($this->isBookable)) { $json['is_bookable'] = $this->isBookable; } if (isset($this->profileImageUrl)) { $json['profile_image_url'] = $this->profileImageUrl; } $json = array_filter($json, function ($val) { return $val !== null; }); return (!$asArrayWhenEmpty && empty($json)) ? new stdClass() : $json; } } 