<?php
 declare(strict_types=1); namespace Square\Models; use stdClass; class ListCardsRequest implements \JsonSerializable { private $cursor; private $customerId; private $includeDisabled; private $referenceId; private $sortOrder; public function getCursor(): ?string { return $this->cursor; } public function setCursor(?string $cursor): void { $this->cursor = $cursor; } public function getCustomerId(): ?string { return $this->customerId; } public function setCustomerId(?string $customerId): void { $this->customerId = $customerId; } public function getIncludeDisabled(): ?bool { return $this->includeDisabled; } public function setIncludeDisabled(?bool $includeDisabled): void { $this->includeDisabled = $includeDisabled; } public function getReferenceId(): ?string { return $this->referenceId; } public function setReferenceId(?string $referenceId): void { $this->referenceId = $referenceId; } public function getSortOrder(): ?string { return $this->sortOrder; } public function setSortOrder(?string $sortOrder): void { $this->sortOrder = $sortOrder; } #[\ReturnTypeWillChange] public function jsonSerialize(bool $asArrayWhenEmpty = false) { $json = []; if (isset($this->cursor)) { $json['cursor'] = $this->cursor; } if (isset($this->customerId)) { $json['customer_id'] = $this->customerId; } if (isset($this->includeDisabled)) { $json['include_disabled'] = $this->includeDisabled; } if (isset($this->referenceId)) { $json['reference_id'] = $this->referenceId; } if (isset($this->sortOrder)) { $json['sort_order'] = $this->sortOrder; } $json = array_filter($json, function ($val) { return $val !== null; }); return (!$asArrayWhenEmpty && empty($json)) ? new stdClass() : $json; } } 