<?php
 declare(strict_types=1); namespace Square\Models; class TenderCardDetailsEntryMethod { public const SWIPED = 'SWIPED'; public const KEYED = 'KEYED'; public const EMV = 'EMV'; public const ON_FILE = 'ON_FILE'; public const CONTACTLESS = 'CONTACTLESS'; } 