<?php
 $PHPMAILER_LANG['authenticate'] = 'SMTP Greška: Neuspjela autentikacija.'; $PHPMAILER_LANG['connect_host'] = 'SMTP Greška: Ne mogu se spojiti na SMTP poslužitelj.'; $PHPMAILER_LANG['data_not_accepted'] = 'SMTP Greška: Podatci nisu prihvaćeni.'; $PHPMAILER_LANG['empty_message'] = 'Sadržaj poruke je prazan.'; $PHPMAILER_LANG['encoding'] = 'Nepoznati encoding: '; $PHPMAILER_LANG['execute'] = 'Nije moguće izvršiti naredbu: '; $PHPMAILER_LANG['file_access'] = 'Nije moguće pristupiti datoteci: '; $PHPMAILER_LANG['file_open'] = 'Nije moguće otvoriti datoteku: '; $PHPMAILER_LANG['from_failed'] = 'SMTP Greška: Slanje s navedenih e-mail adresa nije uspjelo: '; $PHPMAILER_LANG['recipients_failed'] = 'SMTP Greška: Slanje na navedenih e-mail adresa nije uspjelo: '; $PHPMAILER_LANG['instantiate'] = 'Ne mogu pokrenuti mail funkcionalnost.'; $PHPMAILER_LANG['invalid_address'] = 'E-mail nije poslan. Neispravna e-mail adresa: '; $PHPMAILER_LANG['mailer_not_supported'] = ' mailer nije podržan.'; $PHPMAILER_LANG['provide_address'] = 'Definirajte barem jednu adresu primatelja.'; $PHPMAILER_LANG['signing'] = 'Greška prilikom prijave: '; $PHPMAILER_LANG['smtp_connect_failed'] = 'Spajanje na SMTP poslužitelj nije uspjelo.'; $PHPMAILER_LANG['smtp_error'] = 'Greška SMTP poslužitelja: '; $PHPMAILER_LANG['variable_set'] = 'Ne mogu postaviti varijablu niti ju vratiti nazad: '; $PHPMAILER_LANG['extension_missing'] = 'Nedostaje proširenje: '; 