/*
 =======================================================================*\
|| ###################################################################### ||
|| # vBulletin 6.2.3
|| # ------------------------------------------------------------------ # ||
|| # Copyright 2000-2026 MH Sub I, LLC dba vBulletin. All Rights Reserved.  # ||
|| # This file may not be redistributed in whole or significant part.   # ||
|| # ----------------- VBULLETIN IS NOT FREE SOFTWARE ----------------- # ||
|| # http://www.vbulletin.com | http://www.vbulletin.com/license.html   # ||
|| ###################################################################### ||
\*========================================================================*/
vBulletin.precache(["bademail","contact_us","nosubject","please_complete_required_fields","sentfeedback"],[]);
(function(d,h,f,k,e){function l(){e.reset();e.initForm(d("form.contactusForm"),a=>{a=d(a.currentTarget);a=h.getFormData(a);let g={};for(var b of["name","email","subject","other_subject","message"]){if("other_subject"!=b&&""==(a[b]||"").trim())return f.warning("contact_us","please_complete_required_fields"),!1;g[b]=a[b];delete a[b]}for(const [c]of Object.entries(a))b=c.replace(/^humanverify/,"hvinput"),b!=c&&(a[b]=a[c],delete a[c]);a.maildata=g;k.ajax({call:"/ajax/api/contactus/sendMail",data:a,success:function(c){f.alert("contact_us",
"sentfeedback",!1,()=>{location.href=pageData.baseurl})},api_error:e.resetOnError,title_phrase:"contact_us"});return!1})}d(()=>{l()})})(jQuery,vBulletin,vBulletin.dialogtools,vBulletin.ajaxtools,vBulletin.hv);
