<?php
 namespace Eluceo\iCal\Domain\ValueObject\Alarm; final class EmailAction extends Action { private string $summary; private string $description; public function __construct(string $summary, string $description) { $this->summary = $summary; $this->description = $description; } public function getDescription(): string { return $this->description; } public function getSummary(): string { return $this->summary; } } 