<?php
 $PHPMAILER_LANG['authenticate'] = 'خطأ SMTP : لا يمكن تأكيد الهوية.'; $PHPMAILER_LANG['connect_host'] = 'خطأ SMTP: لا يمكن الاتصال بالخادم SMTP.'; $PHPMAILER_LANG['data_not_accepted'] = 'خطأ SMTP: لم يتم قبول المعلومات .'; $PHPMAILER_LANG['empty_message'] = 'نص الرسالة فارغ'; $PHPMAILER_LANG['encoding'] = 'ترميز غير معروف: '; $PHPMAILER_LANG['execute'] = 'لا يمكن تنفيذ : '; $PHPMAILER_LANG['file_access'] = 'لا يمكن الوصول للملف: '; $PHPMAILER_LANG['file_open'] = 'خطأ في الملف: لا يمكن فتحه: '; $PHPMAILER_LANG['from_failed'] = 'خطأ على مستوى عنوان المرسل : '; $PHPMAILER_LANG['instantiate'] = 'لا يمكن توفير خدمة البريد.'; $PHPMAILER_LANG['invalid_address'] = 'الإرسال غير ممكن لأن عنوان البريد الإلكتروني غير صالح: '; $PHPMAILER_LANG['mailer_not_supported'] = ' برنامج الإرسال غير مدعوم.'; $PHPMAILER_LANG['provide_address'] = 'يجب توفير عنوان البريد الإلكتروني لمستلم واحد على الأقل.'; $PHPMAILER_LANG['recipients_failed'] = 'خطأ SMTP: الأخطاء التالية فشل في الارسال لكل من : '; $PHPMAILER_LANG['signing'] = 'خطأ في التوقيع: '; $PHPMAILER_LANG['smtp_connect_failed'] = 'SMTP Connect() غير ممكن.'; $PHPMAILER_LANG['smtp_error'] = 'خطأ على مستوى الخادم SMTP: '; $PHPMAILER_LANG['variable_set'] = 'لا يمكن تعيين أو إعادة تعيين متغير: '; $PHPMAILER_LANG['extension_missing'] = 'الإضافة غير موجودة: '; 