<?php
 namespace Stripe\Service\Apps; class SecretService extends \Stripe\Service\AbstractService { public function all($params = null, $opts = null) { return $this->requestCollection('get', '/v1/apps/secrets', $params, $opts); } public function create($params = null, $opts = null) { return $this->request('post', '/v1/apps/secrets', $params, $opts); } public function deleteWhere($params = null, $opts = null) { return $this->request('post', '/v1/apps/secrets/delete', $params, $opts); } public function find($params = null, $opts = null) { return $this->request('get', '/v1/apps/secrets/find', $params, $opts); } } 