<?php
 namespace Composer\Autoload; class ComposerStaticInit1203929096a415a65874074059446552 { public static $files = array ( '7b11c4dc42b3b3023073cb14e519683c' => __DIR__ . '/..' . '/ralouphie/getallheaders/src/getallheaders.php', '6e3fae29631ef280660b3cdad06f25a8' => __DIR__ . '/..' . '/symfony/deprecation-contracts/function.php', '37a3dc5111fe8f707ab4c132ef1dbc62' => __DIR__ . '/..' . '/guzzlehttp/guzzle/src/functions_include.php', 'e39a8b23c42d4e1452234d762b03835a' => __DIR__ . '/..' . '/ramsey/uuid/src/functions.php', ); public static $prefixLengthsPsr4 = array ( 'v' => array ( 'voku\\' => 5, ), 'S' => array ( 'SpomkyLabs\\Pki\\' => 15, 'Shopify\\' => 8, ), 'R' => array ( 'Ramsey\\Uuid\\' => 12, 'Ramsey\\Collection\\' => 18, ), 'P' => array ( 'Psr\\Log\\' => 8, 'Psr\\Http\\Message\\' => 17, 'Psr\\Http\\Client\\' => 16, 'Psr\\Clock\\' => 10, 'PHPMailer\\PHPMailer\\' => 20, ), 'M' => array ( 'Minishlink\\WebPush\\' => 19, ), 'L' => array ( 'League\\OAuth2\\Client\\' => 21, ), 'K' => array ( 'Krombox\\OAuth2\\Client\\' => 22, ), 'J' => array ( 'Jose\\Component\\' => 15, ), 'G' => array ( 'GuzzleHttp\\Psr7\\' => 16, 'GuzzleHttp\\Promise\\' => 19, 'GuzzleHttp\\' => 11, 'Greew\\OAuth2\\Client\\Provider\\' => 29, ), 'F' => array ( 'Firebase\\JWT\\' => 13, ), 'E' => array ( 'Eluceo\\iCal\\' => 12, ), 'D' => array ( 'Doctrine\\Inflector\\' => 19, ), 'B' => array ( 'Brick\\Math\\' => 11, 'Base64Url\\' => 10, ), ); public static $prefixDirsPsr4 = array ( 'voku\\' => array ( 0 => __DIR__ . '/..' . '/voku/portable-ascii/src/voku', ), 'SpomkyLabs\\Pki\\' => array ( 0 => __DIR__ . '/..' . '/spomky-labs/pki-framework/src', ), 'Shopify\\' => array ( 0 => __DIR__ . '/..' . '/shopify/shopify-api/src', ), 'Ramsey\\Uuid\\' => array ( 0 => __DIR__ . '/..' . '/ramsey/uuid/src', ), 'Ramsey\\Collection\\' => array ( 0 => __DIR__ . '/..' . '/ramsey/collection/src', ), 'Psr\\Log\\' => array ( 0 => __DIR__ . '/..' . '/psr/log/src', ), 'Psr\\Http\\Message\\' => array ( 0 => __DIR__ . '/..' . '/psr/http-factory/src', 1 => __DIR__ . '/..' . '/psr/http-message/src', ), 'Psr\\Http\\Client\\' => array ( 0 => __DIR__ . '/..' . '/psr/http-client/src', ), 'Psr\\Clock\\' => array ( 0 => __DIR__ . '/..' . '/psr/clock/src', ), 'PHPMailer\\PHPMailer\\' => array ( 0 => __DIR__ . '/..' . '/phpmailer/phpmailer/src', ), 'Minishlink\\WebPush\\' => array ( 0 => __DIR__ . '/..' . '/minishlink/web-push/src', ), 'League\\OAuth2\\Client\\' => array ( 0 => __DIR__ . '/..' . '/league/oauth2-google/src', 1 => __DIR__ . '/..' . '/league/oauth2-client/src', ), 'Krombox\\OAuth2\\Client\\' => array ( 0 => __DIR__ . '/..' . '/krombox/oauth2-wordpress/src', ), 'Jose\\Component\\' => array ( 0 => __DIR__ . '/..' . '/web-token/jwt-library', ), 'GuzzleHttp\\Psr7\\' => array ( 0 => __DIR__ . '/..' . '/guzzlehttp/psr7/src', ), 'GuzzleHttp\\Promise\\' => array ( 0 => __DIR__ . '/..' . '/guzzlehttp/promises/src', ), 'GuzzleHttp\\' => array ( 0 => __DIR__ . '/..' . '/guzzlehttp/guzzle/src', ), 'Greew\\OAuth2\\Client\\Provider\\' => array ( 0 => __DIR__ . '/..' . '/greew/oauth2-azure-provider/src/Provider', ), 'Firebase\\JWT\\' => array ( 0 => __DIR__ . '/..' . '/firebase/php-jwt/src', ), 'Eluceo\\iCal\\' => array ( 0 => __DIR__ . '/..' . '/eluceo/ical/src', ), 'Doctrine\\Inflector\\' => array ( 0 => __DIR__ . '/..' . '/doctrine/inflector/src', ), 'Brick\\Math\\' => array ( 0 => __DIR__ . '/..' . '/brick/math/src', ), 'Base64Url\\' => array ( 0 => __DIR__ . '/..' . '/spomky-labs/base64url/src', ), ); public static $classMap = array ( 'Composer\\InstalledVersions' => __DIR__ . '/..' . '/composer/InstalledVersions.php', ); public static function getInitializer(ClassLoader $loader) { return \Closure::bind(function () use ($loader) { $loader->prefixLengthsPsr4 = ComposerStaticInit1203929096a415a65874074059446552::$prefixLengthsPsr4; $loader->prefixDirsPsr4 = ComposerStaticInit1203929096a415a65874074059446552::$prefixDirsPsr4; $loader->classMap = ComposerStaticInit1203929096a415a65874074059446552::$classMap; }, null, ClassLoader::class); } } 