<?php
 declare(strict_types=1); namespace Shopify\Rest\Admin2025_10; use Shopify\Auth\Session; use Shopify\Rest\Base; class AccessScope extends Base { public static string $API_VERSION = "2025-10"; protected static array $HAS_ONE = []; protected static array $HAS_MANY = []; protected static ?string $CUSTOM_PREFIX = "/admin/oauth"; protected static array $PATHS = [ ["http_method" => "get", "operation" => "get", "ids" => [], "path" => "access_scopes.json"] ]; public static function all( Session $session, array $urlIds = [], array $params = [] ): array { return parent::baseFind( $session, [], $params, ); } } 