<?php
 declare(strict_types=1); namespace SpomkyLabs\Pki\ASN1\Type\Tagged; use SpomkyLabs\Pki\ASN1\Feature\ElementBase; use SpomkyLabs\Pki\ASN1\Type\UnspecifiedType; interface ExplicitTagging extends ElementBase { public function explicit(): UnspecifiedType; } 