<?php
 namespace Eluceo\iCal\Domain\ValueObject; final class Category { private string $category; public function __construct(string $category) { $this->category = $category; } public function __toString(): string { return $this->category; } } 