<?php
 declare(strict_types=1); namespace SpomkyLabs\Pki\CryptoTypes\AlgorithmIdentifier\Hash; use SpomkyLabs\Pki\ASN1\Element; use SpomkyLabs\Pki\ASN1\Type\UnspecifiedType; final class HMACWithSHA224AlgorithmIdentifier extends RFC4231HMACAlgorithmIdentifier { private function __construct(?Element $params) { parent::__construct(self::OID_HMAC_WITH_SHA224, $params); } public static function create(?Element $params = null): self { return new self($params); } public static function fromASN1Params(?UnspecifiedType $params = null): self { return self::create($params?->asNull()); } public function name(): string { return 'hmacWithSHA224'; } } 