<?php
 $PHPMAILER_LANG['authenticate'] = 'Помилка SMTP: помилка авторизації.'; $PHPMAILER_LANG['connect_host'] = 'Помилка SMTP: не вдається під\'єднатися до SMTP-серверу.'; $PHPMAILER_LANG['data_not_accepted'] = 'Помилка SMTP: дані не прийнято.'; $PHPMAILER_LANG['encoding'] = 'Невідоме кодування: '; $PHPMAILER_LANG['execute'] = 'Неможливо виконати команду: '; $PHPMAILER_LANG['file_access'] = 'Немає доступу до файлу: '; $PHPMAILER_LANG['file_open'] = 'Помилка файлової системи: не вдається відкрити файл: '; $PHPMAILER_LANG['from_failed'] = 'Невірна адреса відправника: '; $PHPMAILER_LANG['instantiate'] = 'Неможливо запустити функцію mail().'; $PHPMAILER_LANG['provide_address'] = 'Будь ласка, введіть хоча б одну email-адресу отримувача.'; $PHPMAILER_LANG['mailer_not_supported'] = ' - поштовий сервер не підтримується.'; $PHPMAILER_LANG['recipients_failed'] = 'Помилка SMTP: не вдалося відправлення для таких отримувачів: '; $PHPMAILER_LANG['empty_message'] = 'Пусте повідомлення'; $PHPMAILER_LANG['invalid_address'] = 'Не відправлено через неправильний формат email-адреси: '; $PHPMAILER_LANG['signing'] = 'Помилка підпису: '; $PHPMAILER_LANG['smtp_connect_failed'] = 'Помилка з\'єднання з SMTP-сервером'; $PHPMAILER_LANG['smtp_error'] = 'Помилка SMTP-сервера: '; $PHPMAILER_LANG['variable_set'] = 'Неможливо встановити або скинути змінну: '; $PHPMAILER_LANG['extension_missing'] = 'Розширення відсутнє: '; 