<?php
 class vB_Options_Option_Sitemappath extends vB_Options_Option { protected function validateCustom(array $validation, mixed $rawvalue) : bool|string|array { $rawvalue = trim($rawvalue); if ($rawvalue AND !is_writable(resolve_server_path($rawvalue))) { return 'you_did_not_enter_a_valid_value'; } return true; } } 