<?php
 declare(strict_types=1); namespace Square\Models; class BusinessAppointmentSettingsCancellationPolicy { public const CANCELLATION_TREATED_AS_NO_SHOW = 'CANCELLATION_TREATED_AS_NO_SHOW'; public const CUSTOM_POLICY = 'CUSTOM_POLICY'; } 