<?php
 namespace Facebook; class FacebookCanvasLoginHelper extends FacebookSignedRequestFromInputHelper { public function getAppData() { return $this->signedRequest ? $this->signedRequest->get('app_data') : null; } public function getRawSignedRequest() { $rawSignedRequest = $this->getRawSignedRequestFromPost(); if ($rawSignedRequest) { return $rawSignedRequest; } return null; } } 