<?php
 namespace Stripe\Service; class FileService extends \Stripe\Service\AbstractService { public function all($params = null, $opts = null) { return $this->requestCollection('get', '/v1/files', $params, $opts); } public function retrieve($id, $params = null, $opts = null) { return $this->request('get', $this->buildPath('/v1/files/%s', $id), $params, $opts); } public function create($params = null, $opts = null) { $opts = \Stripe\Util\RequestOptions::parse($opts); if (!isset($opts->apiBase)) { $opts->apiBase = $this->getClient()->getFilesBase(); } $flatParams = \array_column(\Stripe\Util\Util::flattenParams($params), 1, 0); return $this->request('post', '/v1/files', $flatParams, $opts); } } 