<?php
 declare(strict_types=1); namespace Brick\Math; enum RoundingMode { case UNNECESSARY; case UP; case DOWN; case CEILING; case FLOOR; case HALF_UP; case HALF_DOWN; case HALF_CEILING; case HALF_FLOOR; case HALF_EVEN; } 