<?php
 declare(strict_types=1); namespace Square\Models; class ErrorCategory { public const API_ERROR = 'API_ERROR'; public const AUTHENTICATION_ERROR = 'AUTHENTICATION_ERROR'; public const INVALID_REQUEST_ERROR = 'INVALID_REQUEST_ERROR'; public const RATE_LIMIT_ERROR = 'RATE_LIMIT_ERROR'; public const PAYMENT_METHOD_ERROR = 'PAYMENT_METHOD_ERROR'; public const REFUND_ERROR = 'REFUND_ERROR'; public const MERCHANT_SUBSCRIPTION_ERROR = 'MERCHANT_SUBSCRIPTION_ERROR'; } 