<?php
 namespace Eluceo\iCal\Domain\ValueObject; final class MultiDay extends Occurrence { private Date $firstDay; private Date $lastDay; public function __construct(Date $firstDay, Date $lastDay) { $this->firstDay = $firstDay; $this->lastDay = $lastDay; } public function getFirstDay(): Date { return $this->firstDay; } public function getLastDay(): Date { return $this->lastDay; } } 