/*
 =======================================================================*\
|| ###################################################################### ||
|| # vBulletin 6.2.3
|| # ------------------------------------------------------------------ # ||
|| # Copyright 2000-2026 MH Sub I, LLC dba vBulletin. All Rights Reserved.  # ||
|| # This file may not be redistributed in whole or significant part.   # ||
|| # ----------------- VBULLETIN IS NOT FREE SOFTWARE ----------------- # ||
|| # http://www.vbulletin.com | http://www.vbulletin.com/license.html   # ||
|| ###################################################################### ||
\*========================================================================*/
// ***************************
// js.compressed/jquery/jquery.condense.custom.min.js
// ***************************
/*
 Condense 0.1 - Condense and expand text heavy elements

 (c) 2008 Joseph Sillitoe
 Dual licensed under the MIT License (MIT-LICENSE) and GPL License,version 2 (GPL-LICENSE).

 Modified for vBulletin:
  - Added callbacks when initializing condense plugin is done (onInit),
    when condensing is done (onCondense),
    when expanding is done (onExpand) and
    when condensing or expanding is done (onToggle).
  - Added patch for infinite loop when condense length cutoff occurs in consecutive spaces (https://github.com/jsillitoe/jquery-condense-plugin/issues/5)
*/
(function(h){function m(a,c){if(h.trim(a.text()).length<=c.condensedLength+c.minTrail)return k("element too short: skipping."),!1;let b=h.trim(a.html()),d=h.trim(a.text());a=a.clone();var e=0;do{a:{var l=b;var f=c.delim,g=c.condensedLength+e;do{g=l.indexOf(f,g);if(0>g){k("No delimiter found.");l=l.length;break a}for(e=!0;n(l,g);)g++,e=!1}while(!e);k("Delimiter found in html at: "+g);l=g}a.html(b.substring(0,l+1));f=a.text().length;g=a.html().length;e=a.html().length-f;k("condensing... [html-length:"+
g+" text-length:"+f+" delta: "+e+" break-point: "+l+"]")}while(e&&a.text().length<c.condensedLength);if(d.length-f<c.minTrail)return k("not enough trailing text: skipping."),!1;k("clone condensed. [text-length:"+f+"]");return a}function n(a,c){return a.indexOf(">",c)<a.indexOf("<",c)}function p(a,c){k("Condense Trigger: "+a.html());var b=a.parent(),d=b.next();d.show();var e=d.width(),l=d.height();d.hide();var f=b.width(),g=b.height();b.animate({height:l,width:e,opacity:1},c.lessSpeed,c.easing,function(){b.height(g).width(f).hide();
d.show();"function"==typeof c.onCondense&&c.onCondense.apply(a,[d]);"function"==typeof c.onToggle&&c.onToggle.apply(a,[b,d,!0])})}function q(a,c){k("Expand Trigger: "+a.html());var b=a.parent(),d=b.prev();d.show();var e=d.width(),l=d.height();d.width(b.width()+"px").height(b.height()+"px");b.hide();d.animate({height:l,width:e,opacity:1},c.moreSpeed,c.easing,function(){"function"==typeof c.onExpand&&c.onExpand.apply(a,[d]);"function"==typeof c.onToggle&&c.onToggle.apply(a,[d,b,!1])});b.attr("id")&&
(e=b.attr("id"),b.attr("id","condensed_"+e),d.attr("id",e))}function k(a){window.console&&window.console.log&&window.console.log(a)}h.fn.condense=function(a){h.metadata?k("metadata plugin detected"):k("metadata plugin not present");var c=h.extend({},h.fn.condense.defaults,a);return this.each(function(){$this=h(this);var b=h.metadata?h.extend({},c,$this.metadata()):c;k("Condensing ["+$this.text().length+"]: "+$this.text());var d=m($this,b);if(d){$this.attr("id")?$this.attr("id","condensed_"+$this.attr("id")):
!1;var e=" <span class='condense_control condense_control_more' style='cursor:pointer;'>"+b.moreText+"</span>",l=" <span class='condense_control condense_control_less' style='cursor:pointer;'>"+b.lessText+"</span>";let g=null;var f=d.contents().last();d.append(e);$this.after(d).hide().append(l);for(e=["P","DIV","SPAN"];f&&e.includes(f.prop("tagName"))&&"block"==f.css("display");)g=f,f=g.contents().last();f=h(".condense_control_more",d);g?g.append(b.ellipsis):f.before(b.ellipsis);f.click(function(){k("moreControl clicked.");
q(h(this),b)});h(".condense_control_less",$this).click(function(){k("lessControl clicked.");p(h(this),b)})}"function"==typeof b.onInit&&b.onInit.apply(this,[d])})};h.fn.condense.defaults={condensedLength:200,minTrail:20,delim:" ",moreText:"[more]",lessText:"[less]",ellipsis:" ( ... )",moreSpeed:"normal",lessSpeed:"normal",easing:"linear",onInit:null,onCondense:null,onExpand:null,onToggle:null}})(jQuery);
;

// ***************************
// js.compressed/notice.js
// ***************************
vBulletin.precache(["login","cancel","see_less","see_more"],["noticepreviewlength"]);((a,b,e)=>{a(()=>{let c=a(".js-notice-text"),d=e.get("noticepreviewlength");c.removeClass("h-hide-imp");d&&c.condense({condensedLength:d,minTrail:20,delim:" ",moreText:b.get("see_more"),lessText:b.get("see_less"),ellipsis:"...",moreSpeed:"fast",lessSpeed:"fast",easing:"linear"})})})(jQuery,vBulletin.phrase,vBulletin.options);
;

