<?php
 declare(strict_types=1); namespace Square\Models; class CustomAttributeDefinitionVisibility { public const VISIBILITY_HIDDEN = 'VISIBILITY_HIDDEN'; public const VISIBILITY_READ_ONLY = 'VISIBILITY_READ_ONLY'; public const VISIBILITY_READ_WRITE_VALUES = 'VISIBILITY_READ_WRITE_VALUES'; } 