<?php
 declare(strict_types=1); namespace SpomkyLabs\Pki\X501\StringPrep; use const MB_CASE_LOWER; final class MapStep implements PrepareStep { private function __construct( private readonly bool $fold ) { } public static function create(bool $fold = false): self { return new self($fold); } public function apply(string $string): string { if ($this->fold) { $string = mb_convert_case($string, MB_CASE_LOWER, 'UTF-8'); } return $string; } } 