<?php
 class vB_Utility_Template_ParserNode_Curly_Template extends vB_Utility_Template_ParserNode_Curly { public function validate() : array { $errors = []; $attributecount = sizeof($this->main_node->attributes); if ($attributecount == 0) { $errors[] = 'no_variable_specified'; } return $errors; } public function compile() : string { $arguments = $this->getRenderedNamedAttributes(1); $arguments = '[' . implode(', ', $arguments) . ']'; $template_name = $this->attributeToString($this->main_node->attributes[0]); return 'vB_Template_Runtime::includeTemplate(' . $template_name . ", $arguments" . ')'; } } 