<?php
 namespace Stripe\Identity; class VerificationReport extends \Stripe\ApiResource { const OBJECT_NAME = 'identity.verification_report'; use \Stripe\ApiOperations\All; use \Stripe\ApiOperations\Retrieve; const TYPE_DOCUMENT = 'document'; const TYPE_ID_NUMBER = 'id_number'; } 