<?php
 namespace Stripe\Identity; class VerificationSession extends \Stripe\ApiResource { const OBJECT_NAME = 'identity.verification_session'; use \Stripe\ApiOperations\All; use \Stripe\ApiOperations\Create; use \Stripe\ApiOperations\Retrieve; use \Stripe\ApiOperations\Update; const STATUS_CANCELED = 'canceled'; const STATUS_PROCESSING = 'processing'; const STATUS_REQUIRES_INPUT = 'requires_input'; const STATUS_VERIFIED = 'verified'; const TYPE_DOCUMENT = 'document'; const TYPE_ID_NUMBER = 'id_number'; public function cancel($params = null, $opts = null) { $url = $this->instanceUrl() . '/cancel'; list($response, $opts) = $this->_request('post', $url, $params, $opts); $this->refreshFrom($response, $opts); return $this; } public function redact($params = null, $opts = null) { $url = $this->instanceUrl() . '/redact'; list($response, $opts) = $this->_request('post', $url, $params, $opts); $this->refreshFrom($response, $opts); return $this; } } 