<?php
 trait vB_Trait_NoSerialize { public function __serialize() : array { throw new Exception('Serialization not supported'); } public function __unserialize(array $serialized) : void { throw new Exception('Serialization not supported'); } } 