<?php
 class vB_DataManager_StyleVarTextTransform extends vB_DataManager_StyleVar { protected array $childfields = [ 'texttransform' => [vB_Cleaner::TYPE_STR, vB_DataManager_Constants::REQ_NO, vB_DataManager_Constants::VF_METHOD, 'verify_texttransfrom'], 'stylevar_texttransform' => [vB_Cleaner::TYPE_STR, vB_DataManager_Constants::REQ_NO, vB_DataManager_Constants::VF_METHOD, 'verify_value_stylevar'], ]; public $datatype = 'TextTransform'; } 