<?php
 $PHPMAILER_LANG['authenticate'] = 'SMTP грешка: Не може да се удостовери пред сървъра.'; $PHPMAILER_LANG['connect_host'] = 'SMTP грешка: Не може да се свърже с SMTP хоста.'; $PHPMAILER_LANG['data_not_accepted'] = 'SMTP грешка: данните не са приети.'; $PHPMAILER_LANG['empty_message'] = 'Съдържанието на съобщението е празно'; $PHPMAILER_LANG['encoding'] = 'Неизвестно кодиране: '; $PHPMAILER_LANG['execute'] = 'Не може да се изпълни: '; $PHPMAILER_LANG['file_access'] = 'Няма достъп до файл: '; $PHPMAILER_LANG['file_open'] = 'Файлова грешка: Не може да се отвори файл: '; $PHPMAILER_LANG['from_failed'] = 'Следните адреси за подател са невалидни: '; $PHPMAILER_LANG['instantiate'] = 'Не може да се инстанцира функцията mail.'; $PHPMAILER_LANG['invalid_address'] = 'Невалиден адрес: '; $PHPMAILER_LANG['mailer_not_supported'] = ' - пощенски сървър не се поддържа.'; $PHPMAILER_LANG['provide_address'] = 'Трябва да предоставите поне един email адрес за получател.'; $PHPMAILER_LANG['recipients_failed'] = 'SMTP грешка: Следните адреси за Получател са невалидни: '; $PHPMAILER_LANG['signing'] = 'Грешка при подписване: '; $PHPMAILER_LANG['smtp_connect_failed'] = 'SMTP провален connect().'; $PHPMAILER_LANG['smtp_error'] = 'SMTP сървърна грешка: '; $PHPMAILER_LANG['variable_set'] = 'Не може да се установи или възстанови променлива: '; $PHPMAILER_LANG['extension_missing'] = 'Липсва разширение: '; 