<?php
 class vB_Utility_Template_ParserNode_Curly_Time extends vB_Utility_Template_ParserNode_CurlyRuntime { protected static string $function = 'time'; protected static string $noparamerror = 'no_time_specified'; protected static int $maxparams = 2; } 