<?php
 declare(strict_types=1); namespace Square\Models; class BusinessAppointmentSettingsAlignmentTime { public const SERVICE_DURATION = 'SERVICE_DURATION'; public const QUARTER_HOURLY = 'QUARTER_HOURLY'; public const HALF_HOURLY = 'HALF_HOURLY'; public const HOURLY = 'HOURLY'; } 