<?php
 declare(strict_types=1); namespace Square\Models; use stdClass; class OrderFulfillmentUpdatedObject implements \JsonSerializable { private $orderFulfillmentUpdated; public function getOrderFulfillmentUpdated(): ?OrderFulfillmentUpdated { return $this->orderFulfillmentUpdated; } public function setOrderFulfillmentUpdated(?OrderFulfillmentUpdated $orderFulfillmentUpdated): void { $this->orderFulfillmentUpdated = $orderFulfillmentUpdated; } #[\ReturnTypeWillChange] public function jsonSerialize(bool $asArrayWhenEmpty = false) { $json = []; if (isset($this->orderFulfillmentUpdated)) { $json['order_fulfillment_updated'] = $this->orderFulfillmentUpdated; } $json = array_filter($json, function ($val) { return $val !== null; }); return (!$asArrayWhenEmpty && empty($json)) ? new stdClass() : $json; } } 