<?php
 namespace Stripe\Service\BillingPortal; class SessionService extends \Stripe\Service\AbstractService { public function create($params = null, $opts = null) { return $this->request('post', '/v1/billing_portal/sessions', $params, $opts); } } 