<?php
 declare(strict_types=1); namespace Square\Models; class TenderCardDetailsStatus { public const AUTHORIZED = 'AUTHORIZED'; public const CAPTURED = 'CAPTURED'; public const VOIDED = 'VOIDED'; public const FAILED = 'FAILED'; } 