<?php
 class vB_Api_Session extends vB_Api { public function startGuestSession() { $session = vB_Session_Web::getSession(0, ''); $languageid = vB::getDatastore()->getOption('languageid'); $session->set('languageid', $languageid); vB::skipShutdown(true); vB::setCurrentSession($session); return ['success' => true]; } } 