<?php
 declare(strict_types=1); namespace Square\Models; class InvoiceRequestMethod { public const EMAIL = 'EMAIL'; public const CHARGE_CARD_ON_FILE = 'CHARGE_CARD_ON_FILE'; public const SHARE_MANUALLY = 'SHARE_MANUALLY'; public const CHARGE_BANK_ON_FILE = 'CHARGE_BANK_ON_FILE'; public const SMS = 'SMS'; public const SMS_CHARGE_CARD_ON_FILE = 'SMS_CHARGE_CARD_ON_FILE'; public const SMS_CHARGE_BANK_ON_FILE = 'SMS_CHARGE_BANK_ON_FILE'; } 