<?php
 namespace Stripe; class TaxRate extends ApiResource { const OBJECT_NAME = 'tax_rate'; use ApiOperations\All; use ApiOperations\Create; use ApiOperations\Retrieve; use ApiOperations\Update; const TAX_TYPE_GST = 'gst'; const TAX_TYPE_HST = 'hst'; const TAX_TYPE_JCT = 'jct'; const TAX_TYPE_PST = 'pst'; const TAX_TYPE_QST = 'qst'; const TAX_TYPE_RST = 'rst'; const TAX_TYPE_SALES_TAX = 'sales_tax'; const TAX_TYPE_VAT = 'vat'; } 