<?php
 namespace Stripe; class SubscriptionItem extends ApiResource { const OBJECT_NAME = 'subscription_item'; use ApiOperations\All; use ApiOperations\Create; use ApiOperations\Delete; use ApiOperations\NestedResource; use ApiOperations\Retrieve; use ApiOperations\Update; const PATH_USAGE_RECORDS = '/usage_records'; public static function createUsageRecord($id, $params = null, $opts = null) { return self::_createNestedResource($id, static::PATH_USAGE_RECORDS, $params, $opts); } public function usageRecordSummaries($params = null, $opts = null) { $url = $this->instanceUrl() . '/usage_record_summaries'; list($response, $opts) = $this->_request('get', $url, $params, $opts); $obj = \Stripe\Util\Util::convertToStripeObject($response, $opts); $obj->setLastResponse($response); return $obj; } const PATH_USAGE_RECORD_SUMMARIES = '/usage_record_summaries'; public static function allUsageRecordSummaries($id, $params = null, $opts = null) { return self::_allNestedResources($id, static::PATH_USAGE_RECORD_SUMMARIES, $params, $opts); } } 