<?php
 namespace Stripe\Treasury; class ReceivedCredit extends \Stripe\ApiResource { const OBJECT_NAME = 'treasury.received_credit'; use \Stripe\ApiOperations\All; use \Stripe\ApiOperations\Retrieve; const FAILURE_CODE_ACCOUNT_CLOSED = 'account_closed'; const FAILURE_CODE_ACCOUNT_FROZEN = 'account_frozen'; const FAILURE_CODE_OTHER = 'other'; const NETWORK_ACH = 'ach'; const NETWORK_CARD = 'card'; const NETWORK_STRIPE = 'stripe'; const NETWORK_US_DOMESTIC_WIRE = 'us_domestic_wire'; const STATUS_FAILED = 'failed'; const STATUS_SUCCEEDED = 'succeeded'; } 