<?php
 class vB_Utility_Template_ParserNode_Tag_Comment extends vB_Utility_Template_ParserNode_Tag { public function validate() : array { return []; } public function compile() : string { return "''"; } } 