<?php
 namespace Stripe\ApiOperations; trait Retrieve { public static function retrieve($id, $opts = null) { $opts = \Stripe\Util\RequestOptions::parse($opts); $instance = new static($id, $opts); $instance->refresh(); return $instance; } } 