<?php
 $PHPMAILER_LANG['authenticate'] = 'SMTP Error: Chyba autentifikácie.'; $PHPMAILER_LANG['connect_host'] = 'SMTP Error: Nebolo možné nadviazať spojenie so SMTP serverom.'; $PHPMAILER_LANG['data_not_accepted'] = 'SMTP Error: Dáta neboli prijaté'; $PHPMAILER_LANG['empty_message'] = 'Prázdne telo správy.'; $PHPMAILER_LANG['encoding'] = 'Neznáme kódovanie: '; $PHPMAILER_LANG['execute'] = 'Nedá sa vykonať: '; $PHPMAILER_LANG['file_access'] = 'Súbor nebol nájdený: '; $PHPMAILER_LANG['file_open'] = 'File Error: Súbor sa otvoriť pre čítanie: '; $PHPMAILER_LANG['from_failed'] = 'Následujúca adresa From je nesprávna: '; $PHPMAILER_LANG['instantiate'] = 'Nedá sa vytvoriť inštancia emailovej funkcie.'; $PHPMAILER_LANG['invalid_address'] = 'Neodoslané, emailová adresa je nesprávna: '; $PHPMAILER_LANG['invalid_hostentry'] = 'Záznam hostiteľa je nesprávny: '; $PHPMAILER_LANG['invalid_host'] = 'Hostiteľ je nesprávny: '; $PHPMAILER_LANG['mailer_not_supported'] = ' emailový klient nieje podporovaný.'; $PHPMAILER_LANG['provide_address'] = 'Musíte zadať aspoň jednu emailovú adresu príjemcu.'; $PHPMAILER_LANG['recipients_failed'] = 'SMTP Error: Adresy príjemcov niesu správne '; $PHPMAILER_LANG['signing'] = 'Chyba prihlasovania: '; $PHPMAILER_LANG['smtp_connect_failed'] = 'SMTP Connect() zlyhalo.'; $PHPMAILER_LANG['smtp_error'] = 'SMTP chyba serveru: '; $PHPMAILER_LANG['variable_set'] = 'Nemožno nastaviť alebo resetovať premennú: '; $PHPMAILER_LANG['extension_missing'] = 'Chýba rozšírenie: '; 