<?php
 declare(strict_types=1); namespace Shopify\Rest\Admin2024_04; use Shopify\Auth\Session; use Shopify\Rest\Base; class AbandonedCheckout extends Base { public static string $API_VERSION = "2024-04"; protected static array $HAS_ONE = [ "currency" => Currency::class, "customer" => Customer::class ]; protected static array $HAS_MANY = [ "discount_codes" => DiscountCode::class ]; protected static array $PATHS = [ ["http_method" => "get", "operation" => "checkouts", "ids" => [], "path" => "checkouts.json"], ["http_method" => "get", "operation" => "checkouts", "ids" => [], "path" => "checkouts.json"] ]; public static function checkouts( Session $session, array $urlIds = [], array $params = [] ): ?array { $response = parent::request( "get", "checkouts", $session, [], $params, [], ); return $response->getDecodedBody(); } } 