#colorPicker
{
	background: black;
	position: absolute;
	left: 0px;
	top: 0px;
	width: calc(var(--color-picker-size) * 21 + 22px);
}
#colorFeedback
{
	border: solid 1px black;
	border-bottom: none;
	width: calc(var(--color-picker-size) * 21 + 22px);
	padding-left: 0;
	padding-right: 0;
}
#colorFeedback input
{
	font: 11px verdana, arial, helvetica, sans-serif;
}
#colorFeedback button
{
	width: 19px;
	height: 19px;
}
#txtColor
{
	border: inset 1px;
	width: 70px;
}
#colorSurround
{
	border: inset 1px;
	white-space: nowrap;
	width: calc(var(--color-picker-size) * 6);
	height: 15px;
}
#colorSurround td
{
	background-color: none;
	border: none;
	width: calc(var(--color-picker-size) * 3);
	height: 15px;
}
#swatches
{
	background-color: black;
	width: calc(var(--color-picker-size) * 21 + 22px);
}
#swatches td
{
	background: black;
	border: none;
	width: var(--color-picker-size);
	height: var(--color-picker-size);
}
