/*
 =======================================================================*\
|| ###################################################################### ||
|| # vBulletin 6.2.3
|| # ------------------------------------------------------------------ # ||
|| # Copyright 2000-2026 MH Sub I, LLC dba vBulletin. All Rights Reserved.  # ||
|| # This file may not be redistributed in whole or significant part.   # ||
|| # ----------------- VBULLETIN IS NOT FREE SOFTWARE ----------------- # ||
|| # http://www.vbulletin.com | http://www.vbulletin.com/license.html   # ||
|| ###################################################################### ||
\*========================================================================*/
(function(b){function p(a){a.preventDefault();a=b(this);a.hasClass("option-less")&&(b(".faqSearchControl.option-more").removeClass("h-hide"),b(".faqSearchFields").addClass("h-hide"));a.hasClass("option-more")&&(a.addClass("h-hide"),b(".faqSearchFields").removeClass("h-hide"))}function k(a){var c=b(".faq-content .faq-answer");b(".faq-group-title",c).html(a.title);b(".faq-group-body",c).html(a.text);b(".faq-groups .faq-link.selected").removeClass("selected");b(".faq-groups .faq-link").each(function(){var d=
b(this);if(d.data("group")==a.faqparent&&d.data("item")==a.faqname)return d.addClass("selected"),b(".js-rx-help-menu-select").selectBox("value",d.data("path")),!1});l(c)}function l(a){var c=b(".js-faq-search-query").data("highlight");c&&b(c.split(",")).each(function(d,e){b(".faq-group-body",a).highlight(e)})}function q(a){a.preventDefault();var c=b(this).data("group"),d=b(this).data("item");window.location.hash=b(this).data("path");g[c]&&g[c][d]?k(g[c][d]):vBulletin.AJAX({url:vBulletin.getAjaxBaseurl()+
"/ajax/api/help/getAnswers",data:{group:c},success:function(e,f,m){e.answers?(g[c]=e.answers,g[c][d]?k(g[c][d]):console.log("can't load help for "+c+"/"+d)):console.log("can't load help for "+c)}})}function h(a){b(".faq-groups a").each(function(){var c=b(this);if(c.data("path")==a){for(var d=c,e,f=!1,m=100;--m;)if(d=d.parent().closest(".faq-group"),e=d.find("> .faq-group-title"),1==e.length)f=e;else break;f&&1==f.length&&(d=b(".faq-groups"),e=b(".faqs"),d.removeClass("h-hide-on-small"),e.css("width",
"220px"),f.trigger("click"),d.addClass("h-hide-on-small"),e.css("width",""));c.is(".faq-link")||c.parent().find(".faq-link").first().trigger("click");c.trigger("click");return!1}})}function r(a){a=b(a.target).attr("href");if("help#"==a.substr(0,5))return a=a.substr(5),h(a),!1}function n(a,c,d){a.find("> li.faq-group, > li").each(function(){var e=b(this),f=e.find("> .faq-group-title, > .faq-link");b("<option />").prop("value",f.data("path")).text(c+" "+f.text()).appendTo(d);e=e.find("> .sub-faqs > .faq-group-body");
0<e.length&&n(e,c+"---",d)})}function t(a){a=a.target;a=b(a[a.selectedIndex]).val();h(a)}var g={};b(function(){b(".faqSearchControl").off("click").on("click",p);b(".help-widget").off("click",".faq-link").on("click",".faq-link",q);b(".help-widget").off("click",".faq-content a").on("click",".faq-content a",r);b(".faqs ul.acc").accordion({heightStyle:"content",icons:{activeHeader:"js-help-icon h-center-vertical h-margin-right-s b-icon-fa b-icon-fa--12 fa-solid fa-caret-down ",header:"js-help-icon h-center-vertical h-margin-right-s b-icon-fa b-icon-fa--12 fa-solid fa-caret-right"}});
b(".js-help-icon").removeClass("ui-icon").parent().addClass("h-center-vertical-container");if(window.location.hash){var a=window.location.hash.substr(1);h(a)}l(b(".faq-content .faq-answer"));a=b(".faq-groups");var c=b("<select />").addClass("js-rx-help-menu-select");n(a,"",c);var d=b("<div />").addClass("rx-help-menu h-hide-on-large").append(c).insertAfter(a);c.off("change").on("change",t);a.addClass("h-hide-on-small");d.removeClass("h-hide-on-large");c.selectBox();d.addClass("h-hide-on-large")})})(jQuery);
