<?php
 declare(strict_types=1); namespace Square\Models; class GiftCardActivityAdjustIncrementReason { public const COMPLIMENTARY = 'COMPLIMENTARY'; public const SUPPORT_ISSUE = 'SUPPORT_ISSUE'; public const TRANSACTION_VOIDED = 'TRANSACTION_VOIDED'; } 