<?php
 declare(strict_types=1); namespace Square\Models; class InventoryState { public const CUSTOM = 'CUSTOM'; public const IN_STOCK = 'IN_STOCK'; public const SOLD = 'SOLD'; public const RETURNED_BY_CUSTOMER = 'RETURNED_BY_CUSTOMER'; public const RESERVED_FOR_SALE = 'RESERVED_FOR_SALE'; public const SOLD_ONLINE = 'SOLD_ONLINE'; public const ORDERED_FROM_VENDOR = 'ORDERED_FROM_VENDOR'; public const RECEIVED_FROM_VENDOR = 'RECEIVED_FROM_VENDOR'; public const IN_TRANSIT_TO = 'IN_TRANSIT_TO'; public const NONE = 'NONE'; public const WASTE = 'WASTE'; public const UNLINKED_RETURN = 'UNLINKED_RETURN'; public const COMPOSED = 'COMPOSED'; public const DECOMPOSED = 'DECOMPOSED'; public const SUPPORTED_BY_NEWER_VERSION = 'SUPPORTED_BY_NEWER_VERSION'; } 