<?php
 namespace League\OAuth2\Client\Tool; trait ArrayAccessorTrait { private function getValueByKey(array $data, $key, $default = null) { if (!is_string($key) || empty($key) || !count($data)) { return $default; } if (strpos($key, '.') !== false) { $keys = explode('.', $key); foreach ($keys as $innerKey) { if (!is_array($data) || !array_key_exists($innerKey, $data)) { return $default; } $data = $data[$innerKey]; } return $data; } return array_key_exists($key, $data) ? $data[$key] : $default; } } 