<?php

class wordpresslogin_Product
{
	public $vbMinVersion = '6.1.2 Alpha 3';
	public $vbMaxVersion = '6.9.9';

	public static $AutoInstall = true;

	public $hookClasses = [
		'wordpresslogin_Hooks'
	];
}
