<?php
 $PHPMAILER_LANG['authenticate'] = 'SMTP klaida: autentifikacija nepavyko.'; $PHPMAILER_LANG['connect_host'] = 'SMTP klaida: nepavyksta prisijungti prie SMTP stoties.'; $PHPMAILER_LANG['data_not_accepted'] = 'SMTP klaida: duomenys nepriimti.'; $PHPMAILER_LANG['empty_message'] = 'Laiško turinys tuščias'; $PHPMAILER_LANG['encoding'] = 'Neatpažinta koduotė: '; $PHPMAILER_LANG['execute'] = 'Nepavyko įvykdyti komandos: '; $PHPMAILER_LANG['file_access'] = 'Byla nepasiekiama: '; $PHPMAILER_LANG['file_open'] = 'Bylos klaida: Nepavyksta atidaryti: '; $PHPMAILER_LANG['from_failed'] = 'Neteisingas siuntėjo adresas: '; $PHPMAILER_LANG['instantiate'] = 'Nepavyko paleisti mail funkcijos.'; $PHPMAILER_LANG['invalid_address'] = 'Neteisingas adresas: '; $PHPMAILER_LANG['mailer_not_supported'] = ' pašto stotis nepalaikoma.'; $PHPMAILER_LANG['provide_address'] = 'Nurodykite bent vieną gavėjo adresą.'; $PHPMAILER_LANG['recipients_failed'] = 'SMTP klaida: nepavyko išsiųsti šiems gavėjams: '; $PHPMAILER_LANG['signing'] = 'Prisijungimo klaida: '; $PHPMAILER_LANG['smtp_connect_failed'] = 'SMTP susijungimo klaida'; $PHPMAILER_LANG['smtp_error'] = 'SMTP stoties klaida: '; $PHPMAILER_LANG['variable_set'] = 'Nepavyko priskirti reikšmės kintamajam: '; 