/*
 =======================================================================*\
|| ###################################################################### ||
|| # vBulletin 6.2.3
|| # ------------------------------------------------------------------ # ||
|| # Copyright 2000-2026 MH Sub I, LLC dba vBulletin. All Rights Reserved.  # ||
|| # This file may not be redistributed in whole or significant part.   # ||
|| # ----------------- VBULLETIN IS NOT FREE SOFTWARE ----------------- # ||
|| # http://www.vbulletin.com | http://www.vbulletin.com/license.html   # ||
|| ###################################################################### ||
\*========================================================================*/
// ***************************
// js.compressed/password.js
// ***************************
vBulletin.precache("error password_needs_numbers password_needs_special_chars password_needs_uppercase password_too_short passwords_must_match".split(" "),["passwordminlength","passwordrequirenumbers","passwordrequirespecialchars","passwordrequireuppercase"]);
$.extend(vBulletin,function(f){function c(a,b){vBulletin.error("error",a,function(){b.trigger("focus")})}return{checkPassword:function(a,b){var d=a.val();if(d.length<vBulletin.options.get("passwordminlength"))return c("password_too_short",a),!1;if(vBulletin.options.get("passwordrequireuppercase")&&!d.match(/[A-Z]/))return c("password_needs_uppercase",a),!1;if(vBulletin.options.get("passwordrequirenumbers")&&!d.match(/[0-9]/))return c("password_needs_numbers",a),!1;if(vBulletin.options.get("passwordrequirespecialchars")){var e=
vBulletin.regexEscape(" !\"#$%&'()*+,-./:;<=>?@[\\]^_`{|}~");if(!d.match(new RegExp("["+e+"]")))return c("password_needs_special_chars",a),!1}return b&&b.val&&d!=b.val()?(c("passwords_must_match",b),!1):!0}}}(jQuery));
;

// ***************************
// js.compressed/usersettings.js
// ***************************
vBulletin.precache("email_addresses_must_match signature signature_saved usersetting_signatures_link end_subscription end_subscription_confirm cancel two_factor_authentication mfa_enabled mfa_verified privacyconsent_terms_delete_warning_detailed usersetting_deleteaccount_label are_you_sure_logout_all".split(" "),["ctMaxChars","user_autodelete_cooldown"]);
(function(a,C,D,w,v){function x(){a(".js-export-personal-data-form").submit();return!1}function E(){a(".js-signature__edit").off("click").on("click",function(c){c.preventDefault();a("#editSignatureDialog").dialog({title:vBulletin.phrase.get("usersetting_signatures_link"),autoOpen:!1,modal:!0,resizable:!1,closeOnEscape:!1,showCloseButton:!1,width:500,dialogClass:"signature-dialog-container dialog-container dialog-box",create:function(){var d=a(this),e=a(".js-editor",d);vBulletin.ckeditor.initEditor(e,
{success:function(g){let n=()=>{0<d.find(".js-attach-list").data("attach-count")&&C.contentEntryBox.openAttachmentPanel(d.find(".js-content-entry"))};n();var p=vBulletin.ckeditor.getEditor(g);p.setData(e.prev(".js-editor-parsed-text").html(),function(){p.resetDirty()});d.on("dialogopen",function(){n();p.setData(a(".js-signature__preview").html(),function(){p.resetDirty()})})},error:function(){e.val(e.prev(".js-editor-parsed-text").html().replace(/<br\s*[\/]?>/gi,"\n")).data("orig-value",e.val());
d.on("dialogopen",function(){e.val(a(".js-signature__preview").html().replace(/<br\s*[\/]?>/gi,"\n")).data("orig-value",e.val())})},hideLoadingDialog:!0});a(".js-signature__cancel",d).off("click").on("click",function(g){(vBulletin.ckeditor.editorExists(e)?vBulletin.ckeditor.getEditor(e).checkDirty():e.val()!=e.data("orig-value"))?v.openConfirmDialogSimple({title:"cancel_edit",message:"all_changes_made_will_be_lost_would_you_like_to_continue",iconType:"warning",onClickYes:()=>d.dialog("close")}):d.dialog("close")});
a(".js-signature__submit",d).off("click").on("click",function(g){g.preventDefault();g=vBulletin.ckeditor.editorExists(e)?vBulletin.ckeditor.getEditor(e).getData():e.val();var n=[];a('input[name|="filedataids[]"]',d).each(function(){n.push(a(this).val())});vBulletin.AJAX({url:this.form.action,type:this.form.method,data:{signature:g,filedataids:n},title_phrase:"signature",error_phrase:"error_saving_signature",success:function(p){a(".js-signature__preview").html(p);vBulletin.alert("signature","signature_saved");
d.dialog("close")},allowEmptyResponse:!0,complete:function(){a("body").css("cursor","default")}});return!1})}}).dialog("open");return!1});var h=a(".js-mfa-reset"),f=h.closest("form"),q=a(".js-mfa-enable"),k=q.closest("form"),l=function(c){c.preventDefault();vBulletin.AJAX({call:"/ajax/api/user/resetMfaSecret",data:f.serializeArray(),success:function(d){a(".js-mfa-request-panel").addClass("h-hide");var e=a(".js-mfa-secret-panels"),g=a(".js-mfa-qr-code"),n=g.parent().width(),p="otpauth://totp/"+escape(g.data("descrption"))+
"?secret="+d.secret;e.hide();e.removeClass("h-hide");a(".js-mfa-secret-text").text(d.secret);g.html("");g.qrcode({width:n,height:n,text:p});e.show("slow")},after_error:function(){f.find("input").not('[name="securitytoken"]').val("")}})},b=function(c){c.preventDefault();vBulletin.AJAX({call:"/ajax/api/user/enableMfa",data:k.serializeArray(),success:function(d){vBulletin.alert("two_factor_authentication",d.alreadyenabled?"mfa_verified":"mfa_enabled");k.find('input[name="mfa_authcode"]').val("")},after_error:function(){k.find("input").not('[name="securitytoken"]').val("")}})};
h.off("click").on("click",l);f.off("submit").on("submit",l);q.off("click").on("click",b);k.off("submit").on("submit",b);a(".js-export-personal-data").off("click",x).on("click",x)}if(!vBulletin.pageHasSelectors([".profile-settings-widget"]))return!1;var t;a(function(){a(".js-user-settings form").trigger("reset");E();a(".b-form-select__select").selectBox();vBulletin.options.get("ctMaxChars");a(".js-user-settings__reset").off("click").on("click",resetFormFields);a(".js-birth__month").val(a("#bd_month").val());
a(".js-birth__month").selectBox().change(function(){a("#bd_day").val(a(".js-birth__day option:selected").val());updateDaySelectBox(a(".js-birth__day"),a(".js-birth__month").val())});a(".js-birth__year").off("blur").on("blur",function(){a("#bd_day").val(a(".js-birth__day option:selected").val());updateDaySelectBox(a(".js-birth__day"),a(".js-birth__month").val())});vBulletin.ajaxForm.apply(a("#profileSettings_form"),[{success:function(){location.reload(!0)},api_error:function(b,c,d){var e=vBulletin.ajaxtools;
d.after_error=()=>{if(e.hasError(b,"displayname_change_too_frequent")){var g=a('input[name="displayname"]');g.val(g.attr("value"))}};e.showApiError(b,c,d);return!1}}]);createDaySelectBox(a(".js-birth__day"));var h=1==a(".js-user-settings .b-tabbed-pane__tabs").data("allow-history"),f=vBulletin.history.instance(h),q=a(".js-module-top-anchor").attr("id");if(f.isEnabled()){h=f.getState();if(!h||a.isEmptyObject(h.data))h=location.pathname.match(/\/(profile|account|privacy|notifications|subscriptions)\/?$/),
f.setDefaultState({from:"tabs",tab:h&&h[1]||"profile"},document.title,location.href);f.setStateChange(function(b){var c=f.getState();"tabs"==c.data.from&&(f.log(c.data,c.title,c.url),b=t.tabbedPane("getSelectedTab"),c="#"+c.data.tab+"Tab",b.children("a").prop("hash")!=c&&(b=t.tabbedPane("findTabAnchorByHash",c).data("bypassPushState",!0),t.tabbedPane("selectTab",b)))},"tabs")}t=a(".b-tabbed-pane").tabbedPane({callback:function(b,c){if(f.isEnabled()&&!b.data("bypassPushState")){c={from:"tabs",tab:b.data("url-path")};
var d=vBulletin.makeTabUrl(location.href,c.tab,!1);f.pushState(c,document.title,d)}a("select.b-form-select__select").selectBox();b.data("bypassPushState",null)}});if(!f.isEnabled())t.on("selectTab",function(b,c){location.href=vBulletin.makeTabUrl(location.href,a(c).data("url-path"),!1,q);return!1});a("#new_useremail").off("focus.usersettings").on("focus.usersettings",function(b){b.preventDefault();a("#new_email_container").addClass("isActive").slideDown("3000")});a("#user_newpass").off("focus.usersettings").on("focus.usersettings",
function(b){b.preventDefault();a("#new_pass_container").addClass("isActive").slideDown("3000")});a("#settingsErrorClose").off("click").on("click",function(){a("#settingsErrorDialog").dialog("close")});a("#accountSettings_form").ajaxForm({dataType:"json",beforeSubmit:function(b,c,d){return k()},success:function(b,c,d,e){b&&b.response&&b.response.newtoken&&vBulletin.doReplaceSecurityToken(b.response.newtoken);if(b&&b.response&&b.response.errors){c=[];for(var g in b.response.errors)"exception_trace"!=
b.response.errors[g][0]&&"errormsg"!=b.response.errors[g][0]&&c.push(vBulletin.phrase.get(b.response.errors[g]));openAlertDialog({title:vBulletin.phrase.get("error"),message:c.join("<br />"),iconType:"warning"})}else location.reload(!0)}});var k=function(){var b=a("#user_currentpass"),c=a("#user_newpass"),d=a("#user_newpass2"),e=c.val(),g=d.val(),n=function(p,m){vBulletin.error("error",p,m)};if(e||g){if(""==b.val())return n("enter_current_password",b),!1;if(!vBulletin.checkPassword(c,d))return!1}else c.removeAttr("name"),
d.removeAttr("name");c=a("#new_useremail");d=a("#new_useremail2");e=c.val();g=d.val();if(e||g){if(""==b.val())return n("enter_current_password",b),!1;if(e!=g)return n("email_addresses_must_match",c),!1;if(!isValidEmailAddress(c.val()))return n("invalid_email_address",c),!1}else c.removeAttr("name"),d.removeAttr("name");return!0};a(".js-logout-all-devices").offon("click",b=>{const c=a(b.currentTarget).data("logouthash");v.openConfirmDialogSimple({title:"warning",message:["are_you_sure_logout_all"],
iconType:"warning",yesPhrase:"log_out",noPhrase:"cancel",onClickYes:()=>{w.ajax({call:"/ajax/api/user/logoutAllDevices",data:{logouthash:c},success:d=>location.href=pageData.baseurl})}});return!1});(function(){var b=a("#ignorelist_container").val(),c=new vBulletin_Autocomplete(a("#ignorelist_container"),{apiClass:"user",minLength:a("#minuserlength").val(),maxItems:a("#maxitems").val()});b&&(b=b.split(","),a.each(b,function(d,e){e=a.trim(e);c.addElement(e)}))})();(function(){var b=a("#blockpmlist_container").val(),
c=new vBulletin_Autocomplete(a("#blockpmlist_container"),{apiClass:"user",minLength:a("#minuserlength_blockpm").val(),maxItems:a("#maxitems_blockpm").val()});b&&(b=b.split(","),a.each(b,function(d,e){e=a.trim(e);c.addElement(e)}))})();a("#follower_request").off("change").on("change",function(){a(this).prop("checked")&&a("#general_followrequest").prop("checked",!0)});a(".js-usersetting-privacy-deleteaccount").offon("click",()=>{v.openConfirmDialogSimple({title:"warning",message:["privacyconsent_terms_delete_warning_detailed",
D.get("user_autodelete_cooldown")],iconType:"warning",yesPhrase:"usersetting_deleteaccount_label",noPhrase:"cancel",onClickYes:()=>{w.ajax({call:"/profile/withdrawPrivacyConsent",success:b=>location.href=b.url})}})});a("#general_followrequest").off("change").on("change",function(){a(this).prop("checked")||a("#follower_request").prop("checked",!1)});var l=a("#subscriptionsTab");0<l.length&&(a(".js-subscription-cost",l).change(function(){var b=a(this).closest(".js-newsubscription_row"),c=a(this).find("option:selected").first(),
d=c.data("currency"),e=c.data("recurring"),g=b.data("id"),n=c.data("subid"),p=a(this).closest(".js-subscriptions_list"),m=a(".js-order_confirm",l),u=a(".js-payment-form",l),y=a(".js-payment-form-loading",l),F=b.data("allowedapis");b=a(".js-paymentapi-selector",m);var z=0,A;var B=function(){a(".js-subscriptions-order",m).prop("disabled",!0);a("body").css("cursor","wait");vBulletin.AJAX({call:"/ajax/api/paidsubscription/placeorder",data:{subscriptionid:g,subscriptionsubid:n,paymentapiclass:a(".js-paymentapi:checked",
m).val(),currency:d},complete:function(){y.addClass("h-hide");a("body").css("cursor","auto")},success:function(r){u.html(r);u.trigger("vb-instrument");m.addClass("h-hide");p.addClass("h-hide");u.offon("click",".js-subscription__cancel",()=>{u.html("").addClass("h-hide");a(".js-subscription__remove",m).trigger("click");return!1});u.removeClass("h-hide")}})};a(this).selectBox("value","");a('<tr class="confirm_data"><td>'+c.data("subtitle")+"</td><td>"+c.data("duration")+"</td><td>"+c.data("value")+
"</td></tr>").appendTo(a(".js-order_confirm_table",m));b.removeClass("h-hide");p.addClass("h-hide");m.off("click",".js-subscription__remove").on("click",".js-subscription__remove",function(){a(".confirm_data",m).remove();a(".js-paymentapi",m).closest("label").removeClass("h-hide");a(".js-subscriptions-order",m).prop("disabled",!1);a(".js-subscription-cost",p).selectBox("value","");m.addClass("h-hide");p.removeClass("h-hide");return!1});m.offon("click",".js-paymentapi",function(){a(".js-subscriptions-order",
m).prop("disabled",!1)});a(".js-paymentapi",m).each(function(){var r=a(this),G=r.attr("data-currency").split(","),H=r.data("recurring");-1==a.inArray(d,G)||-1==a.inArray(r.val(),F)||e&&!H?r.closest("label").addClass("h-hide"):(z++,A=r)});1==z?(A.click(),b.addClass("h-hide"),y.removeClass("h-hide"),B()):(m.off("click",".js-subscriptions-order").on("click",".js-subscriptions-order",B),m.removeClass("h-hide"))}),a(".js-subscription__end",l).on("click",function(){var b=a(this).attr("data-id"),c=a(this).closest("tr"),
d=a(this).closest("table");v.openConfirmDialog({title:vBulletin.phrase.get("end_subscription"),message:vBulletin.phrase.get("end_subscription_confirm"),iconType:"warning",buttonLabel:{yesLabel:vBulletin.phrase.get("end_subscription"),noLabel:vBulletin.phrase.get("cancel")},onClickYes:function(){a("body").css("cursor","wait");vBulletin.AJAX({call:"/ajax/api/paidsubscription/endsubscription",data:{subscriptionid:b},complete:function(){a("body").css("cursor","auto")},success:function(e){c.remove();1>=
d.find("tr").length&&d.closest(".js-existing-subscription-row").remove()},api_error:a.noop})}});return!1}))});createDaySelectBox=function(h){var f="",q=a(".js-birth__month").val(),k=a("#bd_year").val();q=new Date(k,q,0);if(""==a("#bd_day").val()||null==a("#bd_day").val())f+="<option name='day' value='' selected='selected'></option>";for(k=1;k<=q.getDate();k++)k=10>k?"0"+k:k,f=k==a("#bd_day").val()?f+("<option name='day' value='"+k+"' selected='selected'>"+k+"</option>"):f+("<option name='day' value='"+
k+"'>"+k+"</option>");h.html(f);h.selectBox("destroy").selectBox()};updateDaySelectBox=function(h,f){var q=""!=a(".js-birth__year").val()?a(".js-birth__year").val():0;f=new Date(q,f,0);q="";var k=parseInt(h.filter("select").val(),10);f=f.getDate();for(var l=1;l<=f;l++)l=10>l?"0"+l:l,q+="<option name='day' value='"+l+"'"+(k==l?' selected="selected"':"")+">"+l+"</option>";updateSelectBox(h,q)};updateSelectBox=function(h,f){h.selectBox("destroy");f&&h.html(f);h.selectBox()};resetFormFields=function(){var h=
a(this.form);setTimeout(function(){a("input",h).trigger("change");a("select.b-form-select__select",h).each(function(){updateSelectBox(a(this))})},100)}})(jQuery,vBulletin,vBulletin.options,vBulletin.ajaxtools,vBulletin.dialogtools);
;

// ***************************
// js.compressed/paidsubscription.js
// ***************************
vBulletin.precache("paymentapi payment_api_error paymentapi_paymentsubmitted paypal2_paymentsuccess paypal2_paymentsuccess_reg paypal2_waitingforwebhook".split(" "),[]);vBulletin.ensureObj("paypal2");
((l,h,e)=>{function u(a,q,n){function p(c,m,v,w){c={style:{tagline:!1},onError(d){g()}};let t=r;f.data("recurring")?(c.createSubscription=function(d,k){return f.data("subscriptionid")},c.onApprove=async function(d){await m.AJAX({call:"/ajax/api/paidsubscription/completePaypalSubscription",data:{order_id:d.orderID,subscription_id:d.subscriptionID},success(k,x,y){k.success&&(m.dialogtools.alert("paymentapi_paymentsubmitted","paypal2_waitingforwebhook"),t())}})}):(c.createOrder=async function(d,k){d=
await m.AJAX({call:"/ajax/api/paidsubscription/preparePayPalOrder",data:b.serializeArray()});if(d.id)return d.id},c.onApprove=async function(d){await m.AJAX({call:"/ajax/api/paidsubscription/completePayPalOrder",data:{order_id:d.orderID},success(k,x,y){console.log(k);k.success&&(m.dialogtools.alert("paymentapi_paymentsubmitted",isRegistration?"paypal2_paymentsuccess_reg":"paypal2_paymentsuccess"),t())}})});v.Buttons(c).render(w)}const f=l(n),b=f.closest("form"),g=()=>{h.dialogtools.alert("paymentapi",
"payment_api_error","error")};isRegistration="registration"===f.data("context");let r;if(isRegistration){let c=b.closest(".js-dialog");c.find(".js-button-primary").hide();r=()=>{f.hide();c.dialog("close");h.ensureMethod(e,"regfinal")()}}else b.find(":submit:enabled").hide(),r=()=>{f.hide()};h.ready("paypal2").then(()=>z(h,a,q)).then(c=>p(jQuery,h,window[c],n)).catch(c=>{console.log(c);g()})}function z(a,q,n){return new Promise((p,f)=>{let b="paypal2_"+q.toUpperCase()+(n?"_recurring":"_onetime");a.ensureObj("urls",
{},e);a.ensureObj("urls_loaded",{},e);if(e.urls.hasOwnProperty(b))if(e.urls_loaded.hasOwnProperty(b))p(b);else{e.urls_loaded[b]=!0;let g=document.createElement("script");g.onload=()=>p(b);g.onerror=()=>f("Failed to load PayPal JS for "+b+" :"+e.urls[b]);g.setAttribute("src",e.urls[b]);g.setAttribute("data-namespace",b);document.head.appendChild(g)}else f("Failed to find JS URL cache for "+b)})}l(document).on("vb-instrument",a=>{a=l(a.target).find(".js-paypal2-btn-container");0<a.length&&!a.data("paypal2-initialized")&&
(a.data("paypal2-initialized",!0),u(a.data("currency"),a.data("recurring"),"#"+a.attr("id")))});l(()=>{let a=l(".js-paypal2-urls");0<a.length&&(e.urls=a.data("paypalUrls"),h.ready("paypal2").resolve())})})(jQuery,vBulletin,vBulletin.paypal2);
;

// ***************************
// js.compressed/css_b_tabbed_pane.js
// ***************************
(function(e){e.tabbedPane=function(g,l){var a=this,f=e(g),k={paneContext:f,paneSelectedClassName:"b-tabbed-pane__pane--selected",paneSelector:".b-tabbed-pane__pane",tabSelectedClassName:"b-tabbed-pane__tab--selected",tabSelector:".b-tabbed-pane__tab"},b;a.init=function(){a.settings=b=e.extend({},k,l);f.data("tabbedPane",{});b.tabSelectedClass="."+b.tabSelectedClassName;b.paneSelectedClass="."+b.paneSelectedClassName;a.getTabs();a.bindTabClicks()};a.getTabs=function(){var c;a.tabs=f.find(b.tabSelector);
a.panes=e();a.tabs.each(function(){var d=e(this),h=d.children("a");d.data("tabbedPane",{});targetId=h.attr("href");targetId=targetId.match(/#([^\?]+)/)[0].substr(1);c=b.paneContext.find("#"+targetId);c.length?(a.panes=a.panes.add(c),d.data("tabbedPane").pane=c):a.tabs=a.tabs.not(d)})};a.bindTabClicks=function(){a.tabs.children("a").on("click.tabbedPane",function(c,d){c.preventDefault();if(!1===f.triggerHandler("selectTab",[this]))return!1;a.selectTab(e(this),d||b.callback)})};a.selectTab=function(c,
d){window.location.hash.match(/^[^\?]*/);var h=c.parent().data("tabbedPane").pane;c.hasClass(b.tabActiveClass)&&h.hasClass(b.paneActiveClass)||(a.tabs.filter(b.tabSelectedClass).removeClass(b.tabSelectedClassName).children().removeClass(b.tabSelectedClassName),c.parent().addClass(b.tabSelectedClassName).children().addClass(b.tabSelectedClassName),a.panes.filter(b.paneSelectedClass).removeClass(b.paneSelectedClassName),h.addClass(b.paneSelectedClassName),"function"===typeof d&&d.apply(f,[c,h]))};a.publicMethods=
{getSelectedTab:function(){return a.tabs.filter(b.tabSelectedClass)},getSelectedPane:function(){return a.panes.filter(b.paneSelectedClass)},selectTab:function(c,d){c.trigger("click",[d]).trigger("focus")},findTabAnchorByHash:function(c){return a.tabs.children("a").filter('a[href*="'+c+'"]')}};a.init()};e.fn.tabbedPane=function(g){var l=arguments,a,f=this.each(function(){var k=e(this),b=k.data("tabbedPane");void 0===b&&(b=new e.tabbedPane(this,g),k.data("tabbedPane",b));if(b.publicMethods[g])return a=
b.publicMethods[g].apply(b,Array.prototype.slice.call(l,1)),!1});return"undefined"!==typeof a?a:f}})(jQuery);
;

