<?php
 declare(strict_types=1); namespace Square\Models; class BusinessAppointmentSettingsMaxAppointmentsPerDayLimitType { public const PER_TEAM_MEMBER = 'PER_TEAM_MEMBER'; public const PER_LOCATION = 'PER_LOCATION'; } 