<?php
 $PHPMAILER_LANG['authenticate'] = 'SMTP hiba: az azonosítás sikertelen.'; $PHPMAILER_LANG['connect_host'] = 'SMTP hiba: nem lehet kapcsolódni az SMTP-szerverhez.'; $PHPMAILER_LANG['data_not_accepted'] = 'SMTP hiba: adatok visszautasítva.'; $PHPMAILER_LANG['empty_message'] = 'Üres az üzenettörzs.'; $PHPMAILER_LANG['encoding'] = 'Ismeretlen kódolás: '; $PHPMAILER_LANG['execute'] = 'Nem lehet végrehajtani: '; $PHPMAILER_LANG['file_access'] = 'A következő fájl nem elérhető: '; $PHPMAILER_LANG['file_open'] = 'Fájl hiba: a következő fájlt nem lehet megnyitni: '; $PHPMAILER_LANG['from_failed'] = 'A feladóként megadott következő cím hibás: '; $PHPMAILER_LANG['instantiate'] = 'A PHP mail() függvényt nem sikerült végrehajtani.'; $PHPMAILER_LANG['invalid_address'] = 'Érvénytelen cím: '; $PHPMAILER_LANG['mailer_not_supported'] = ' a mailer-osztály nem támogatott.'; $PHPMAILER_LANG['provide_address'] = 'Legalább egy címzettet fel kell tüntetni.'; $PHPMAILER_LANG['recipients_failed'] = 'SMTP hiba: a címzettként megadott következő címek hibásak: '; $PHPMAILER_LANG['signing'] = 'Hibás aláírás: '; $PHPMAILER_LANG['smtp_connect_failed'] = 'Hiba az SMTP-kapcsolatban.'; $PHPMAILER_LANG['smtp_error'] = 'SMTP-szerver hiba: '; $PHPMAILER_LANG['variable_set'] = 'A következő változók beállítása nem sikerült: '; $PHPMAILER_LANG['extension_missing'] = 'Bővítmény hiányzik: '; 