<?php
 declare(strict_types=1); namespace Square\Models; class GiftCardActivityType { public const ACTIVATE = 'ACTIVATE'; public const LOAD = 'LOAD'; public const REDEEM = 'REDEEM'; public const CLEAR_BALANCE = 'CLEAR_BALANCE'; public const DEACTIVATE = 'DEACTIVATE'; public const ADJUST_INCREMENT = 'ADJUST_INCREMENT'; public const ADJUST_DECREMENT = 'ADJUST_DECREMENT'; public const REFUND = 'REFUND'; public const UNLINKED_ACTIVITY_REFUND = 'UNLINKED_ACTIVITY_REFUND'; public const IMPORT = 'IMPORT'; public const BLOCK = 'BLOCK'; public const UNBLOCK = 'UNBLOCK'; public const IMPORT_REVERSAL = 'IMPORT_REVERSAL'; } 