<?php
 declare(strict_types=1); namespace Square\Models; use stdClass; class CatalogQueryItemsForModifierList implements \JsonSerializable { private $modifierListIds; public function __construct(array $modifierListIds) { $this->modifierListIds = $modifierListIds; } public function getModifierListIds(): array { return $this->modifierListIds; } public function setModifierListIds(array $modifierListIds): void { $this->modifierListIds = $modifierListIds; } #[\ReturnTypeWillChange] public function jsonSerialize(bool $asArrayWhenEmpty = false) { $json = []; $json['modifier_list_ids'] = $this->modifierListIds; $json = array_filter($json, function ($val) { return $val !== null; }); return (!$asArrayWhenEmpty && empty($json)) ? new stdClass() : $json; } } 