<?php
 declare(strict_types=1); namespace Minishlink\WebPush; interface SubscriptionInterface { public function getEndpoint(): string; public function getPublicKey(): ?string; public function getAuthToken(): ?string; public function getContentEncoding(): ?string; } 