<?php
 declare(strict_types=1); namespace Square\Models; class LoyaltyProgramAccrualRuleType { public const VISIT = 'VISIT'; public const SPEND = 'SPEND'; public const ITEM_VARIATION = 'ITEM_VARIATION'; public const CATEGORY = 'CATEGORY'; } 