<?php
 namespace Eluceo\iCal\Domain\ValueObject; final class Member { private ?EmailAddress $emailAddress = null; public function __construct(EmailAddress $emailAddress) { $this->emailAddress = $emailAddress; } public function getEmailAddress(): EmailAddress { assert($this->emailAddress !== null); return $this->emailAddress; } } 