<?php
 declare(strict_types=1); namespace Ramsey\Collection; use Ramsey\Collection\Exception\NoSuchElementException; use RuntimeException; interface QueueInterface extends ArrayInterface { public function add(mixed $element): bool; public function element(): mixed; public function offer(mixed $element): bool; public function peek(): mixed; public function poll(): mixed; public function remove(): mixed; public function getType(): string; } 