<?php
 declare(strict_types=1); namespace Square\Models; class ActionCancelReason { public const BUYER_CANCELED = 'BUYER_CANCELED'; public const SELLER_CANCELED = 'SELLER_CANCELED'; public const TIMED_OUT = 'TIMED_OUT'; } 