<?php
 namespace Stripe\TestHelpers; class TestClock extends \Stripe\ApiResource { const OBJECT_NAME = 'test_helpers.test_clock'; use \Stripe\ApiOperations\All; use \Stripe\ApiOperations\Create; use \Stripe\ApiOperations\Delete; use \Stripe\ApiOperations\Retrieve; const STATUS_ADVANCING = 'advancing'; const STATUS_INTERNAL_FAILURE = 'internal_failure'; const STATUS_READY = 'ready'; public function advance($params = null, $opts = null) { $url = $this->instanceUrl() . '/advance'; list($response, $opts) = $this->_request('post', $url, $params, $opts); $this->refreshFrom($response, $opts); return $this; } } 