<?php
 $PHPMAILER_LANG['authenticate'] = 'Erro SMTP: Non puido ser autentificado.'; $PHPMAILER_LANG['connect_host'] = 'Erro SMTP: Non puido conectar co servidor SMTP.'; $PHPMAILER_LANG['data_not_accepted'] = 'Erro SMTP: Datos non aceptados.'; $PHPMAILER_LANG['empty_message'] = 'Corpo da mensaxe vacía'; $PHPMAILER_LANG['encoding'] = 'Codificación descoñecida: '; $PHPMAILER_LANG['execute'] = 'Non puido ser executado: '; $PHPMAILER_LANG['file_access'] = 'Nob puido acceder ó arquivo: '; $PHPMAILER_LANG['file_open'] = 'Erro de Arquivo: No puido abrir o arquivo: '; $PHPMAILER_LANG['from_failed'] = 'A(s) seguinte(s) dirección(s) de remitente(s) deron erro: '; $PHPMAILER_LANG['instantiate'] = 'Non puido crear unha instancia da función Mail.'; $PHPMAILER_LANG['invalid_address'] = 'Non puido envia-lo correo: dirección de email inválida: '; $PHPMAILER_LANG['mailer_not_supported'] = ' mailer non está soportado.'; $PHPMAILER_LANG['provide_address'] = 'Debe engadir polo menos unha dirección de email coma destino.'; $PHPMAILER_LANG['recipients_failed'] = 'Erro SMTP: Os seguintes destinos fallaron: '; $PHPMAILER_LANG['signing'] = 'Erro ó firmar: '; $PHPMAILER_LANG['smtp_connect_failed'] = 'SMTP Connect() fallou.'; $PHPMAILER_LANG['smtp_error'] = 'Erro do servidor SMTP: '; $PHPMAILER_LANG['variable_set'] = 'Non puidemos axustar ou reaxustar a variábel: '; 