<?php
 declare(strict_types=1); namespace Square\Models; use stdClass; class UpdateWageSettingRequest implements \JsonSerializable { private $wageSetting; public function __construct(WageSetting $wageSetting) { $this->wageSetting = $wageSetting; } public function getWageSetting(): WageSetting { return $this->wageSetting; } public function setWageSetting(WageSetting $wageSetting): void { $this->wageSetting = $wageSetting; } #[\ReturnTypeWillChange] public function jsonSerialize(bool $asArrayWhenEmpty = false) { $json = []; $json['wage_setting'] = $this->wageSetting; $json = array_filter($json, function ($val) { return $val !== null; }); return (!$asArrayWhenEmpty && empty($json)) ? new stdClass() : $json; } } 