<?php
 declare(strict_types=1); namespace Square\Models; use stdClass; class UpdateWageSettingResponse implements \JsonSerializable { private $wageSetting; private $errors; public function getWageSetting(): ?WageSetting { return $this->wageSetting; } public function setWageSetting(?WageSetting $wageSetting): void { $this->wageSetting = $wageSetting; } public function getErrors(): ?array { return $this->errors; } public function setErrors(?array $errors): void { $this->errors = $errors; } #[\ReturnTypeWillChange] public function jsonSerialize(bool $asArrayWhenEmpty = false) { $json = []; if (isset($this->wageSetting)) { $json['wage_setting'] = $this->wageSetting; } if (isset($this->errors)) { $json['errors'] = $this->errors; } $json = array_filter($json, function ($val) { return $val !== null; }); return (!$asArrayWhenEmpty && empty($json)) ? new stdClass() : $json; } } 