<?php
 declare(strict_types=1); namespace Square\Models; use stdClass; class Vendor implements \JsonSerializable { private $id; private $createdAt; private $updatedAt; private $name; private $address; private $contacts; private $accountNumber; private $note; private $version; private $status; public function getId(): ?string { return $this->id; } public function setId(?string $id): void { $this->id = $id; } public function getCreatedAt(): ?string { return $this->createdAt; } public function setCreatedAt(?string $createdAt): void { $this->createdAt = $createdAt; } public function getUpdatedAt(): ?string { return $this->updatedAt; } public function setUpdatedAt(?string $updatedAt): void { $this->updatedAt = $updatedAt; } public function getName(): ?string { return $this->name; } public function setName(?string $name): void { $this->name = $name; } public function getAddress(): ?Address { return $this->address; } public function setAddress(?Address $address): void { $this->address = $address; } public function getContacts(): ?array { return $this->contacts; } public function setContacts(?array $contacts): void { $this->contacts = $contacts; } public function getAccountNumber(): ?string { return $this->accountNumber; } public function setAccountNumber(?string $accountNumber): void { $this->accountNumber = $accountNumber; } public function getNote(): ?string { return $this->note; } public function setNote(?string $note): void { $this->note = $note; } public function getVersion(): ?int { return $this->version; } public function setVersion(?int $version): void { $this->version = $version; } public function getStatus(): ?string { return $this->status; } public function setStatus(?string $status): void { $this->status = $status; } #[\ReturnTypeWillChange] public function jsonSerialize(bool $asArrayWhenEmpty = false) { $json = []; if (isset($this->id)) { $json['id'] = $this->id; } if (isset($this->createdAt)) { $json['created_at'] = $this->createdAt; } if (isset($this->updatedAt)) { $json['updated_at'] = $this->updatedAt; } if (isset($this->name)) { $json['name'] = $this->name; } if (isset($this->address)) { $json['address'] = $this->address; } if (isset($this->contacts)) { $json['contacts'] = $this->contacts; } if (isset($this->accountNumber)) { $json['account_number'] = $this->accountNumber; } if (isset($this->note)) { $json['note'] = $this->note; } if (isset($this->version)) { $json['version'] = $this->version; } if (isset($this->status)) { $json['status'] = $this->status; } $json = array_filter($json, function ($val) { return $val !== null; }); return (!$asArrayWhenEmpty && empty($json)) ? new stdClass() : $json; } } 