<?php
 declare(strict_types=1); namespace Shopify\Rest\Admin2024_01; use Shopify\Auth\Session; use Shopify\Rest\Base; class InventoryLevel extends Base { public static string $API_VERSION = "2024-01"; protected static array $HAS_ONE = []; protected static array $HAS_MANY = []; protected static array $PATHS = [ ["http_method" => "delete", "operation" => "delete", "ids" => [], "path" => "inventory_levels.json"], ["http_method" => "get", "operation" => "get", "ids" => [], "path" => "inventory_levels.json"], ["http_method" => "post", "operation" => "adjust", "ids" => [], "path" => "inventory_levels/adjust.json"], ["http_method" => "post", "operation" => "connect", "ids" => [], "path" => "inventory_levels/connect.json"], ["http_method" => "post", "operation" => "set", "ids" => [], "path" => "inventory_levels/set.json"] ]; public static function delete( Session $session, array $urlIds = [], array $params = [] ): ?array { $response = parent::request( "delete", "delete", $session, [], $params, ); return $response->getDecodedBody(); } public static function all( Session $session, array $urlIds = [], array $params = [] ): array { return parent::baseFind( $session, [], $params, ); } public function adjust( array $params = [], $body = [] ): ?array { $response = parent::request( "post", "adjust", $this->session, [], $params, $body, $this, ); return $response->getDecodedBody(); } public function connect( array $params = [], $body = [] ): ?array { $response = parent::request( "post", "connect", $this->session, [], $params, $body, $this, ); return $response->getDecodedBody(); } public function set( array $params = [], $body = [] ): ?array { $response = parent::request( "post", "set", $this->session, [], $params, $body, $this, ); return $response->getDecodedBody(); } } 