<?php
 class vB_Utility_Template_ParserNode_Curly_Rawphrase extends vB_Utility_Template_ParserNode_Curly { public function validate() : array { $errors = []; $attributecount = sizeof($this->main_node->attributes); if ($attributecount == 0) { $errors[] = 'no_phrase_specified'; } return $errors; } public function compile() : string { $arguments = $this->getRenderedAttributes(); return 'vB_Template_Runtime::parsePhrase(' . implode(', ', $arguments) . ')'; } } 