<?php
 namespace Stripe; class Product extends ApiResource { const OBJECT_NAME = 'product'; use ApiOperations\All; use ApiOperations\Create; use ApiOperations\Delete; use ApiOperations\Retrieve; use ApiOperations\Search; use ApiOperations\Update; const TYPE_GOOD = 'good'; const TYPE_SERVICE = 'service'; public static function search($params = null, $opts = null) { $url = '/v1/products/search'; return self::_searchResource($url, $params, $opts); } } 