<?php
 $PHPMAILER_LANG['authenticate'] = 'Chyba SMTP: Autentizace selhala.'; $PHPMAILER_LANG['connect_host'] = 'Chyba SMTP: Nelze navázat spojení se SMTP serverem.'; $PHPMAILER_LANG['data_not_accepted'] = 'Chyba SMTP: Data nebyla přijata.'; $PHPMAILER_LANG['empty_message'] = 'Prázdné tělo zprávy'; $PHPMAILER_LANG['encoding'] = 'Neznámé kódování: '; $PHPMAILER_LANG['execute'] = 'Nelze provést: '; $PHPMAILER_LANG['file_access'] = 'Nelze získat přístup k souboru: '; $PHPMAILER_LANG['file_open'] = 'Chyba souboru: Nelze otevřít soubor pro čtení: '; $PHPMAILER_LANG['from_failed'] = 'Následující adresa odesílatele je nesprávná: '; $PHPMAILER_LANG['instantiate'] = 'Nelze vytvořit instanci emailové funkce.'; $PHPMAILER_LANG['invalid_address'] = 'Neplatná adresa: '; $PHPMAILER_LANG['invalid_hostentry'] = 'Záznam hostitele je nesprávný: '; $PHPMAILER_LANG['invalid_host'] = 'Hostitel je nesprávný: '; $PHPMAILER_LANG['mailer_not_supported'] = ' mailer není podporován.'; $PHPMAILER_LANG['provide_address'] = 'Musíte zadat alespoň jednu emailovou adresu příjemce.'; $PHPMAILER_LANG['recipients_failed'] = 'Chyba SMTP: Následující adresy příjemců nejsou správně: '; $PHPMAILER_LANG['signing'] = 'Chyba přihlašování: '; $PHPMAILER_LANG['smtp_connect_failed'] = 'SMTP Connect() selhal.'; $PHPMAILER_LANG['smtp_error'] = 'Chyba SMTP serveru: '; $PHPMAILER_LANG['variable_set'] = 'Nelze nastavit nebo změnit proměnnou: '; $PHPMAILER_LANG['extension_missing'] = 'Chybí rozšíření: '; 