vBulletin.precache(
	[
		// phrases
		'wordpresslogin_connect_to_provider',
		'wordpresslogin_disconnect_complete',
		'wordpresslogin_disconnect_from_provider',
	],
	[
		'wordpresslogin_site_name',
	]
);
{
	const vB = vBulletin,
		sitename = vB.options.get('wordpresslogin_site_name'),
		phrases = {
			connect_to_provider: ['wordpresslogin_connect_to_provider', sitename],
			disconnect_from_provider: ['wordpresslogin_disconnect_from_provider', sitename],
			after_unlink_title: ['wordpresslogin_disconnect_from_provider', sitename],
			after_unlink_body: ['wordpresslogin_disconnect_complete', sitename],
		};
	vB.ready('oauth').then(() => {
		vB.oauth.init('wordpresslogin', phrases);
	});
}