<?php
 declare(strict_types=1); namespace Square\Models; class BookingBookingSource { public const FIRST_PARTY_MERCHANT = 'FIRST_PARTY_MERCHANT'; public const FIRST_PARTY_BUYER = 'FIRST_PARTY_BUYER'; public const THIRD_PARTY_BUYER = 'THIRD_PARTY_BUYER'; public const API = 'API'; } 