<?php
 class vB_Utility_Template_ParserNode_Curly_Spritepath extends vB_Utility_Template_ParserNode_Curly { public function validate() : array { $errors = []; $attributecount = sizeof($this->main_node->attributes); if ($attributecount == 0) { $errors[] = 'no_variable_specified'; } return $errors; } public function compile() : string { $arguments = []; foreach ($this->main_node->attributes AS $attribute) { if ($attribute instanceof vB_CurlyNode) { $attribute = $this->createNode($attribute)->compile(); } $arguments[] = $attribute; } return '\'\' . vB_Template_Runtime::includeSpriteFile(\'' . implode(', ', $arguments) . '\'); $final_rendered .= \'\''; } } 