<?php
 declare(strict_types=1); namespace SpomkyLabs\Pki\X501\MatchingRule; use SpomkyLabs\Pki\X501\StringPrep\StringPreparer; final class CaseIgnoreMatch extends StringPrepMatchingRule { private function __construct(int $stringType) { parent::__construct( StringPreparer::forStringType($stringType)->withCaseFolding(true) ); } public static function create(int $stringType): self { return new self($stringType); } } 