<?php
 declare(strict_types=1); namespace Square\Models; class BankAccountType { public const CHECKING = 'CHECKING'; public const SAVINGS = 'SAVINGS'; public const INVESTMENT = 'INVESTMENT'; public const OTHER = 'OTHER'; public const BUSINESS_CHECKING = 'BUSINESS_CHECKING'; } 