<?php
 namespace Stripe\Service\TestHelpers; class TestClockService extends \Stripe\Service\AbstractService { public function advance($id, $params = null, $opts = null) { return $this->request('post', $this->buildPath('/v1/test_helpers/test_clocks/%s/advance', $id), $params, $opts); } public function all($params = null, $opts = null) { return $this->requestCollection('get', '/v1/test_helpers/test_clocks', $params, $opts); } public function create($params = null, $opts = null) { return $this->request('post', '/v1/test_helpers/test_clocks', $params, $opts); } public function delete($id, $params = null, $opts = null) { return $this->request('delete', $this->buildPath('/v1/test_helpers/test_clocks/%s', $id), $params, $opts); } public function retrieve($id, $params = null, $opts = null) { return $this->request('get', $this->buildPath('/v1/test_helpers/test_clocks/%s', $id), $params, $opts); } } 