<?php
 declare(strict_types=1); namespace SpomkyLabs\Pki\X509\Certificate\Extension\DistributionPoint; use SpomkyLabs\Pki\ASN1\Element; use SpomkyLabs\Pki\X501\ASN1\RDN; final class RelativeName extends DistributionPointName { private function __construct( private readonly RDN $rdn ) { parent::__construct(self::TAG_RDN); } public static function create(RDN $rdn): self { return new self($rdn); } public function rdn(): RDN { return $this->rdn; } protected function _valueASN1(): Element { return $this->rdn->toASN1(); } } 