<?php
 declare(strict_types=1); namespace SpomkyLabs\Pki\ASN1\Feature; use SpomkyLabs\Pki\ASN1\Element; use SpomkyLabs\Pki\ASN1\Type\TaggedType; use SpomkyLabs\Pki\ASN1\Type\UnspecifiedType; interface ElementBase extends Encodable { public function typeClass(): int; public function isConstructed(): bool; public function tag(): int; public function isType(int $tag): bool; public function expectType(int $tag): self; public function isTagged(): bool; public function expectTagged(?int $tag = null): TaggedType; public function asElement(): Element; public function asUnspecified(): UnspecifiedType; } 