<?php
 declare(strict_types=1); namespace Square\Models; use stdClass; class V1SettlementEntry implements \JsonSerializable { private $paymentId; private $type; private $amountMoney; private $feeMoney; public function getPaymentId(): ?string { return $this->paymentId; } public function setPaymentId(?string $paymentId): void { $this->paymentId = $paymentId; } public function getType(): ?string { return $this->type; } public function setType(?string $type): void { $this->type = $type; } public function getAmountMoney(): ?V1Money { return $this->amountMoney; } public function setAmountMoney(?V1Money $amountMoney): void { $this->amountMoney = $amountMoney; } public function getFeeMoney(): ?V1Money { return $this->feeMoney; } public function setFeeMoney(?V1Money $feeMoney): void { $this->feeMoney = $feeMoney; } #[\ReturnTypeWillChange] public function jsonSerialize(bool $asArrayWhenEmpty = false) { $json = []; if (isset($this->paymentId)) { $json['payment_id'] = $this->paymentId; } if (isset($this->type)) { $json['type'] = $this->type; } if (isset($this->amountMoney)) { $json['amount_money'] = $this->amountMoney; } if (isset($this->feeMoney)) { $json['fee_money'] = $this->feeMoney; } $json = array_filter($json, function ($val) { return $val !== null; }); return (!$asArrayWhenEmpty && empty($json)) ? new stdClass() : $json; } } 