<?php
 declare(strict_types=1); namespace Square\Models; use stdClass; class RetrieveTeamMemberResponse implements \JsonSerializable { private $teamMember; private $errors; public function getTeamMember(): ?TeamMember { return $this->teamMember; } public function setTeamMember(?TeamMember $teamMember): void { $this->teamMember = $teamMember; } public function getErrors(): ?array { return $this->errors; } public function setErrors(?array $errors): void { $this->errors = $errors; } #[\ReturnTypeWillChange] public function jsonSerialize(bool $asArrayWhenEmpty = false) { $json = []; if (isset($this->teamMember)) { $json['team_member'] = $this->teamMember; } if (isset($this->errors)) { $json['errors'] = $this->errors; } $json = array_filter($json, function ($val) { return $val !== null; }); return (!$asArrayWhenEmpty && empty($json)) ? new stdClass() : $json; } } 