<?php
 declare(strict_types=1); namespace Square\Models; use stdClass; class OrderLineItemPricingBlocklistsBlockedTax implements \JsonSerializable { private $uid; private $taxUid; private $taxCatalogObjectId; public function getUid(): ?string { return $this->uid; } public function setUid(?string $uid): void { $this->uid = $uid; } public function getTaxUid(): ?string { return $this->taxUid; } public function setTaxUid(?string $taxUid): void { $this->taxUid = $taxUid; } public function getTaxCatalogObjectId(): ?string { return $this->taxCatalogObjectId; } public function setTaxCatalogObjectId(?string $taxCatalogObjectId): void { $this->taxCatalogObjectId = $taxCatalogObjectId; } #[\ReturnTypeWillChange] public function jsonSerialize(bool $asArrayWhenEmpty = false) { $json = []; if (isset($this->uid)) { $json['uid'] = $this->uid; } if (isset($this->taxUid)) { $json['tax_uid'] = $this->taxUid; } if (isset($this->taxCatalogObjectId)) { $json['tax_catalog_object_id'] = $this->taxCatalogObjectId; } $json = array_filter($json, function ($val) { return $val !== null; }); return (!$asArrayWhenEmpty && empty($json)) ? new stdClass() : $json; } } 