<?php
// vb6 6.2.3, L3138846, 18:27:41, Sun Aug 30th 2026
$md5_sums = array(
	'/' => array(
		'LICENSE' => 'c69442db8a8e9b0738facf0b212c049a',
		'favicon.ico' => 'c1f20852dd1caf078f49de77a2de8e3f',
		'htaccess.txt' => 'b53c6e59f7a1ac2e459ffe0844b591ea',
		'index.php' => 'dc66b0810b4c8ac0fcac6b286341e8a2',
		'robots.txt.new' => '65c1ae642ab8060f83bf0f31505c7ca4',
		'web.config' => '8066a22c1b5069bb6d5e5144956ab493',
	),
	'/core' => array(
		'api.php' => 'd06364db596f166554adadcd57d2d94c',
		'attachment.php' => '9c6d672114b5a278b87b38eeae8786cf',
		'clear.gif' => '9bb191c6827273aa978cab39a3587950',
		'css.php' => 'a79b0eba925e5de450d3f9ab41c9cfb0',
		'image.php' => 'b1a59205ccaad0485666c4c973a3b98c',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'login.php' => '55c796a289a34108391f9d4b0107e7ab',
		'payment_gateway.php' => '263bab051ac32ccd75be9e9ad63aace8',
		'sprite.php' => 'e3574194336aed613334e54f1bf69cf4',
		'xmlsitemap.php' => '43747f804204754354a2152ad4918256',
	),
	'/core/admincp' => array(
		'admininfraction.php' => '92dcac0454ffe9e3b9b1acd7c75d2b49',
		'adminlog.php' => '6b206a98191765fd39d208ce923348fd',
		'adminpermissions.php' => '7d77d8f95c22a5214e0492f59d4d160a',
		'api.php' => 'a238c0ac8ab7f572539e24fb31e7278b',
		'apilog.php' => '8f7244b88444b63d55c637578315be3d',
		'apistats.php' => 'f4abcb73530b4547a0f267b7c4527ad9',
		'attachment.php' => '95b9f45546db773b88c7896d3b9d6199',
		'attachmentpermission.php' => 'e782e1701d6958c03f774639c3955c27',
		'avatar.php' => '5f3d834404a11146098a26a1cc743711',
		'banning.php' => '4963ebc12e4aa77bb7caba442febebe7',
		'bbcode.php' => 'efaf6f21dec37df1a916c3612df0af64',
		'calendar.php' => '614022364bda28e18187577be21ca069',
		'clear.gif' => '9bb191c6827273aa978cab39a3587950',
		'cms.php' => 'a0105b3c77356f85d49fdcdd5985212b',
		'cronadmin.php' => 'c6483d4316687ab6a7b3a3db2367d437',
		'cronlog.php' => '95a3280f1eacc6b4da4d0daf8d9d98be',
		'diagnostic.php' => 'da705165f4b5a9b30e5c390bd43e5dd8',
		'email.php' => 'c7c8e8de0a4d867c36d602ee65d4181c',
		'eventhighlight.php' => '2d11b39975d02a18c5c3f930c498745b',
		'faq.php' => '6651fb343e0b9bf71396f6597e37436a',
		'fcm.php' => '9b9204aa6f8c1839c7db51628a263aa8',
		'forum.php' => 'a9df8978f63306d3327e15e4a379b9e0',
		'forumpermission.php' => 'd5f82f39889a9d5b80c9769407e9b5aa',
		'global.php' => '6de5a3f9445db596e755fe9ed8281896',
		'help.php' => '9d51c482fc128b3601a75b2d5d13afdb',
		'hook.php' => 'bc540220d9ae2170b3f3216884bdfc58',
		'image.php' => 'eefcd3c5126ef87b4cc3733e21549932',
		'index.php' => '83ebbffc941d80682f1965b399f26556',
		'language.php' => '6fc6f521351438f3fdf2d8b422ef87a5',
		'locations.php' => 'f52ba889008839cc67a8563a76ae6d54',
		'managereactions.php' => '22aa827d33921efe549cd4f4fcde3714',
		'misc.php' => '3c440079e870f422b6302f50e9c0a8ab',
		'moderator.php' => '401d4945af38a2cc2b32e1763b3b9b2c',
		'modlog.php' => '31beba695f6c52e760d7d5d98fd2b6e7',
		'newsproxy.php' => '840270ece7df58e5369240770a4202dd',
		'nodefield.php' => '2ef8531b0952135702d28e7f4ccb1db7',
		'nodetools.php' => '8cb6aee77943b096e086c03a8c1c914c',
		'notice.php' => '7a581f28fd790fd52e4515bc51583c0c',
		'options.php' => 'f6ef0292042e812a9f341f46f4689f7a',
		'optionsemail.php' => 'c65f79c0770112b27c721faa6c2e24b8',
		'pagepermission.php' => '12971f165c4794dca209f289b2cd24b2',
		'phrase.php' => 'b86724be048732c67601f6a44de54c8b',
		'prefix.php' => '0706d7e31f553d65444342267d5c077f',
		'product.php' => '0ca2cf08284b47c2c235b7a8e0f54016',
		'profilefield.php' => 'd2bebac121c3c5e673c5bc6592a186dd',
		'push.php' => '36015f8e3d0eb0085e0deca4c1a2b279',
		'queries.php' => 'df551c70e41d85958a6a516d043b67af',
		'ranks.php' => '77962467644b6ff1a0dc00c429b3af59',
		'replacement.php' => '247f1e5750a10b748be5192f5231de35',
		'resources.php' => '451c1293de484293961f74ec3cf1ea28',
		'rssposter.php' => '641ff1a8729bea1d2cd3372e23d92a8f',
		'search.php' => '1220149d74e709ccebe5dfe74943ac25',
		'sitemap.php' => 'a3ebfe89a60de5964467db9ce108b7d1',
		'socialgroups.php' => '1ba88ebe98cb8d49e1de376c14546c4b',
		'stats.php' => '7bb3b2f5a805758fcbdb2a3e0dabe71b',
		'styleschedule.php' => 'eb91b90a843b2bcbe2430bbb9808650c',
		'stylevar.php' => 'd41665967827706c2890fc5bdb8fff75',
		'subscriptionpermission.php' => 'df8dcb1feb285a42ecb4f60ed6569e52',
		'subscriptions.php' => '1edd17acc5d056d644088575fe74e99a',
		'tag.php' => '9bed97b7e9f3e3a0fc526b7055243959',
		'template.php' => '947017c731a64586f08c73c147f410b7',
		'textarea.php' => 'b96b9347de0aab5d9aceea1de56e75a6',
		'urlaccesslist.php' => '422375125e18831a1dd8c857da7a451b',
		'user.php' => '321ab3b058ab8f7312321651203d3016',
		'usergroup.php' => 'ce2722d4c5ec5a0e03151da7585f0575',
		'usergroupsubscription.php' => 'f0a9ad6d3d6133b0a99ef3354c306e5e',
		'usertitle.php' => '921b54f474d9954ec0be33a52799031d',
		'usertools.php' => '6c7c5e3a7273bef7a01b4ddac43d4b7a',
		'verify.php' => '4f5c8f755f11ac731b4447bb11ab1848',
	),
	'/core/cache' => array(
		'.htaccess' => '56a98c3e6db19bd9a0c120919fe77b28',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/core/cache/css' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/core/cache/relatedtopics' => array(
	),
	'/core/cache/template' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/core/clientscript' => array(
		'.htaccess' => '56a98c3e6db19bd9a0c120919fe77b28',
		'index.html' => 'd41d8cd98f00b204e9800998ecf8427e',
		'jquery-ui-datepicker-1.12.1.min.js' => 'ee07b0cf94d509f62372d9e473171ee1',
		'vbulletin-core.js' => '72904042e33c1269a057e0aa91691514',
		'vbulletin_admininfraction.js' => 'ddba3bce29f45b217da4744ecc3a9289',
		'vbulletin_attachment.js' => '2e59ee537236553ae52c2ee724316df9',
		'vbulletin_channel.js' => '8457f13d53907d73a7c2969fca880686',
		'vbulletin_cms.js' => 'bc428a715dd7f8345c83b5f9404743c7',
		'vbulletin_codemirrorinit.js' => '3036afd8c717486cbaa3555b1ca413ed',
		'vbulletin_cpcolorpicker.js' => '98d89169c0fac36a9cc9a632926c5de9',
		'vbulletin_cphead.js' => '7f6b47bbede053ba04c5a68622b559e2',
		'vbulletin_cphome_scripts.js' => '08690a8ff7df08a92e45cf3b6559042f',
		'vbulletin_cplogin.js' => 'fc001878df4037f56a5d09f2bee890b0',
		'vbulletin_cpoptions_scripts.js' => 'd96b3cf3d34b25265c1f2d5edc51e14b',
		'vbulletin_date_picker.css' => '89e355b73bc36430bd4b15a7d9728f6c',
		'vbulletin_date_picker.js' => '1d8cc91d4d1cef279bc7571d537a215c',
		'vbulletin_diagnostic.js' => '1bcb89c6da2910662fe1e737f30caad8',
		'vbulletin_eventhighlight.js' => 'ce46b40743dccde6e50203693dfa0c23',
		'vbulletin_global.js' => '82cd6053b8e0c6a6d6cb34f07edf7ec0',
		'vbulletin_hv.js' => '003dccdc49f662b9b5ec264eb4a105db',
		'vbulletin_inlinemod.js' => '4a4893ab6044be937ff1e07284c4f87d',
		'vbulletin_md5.js' => 'c1d7b1ae6bc9692e37e3de3af8c3dc2a',
		'vbulletin_paginate.js' => '3f442648a2f0bacdbf4a134f42be79f8',
		'vbulletin_product.js' => '56023ea71c7f8a39f1cb0015c290d487',
		'vbulletin_replacementvars.js' => '906987dfe7d614da1b461e41b4e0e6f4',
		'vbulletin_settings_validate.js' => '67efaf8638465b365a45c13b28869576',
		'vbulletin_stylevars.js' => 'c0c62cf8069f65a8579e123bf63af2f4',
		'vbulletin_subscription.js' => 'fb200d184c61f24f8e82cf9fa8edb622',
		'vbulletin_tags.js' => '0455177d73ae48cb5eb76879d848ff05',
		'vbulletin_templatemgr.js' => '5563f943a628b1d7b4323f591440ba37',
		'vbulletin_textarea.js' => 'ac5e2355ac2a81ea58e9f7ebc105cf7f',
		'vbulletin_user.js' => '4ee22c874774b7053e3927fa6ef1000a',
		'vbulletin_usergroup.js' => '5bb4d338b0b80e539602096caefdae4a',
	),
	'/core/clientscript/codemirror' => array(
	),
	'/core/clientscript/codemirror/addon' => array(
	),
	'/core/clientscript/codemirror/addon/dialog' => array(
		'dialog.css' => '910c1893a275073be1f80f32b77cd5a4',
		'dialog.js' => '5313293614d5eb85dafa26df6b0dda0d',
	),
	'/core/clientscript/codemirror/addon/edit' => array(
		'closebrackets.js' => '1d691c75b95c6967b0a29865a302d5f9',
		'closetag.js' => '46ea535d3a17ee4aaabdfa74b741b8b7',
		'continuecomment.js' => '457d75e7fc8ee2dcfca787d739f64d50',
		'continuelist.js' => '32a633aabf220ecbd585e517891b797d',
		'matchbrackets.js' => '45c8d10daf42537b2e73a15d54d7f879',
		'matchtags.js' => '4b0b6b3278dd26ee7de91fb57a746f2f',
		'trailingspace.js' => '53775246494a906f35c176064b0e1790',
	),
	'/core/clientscript/codemirror/addon/fold' => array(
		'brace-fold.js' => '7fd555e31badb4918a7ec8b9080b600e',
		'collapserange.js' => 'eaa49c1089b21d43f5adc134cf0597cf',
		'comment-fold.js' => '67ac591c23fd52e10b21bca75a904fd7',
		'foldcode.js' => '9e2ee7846dfad540a3abaa8277005f17',
		'foldgutter.css' => '1fb5a8a2d160bdc511b30881fdbcda6f',
		'foldgutter.js' => 'f128b2e16b974ea6c10e0fcf95956e24',
		'indent-fold.js' => '4412c591f48b2d2bbe9c5139bb1d52b2',
		'markdown-fold.js' => '6c40139c3c6a06a7c7d6fedde26dafeb',
		'xml-fold.js' => 'e064e5342614b3f859d9250635a6cdc7',
	),
	'/core/clientscript/codemirror/addon/format' => array(
		'formatting.js' => '0f4883e9c20872ba554e109d39051b29',
	),
	'/core/clientscript/codemirror/addon/hint' => array(
		'anyword-hint.js' => '26c98398f27a02685ce046fa1b990bca',
		'css-hint.js' => '5d8c5d6dbddad1ccdba5188806127ab8',
		'html-hint.js' => '8e8160c22d56fd2ab5e6076c7d111567',
		'javascript-hint.js' => 'd79ae58e0f25aabc775c71bb0af99357',
		'pig-hint.js' => '8c537488a80677654ee6b63728c502dc',
		'python-hint.js' => 'ba8376020ec5868f56a94034bf396726',
		'show-hint.css' => '6909e2a9d8f4b5a51b0fbe5e6768b722',
		'show-hint.js' => '4a4b7a1b5fdd36963947af07e04ae1e4',
		'simple-hint.css' => '09865a50f334e22601e5182592fb1db4',
		'simple-hint.js' => '03021d7aafb5d419da820a160b1c647e',
		'sql-hint.js' => '4c27642784664b7e0484a11ad2850c57',
		'vbulletin-hint.js' => '405e0e0354ab9accc8315808f720cc77',
		'xml-hint.js' => 'f180bfd685b5898fde86c801194218de',
	),
	'/core/clientscript/codemirror/addon/lint' => array(
		'coffeescript-lint.js' => '5b4cdc79d41492bca3a33aa974f879af',
		'css-lint.js' => '1b9ea00b499d63f0adcd28cb5b28deba',
		'javascript-lint.js' => '5eea14cae6248e6cc4c8e776e12c4891',
		'json-lint.js' => '82769a33f1e18715fd1da3cb3c3c833e',
		'lint.css' => '5f5d243947ec3ae1b8f37d85f0fa2a2d',
		'lint.js' => '6ebc8915cbf8e7c9fd1e7fbbfecb10ce',
		'yaml-lint.js' => 'a71679086add6c29d3e09cea1b85b20f',
	),
	'/core/clientscript/codemirror/addon/mode' => array(
		'loadmode.js' => '6723cf5089729dc508502d24fa336f5f',
		'multiplex.js' => '33ad8c8d3b016bc2935afdc223dc8ccf',
		'multiplex_test.js' => '9b495b24f2c22cc50dbb554a396f733b',
		'overlay.js' => 'f3460ac1c22c7eae87b61e2e146a3637',
	),
	'/core/clientscript/codemirror/addon/runmode' => array(
		'colorize.js' => '9e9364426c3d48fd1f11f27a93fc1e69',
		'runmode-standalone.js' => 'e4b19cd3ddd08ff3068ee4693ae1f432',
		'runmode.js' => 'f4d96c34d4ebe3a641a4111394b61167',
		'runmode.node.js' => 'eeb5bf72e3fe3397bfebd68357798f7a',
	),
	'/core/clientscript/codemirror/addon/search' => array(
		'match-highlighter.js' => '9453d57dd359fd804723e49c044d943e',
		'search.js' => 'ac43e7caf6206430cfcbe6e7eebf57ab',
		'searchcursor.js' => 'e25169181322c4462986f7aacb99be52',
	),
	'/core/clientscript/codemirror/addon/selection' => array(
		'active-line.js' => '9a393ed5437f0f43e129c675084c5309',
		'mark-selection.js' => '507aa55d1fcd70b91dcb696dc3bd778e',
	),
	'/core/clientscript/codemirror/lib' => array(
		'codemirror.css' => '3859c14afe8816503469494090483e29',
		'codemirror.js' => '7aee4ce640a8ffc4b896fa6936f5582e',
	),
	'/core/clientscript/codemirror/mode' => array(
	),
	'/core/clientscript/codemirror/mode/clike' => array(
		'clike.js' => 'b943a343f18ba25143fc608785dd4eb2',
		'index.html' => '71492e4d651e38650ec7a77b572b5f99',
		'scala.html' => 'd9525d0eae7cc074d4db5c44a7b90579',
	),
	'/core/clientscript/codemirror/mode/css' => array(
		'css.js' => '376ffc8a9fe05169ca95c077f1de2e29',
		'index.html' => 'a7c62af7b2b472e23c15ad5d89ac70ff',
		'test.js' => '5f842d82d39a74ff608cddc8efceddc6',
	),
	'/core/clientscript/codemirror/mode/htmlmixed' => array(
		'htmlmixed.js' => '0c9b53ade03ec21f4d45ac1c01cfe856',
		'index.html' => '340264d421aa63006c616078beacd8a4',
	),
	'/core/clientscript/codemirror/mode/javascript' => array(
		'index.html' => 'cffb874e824469b591af277d827228c3',
		'javascript.js' => '4bc76ad2f2a29416edde73511c0c2221',
		'typescript.html' => 'd306cc8186c7610353ced61d14e33afc',
	),
	'/core/clientscript/codemirror/mode/php' => array(
		'index.html' => '688ee2076aacf1c408b156688c431ced',
		'php.js' => '89adff1481cd8a0ba484e5671ede783c',
	),
	'/core/clientscript/codemirror/mode/sql' => array(
		'index.html' => '5e0fe0a3dc9ab746c0a638f34b2ce844',
		'sql.js' => '6028e9b12cd676a4a28a59d1c81e4f10',
	),
	'/core/clientscript/codemirror/mode/vbulletin' => array(
		'vbulletin.js' => '260a556e36b7bb6d43683f57b73c36e3',
	),
	'/core/clientscript/codemirror/mode/xml' => array(
		'index.html' => 'beb453a53923e9600517def5dd8041ae',
		'xml.js' => '326e874d06181920d55dc5f2580a3552',
	),
	'/core/clientscript/sitemap' => array(
		'index.html' => 'd41d8cd98f00b204e9800998ecf8427e',
	),
	'/core/clientscript/yui' => array(
		'README' => '8b40c563412ed567af93415792390815',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/core/clientscript/yui/connection' => array(
		'connection-min.js' => 'ed935da9668b7350505daa30027a6f44',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/core/clientscript/yui/utilities' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'utilities.js' => '3c722d0dcc575f618e87f3e27489f5c3',
	),
	'/core/clientscript/yui/yahoo-dom-event' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'yahoo-dom-event.js' => 'f16dcd51fd1d51fac21a9724911184c4',
	),
	'/core/clientscript/yui/yuiloader-dom-event' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'yuiloader-dom-event.js' => '3f9f665102a17667544541d37f4017c6',
	),
	'/core/cpstyles' => array(
		'.htaccess' => '56a98c3e6db19bd9a0c120919fe77b28',
		'colorpicker.css' => 'e55e948fa0b7c0fb699df6b446c2541d',
		'global.css' => '482d3722a0d38825f6c9bbfdc64d1d77',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/core/cpstyles/vBulletin_5_Default' => array(
		'add_small.png' => '4600b476e46bab869bfd9b3763ac3e1c',
		'admincp_btn_primary.png' => '6b7417d427461515c783463d948c9686',
		'admincp_btn_secondary.png' => '5d6a131cc5358215b83e7a4d3835a3eb',
		'admincp_btn_title.png' => 'd93ee71547ff41b1216679a792440a2f',
		'admincp_hd_back.png' => '4d0fc554246f484b35541b1d332ea3b0',
		'admincp_modhd_back.png' => '8a0f773c4feea5e89cb428f48a5158f2',
		'admincp_modheader_back.png' => '8a0f773c4feea5e89cb428f48a5158f2',
		'admincp_modtitle_back.png' => 'c237aa00f9eb3092b43f0ab006e34128',
		'arrow_down.png' => '6d34335de41e0234e586975556737503',
		'arrow_up.png' => '40d81c2a3d300abe231ef2a5c449ca1c',
		'calendar_popup.png' => '6b994a59262c5474b7fd823c500a4e6e',
		'collapse_generic.gif' => 'a38ce1b9f0e0306abb07e6b8701f2c75',
		'collapse_generic_collapsed.gif' => '8524780c05f61ab079d2c7d3a7318977',
		'colorpicker_close.gif' => '1cd27e0a72e66b8ebfa890f58772cb13',
		'colorpicker_toggle.gif' => '86542a980acd908a4374e1a519cae750',
		'colorpicker_transparent.gif' => 'f736e820aff9eb006f7d9f844c62e119',
		'controlpanel.css' => '73c55c4e0219027eb00ab28ae40d811c',
		'cp_button_bg.gif' => 'dde6caaaf00ebed188242bb5b323709a',
		'cp_colheader_bg.gif' => '792347248850ace4ada6de7efe744374',
		'cp_collapse.gif' => '9b6a6efc5a46ac0cd695e3953af9811c',
		'cp_collapse.png' => 'c60f0e0522396d5930532079829caf06',
		'cp_collapse.svg' => 'ddae904fc11dd01a58ebd5853f86f2d5',
		'cp_expand_ltr.gif' => '2a10641e46c7ce224c27328bb56551ba',
		'cp_expand_ltr.png' => '56da25ae3d9eac8436c4c0f8bf37f0f1',
		'cp_expand_ltr.svg' => '9f0f1edbb076999cf936ed186a3a81be',
		'cp_expand_rtl.gif' => '0c628e79cde793c10a04e8bd1e71b3a0',
		'cp_expand_rtl.png' => 'b5feb954d71695392ed377197c7e8f97',
		'cp_expand_rtl.svg' => '9f0f1edbb076999cf936ed186a3a81be',
		'cp_help.gif' => 'd7e6bf4df74bbd8ea0e6412c5cc61d9e',
		'cp_help.png' => '13177b5d71f80557f75f459aa2953e62',
		'cp_help.svg' => 'ea8c29fa714004f27c691765ef5a95b0',
		'cp_logo.gif' => '1ae9d813b66a43e05d8dd4fa8e0381f0',
		'cp_logo.png' => 'ff81907f4d3a6e8e49d1af8951c6ed99',
		'cp_logo.svg' => '7972c5ef09007dd566b281ea165cdfe9',
		'cp_navbody_bg.gif' => 'e4ebffcdf847119ea37ebe40d52e093c',
		'cp_tblhead_bg.gif' => '9f07132b207f8b707423d23cae42d782',
		'cp_tick_no.gif' => '53e65d928745b56c0f783aba43c3bfd6',
		'cp_tick_yes.gif' => 'b0eb20556099fd53eada64378dad4934',
		'delete_small.png' => '742d4984d815c3c77d6bbd2d5436c194',
		'edit_small.png' => '4175fe4c7645722b0b48460bd630c4db',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'lightbox_progress.gif' => '76cdb2ec75cec78b406817827f0d0263',
		'merge_conflict_bg.png' => '2c44068b7fce6909ba073285ba873b2d',
		'move_down.gif' => '8c82b781a5f6915de321bc66e26c1939',
		'move_up.gif' => '9b6a6efc5a46ac0cd695e3953af9811c',
		'option_name_bg.gif' => 'ed888dc2f53e6b4fd4f3b71e27942bdc',
		'permission-not-set_small.png' => '47c7727c7315058ab92990e93f3c6d26',
		'permission-set_small.png' => 'cc234f0e86907f4f92558df5c3ea600f',
		'progress.gif' => '17b57c3fb42e3452f78d291e21bc0627',
		'sprites_ltr.svg' => '92c5ffd94bd1711984809787626ef818',
		'sprites_rtl.svg' => '793e7a92b591d67bbae3343275be40a5',
		'subscribed.png' => '63727b928aac49d9b10cb30e99701df3',
	),
	'/core/images' => array(
		'.htaccess' => '56a98c3e6db19bd9a0c120919fe77b28',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/core/images/default' => array(
		'default_avatar_large.png' => 'fc273bb8d69945def3155d55fa333a4f',
		'default_avatar_medium.png' => 'a3e45a91848e8c4429691550fd8a23a3',
		'default_avatar_thumb.png' => '177b1cbfd8934a6e29a121bab3d75fa6',
		'default_blog_icon.png' => 'cd92ac9732e233390e1bdb24397c0c34',
		'default_blog_large.png' => '682166140813633c911db83a3002f703',
		'default_sg_icon.png' => '9e4da3c3edb65d69c40a117fba954938',
		'default_sg_large.png' => 'a5517e2a6d33e62c97d8c9a1d96137af',
	),
	'/core/images/default/google-material' => array(
		'content_copy.svg' => '4e3de66e949199d7fd638e93f2d6d7a1',
		'image_placeholder.svg' => 'b784aad92e2711858e9d65bcead32ad8',
	),
	'/core/images/icons' => array(
		'icon1.png' => 'ddbc31b1b9d96928ed0aa68ce4b9ede4',
		'icon10.png' => '4a1cbb521b86936f9d23e1b8220e8167',
		'icon11.png' => '5b8ba0349d8dd3f49a0c4b408b036663',
		'icon12.png' => 'efc17c030995785c29e72614748df6fc',
		'icon13.png' => '9242b5974296de79ff6084a7df39fc87',
		'icon14.png' => '77980676f864d17e2f9ba7922fa551ea',
		'icon2.png' => 'da493d4f23e3afd6dc986cea8f4b3aa3',
		'icon3.png' => '11c1bf212041a5e9cc6c4a87eab82107',
		'icon4.png' => 'ee1c51ec8f03fac155f0d4ec5bced225',
		'icon5.png' => 'df97d6d8859f4410fc909c7383ad5a9e',
		'icon6.png' => '2c05ee6f4dedcfb749897a883dc9251a',
		'icon7.png' => '82ea626f3ad052c5b37f7f96afa19347',
		'icon8.png' => 'e391b017c24b8604f83dfd91dc0e2daf',
		'icon9.png' => '5db1b276bedd700312b20ef51c94056c',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'trashcan_small.png' => '7751e5a489d81d711e2b4a3918980299',
	),
	'/core/images/ranks' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/core/images/regimage' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/core/images/regimage/backgrounds' => array(
		'background1.jpg' => '11513c2082f25097f3212b57aa3583d5',
		'background10.jpg' => '9e6bba33e783c5140df6ad3379054876',
		'background2.jpg' => '19d01a63c4e1f7c1f4f1aa76a38abfe3',
		'background3.jpg' => 'f1e27449351eb04d32456c2bdcaea38e',
		'background4.jpg' => 'f8aa000a73f1d5b2b4880a02475bd215',
		'background5.jpg' => 'c1a402561c79a908dddc643ac8dfb664',
		'background6.jpg' => 'c02d5ca8418506dc041f7000a932a9e2',
		'background7.jpg' => '0c966be4768c98d26fa9231c4ab98213',
		'background8.jpg' => '25b03e2c9892f3275d166a5c04176ab9',
		'background9.jpg' => 'afedccb59b1aaf6ca995681397246d47',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/core/images/regimage/fonts' => array(
		'EFFLB___.TTF' => 'b475aa1a0c2b7c966d0604870b5cf5e8',
		'HECK.TTF' => '407f2b596b32a378a8dd10dd7d3a92ea',
		'MINYN___.ttf' => '50538fd3544d57839c0ed75d12fec963',
		'SPONGY.ttf' => 'b590de92a775bf33138a34c727a7a138',
		'WetPet.ttf' => '9dd32d92eed4a5255eb75c8f563cf321',
		'edmunds.ttf' => '2e4df236378ee4e138a4c4c0c9eedc4f',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'read_me.html' => '2cf8b9020343162ee4b466176c72e171',
	),
	'/core/images/regimage/misc' => array(
		'sample.pdf' => '03c4808eeb7f3c92bf567369f38a88df',
		'vb_logo_darkblue.png' => '0bf7a99ae78525d68f8918ddf3196e5f',
	),
	'/core/images/smilies' => array(
		'biggrin.png' => 'aaabf341165fc64cc86c33aa791fc030',
		'confused.png' => '6a892dc0ccc349c4653a26dcf0f2956b',
		'cool.png' => 'fbfc75e899a2f973db9ec22c02090f39',
		'eek.png' => '0fcb5fd47fb0c8d33dc34fb4d96f5ff6',
		'frown.png' => 'ade3c5116480bd6c8f53bb7bb7acfa4e',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'mad.png' => '395f02aa18e8003b672e3d896b9a7d9a',
		'redface.png' => '1404b771355ed12a0b58a3e7e9b13017',
		'rolleyes.png' => '8a7fbb11f2b0b6b0cc45d6edea5150ab',
		'smile.png' => '34fc6dc3ee0c950fd5aafc2cb4e9b695',
		'tongue.png' => '28e5a34cba8989f2c726d6cee85166a5',
		'wink.png' => '5a96cbfc622b34f77f6b5257dd9d300f',
	),
	'/core/includes' => array(
		'adminfunctions.php' => '89e1e6b2276fbcbe03ade28b4a99808a',
		'adminfunctions_help.php' => 'c1094e89776951ab3de9dfad55262986',
		'adminfunctions_language.php' => 'd03d22f6a0eaf3c64a279d11fec7b5c9',
		'adminfunctions_navpanel.php' => '459db21927f789397e2b91066acb3179',
		'adminfunctions_options.php' => '0fbeaae25e8cf830733969952d9fcbfd',
		'adminfunctions_prefix.php' => 'a7b1fdbdc44451543d4e5487058cf6d6',
		'adminfunctions_product.php' => '9e31a8473206bfc6ef025ac7142ebee8',
		'adminfunctions_profilefield.php' => '2a03e99a1735c05948d16e2b0ff00be5',
		'adminfunctions_template.php' => 'c93a284509fd8aed4500a85f73272c5b',
		'adminfunctions_user.php' => 'eef419404bbeea782edb22b4e7dea8f3',
		'class_bbcode.php' => '7be2d93169e4894b738b45172afbffd2',
		'class_bbcode_alt.php' => '652106386aea5f3d3cc91f15bbf0dc9a',
		'class_bitfield_builder.php' => 'b13027d2e88e8de484d68ee8de209e39',
		'class_core.php' => 'cd41f9685a2ffc47bf55542b546d921e',
		'class_dbalter.php' => '10ba3634e439b2da9b63417e7ee38c17',
		'class_diff.php' => '5d3794c81268347471e03452e58d7541',
		'class_filesystemxml_replace.php' => '0ba2c4694a47f4966f9ae2db5c8cd646',
		'class_filesystemxml_template.php' => '13c7ad09abc47bd446a2c868653664da',
		'class_merge.php' => 'a5e322bf701fbf82b905f8e0681752ae',
		'class_paid_subscription.php' => '91c56b0f9f0f2763a1e8957ac356abba',
		'class_rss_poster.php' => '0f312f65c1b2c6108faac8b8642114e4',
		'class_sigparser.php' => '4a0f11622be284aa030a8595a7af69fa',
		'class_sigparser_char.php' => '327770e2508da946755e36a8896da658',
		'class_sitemap.php' => '0ba4ee43252ef2b60327e01b6c99b8ba',
		'class_stylevar.php' => '86abc1b418826afb308b69766ceb1db0',
		'class_template_merge.php' => '71b66d806ce5b6c6fa1e110d14bc3df6',
		'class_upload.php' => 'e756b86ee4e4b7716a72c1388e5ded47',
		'class_userchangelog.php' => 'd972e3fd8144bf1097acb31a327bd69a',
		'config_cli.php.new' => '97a6b01433e0ed98c33073cb82227177',
		'functions.php' => '3fac54910dff031da842857dd5582f65',
		'functions_banning.php' => 'd60be9d470299c6829aa8c96e61d4ac9',
		'functions_cron.php' => '523d7d201156c40e3e6be5a0a9acb85e',
		'functions_faq.php' => 'aab35a9411fe3d561a3f828247135ca3',
		'functions_file.php' => '43e240a4b378fd9c665d8bc0044c9d2d',
		'functions_filesystemxml.php' => 'f811cbce616d13e13c4f18818939e274',
		'functions_log_error.php' => '63de2f1080c389651e03ef664edb0f4f',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'init.php' => 'b88e9bc5147d5f3f39603a1d0e2d84c9',
		'vbulletin_credits.php' => '0a5897b66585eeba204979c96caa78aa',
		'version_base_vbulletin.php' => '4774dc56f4e9c19777b19ac9a25d7e90',
	),
	'/core/includes/cron' => array(
		'activate.php' => '2086594bd79393c9b5eae85ef853f8a2',
		'birthday.php' => 'c5aacf2a0978473c17cfcbe476aefab8',
		'calendar_cleanup.php' => '9369dda4bbec64f6782edf8bf926ff33',
		'ccbill.php' => 'dfa8ef0ff564c1e4a90b4c94fe41cd81',
		'cleanup.php' => 'b2186804e5ab9a6899250fa0f2a1c136',
		'cleanup2.php' => '0e0b611b650b929bda8664be81c2ed9c',
		'dailycleanup.php' => 'e37cdd6441bcd2ae8be5320f13ed10f7',
		'digestdaily.php' => '48bb6317c0eb0aad2a9add6a0601a2f6',
		'digestweekly.php' => '89abeea2059e2412291cabdab9d87104',
		'fcmqueue.php' => '30d8cccb8c2e4c50b4664abd9f43c398',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'infractions.php' => 'cf8214e64f2649c6e7c1654e65c942eb',
		'mailqueue.php' => '72424016220063c4eb2fc0ff54e17364',
		'notification_cleanup.php' => '29a3f4988ba1ee3f9463ac8136f6411b',
		'privacyconsentremoveuser.php' => '593d016665c96aa1f45d2ddde4620b00',
		'privatemessage_cleanup.php' => 'aedc6443274957015defb3f137385b2e',
		'promotion.php' => 'd78ab6aca454c9eb36addb1198fc0d96',
		'relatedtopicsfull.php' => 'c28ee88975d18a769c49c26d38f42d11',
		'relatedtopicsinc.php' => '4496fc29a2a1ded101fb93d27d34b9e3',
		'removebans.php' => '14deaec3df1c4c752d224847394a775f',
		'rssposter.php' => '31dbc3f507fa613dace0b785166cc5f6',
		'sitemap.php' => '42817869873945c0edbdaea2e406a4be',
		'stats.php' => '3a381d37533c2d88d33a3f04ae9d5032',
		'subscriptions.php' => '8f225e17e77fe6cd20b570384251f5dc',
		'trending.php' => '51dc9163ef8445c7177a7b6f931e4bcb',
		'unpublished.php' => 'ef66125652dc35bed1dd6b33b6b59c6e',
	),
	'/core/includes/datastore' => array(
		'datastore_cache.php' => 'e09dd92d472dd569eee1eb3b9fae56bb',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/core/includes/paymentapi' => array(
		'class_2checkout.php' => 'fc48f3274d4490139804bc8cee48093e',
		'class_authorizenet.php' => '95cdb4686fb81f879866c4d0ceafc6f4',
		'class_ccbill.php' => '1f5d92f4dd6544984d244c758047497b',
		'class_moneybookers.php' => '0b61bb12b62cd82ababa3ac776707632',
		'class_nochex.php' => 'b5bff9b836980d2b83289123d564c5ae',
		'class_paypal.php' => '0832a6bc1a7c847c0c67ccdf6d302fc3',
		'class_paypal2.php' => '2d18a0fead06cb9b27a2475e40c9974f',
		'class_square.php' => '26856a088c14ac585c91ebf30f16485d',
		'class_stripe.php' => '78f87b034ce2d0d68b8e5219526bb063',
		'class_worldpay.php' => '1016927d5123cd2b9affaf588338cedc',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/core/includes/xml' => array(
		'bbcode_video_vbulletin.xml' => '9268574c0b2ce46a30e2ecef5fdce0f9',
		'bitfield_vbulletin.xml' => '047946e6cf6b1cb5af474c8d137a2694',
		'cpnav_vbulletin.xml' => '96331eae0ebc0493cdd28e0fcdd75040',
		'cssrollup_vbulletin.xml' => 'dc58c3ce9580a1cd775de9ddef2a8005',
		'hooks_vbulletin.xml' => 'a1f32c7301e53388d3ea3a6e1e553566',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'js_safe_phrases.xml' => '403bd6ba694fa09da16a3efccba4c61d',
		'jsrollup_vbulletin.xml' => '50fbf2f99639f2f6ab1071a4e4b84e61',
		'pwschemes_vbulletin.xml' => '671dff66b467bd626b40484a754e7b9b',
		'spiders_vbulletin.xml' => '209a7ac07bb923852c6fb7235b7b87bc',
		'vbulletin-pages.xml' => '891ea2288997b74a53fb8e60884f3f0b',
		'vbulletin-pagetemplates.xml' => '376738c1bdc3781eb0d3f818e93e1099',
		'vbulletin-routes.xml' => 'ff6dc56bd1d2920c57c8eecbab811a14',
	),
	'/core/install' => array(
		'functions_installupgrade.php' => 'd0b8ace29dfdec637f862ea2c273876a',
		'index.php' => '812ffdaedb152d33d2f8a9deabfdfaab',
		'init.php' => 'beabcca95f42e8944cd62a3cad4a1574',
		'install_versions.php' => 'ffd595c40ee71da0ffa8ba8766fcebcf',
		'mysql-data.php' => 'eed2a89d044cbcc7baf851f7655c0d7f',
		'mysql-schema.php' => '428efc96dbcf939aded3d0de9f791dc3',
		'tableprefix.php' => '2f1b26a3ae0d60ef93d30dc3d467d1bf',
		'unserializefix.php' => '7cb50ae6102a1529c5c81395973f125f',
		'upgrade.php' => '21e066f9df5e098975774d1b8411700d',
		'upgrade_language_en.xml' => 'b789242f7f3af2824e07b475d8bdb495',
		'upgrade_options.php' => '05cf95d6828302d117537658602ff379',
		'vbulletin-adminhelp.xml' => '965b05904995f53632c992418819ddc5',
		'vbulletin-channels.xml' => 'b84ad709fa12f61512e75a81959c6765',
		'vbulletin-grid.xml' => '7543d3efa4773fd6619d18f0dbbd58f4',
		'vbulletin-language.xml' => 'ac792504ab55929ce266b04f093f45b5',
		'vbulletin-pages.xml' => '891ea2288997b74a53fb8e60884f3f0b',
		'vbulletin-pagetemplates.xml' => '376738c1bdc3781eb0d3f818e93e1099',
		'vbulletin-routes.xml' => 'ff6dc56bd1d2920c57c8eecbab811a14',
		'vbulletin-screenlayouts.xml' => '7d84ac8003a1910f8538d099335c1090',
		'vbulletin-settings.xml' => '86e4195ad1cba7f4ef2c91049efb20ea',
		'vbulletin-style-five.xml' => 'f7267f49813214525dd4ff09ab09fd21',
		'vbulletin-style.xml' => '060e4874c4c4ff36a80f761b3d3bce43',
		'vbulletin-upgrade.css' => '0da6bdc591ee1eb9f68efcc481daf69f',
		'vbulletin-upgrade.js' => '404e9e186189431184595a1fadc21073',
		'vbulletin-widgets.xml' => '65ce8364a5817f966a52d98d2256ccef',
	),
	'/core/install/customlanguages' => array(
		'readme.txt' => '2d66487f71a569abc2b1dd6d938ea885',
	),
	'/core/install/includes' => array(
		'bulkimporter.php' => '480afa83b968e214423fe35d7f92bd1f',
		'class_servertest.php' => '1d88bbcaf7c7310b564a8a555aad4264',
		'class_sigpic.php' => 'c9acf33cb0eea57c926247dec0aec40e',
		'class_upgrade.php' => 'ee257114c409e35f0cf20ba37fe05ab2',
		'class_upgrade_3xx.php' => 'a89c5530f9c2b0bcd10ccd16178b4d33',
		'class_upgrade_4xx.php' => '0da5e3f8a168a4e0438a01fed3344a7b',
		'class_upgrade_50x.php' => '146751cf5c42a38eac3e136290c1820c',
		'class_upgrade_51x.php' => 'abcc08f164bba10515b1ed896ee01ba7',
		'class_upgrade_52x.php' => '691486b7f39bbdd60113ef698ae21869',
		'class_upgrade_53x.php' => 'fc80e5af6109da7c06200c824e3af280',
		'class_upgrade_54x.php' => 'a852e7dbb8c6f5d2e1378fe8d5bba099',
		'class_upgrade_55x.php' => '411a5e0404abb33c686d0aab6da39ef8',
		'class_upgrade_56x.php' => 'bc334ccdb88c24b3f3afa58aea3896e4',
		'class_upgrade_57x.php' => '0fd36ef301a8016040c60e708d9c2e0a',
		'class_upgrade_60x.php' => '7eec5f27228463b8b2dc1c51d786c95b',
		'class_upgrade_61x.php' => '36aad18d48381f145fe50b7561c9775c',
		'class_upgrade_62x.php' => '4caccd9f2a73b9b122fd2f1ea3cd4818',
		'class_upgrade_ajax.php' => 'f8fb281b3305c7968e41ffac8f8ca9b5',
		'class_upgrade_cli.php' => '96f2f31728e14766702b0d27b6dd893d',
		'class_upgrade_final.php' => 'ea32a231af5d4581b914e36af8926e8c',
		'class_upgrade_install.php' => 'e358bb6574986d8355630b57ccf87037',
		'class_upgrade_product.php' => 'abe1cc04e162592325a457d31b5a4ab0',
		'class_versionmap.php' => 'b76deff7fa48ffa30497d6e7e20311d3',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'language.php' => '4e64caafacbcdc800c2c3868dedebf0a',
	),
	'/core/install/legacy' => array(
	),
	'/core/install/legacy/380a2' => array(
		'functions.php' => '6bb4217a6f51ad55746e79bfd0bb9e1d',
		'includes.php' => '5cca93a49764051b761de00d9ae2563c',
	),
	'/core/install/legacy/400a1' => array(
		'functions.php' => 'a4b297fb17ce4543a7799f3212a5ac45',
		'includes.php' => '53b8b9737d2ac728670810273a66a7a0',
	),
	'/core/install/legacy/400a1/packages' => array(
	),
	'/core/install/legacy/400a1/packages/vbattach' => array(
		'attach.php' => '50b553e4698926c48b5f857277d2b872',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/core/install/legacy/400a1/vb' => array(
	),
	'/core/install/legacy/400a1/vb/datamanager' => array(
		'attachdata.php' => '5ce8ba3023e27fa173ff98fdbdcd3e52',
		'attachment.php' => 'ea468b5a2ac6c629be28391b0f3dbf59',
		'attachmentfiledata.php' => '64924543893ff453cdf3da16cb726e52',
	),
	'/core/install/themes' => array(
		'vbulletin-theme-blackred.xml' => '9677e7b40fc740c253dda3af3f2283b6',
		'vbulletin-theme-blue-green.xml' => 'a9266e20755225e048cdd3f25d8b072f',
		'vbulletin-theme-blueyellow.xml' => '678f6cb921dea2cc07f810e74bc4168c',
		'vbulletin-theme-cool-blue.xml' => 'bfe1b093dae451b1a6685f466213f162',
		'vbulletin-theme-dark.xml' => 'a56ae04d2f1f8f11b798ae1f7206ac73',
		'vbulletin-theme-denim.xml' => 'c9741ccf50f8058b0d4b459cb8d2fc94',
		'vbulletin-theme-gradient.xml' => '6f1ae33bcf2af25de157250fe16e3b2d',
		'vbulletin-theme-greystripes.xml' => '195f39ee9a12e36a7a10f2ce9175239f',
		'vbulletin-theme-grunge.xml' => 'b8ef7e94f8e063789f51bad2b0b25e35',
		'vbulletin-theme-halloween.xml' => '27841cfb86b1d5eb96dfdd837f42949c',
		'vbulletin-theme-lightblue.xml' => '1b1cf9e9828d2cc1dd14a14ea30a2a01',
		'vbulletin-theme-oldschool.xml' => 'ea0a20cc4bf358529741e32a1906af02',
		'vbulletin-theme-orange-purple.xml' => '81b1eb18a9d66598c7e8f3b063785931',
		'vbulletin-theme-pink.xml' => '4f171034f16df0120fa31923f8946927',
		'vbulletin-theme-red.xml' => '3e99ebea2a5affd068728cd1bdb9f9f6',
		'vbulletin-theme-stripes.xml' => 'ad1b7197bfffcd7607f51edff12e44fd',
		'vbulletin-theme-winter.xml' => '5ac514ba41a655f30ac707e71a84db78',
		'vbulletin-theme-wood.xml' => '75c043fcd1f3c4e994609521c1692307',
	),
	'/core/libraries' => array(
		'libraries.phar' => 'f527e00ca25a73b73c67dbc1af3e58d9',
	),
	'/core/libraries/data' => array(
	),
	'/core/libraries/license' => array(
		'composer_brick_math_LICENSE' => '755aadbc69e2680a428fe25bf567a858',
		'composer_composer_LICENSE' => '955d5fe58c231244f6b49000f383b5e2',
		'composer_doctrine_inflector_LICENSE' => '6eb5e32a565f247832c2a00cf90ded7c',
		'composer_eluceo_ical_LICENSE' => '1baaed1897c541bafb6ce66088ad8eca',
		'composer_firebase_php-jwt_LICENSE' => '896dee34dec9cdafcd250791d03131f4',
		'composer_greew_oauth2-azure-provider_LICENSE' => '1fc7b973220111bb5c3290257803006a',
		'composer_guzzlehttp_guzzle_LICENSE' => '9a8eefeec4fee45cb835a0f7054073fe',
		'composer_guzzlehttp_promises_LICENSE' => '8035eaaec6b3b562c1aed15adc8b908a',
		'composer_guzzlehttp_psr7_LICENSE' => 'db7096d1ec87ffcdc25c249bcf336120',
		'composer_krombox_oauth2-wordpress_LICENSE' => '2f248225b42e7fec760454128c43ac8c',
		'composer_league_oauth2-client_LICENSE' => 'a4f0837c9d93294a47ff451e6ae38717',
		'composer_league_oauth2-google_LICENSE' => 'b8748fa91e61d429304a3e58c02884c6',
		'composer_minishlink_web-push_LICENSE' => 'df312c56c29fefcbfaa0f6f3bc4c87b8',
		'composer_phpmailer_phpmailer_COMMITMENT' => '7ad922bcc16462a101862b1b0b15182f',
		'composer_phpmailer_phpmailer_LICENSE' => '23c2a5e0106b99d75238986559bb5fc6',
		'composer_phpmailer_phpmailer_VBULLETIN' => '345e515523a5d17e9b104b69c763df1c',
		'composer_psr_clock_LICENSE' => '3158bb09d112563c27a1e90264088c16',
		'composer_psr_http-client_LICENSE' => '70cd1d4d5bb26324a567dd5c3c412cca',
		'composer_psr_http-factory_LICENSE' => '881e228f5e6e60e07b9475850cdc2884',
		'composer_psr_http-message_LICENSE' => '1b0b156bcf7972a5f131e1e461e84b30',
		'composer_psr_log_LICENSE' => '1a74629072fd794937be394ab689327e',
		'composer_ralouphie_getallheaders_LICENSE' => 'f7786f46efa7706a39adcd5b5e1ec2c3',
		'composer_ramsey_collection_LICENSE' => 'd8624ad739f59d4e8ae6723847007147',
		'composer_ramsey_uuid_LICENSE' => 'ddbf44d0e12668ad8cd392e3c1cbbc37',
		'composer_shopify_shopify-api_LICENSE' => 'b57afdc3804fd2f6d4f4daf889421b90',
		'composer_spomky-labs_base64url_LICENSE' => '35aeec8c12aabce3d0d1740438aa885b',
		'composer_spomky-labs_pki-framework_LICENSE' => 'ca4d2e84d098a5f871984c6ca9a6face',
		'composer_symfony_deprecation-contracts_LICENSE' => 'f288a4ab278f67080fb70a531307837a',
		'composer_voku_portable-ascii_LICENSE.txt' => '5b18f4441388fecd6c3162aaddda861f',
		'composer_web-token_jwt-library_LICENSE' => '27038a84ac6a315f3f674a60f3d54972',
		'facebook_LICENSE' => '99b14c7884c884d12da3d43981df797d',
		'misc_emoji_license.txt' => '4b11b5cbb0a24df9f4e7db63db98f22f',
		'square_square-php-sdk_LICENSE' => 'cf90287c055749e5b238347ed4285bc7',
		'square_unirest-php_LICENSE' => '7a83288907b21923ef412c640c385858',
		'stripe_LICENSE' => '7d3ba0ac2a57368a17ff05cd5dc09a4d',
	),
	'/core/libraries_phartemp' => array(
	),
	'/core/libraries_phartemp/base32' => array(
		'base32.php' => '06016440d79ca2728fb228bf7795f693',
	),
	'/core/libraries_phartemp/facebook' => array(
		'LICENSE' => '99b14c7884c884d12da3d43981df797d',
		'README.md' => '65baf7efacafb30b7de75b5dbaaf72db',
		'autoload.php' => '00a5a8b0e02e898aeb88cca6422213a6',
	),
	'/core/libraries_phartemp/facebook/src' => array(
	),
	'/core/libraries_phartemp/facebook/src/Facebook' => array(
		'FacebookAuthorizationException.php' => 'e1404afb92267a3d1119e664a5cfda2c',
		'FacebookCanvasLoginHelper.php' => 'b2d83cffc2f7cf03ddfc64b80dcda278',
		'FacebookClientException.php' => '8856e7f508704fb2c994d521c6688b3e',
		'FacebookJavaScriptLoginHelper.php' => '6a0bef2dd723700ccf9153faf2c31145',
		'FacebookOtherException.php' => 'a4e01cb88792679fb0f5b8d8640e1226',
		'FacebookPageTabHelper.php' => '43054ab764d717a70f789d9fa2c540ad',
		'FacebookPermissionException.php' => '81d40d5f7746e484e3f634f29f14f794',
		'FacebookRedirectLoginHelper.php' => 'f114b84e24728ba3cef89c8963e423be',
		'FacebookRequest.php' => '5cf3724a127921f912ee0b3794e16c12',
		'FacebookRequestException.php' => '5441dc4b608b96cd74c1247c81890ec2',
		'FacebookResponse.php' => '359391495feddebfefd3a63e527cb7fa',
		'FacebookSDKException.php' => '43e60e719eb4775b562aacb1227db162',
		'FacebookServerException.php' => '07b78ab2c7ff983eb6aea034cfff6e91',
		'FacebookSession.php' => '2b8ae2cdbfa197b0e25897e7001673eb',
		'FacebookSignedRequestFromInputHelper.php' => 'dc014b97ea0d15f9220dc047c3c6b979',
		'FacebookThrottleException.php' => '119313ec034c3203a9571a333eb253ef',
		'GraphAlbum.php' => '5c1aebc1eb16a283dd1fc893626cd6ba',
		'GraphLocation.php' => 'ceb951d37b04961543ea04cc3e722539',
		'GraphObject.php' => '3aad7b7b866e23649ce8217a2589b9fc',
		'GraphPage.php' => '11f9476d899e63909e9bef50f27cf155',
		'GraphSessionInfo.php' => '8ecbf87fec3dcca6ae0e83609781c681',
		'GraphUser.php' => '86d30e6d9ee032e71fa7b73c643d0833',
		'GraphUserPage.php' => '2e3a3bf904dae7fef3c7bc66c05402a7',
	),
	'/core/libraries_phartemp/facebook/src/Facebook/Entities' => array(
		'AccessToken.php' => 'f8a61f5cdd02e141171494089942bffb',
		'SignedRequest.php' => '4f574730f940eb29f3ba483e28c5289e',
	),
	'/core/libraries_phartemp/facebook/src/Facebook/HttpClients' => array(
		'FacebookCurl.php' => 'd7dca80dda727a7cb2f674c4b0c8fae7',
		'FacebookCurlHttpClient.php' => '485750cdb4a4240f3493661a2fa5f182',
		'FacebookGuzzleHttpClient.php' => '84d19b9655363e71e8acdbe07ac9a423',
		'FacebookHttpable.php' => 'd75d64da97d88f48101b8acee7f75477',
		'FacebookStream.php' => 'dbe9e100b80f14ef390488a9641a34f4',
		'FacebookStreamHttpClient.php' => '95978ceb94536ab2c4b019efd8b967d1',
		'fb_ca_chain_bundle.crt' => 'c4290b9deb70d0bef2f88b67fc68c8ec',
	),
	'/core/libraries_phartemp/license' => array(
		'composer_brick_math_LICENSE' => '755aadbc69e2680a428fe25bf567a858',
		'composer_composer_LICENSE' => '955d5fe58c231244f6b49000f383b5e2',
		'composer_doctrine_inflector_LICENSE' => '6eb5e32a565f247832c2a00cf90ded7c',
		'composer_eluceo_ical_LICENSE' => '1baaed1897c541bafb6ce66088ad8eca',
		'composer_firebase_php-jwt_LICENSE' => '896dee34dec9cdafcd250791d03131f4',
		'composer_greew_oauth2-azure-provider_LICENSE' => '1fc7b973220111bb5c3290257803006a',
		'composer_guzzlehttp_guzzle_LICENSE' => '9a8eefeec4fee45cb835a0f7054073fe',
		'composer_guzzlehttp_promises_LICENSE' => '8035eaaec6b3b562c1aed15adc8b908a',
		'composer_guzzlehttp_psr7_LICENSE' => 'db7096d1ec87ffcdc25c249bcf336120',
		'composer_krombox_oauth2-wordpress_LICENSE' => '2f248225b42e7fec760454128c43ac8c',
		'composer_league_oauth2-client_LICENSE' => 'a4f0837c9d93294a47ff451e6ae38717',
		'composer_league_oauth2-google_LICENSE' => 'b8748fa91e61d429304a3e58c02884c6',
		'composer_minishlink_web-push_LICENSE' => 'df312c56c29fefcbfaa0f6f3bc4c87b8',
		'composer_phpmailer_phpmailer_COMMITMENT' => '7ad922bcc16462a101862b1b0b15182f',
		'composer_phpmailer_phpmailer_LICENSE' => '23c2a5e0106b99d75238986559bb5fc6',
		'composer_phpmailer_phpmailer_VBULLETIN' => '345e515523a5d17e9b104b69c763df1c',
		'composer_psr_clock_LICENSE' => '3158bb09d112563c27a1e90264088c16',
		'composer_psr_http-client_LICENSE' => '70cd1d4d5bb26324a567dd5c3c412cca',
		'composer_psr_http-factory_LICENSE' => '881e228f5e6e60e07b9475850cdc2884',
		'composer_psr_http-message_LICENSE' => '1b0b156bcf7972a5f131e1e461e84b30',
		'composer_psr_log_LICENSE' => '1a74629072fd794937be394ab689327e',
		'composer_ralouphie_getallheaders_LICENSE' => 'f7786f46efa7706a39adcd5b5e1ec2c3',
		'composer_ramsey_collection_LICENSE' => 'd8624ad739f59d4e8ae6723847007147',
		'composer_ramsey_uuid_LICENSE' => 'ddbf44d0e12668ad8cd392e3c1cbbc37',
		'composer_shopify_shopify-api_LICENSE' => 'b57afdc3804fd2f6d4f4daf889421b90',
		'composer_spomky-labs_base64url_LICENSE' => '35aeec8c12aabce3d0d1740438aa885b',
		'composer_spomky-labs_pki-framework_LICENSE' => 'ca4d2e84d098a5f871984c6ca9a6face',
		'composer_symfony_deprecation-contracts_LICENSE' => 'f288a4ab278f67080fb70a531307837a',
		'composer_voku_portable-ascii_LICENSE.txt' => '5b18f4441388fecd6c3162aaddda861f',
		'composer_web-token_jwt-library_LICENSE' => '27038a84ac6a315f3f674a60f3d54972',
		'facebook_LICENSE' => '99b14c7884c884d12da3d43981df797d',
		'misc_emoji_license.txt' => '4b11b5cbb0a24df9f4e7db63db98f22f',
		'square_square-php-sdk_LICENSE' => 'cf90287c055749e5b238347ed4285bc7',
		'square_unirest-php_LICENSE' => '7a83288907b21923ef412c640c385858',
		'stripe_LICENSE' => '7d3ba0ac2a57368a17ff05cd5dc09a4d',
	),
	'/core/libraries_phartemp/misc' => array(
	),
	'/core/libraries_phartemp/misc/emoji' => array(
		'emoji-ordering.txt' => 'ad6e89f187f20732cfb62d01f9ad01a6',
		'license.txt' => '4b11b5cbb0a24df9f4e7db63db98f22f',
		'readme.txt' => 'e568e5e7a79524b2bc56457cd4c79bfd',
	),
	'/core/libraries_phartemp/square' => array(
		'autoload.php' => 'f856bb08db15c1c7f87078a3a3e00361',
	),
	'/core/libraries_phartemp/square/jsonmapper' => array(
	),
	'/core/libraries_phartemp/square/jsonmapper/src' => array(
		'JsonMapper.php' => '5e5ccef2fb6e4d0e145bf0541358b316',
		'JsonMapperException.php' => '05fce4d36e6e86602e65e1dae7e0ecd6',
		'TypeCombination.php' => '72a80da8731d042d29e04eb2a04c92ba',
	),
	'/core/libraries_phartemp/square/square-php-sdk' => array(
		'LICENSE' => 'cf90287c055749e5b238347ed4285bc7',
		'README.md' => 'bc207373adf362e07b03663ecd67d209',
	),
	'/core/libraries_phartemp/square/square-php-sdk/src' => array(
		'ApiHelper.php' => '85daa5dfe41e38b2c1ec4d285d981912',
		'AuthManagerInterface.php' => '87c16695c13c6883921f2b2bfabae9ad',
		'BearerAuthCredentials.php' => '75904eb8467a8c4afce18cc9e85dcbb8',
		'BearerAuthManager.php' => 'db47588273cbd14ca54c338c0b8c77f7',
		'ConfigurationDefaults.php' => '59676b1b5c62738d66bd84e05d8835ed',
		'ConfigurationInterface.php' => '542bbabf412a64497d288cb47420f66d',
		'Environment.php' => '1841d6d7a691591f1fd715f0f7e4d103',
		'Server.php' => '3ae083a65ff9817a9df86a84316d7bde',
		'SquareClient.php' => '6ec25414397a39b43d2035853c78c605',
	),
	'/core/libraries_phartemp/square/square-php-sdk/src/Apis' => array(
		'ApplePayApi.php' => '4a2b74cfd7828e09d9aaff2513129bff',
		'BankAccountsApi.php' => '25e2a76516891fe2bc0eeb8bc90d7e38',
		'BaseApi.php' => '0b83fafe95604487b5cb3c1b33d78119',
		'BookingsApi.php' => '22b741fe9fdf34192c18603908e9602e',
		'CardsApi.php' => '7914d327e5c8918061b0e66347305bb9',
		'CashDrawersApi.php' => 'aa227a87b5bc6a5d56230bb3d4af8566',
		'CatalogApi.php' => 'be223da839571b8f349db5ddd9995a46',
		'CheckoutApi.php' => 'b636448b2d38221b6ecc81a9b03ae4b6',
		'CustomerCustomAttributesApi.php' => '45ae5e984451db9a12f656602b1a0bba',
		'CustomerGroupsApi.php' => '45897e63723b0f866e22689612146366',
		'CustomerSegmentsApi.php' => '699d888081a7c49035e1f358efb106ba',
		'CustomersApi.php' => '2ae5ef52ef6d6270f9b0618c96e03c97',
		'DevicesApi.php' => '28a98be4c28c293b131a749b268fbf40',
		'DisputesApi.php' => 'abecb7bb25fcae474e6a3c1e9328e8e5',
		'EmployeesApi.php' => '68f75108358c121439cd4939beb4ab5b',
		'GiftCardActivitiesApi.php' => '5ae7fb761887d50a8a4f522a7e22f193',
		'GiftCardsApi.php' => 'ec550575ea7489753564b305fb250a3e',
		'InventoryApi.php' => '3461cb678ef4c3dda23d362c30cf5b44',
		'InvoicesApi.php' => '5d9f9752000133924c202d729062cdd0',
		'LaborApi.php' => 'a1daf7bbe474a1451ed7dad3aa652b40',
		'LocationsApi.php' => '7179bb3772e33733dc92041a377f9229',
		'LoyaltyApi.php' => '4a0cc73aaf730672cb47d497580ec771',
		'MerchantsApi.php' => '9f6fa0f08cb4f38181076b43cda3e464',
		'MobileAuthorizationApi.php' => 'ec5e6fdc6c02590543027744cae43e89',
		'OAuthApi.php' => '0e1b354faeb5876b7aa15b2c74e5e367',
		'OrdersApi.php' => 'aac637568674d39e438cb67a91e01fc5',
		'PaymentsApi.php' => '9323ca74ea6dafb3bc9470f4298ac323',
		'PayoutsApi.php' => 'ae9b494758bfb80767b66fd9a6821b78',
		'RefundsApi.php' => 'e987575ef88acaa083ab992bfa6f5998',
		'SitesApi.php' => '55bce2c45ee99c23809a3df3f0c7e20c',
		'SnippetsApi.php' => '4e7f62a1711897778fccad6fc6993f8c',
		'SubscriptionsApi.php' => '3c0b75db4a8d0ca2d9f769e499dc454d',
		'TeamApi.php' => '6babb8ac942bd328b5e63a2b24f82783',
		'TerminalApi.php' => 'b47382eec1027c98c6a09539bd68fe56',
		'TransactionsApi.php' => 'de55e72f1d9bee3d802c3178677ca46f',
		'V1TransactionsApi.php' => 'd9a40c4b8c10bf227a596c0585ab9b18',
		'VendorsApi.php' => 'ad54a96d09a777d5269de501dabd8ab4',
	),
	'/core/libraries_phartemp/square/square-php-sdk/src/Exceptions' => array(
		'ApiException.php' => 'b31d0081e863ae97204c20d23c9811ae',
		'Exception.php' => 'd49f870e0db7200661cf976d69054618',
	),
	'/core/libraries_phartemp/square/square-php-sdk/src/Http' => array(
		'ApiResponse.php' => '8e625e43ae6c624b88abf9b05d2e40e9',
		'HttpCallBack.php' => 'b97bc158bc1f0fe9ac83b01099aedb50',
		'HttpContext.php' => '16d2d8892e08e6f941fbd50277771162',
		'HttpMethod.php' => 'ed813695e1f9c6fd704798ce6a9eb0f0',
		'HttpRequest.php' => 'b0bd1dfe593b20902c82e334d2f9a437',
		'HttpResponse.php' => '87b24f3eb5d5cceccf80fbea608c6c6c',
	),
	'/core/libraries_phartemp/square/square-php-sdk/src/Models' => array(
		'ACHDetails.php' => '7a1fa7424190872f11bf7b2c6ec6c6ed',
		'AcceptDisputeResponse.php' => '5104cd9c98c4d281329c0fb883028c3b',
		'AcceptedPaymentMethods.php' => 'cea849969935c6257b1817eeea0e689e',
		'AccumulateLoyaltyPointsRequest.php' => '7d079d384d477583cd7e6c76e1a3376e',
		'AccumulateLoyaltyPointsResponse.php' => 'b70e619f636f37797bd3bbb279ddee01',
		'ActionCancelReason.php' => '87322c1d8fd000adfc5cf4f9b668abeb',
		'ActivityType.php' => '7eb1d2bccfde8213828c221f7eadf8bc',
		'AddGroupToCustomerResponse.php' => 'b2e3f4146e38e658882d2c94a2fdd1ed',
		'AdditionalRecipient.php' => 'e38b21c605eb76f0b0ca7b4e4112f0cb',
		'Address.php' => '6869a601b4ad464d96c51df745aa861a',
		'AdjustLoyaltyPointsRequest.php' => '6977f596bfcebb2150d4b7c804591e75',
		'AdjustLoyaltyPointsResponse.php' => 'a5440bf68ed15853897e32c01fb6fcca',
		'AfterpayDetails.php' => '428bfeba2049f0be9c0251e98e9567cc',
		'ApplicationDetails.php' => '7de3eec221f9f344d3ac738f25e1cd21',
		'ApplicationDetailsExternalSquareProduct.php' => '394fc47d577b5662166ffe546d7bbf41',
		'AppointmentSegment.php' => 'ba7460344b9411970d5be39719cc22d5',
		'Availability.php' => 'aa814e35ef04c36dd15c3ba3338215b3',
		'BankAccount.php' => '045e11197ad7205bfad8aa8fa525064e',
		'BankAccountPaymentDetails.php' => 'b0a598a2202afb03491c42c078c6dec1',
		'BankAccountStatus.php' => 'afd23e533e926ff276724fe951ec26f7',
		'BankAccountType.php' => '6c673e5d31f0704de63cad9360bc7a08',
		'BatchChangeInventoryRequest.php' => 'd7e1305559ee27213e3b7152be13f1b2',
		'BatchChangeInventoryResponse.php' => 'e50a081ab0b22bdc958146ace0f7a4ba',
		'BatchDeleteCatalogObjectsRequest.php' => 'e3b25f24b35950a1d1dfd65adc044718',
		'BatchDeleteCatalogObjectsResponse.php' => '4e7e6bd9ece81f6ee14e962141abce49',
		'BatchRetrieveCatalogObjectsRequest.php' => '213bd68ae9e08df616225c70e53e767f',
		'BatchRetrieveCatalogObjectsResponse.php' => 'd926dba84ded4d9dac51aaaa4aada277',
		'BatchRetrieveInventoryChangesRequest.php' => '8db4d63867e635fd0f7f3dd3484fb75f',
		'BatchRetrieveInventoryChangesResponse.php' => '1fd96aa381354a59d1ad229f68931683',
		'BatchRetrieveInventoryCountsRequest.php' => '88243dcf622b8986744e0387b58539df',
		'BatchRetrieveInventoryCountsResponse.php' => 'da322fff43b359678aa31ce69cc21b5d',
		'BatchRetrieveOrdersRequest.php' => '2f578c522c04cbdb78ac2e1278e0d4a2',
		'BatchRetrieveOrdersResponse.php' => '293cc8f6cbd3f8b209208c5c7b668977',
		'BatchUpsertCatalogObjectsRequest.php' => '6e187dffa8300c43555be4676ad94b38',
		'BatchUpsertCatalogObjectsResponse.php' => '8a830b0864a633871dfb8680de150918',
		'Booking.php' => '7515b98974b6e6a8947e8ec374636d67',
		'BookingBookingSource.php' => 'a4b6a7af4f8f794d603b9f9dd1fee302',
		'BookingCreatorDetails.php' => '3edd0381d6e99357088844e5e94b3c74',
		'BookingCreatorDetailsCreatorType.php' => 'e90775a9ae6eaed742d8a47b7413426e',
		'BookingStatus.php' => 'e899f2a10e79654c1632a90242a6876a',
		'BreakType.php' => '3b327d431e498cf5eb3b6fca6bc3fb16',
		'BulkCreateTeamMembersRequest.php' => '1320af181bf9b3dfbc2cb6df4ce35d33',
		'BulkCreateTeamMembersResponse.php' => 'c289814ff255e86e5dddbd0894f7be03',
		'BulkCreateVendorsRequest.php' => '850789a9a5d55be357a35a4efca79b1b',
		'BulkCreateVendorsResponse.php' => 'd39f5cbdfa7b03e93a82a87449736963',
		'BulkRetrieveVendorsRequest.php' => '53b474153f62dd255faa0bcd1d3eb4c6',
		'BulkRetrieveVendorsResponse.php' => '645cd2d1a5ac66136fe9e642b5d1a767',
		'BulkUpdateTeamMembersRequest.php' => '4d4d79126407f83eb20014890ac12e18',
		'BulkUpdateTeamMembersResponse.php' => '508ed1e275b13abb18e8d3bbbb144dcd',
		'BulkUpdateVendorsRequest.php' => '376b8d0e7c0de50468342dc0585b1f7b',
		'BulkUpdateVendorsResponse.php' => 'de59a6190ebd082ab32716e4a3c50db3',
		'BulkUpsertCustomerCustomAttributesRequest.php' => 'f7cb3de905c681a1141ff6e9c8abc0d3',
		'BulkUpsertCustomerCustomAttributesRequestCustomerCustomAttributeUpsertRequest.php' => '046762998d9e118e112645538ad99f32',
		'BulkUpsertCustomerCustomAttributesResponse.php' => '7f6717f793c38e7213e15829d7b1e26b',
		'BulkUpsertCustomerCustomAttributesResponseCustomerCustomAttributeUpsertResponse.php' => 'ab79d8a475de000a6a17e2a05a4b6426',
		'BusinessAppointmentSettings.php' => 'bada16982baef6c29e872b84888b30e5',
		'BusinessAppointmentSettingsAlignmentTime.php' => '59301d84f138b900a891d8acb83df9b7',
		'BusinessAppointmentSettingsBookingLocationType.php' => '58de6ea8a3a975658de8b0e5856defd4',
		'BusinessAppointmentSettingsCancellationPolicy.php' => '1f84b9e6f1090eeef3c1c5c218630ca9',
		'BusinessAppointmentSettingsMaxAppointmentsPerDayLimitType.php' => '28e092aac1e1423f151264feb9f49f7f',
		'BusinessBookingProfile.php' => 'bee1af9364e12a69fdb0f8194e890037',
		'BusinessBookingProfileBookingPolicy.php' => '74a61abd2b1d7422db28bb4c0b166346',
		'BusinessBookingProfileCustomerTimezoneChoice.php' => 'f09b7743ffdc9d0d092f1c41f6728bcd',
		'BusinessHours.php' => 'ed22c32371c469920911001904e3b932',
		'BusinessHoursPeriod.php' => '5d427cee0b2c341d206a8b126fca5757',
		'BuyNowPayLaterDetails.php' => 'd2320d1784e99f411f5e5839a3398326',
		'CalculateLoyaltyPointsRequest.php' => 'dc1c801996f225741e76acbbf1d28eb2',
		'CalculateLoyaltyPointsResponse.php' => 'b6300c53f7f7f22ed61fd7204f086141',
		'CalculateOrderRequest.php' => '4b922b421ffed29982e9a8ab4f58f336',
		'CalculateOrderResponse.php' => 'f99b36762159e49c4b70d6dd7acb17e0',
		'CancelBookingRequest.php' => 'f0f0792434e491157d7033e8bc788d93',
		'CancelBookingResponse.php' => '7fc1c0e5042a8f6999098e0be66d2db9',
		'CancelInvoiceRequest.php' => 'b56fe2c4c1a80b0a05d68cbc8840436e',
		'CancelInvoiceResponse.php' => '0ba24ccb354bf50327ded0f167b3ca89',
		'CancelPaymentByIdempotencyKeyRequest.php' => '37875dbf2e27e44318b14fffeb14344c',
		'CancelPaymentByIdempotencyKeyResponse.php' => 'a2a338b60f56dd8fe29295ea6fca029b',
		'CancelPaymentResponse.php' => 'fda2cc3113dad203fe0c99d82c302eef',
		'CancelSubscriptionResponse.php' => '4c8e00db55f2c38f4c6bc558acb7c2d6',
		'CancelTerminalActionResponse.php' => '0d44093a5696ade2e824a0101fb41da6',
		'CancelTerminalCheckoutResponse.php' => '7597358a825ad3c6f6dda26305be967b',
		'CancelTerminalRefundResponse.php' => '360c11a017ff57cf5d5077da50621315',
		'CaptureTransactionResponse.php' => '3da0fc05013ed441cf8788178ebea407',
		'Card.php' => '2cd4d9d461a3a10078c0ceaaed714220',
		'CardBrand.php' => 'f85caf656ec07e4ea7af27c8a0c8ea96',
		'CardCoBrand.php' => 'f1e53e2d5a03a4fc356ee68c45357e15',
		'CardPaymentDetails.php' => 'dff2470b53ab212e3d976cbfcd966e83',
		'CardPaymentTimeline.php' => 'eb14bf963d139d9e4eec42cf01f6f3bf',
		'CardPrepaidType.php' => '518fff4f51e00b25971eb16206a31f0d',
		'CardSquareProduct.php' => 'fa9d145caa60ee6db470102bc80ad2cf',
		'CardType.php' => '5b6fd55f2b468f0b84779ef41e1fa940',
		'CashAppDetails.php' => '96aaffa099c57cffe789937b07fb1591',
		'CashDrawerDevice.php' => '6e28357b5639a6736de740ee0ff09f50',
		'CashDrawerEventType.php' => 'e9154dbe4d400f5706d7fa1457f18640',
		'CashDrawerShift.php' => '230e62a8634967ea3efd0112947891fc',
		'CashDrawerShiftEvent.php' => '9d7f051e52a3db6cd854b68c844edf04',
		'CashDrawerShiftState.php' => '194b98e2b0c6cea11909d61a43884307',
		'CashDrawerShiftSummary.php' => '9603bed1757408fcd7af407fd531889b',
		'CashPaymentDetails.php' => 'd264cf564ffa72873f24f57f46ca0cf5',
		'CatalogCategory.php' => '219a681108f6d173a1e54426b63fbdac',
		'CatalogCustomAttributeDefinition.php' => '78f2d5fefd3a13da02b3f6e97a3b1259',
		'CatalogCustomAttributeDefinitionAppVisibility.php' => '0c42d01bbb5f8005ef1a74a2253c37e0',
		'CatalogCustomAttributeDefinitionNumberConfig.php' => '4fa1d5e6f04bfdb894873a34173b773c',
		'CatalogCustomAttributeDefinitionSelectionConfig.php' => '1d0be532327d1061ccd36259b1754d1f',
		'CatalogCustomAttributeDefinitionSelectionConfigCustomAttributeSelection.php' => '450398a244b28c26f51b1d7f5b95242c',
		'CatalogCustomAttributeDefinitionSellerVisibility.php' => 'fa3b94e403965f6eafe6f0f4ca6096bd',
		'CatalogCustomAttributeDefinitionStringConfig.php' => 'e94daa8b2c4fd0a51e6ad4afcce8e257',
		'CatalogCustomAttributeDefinitionType.php' => '0a6bf2d29e67d0f60e26720f8f989fdc',
		'CatalogCustomAttributeValue.php' => 'fa84bc62f4c993af3d7c03f97429b0bf',
		'CatalogDiscount.php' => '70901d82de1a14246effa96a446650d2',
		'CatalogDiscountModifyTaxBasis.php' => '6078465dd6dfcc448bb6eba283f9fd2b',
		'CatalogDiscountType.php' => 'b4c457ee51b5abe810779c7554a75cbe',
		'CatalogIdMapping.php' => '38cb2291e69860797b0945f351ae4d3a',
		'CatalogImage.php' => 'b7ccadad01255c8f0a102ff6d8f65f69',
		'CatalogInfoResponse.php' => '6ee9e675a48f68205b65cb37c8f693e4',
		'CatalogInfoResponseLimits.php' => '0b602877996168f19aada528d6a024a2',
		'CatalogItem.php' => '5091c3dbc5725f3759d97205b9396e80',
		'CatalogItemModifierListInfo.php' => 'cdca3ad8ac2d8d83f3114c1dff8ddbf9',
		'CatalogItemOption.php' => '8f015a427cf7bf5d207b87eb79351262',
		'CatalogItemOptionForItem.php' => '4f362cc810a8fa0c373617bade7029cd',
		'CatalogItemOptionValue.php' => 'f04459f2a2354f4d74a2b16fc9a88d73',
		'CatalogItemOptionValueForItemVariation.php' => 'dd5190ec86062d5ef531c8346cc26a90',
		'CatalogItemProductType.php' => 'db99828b7c149a43bc27c4d7c1c83ca0',
		'CatalogItemVariation.php' => '67e5da5c5c458d5d7e3e781cacab6c91',
		'CatalogMeasurementUnit.php' => '4628cc6a49c28fe57aec52b0f363baba',
		'CatalogModifier.php' => 'bfd7c691c377c216a7c15720c7c15e39',
		'CatalogModifierList.php' => '480844f3812ead04e4516957effaa205',
		'CatalogModifierListSelectionType.php' => '068c9cd08746c0f7ac7cbedc60f3bddd',
		'CatalogModifierOverride.php' => 'c7605eefc0912408739e0707ee0983d8',
		'CatalogObject.php' => '7b6cb1691601dcd44e8aad72a38d1976',
		'CatalogObjectBatch.php' => '4a97c1d35bb0a8f8f5110e1062e2d7fe',
		'CatalogObjectReference.php' => 'c6cd421e5ef6354898a79b74a1d77904',
		'CatalogObjectType.php' => '6271841f3ea4e27b4eb454ef0dc14b85',
		'CatalogPricingRule.php' => 'f37d5d8c77a80e5626468c47d45e4f91',
		'CatalogPricingType.php' => '74d40e51a1bc9be1502142ce7246ea24',
		'CatalogProductSet.php' => '347f824d7eb9ddd4b094b2529e1a4244',
		'CatalogQuery.php' => '21c4d2153346eca3020dc7150e5268ad',
		'CatalogQueryExact.php' => '2feb633daa86365c6810eca44009e46c',
		'CatalogQueryItemVariationsForItemOptionValues.php' => '4269cc825be0bdd66a36095370e7cfca',
		'CatalogQueryItemsForItemOptions.php' => '6ce4cedb9c19193cb7f67b82423aed6a',
		'CatalogQueryItemsForModifierList.php' => '9af43d8c4e9cad5b5aa8f276286902ab',
		'CatalogQueryItemsForTax.php' => '7b6e52174e695ae486dac8e9d7b26067',
		'CatalogQueryPrefix.php' => '74939d761270302e987bdf13eceb7298',
		'CatalogQueryRange.php' => '497bf5149d4d9e7a3e1270c7843bf7a2',
		'CatalogQuerySet.php' => '98d1e4e4cd5c8b45849a1e11db67e6c8',
		'CatalogQuerySortedAttribute.php' => 'acf542b079c7b2284edbca9d8a7340e7',
		'CatalogQueryText.php' => '60215db6f033b563f9c6b2ae29134e40',
		'CatalogQuickAmount.php' => '73168cfc7bda81c5b49107418aa7b488',
		'CatalogQuickAmountType.php' => '5bd42189aeec1ff2ae35e72680f7465f',
		'CatalogQuickAmountsSettings.php' => 'f8c8333b476a183bb10c36174361699e',
		'CatalogQuickAmountsSettingsOption.php' => '1b982d7e2b047c42fa603a58e6c4ef26',
		'CatalogStockConversion.php' => 'a00c1d29bde56941f1bbf0491238651b',
		'CatalogSubscriptionPlan.php' => '2d560949197d7d9e4073c599dcc1afc2',
		'CatalogTax.php' => '13fc3bfc9abd1713ff80107e32f906cd',
		'CatalogTimePeriod.php' => '9755295b8ecbf4463742c4e1d9c0b7bc',
		'CatalogV1Id.php' => '5656d10715a989bf950712e3ec70cdbb',
		'ChangeTiming.php' => '44001a5c3d9f0ca7fdae478f12e2fa22',
		'ChargeRequest.php' => '1e4ce513ddc5c528bd787c2d0ae3b4f3',
		'ChargeRequestAdditionalRecipient.php' => 'a720f3934819d2d0ba95493fa76dd671',
		'ChargeResponse.php' => '15864c9ba0b334ba5f728fe4d4e51974',
		'Checkout.php' => '33575e9ab495127c9fe630c1bf27d1e4',
		'CheckoutOptions.php' => '2a99ff795a8ac329758a3f65c3340b97',
		'CheckoutOptionsPaymentType.php' => '7e86779fbeda0734a97367e3ffad0cf8',
		'CloneOrderRequest.php' => '93610e59f3ea7cf981a93a82ce71383d',
		'CloneOrderResponse.php' => 'bb968ce673d68deb473e39b5ec27825c',
		'CompletePaymentRequest.php' => '274bfeb10346d660aefa6b1333844f88',
		'CompletePaymentResponse.php' => '72d3f956737088fcbab68be8d1a8323f',
		'Coordinates.php' => 'a685bcebc6c568500d6ab00385ec4e5b',
		'Country.php' => 'f0854780d019c1f8a15de56bc9b11497',
		'CreateBookingRequest.php' => '0dab8c6142dd6bc13b89bc9231c2c5d6',
		'CreateBookingResponse.php' => '589b769e9bd46135f8fb332a4deba2c5',
		'CreateBreakTypeRequest.php' => '5aad7ff5dc41e2559691278b604017d4',
		'CreateBreakTypeResponse.php' => '748b363d5986d586de6600b33ef32f32',
		'CreateCardRequest.php' => '93c8d71dd73d0ac156dd04f9f2aa71a8',
		'CreateCardResponse.php' => 'a489dd9261aa34ab962f72a6f5b0abe2',
		'CreateCatalogImageRequest.php' => 'd5999fca26cfee4b3c8ea0130b14b468',
		'CreateCatalogImageResponse.php' => 'dcbd82ee216c1327656f3e14d7324872',
		'CreateCheckoutRequest.php' => 'dea6dcde50a5422d2f55f8146e2c58a6',
		'CreateCheckoutResponse.php' => 'c25d199c2e46fc7dca486655228d67c4',
		'CreateCustomerCardRequest.php' => '7d5386a4d1d5cedb1628fe9a6c2639a4',
		'CreateCustomerCardResponse.php' => '437203c75c4ab05694e31c0acb2775d2',
		'CreateCustomerCustomAttributeDefinitionRequest.php' => '5ec08cae62e41709b58cf21f267259de',
		'CreateCustomerCustomAttributeDefinitionResponse.php' => 'e0a2a22542d1eba20bf944acc2e38a5b',
		'CreateCustomerGroupRequest.php' => 'eee3b5178ac6acd49e23f0e8de5dc833',
		'CreateCustomerGroupResponse.php' => '8ed56f639b22f21c73d3bae4e43fd022',
		'CreateCustomerRequest.php' => 'cfa9b9336651b280706dc10be2aaa0f0',
		'CreateCustomerResponse.php' => '043a20f430adb78465066f4ec399a5ec',
		'CreateDeviceCodeRequest.php' => 'd53f2628b55baa1ba119d50304de1fbc',
		'CreateDeviceCodeResponse.php' => 'cbb6c10775a75370839cbdcfa5cc6be0',
		'CreateDisputeEvidenceFileRequest.php' => 'd1f7e4cb81b58c05dbfea511891a3253',
		'CreateDisputeEvidenceFileResponse.php' => 'a58463f48d647984d887e718f8de0665',
		'CreateDisputeEvidenceTextRequest.php' => 'd5ca2702f0474592e965d93bdb81e0e0',
		'CreateDisputeEvidenceTextResponse.php' => 'd9ac119f5052d176a20b455b0e6cfe78',
		'CreateGiftCardActivityRequest.php' => 'e1e644f76f86835263ff9332ff6d25f2',
		'CreateGiftCardActivityResponse.php' => '989b8035003de2ac18b275586853dd02',
		'CreateGiftCardRequest.php' => '93dd6d1b15f47665940b5f7bbabdfd68',
		'CreateGiftCardResponse.php' => '6e57bf59ddfe9789cc811bb0632885c0',
		'CreateInvoiceRequest.php' => '491787d9f15d9da8f8426ba16d4edc5c',
		'CreateInvoiceResponse.php' => 'ab7b19ac0362dbd6bb82b50fe7d2c072',
		'CreateLocationRequest.php' => '0188a20b27257a3723753dac23ab5205',
		'CreateLocationResponse.php' => 'afb9e8af19100d7cb021adacc3f7a221',
		'CreateLoyaltyAccountRequest.php' => '10711e9a4bcf2133e1206c05eb2717d9',
		'CreateLoyaltyAccountResponse.php' => 'e928f03bd0ac1bf8aed4634294080144',
		'CreateLoyaltyRewardRequest.php' => '284272a386e21fcd9eef252b71ec2ea2',
		'CreateLoyaltyRewardResponse.php' => 'ff84398b45e984a7034f0bbb198730a6',
		'CreateMobileAuthorizationCodeRequest.php' => '231b799aafeeecacf990168cb1dd64c9',
		'CreateMobileAuthorizationCodeResponse.php' => '6d36d8694524329ff259309de83dfa05',
		'CreateOrderRequest.php' => '6eb07569440a401e92a73c9332810fa4',
		'CreateOrderResponse.php' => 'fcd6f4e7649d8eadf4f72673874d3635',
		'CreatePaymentLinkRequest.php' => 'acbaa6b89652bedd38cd97d6fc27362b',
		'CreatePaymentLinkResponse.php' => 'fdc8ba98cc92734f45c3f26ed43c38e7',
		'CreatePaymentRequest.php' => '008543864604fd5117614612826a1c76',
		'CreatePaymentResponse.php' => '39d71727cfa0448f3de9096dbbbe16f1',
		'CreateRefundRequest.php' => '64dfc4847e0bd86a70ce536f5654e4fb',
		'CreateRefundResponse.php' => '32e3e9bafc0efb3cfd22a2b70e3d861e',
		'CreateShiftRequest.php' => '78ac4ffa41f037cc519e0f4158d96b26',
		'CreateShiftResponse.php' => 'efa4fd98185a9590a0af55bc77c274d2',
		'CreateSubscriptionRequest.php' => 'feaefa4028875cb30d025a7fb46689ed',
		'CreateSubscriptionResponse.php' => '0614f793b86e4ef8816e773140d56967',
		'CreateTeamMemberRequest.php' => '679a22497f10897184899b26fbf37678',
		'CreateTeamMemberResponse.php' => '9af380d66a70010541bc2c6853c92a7a',
		'CreateTerminalActionRequest.php' => 'c72b053dd1d74562a6e2c1d2180cee66',
		'CreateTerminalActionResponse.php' => 'a74639941e240f812e54c0b20bd6e386',
		'CreateTerminalCheckoutRequest.php' => '95650dfcb7f34b88b43d3343d4153488',
		'CreateTerminalCheckoutResponse.php' => 'bdc256a2f9ef89993532bf650dc41211',
		'CreateTerminalRefundRequest.php' => 'f53db841cec41a55e470f81acddee32f',
		'CreateTerminalRefundResponse.php' => 'f9ed318011753c48497d6c8dfef35d66',
		'CreateVendorRequest.php' => 'df9d0c275f15b23a138cd6ffeec55fb2',
		'CreateVendorResponse.php' => 'aabf5b144f1140273da41ad4e3110a50',
		'Currency.php' => '0f4471017043d8e159ff0e5ba31b0f4c',
		'CustomAttribute.php' => '9780f39f0d77688b3833561373e0ae2d',
		'CustomAttributeDefinition.php' => 'bd028beeeb99f7b16c187d81e4193f47',
		'CustomAttributeDefinitionVisibility.php' => '8389311a70c04fc3965318651b7c1cc6',
		'CustomAttributeFilter.php' => '645c7557cc8319f776a2b728b7cd3b8f',
		'CustomField.php' => '3f5958ced3ff4d9466e625d4f0ca1461',
		'Customer.php' => '42e2936b5c51409c9a6c0a4a51b47062',
		'CustomerCreationSource.php' => '5f7504edf0fa5b654cbbf59777c86401',
		'CustomerCreationSourceFilter.php' => '7377177080890bbe3c27a1334056377b',
		'CustomerFilter.php' => '9a072860f0c4c6171c3dc1b477c81e94',
		'CustomerGroup.php' => '487fbad1020734ed49baf49ddea3b8aa',
		'CustomerInclusionExclusion.php' => '348f473a9a1264a68d8892a531da8471',
		'CustomerPreferences.php' => 'c558572e26b3eb38aede77e2384bd41b',
		'CustomerQuery.php' => '651edd83d0b970b20c1f0ed63aa5c92c',
		'CustomerSegment.php' => 'ff9b9c334b1a864ad5a0b4ef8b1d3cb8',
		'CustomerSort.php' => '2f85426ac8cc59b7c7ac794bab99b7db',
		'CustomerSortField.php' => '05c5a0a24d37d0e43a5525bf211a8540',
		'CustomerTaxIds.php' => '3424fc7b5da2527da461f87e2326bacf',
		'CustomerTextFilter.php' => 'd425f40a49b0ea67e881424a23030eef',
		'DateRange.php' => '4f3b9fbaa37f9e99771eb295ef44cb13',
		'DayOfWeek.php' => 'ec2cafc4b983a58dc19721aae95485d2',
		'DeleteBreakTypeResponse.php' => '29ab7ce453845443aeb9e910265a0f00',
		'DeleteCatalogObjectResponse.php' => 'e55678f74757162c04235de74bc07c71',
		'DeleteCustomerCardResponse.php' => '5dab592f8a1f859aa48b15ab49417e54',
		'DeleteCustomerCustomAttributeDefinitionResponse.php' => 'fa4731fe85aea1b7b9d22194b1a5849d',
		'DeleteCustomerCustomAttributeResponse.php' => '43961967ce9d12e6a847dae53b59c0df',
		'DeleteCustomerGroupResponse.php' => 'e6cd9ac2d72268730db24c9a8d358605',
		'DeleteCustomerRequest.php' => 'ac812ffb1fb143bb151399584f3d42ab',
		'DeleteCustomerResponse.php' => '2356c954656e8cd067b52aed8b398a18',
		'DeleteDisputeEvidenceResponse.php' => '5eb07d64f23f8fd03deb720b76b987ee',
		'DeleteInvoiceRequest.php' => '78962a8025deceaf9139fc7359b12ca9',
		'DeleteInvoiceResponse.php' => '51686b1e41d9639c953a35a2e688b2b9',
		'DeleteLoyaltyRewardResponse.php' => 'b9f709811af8fb76c19d0822cf8b5b14',
		'DeletePaymentLinkResponse.php' => '0399ba7a22a8fdc0612b58d6fed5dabd',
		'DeleteShiftResponse.php' => '2277bab7823fde5dac6bcc6c2757e9f1',
		'DeleteSnippetResponse.php' => 'b8721244c0ffbe30028c1859f04eb63b',
		'DeleteSubscriptionActionResponse.php' => 'c88b16b69dff0ad8a115ce475e15eb35',
		'DeprecatedCreateDisputeEvidenceFileRequest.php' => '6112a0d6960acd5e0e84c4dcd69df207',
		'DeprecatedCreateDisputeEvidenceFileResponse.php' => 'dc4ef31466aacb14018483333ee01c3e',
		'DeprecatedCreateDisputeEvidenceTextRequest.php' => 'd24db9d88e9416f2eb60672908d5960a',
		'DeprecatedCreateDisputeEvidenceTextResponse.php' => '052e8d7fa380d5adab1dd058c68a5601',
		'Destination.php' => '5b97ce73a56408017f86cebeee49fbe2',
		'DestinationType.php' => 'b9e67ada4b51de6cafaf59af6cff9cec',
		'Device.php' => '6706b067a1b1ac802fa61ebf04d5b889',
		'DeviceCheckoutOptions.php' => '9e22892cb925a6cc77ea5817f4b42ca3',
		'DeviceCode.php' => '0e5e5ca390230c326ea925982ff14fcf',
		'DeviceCodeStatus.php' => '443cf6179cd976bcdc4f70feb6a02bf2',
		'DeviceDetails.php' => '4b549a71475e661eb95b76a2ed2b2371',
		'DeviceMetadata.php' => 'adc6569b9c2b8bec55de621d755e4b15',
		'DigitalWalletDetails.php' => '4abb17050b032e659acb7b46c13ec736',
		'DisableCardResponse.php' => 'e96a00736d56f0369abb723d971ce677',
		'Dispute.php' => 'a7dc72ac66ba1469ae2408ee456eda12',
		'DisputeEvidence.php' => 'c824cabe239d04357a6624c9351b1053',
		'DisputeEvidenceCreatedWebhook.php' => '84136f7b2c4a472f428dd69bca9c5909',
		'DisputeEvidenceCreatedWebhookData.php' => '3f6095551ddb4159c6fcb84a5c268876',
		'DisputeEvidenceCreatedWebhookObject.php' => '1860abdb54bbe1fd7dac0b54a3674272',
		'DisputeEvidenceFile.php' => '62aaf0d2f5d843da3e7c3c4cf2f0147e',
		'DisputeEvidenceType.php' => '0fbb73adcc95a0ccb5b6232d30e82c04',
		'DisputeReason.php' => '72f3196257e7204207d7409b4d03be0a',
		'DisputeState.php' => 'ce80ae600fac8c09bacf463d4d4898b5',
		'DisputedPayment.php' => '3ddc0756a7a1b8c21f177eb83dc054f1',
		'EcomVisibility.php' => 'b082dd91b2643f1bba4a0e3e2a6bfb3a',
		'Employee.php' => '5ce88f4b6bd67f980228a7b921dcf665',
		'EmployeeStatus.php' => '3022c2daf364fe1f1665aa94ba0ad185',
		'EmployeeWage.php' => '8620778ffb7d4a87c2e33ece693c60cd',
		'Error.php' => 'fd3f94d67e86026321ef8d84a9a5a4c8',
		'ErrorCategory.php' => 'b7c17ec07e3a9a1d08c315ceae6900cd',
		'ErrorCode.php' => '54431d5e79d2ac499b92ca4aebcb3769',
		'ExcludeStrategy.php' => 'ffd8e201f4f59d3279886de8102e21d5',
		'ExternalPaymentDetails.php' => 'f6fa1c5ec9004f0906dfdcb223bf072b',
		'FilterValue.php' => '1871cc6c3c523893377ef19fb7baeef0',
		'GetBankAccountByV1IdResponse.php' => '10cb44f99ad54a2989dc53c0f0d724f3',
		'GetBankAccountResponse.php' => 'd9e7ce3269f25d37a7747d5e5c5b174f',
		'GetBreakTypeResponse.php' => 'a6718b8e8e4bbe00aebb545d6b1d75c3',
		'GetDeviceCodeResponse.php' => 'fb27cbc9af70365570bd1255274b32c1',
		'GetEmployeeWageResponse.php' => '05a1ac900df72bf6d2e0a48e7bb44ae3',
		'GetInvoiceResponse.php' => 'f3473ef6a7d62c02e35f72b6e9eea478',
		'GetPaymentRefundResponse.php' => '337b08da2f5e830936413caf1412597c',
		'GetPaymentResponse.php' => 'f431182c5f3f735d99a245adec71b279',
		'GetPayoutResponse.php' => 'b72f2237e11f980a4aa0461103c1955d',
		'GetShiftResponse.php' => 'bdcc83842ae50df2fb8971947ae4b5a0',
		'GetTeamMemberWageResponse.php' => '4b605da80e89fb1afe39c1dc86c7d544',
		'GetTerminalActionResponse.php' => '9e476fe60343c1d9a99122ba6e6d39cf',
		'GetTerminalCheckoutResponse.php' => '76c2b607729f6842351677a6cfcf6c20',
		'GetTerminalRefundResponse.php' => 'd2606aa5a06c0d52c47f1fccd3489687',
		'GiftCard.php' => '3c753a348e622b33234452f031063662',
		'GiftCardActivity.php' => '21c73cf5470ae6da89dea95556901f76',
		'GiftCardActivityActivate.php' => 'b82336831880ad51c36cc6d4fe473c4d',
		'GiftCardActivityAdjustDecrement.php' => 'a89067030c4da0390d77c8f96b894025',
		'GiftCardActivityAdjustDecrementReason.php' => 'e4c21504748e581db2f1f70e79cc9472',
		'GiftCardActivityAdjustIncrement.php' => 'ecfa5daaab86d210b45c84dd9957edd3',
		'GiftCardActivityAdjustIncrementReason.php' => '557dad00c13736aaa644916e8c1c7fac',
		'GiftCardActivityBlock.php' => '1b8f86d15939190200e0b03ae7ab9e75',
		'GiftCardActivityBlockReason.php' => '6c20eda8095fce9b15e5fd2c288a4269',
		'GiftCardActivityClearBalance.php' => '808307b0bc4325feca78354fb6ee9765',
		'GiftCardActivityClearBalanceReason.php' => 'c7ce6366ed41b3798fb42f55902acaa5',
		'GiftCardActivityDeactivate.php' => '9dc20f14758e9d9ea74e0174a0950b4b',
		'GiftCardActivityDeactivateReason.php' => 'facc356f31c4cf9ffe84a5e95314203f',
		'GiftCardActivityImport.php' => 'b97f1a710ffbfceb90c54af518a5a084',
		'GiftCardActivityImportReversal.php' => '9f87f8bae67c942734cbd6af88b13480',
		'GiftCardActivityLoad.php' => '31fc2c22de3c17ad9264c7e12e9fa5a9',
		'GiftCardActivityRedeem.php' => '56f938ae738615abffc759f4a4417930',
		'GiftCardActivityRedeemStatus.php' => '2d97a47fa97d502b43075694ff43e89b',
		'GiftCardActivityRefund.php' => '9fece2b6f407b8611db5c4eb5224ec3d',
		'GiftCardActivityType.php' => 'cb93d4b940d52f71e41e8f14955ae6e5',
		'GiftCardActivityUnblock.php' => 'da18c871b65490fe3054e232a23ff570',
		'GiftCardActivityUnblockReason.php' => '16126f79fbabecb96bbe770143802fc9',
		'GiftCardActivityUnlinkedActivityRefund.php' => '4026afaa46739e322e3b5c043ff00a77',
		'GiftCardGANSource.php' => '5697eb152c6dda0325e1c6ee9fd86291',
		'GiftCardStatus.php' => '1a81a1a196c62bd8f8108ae3863eb1ff',
		'GiftCardType.php' => 'b777c04f74804cb1f0e804b6bb530cbb',
		'InventoryAdjustment.php' => 'c16106adb7b00406652ab6067229d1ec',
		'InventoryAdjustmentGroup.php' => '70356fb1de742a3b4f04d038e16b1f1b',
		'InventoryAlertType.php' => '3066c70210d0fbdeef52f98a0d7ca148',
		'InventoryChange.php' => '2171a8cc7a2283061cc53ab7ae5718ad',
		'InventoryChangeType.php' => '996f8c590f59df07e3e1993255d92b22',
		'InventoryCount.php' => '89d36d43d4ec8e8cc95b7ce5deb14b97',
		'InventoryPhysicalCount.php' => 'd2daa8d7259f8ec7d981368108ef48ed',
		'InventoryState.php' => '4ad2d795aa6a2292b024b19f71758178',
		'InventoryTransfer.php' => 'f8af352316456d51262bcc3338b82db0',
		'Invoice.php' => '3ecc561235d0d0372fd5d27b05d4ca16',
		'InvoiceAcceptedPaymentMethods.php' => '391e8545af3e39441a6ccf4c98b42579',
		'InvoiceAutomaticPaymentSource.php' => '712df61bff5583ff822eca9713171a57',
		'InvoiceCustomField.php' => '1c904d004f3dd22bb58f800b1225d2f8',
		'InvoiceCustomFieldPlacement.php' => 'f2b38009561b9d2c8e37f79ef4a623c0',
		'InvoiceDeliveryMethod.php' => '33fdc7da774d28f2329ad95c4d0d8ddc',
		'InvoiceFilter.php' => 'fbe205f0467f577dac1dff5018a6787d',
		'InvoicePaymentReminder.php' => '2875cd13742455ca2f40dbc070e4a304',
		'InvoicePaymentReminderStatus.php' => 'e24bb92a97127033c64e0edd3c95d027',
		'InvoicePaymentRequest.php' => '40da355c98d426fb5f54b6cb0383f7c1',
		'InvoiceQuery.php' => 'fa594a5d123566fb8717ec1984a6c454',
		'InvoiceRecipient.php' => 'ab24aaffad7afaf5781fad04967725c3',
		'InvoiceRecipientTaxIds.php' => '076e401ec018bb9dbfa504ccf104b2fd',
		'InvoiceRequestMethod.php' => '1aea51f62da91f7428ba912b668ea27a',
		'InvoiceRequestType.php' => 'e74faee769870bab4aa6d08e426983b1',
		'InvoiceSort.php' => '18f942d9e5e5e6769b011419fd87846f',
		'InvoiceSortField.php' => 'cd4bdc80ab3409829444771950fee819',
		'InvoiceStatus.php' => '60338ea9aedb869500c8d168bf777574',
		'ItemVariationLocationOverrides.php' => 'ebd7c6f054fad51ada6444f9efb73594',
		'JobAssignment.php' => '112d75f347c82770642dc65061cde5d9',
		'JobAssignmentPayType.php' => '6b966c57c0d36c45e3229a20abebc101',
		'LinkCustomerToGiftCardRequest.php' => '02b5797293aee3373967a138a9058fb9',
		'LinkCustomerToGiftCardResponse.php' => 'a0ea69b9f362503d71762837ddfdde0f',
		'ListBankAccountsRequest.php' => 'ee7dc0ff01ea933ee5db6f947182cdd9',
		'ListBankAccountsResponse.php' => '576876027ea0c517be93bc580f69d9cf',
		'ListBookingsRequest.php' => '1da7a4e7cde4a8da380f10fbb042f2b6',
		'ListBookingsResponse.php' => 'c6d4230ff9265b42e660a6fbe441acc6',
		'ListBreakTypesRequest.php' => '176e347ef403adc41365a9d7d2873a81',
		'ListBreakTypesResponse.php' => '3258c842eb555a50908d89fb86000d8b',
		'ListCardsRequest.php' => '15f0f9246b39de090bd1d5519cd83fdd',
		'ListCardsResponse.php' => '7e75385ac9c4eea2ff7af4f488013a4a',
		'ListCashDrawerShiftEventsRequest.php' => 'd5d6e05f0f153af2422311e135538fa4',
		'ListCashDrawerShiftEventsResponse.php' => '4311c7b5eb3671c421e0154627d42291',
		'ListCashDrawerShiftsRequest.php' => 'e60ed5a5d9218c7f8cf7a8e72a8b6c3e',
		'ListCashDrawerShiftsResponse.php' => '78ef48e25785526041dad7a6dbe910ee',
		'ListCatalogRequest.php' => '0972ba7cc98a07b8fdfc77fe2dccb6d0',
		'ListCatalogResponse.php' => 'e9aa1b310a9346b596e778759a6209f8',
		'ListCustomerCustomAttributeDefinitionsRequest.php' => '4c0b126160b5b46f95adf095d28c23c4',
		'ListCustomerCustomAttributeDefinitionsResponse.php' => '75807e06724e485fdc0f6ecc7650f362',
		'ListCustomerCustomAttributesRequest.php' => '47c8db3fbf263c42398aaf3bcaa50a39',
		'ListCustomerCustomAttributesResponse.php' => '4bb4a48f5ec871e4ac487646f71d74ed',
		'ListCustomerGroupsRequest.php' => '3faf1c282a3a497dac1c182d37499598',
		'ListCustomerGroupsResponse.php' => '55fde54abed475e3170162a01a1884da',
		'ListCustomerSegmentsRequest.php' => '8f4575ce17aa5125ad51e5df5a558687',
		'ListCustomerSegmentsResponse.php' => 'c66a16f77b3ea1a170746b5ee0f674b5',
		'ListCustomersRequest.php' => '0af18101c5633306a00c022271fb6567',
		'ListCustomersResponse.php' => '16842e7538316745914ade8e39d96820',
		'ListDeviceCodesRequest.php' => '578c27a2eaeda22173c955c53b632784',
		'ListDeviceCodesResponse.php' => '790ae8bc7dd3b5457e9a56405206b1ba',
		'ListDisputeEvidenceRequest.php' => 'a2955be06b8504285a66731672b69903',
		'ListDisputeEvidenceResponse.php' => '2bfc02d5dd56532be68e2cb5455965ff',
		'ListDisputesRequest.php' => '5fae555219b69dd5f1da66ff1b35c5c4',
		'ListDisputesResponse.php' => '87d5442a1419e4dc487458951d83dad7',
		'ListEmployeeWagesRequest.php' => '6312b4bc760d4c8dbc8dbd1021947482',
		'ListEmployeeWagesResponse.php' => '3cc6985ba03a04c11b65666a6b556fa8',
		'ListEmployeesRequest.php' => 'df66162dd8a4cb05a91664cafe7b1402',
		'ListEmployeesResponse.php' => '3b79cb61a8fa1aee4fa62a5434836fbc',
		'ListGiftCardActivitiesRequest.php' => '9ead97b111d0f543f621e417b275fd6a',
		'ListGiftCardActivitiesResponse.php' => '81ac947a75e0894250eba0bb6b58b97f',
		'ListGiftCardsRequest.php' => '4c8bcb4ab6b04ce90a9306c1feef26f5',
		'ListGiftCardsResponse.php' => '3330391bcc9cd2c5c5d49c8c8ea24233',
		'ListInvoicesRequest.php' => '48193dd3b7f7f4ac4d33879b114a21a3',
		'ListInvoicesResponse.php' => 'b9d39b447179058ef527c39f03cf027c',
		'ListLocationsResponse.php' => '1035fe9558a279e8f16c01a5cbb03297',
		'ListLoyaltyProgramsResponse.php' => '5dea7a892c3f52ddef592ab0a3b0f5ff',
		'ListMerchantsRequest.php' => 'e7ef466014a781968f8d5176dc26aee4',
		'ListMerchantsResponse.php' => '0f2093082545e6f001388dff75b67e3c',
		'ListPaymentLinksRequest.php' => 'e701a80b12ceb113e142083d4a4ca77b',
		'ListPaymentLinksResponse.php' => 'f519944a6045a9bfedb2dfc564d9091a',
		'ListPaymentRefundsRequest.php' => '73746805547fb91a004719573c5fefca',
		'ListPaymentRefundsResponse.php' => 'ac4b9588512c66fd245a16904ff1a0a9',
		'ListPaymentsRequest.php' => '8095d44b5be98c9a6f3d59f022c096ae',
		'ListPaymentsResponse.php' => 'f082d058ee504bece94ec5f31c3a6d36',
		'ListPayoutEntriesRequest.php' => '533d0a2992c360466a9407357d7acb20',
		'ListPayoutEntriesResponse.php' => 'c2e28c961f788d1e43e0d1ac8d317b31',
		'ListPayoutsRequest.php' => 'b0167dcace91731d63be109d79c3b94f',
		'ListPayoutsResponse.php' => 'e367fcc5db99bbbd6efea15d0723a004',
		'ListRefundsRequest.php' => 'a7969c45a803c516d09daa724086b0e5',
		'ListRefundsResponse.php' => '730c8dbc07d10d5adeecddda38224160',
		'ListSitesResponse.php' => '7b931b5014a06d74d40baae190050b2c',
		'ListSubscriptionEventsRequest.php' => 'a8aba332c88804887af08b8a3cba8a8c',
		'ListSubscriptionEventsResponse.php' => 'df678bc5042964af23f2205d5a6fdb11',
		'ListTeamMemberBookingProfilesRequest.php' => '92de41a7311f84655218ff108723da69',
		'ListTeamMemberBookingProfilesResponse.php' => '2535085e2c71372652bb8260f8bf2e8b',
		'ListTeamMemberWagesRequest.php' => '46b36850230944ec57e04230ba6c554a',
		'ListTeamMemberWagesResponse.php' => '36179d64f395c219625075324d317ce2',
		'ListTransactionsRequest.php' => '8bf9bc40525b384c2ce86f86ddb621ca',
		'ListTransactionsResponse.php' => '419e0bb53eee8911b5f02dcb7210e7e2',
		'ListWorkweekConfigsRequest.php' => '391903622c2ed2159e9dc6fc59fbf77b',
		'ListWorkweekConfigsResponse.php' => 'd036e09a600045edda7d8c091da19a30',
		'Location.php' => '2900b22b0b2548c8ffbc079a193fb7bc',
		'LocationCapability.php' => '226764f167ca62b47943ed76c2ac7b5c',
		'LocationStatus.php' => '05435d20c5e4b39a024f339f6b59544b',
		'LocationType.php' => 'd4856efc75acf6381db2ee2a6d0ab3e9',
		'LoyaltyAccount.php' => '38da5f161b89b325c97c7fd40e99dad3',
		'LoyaltyAccountExpiringPointDeadline.php' => '3bc0ca64920f78ec18525ee539b9ce0b',
		'LoyaltyAccountMapping.php' => 'df87c963c791e5da75ce40d055b449d7',
		'LoyaltyAccountMappingType.php' => 'ba9fdbd3b2eb70dde3cb224674ba3219',
		'LoyaltyEvent.php' => '4f123331595e46584eb0e93510e0926e',
		'LoyaltyEventAccumulatePoints.php' => '73938c9eb7944aff1d0ecbaa8c31251d',
		'LoyaltyEventAdjustPoints.php' => '7345a648444b2bb7b1e0336de434e272',
		'LoyaltyEventCreateReward.php' => '8db53ed16c7145662198419cf9fa238f',
		'LoyaltyEventDateTimeFilter.php' => '933eca08aa017779979bb53affbe98b4',
		'LoyaltyEventDeleteReward.php' => '7de61443d80d2873194bd1a973b3dc85',
		'LoyaltyEventExpirePoints.php' => 'd4d825d677bf3f638ca8f3a96b81b28b',
		'LoyaltyEventFilter.php' => 'f8779bb2a51664e3908ea1068f843176',
		'LoyaltyEventLocationFilter.php' => '81c381f7d98660d59c3345ac24748202',
		'LoyaltyEventLoyaltyAccountFilter.php' => 'e7890c2802c833561a4a1c37901e1d65',
		'LoyaltyEventOrderFilter.php' => 'e9076c8441781767b9175cf906dff1ec',
		'LoyaltyEventOther.php' => '2787dafbcd2061be2110c7299836bb7a',
		'LoyaltyEventQuery.php' => 'bdb29116a14c09644b7a074051eb6b6d',
		'LoyaltyEventRedeemReward.php' => 'ddef2a1d32ef6f86b37f92e381e8f419',
		'LoyaltyEventSource.php' => 'f859730ed2af277f7390fd92bc0e4ac9',
		'LoyaltyEventType.php' => 'fdc36b255bdd065a8a56a3fe8dba37c2',
		'LoyaltyEventTypeFilter.php' => 'b4cbabe0a487e41777c54faf6c8c83e3',
		'LoyaltyProgram.php' => 'c882b03cfb1e045e5ce97cca12d9ef64',
		'LoyaltyProgramAccrualRule.php' => 'b34215e0188a7b82e83818b3f858349e',
		'LoyaltyProgramAccrualRuleCategoryData.php' => 'd4d7177170244aa82469494cf408a020',
		'LoyaltyProgramAccrualRuleItemVariationData.php' => '7f0a3d2512812900ee6862f3d9ae35f3',
		'LoyaltyProgramAccrualRuleSpendData.php' => 'c5353ae6489bd1410eb1e8896098933b',
		'LoyaltyProgramAccrualRuleTaxMode.php' => 'dd8945557f4615345c2ccfecd9a9a709',
		'LoyaltyProgramAccrualRuleType.php' => '99ba1a91a3e9756d6ebf0c56ade81a1a',
		'LoyaltyProgramAccrualRuleVisitData.php' => '5cf7027fb9213a5961b1ed9e83276c4b',
		'LoyaltyProgramExpirationPolicy.php' => 'b358861b9c7bbd74849665280457d5c6',
		'LoyaltyProgramRewardDefinition.php' => '51fef902255338efafdf6f5cd6928f42',
		'LoyaltyProgramRewardDefinitionScope.php' => 'c835d176b18088a51f89de58b59db83f',
		'LoyaltyProgramRewardDefinitionType.php' => '729dbd1c96def5697e4769af6c169c51',
		'LoyaltyProgramRewardTier.php' => '72f88154b5b2b38f711eb9237b2267b8',
		'LoyaltyProgramStatus.php' => '455f163507111cc3b3d5f2bdf99c4f9c',
		'LoyaltyProgramTerminology.php' => '1c19683bd6b4fb0ae0b7639790e84982',
		'LoyaltyReward.php' => 'e9868a4f2cb710c331dcbbf06c1d23aa',
		'LoyaltyRewardStatus.php' => '16b4d70b0237ac82eed6e055af68e180',
		'MBreak.php' => 'a7cbb3531851e065372ee5d307f2c376',
		'MeasurementUnit.php' => '24a9381fc10c7fed9768893ac2f57ec3',
		'MeasurementUnitArea.php' => 'd746c4e94bbfae9a8a6f4f707beff3cd',
		'MeasurementUnitCustom.php' => '155642ec1305cc9839d032f986736b2f',
		'MeasurementUnitGeneric.php' => '0698611c15249ea74a3fe538046df191',
		'MeasurementUnitLength.php' => '07e102d34669c215373b8e1c608d2b5d',
		'MeasurementUnitTime.php' => '1511a97a30abae55e4b6343f74afb782',
		'MeasurementUnitUnitType.php' => 'f2a980e2c23a3c50cd747048bd2bc5b9',
		'MeasurementUnitVolume.php' => 'c74b5c2d3930f99e1a422c96b4f59925',
		'MeasurementUnitWeight.php' => '4fcd753dd0794576d13964a1388488a5',
		'Merchant.php' => '78704ed33dfbba6b054331dc85f783ae',
		'MerchantStatus.php' => '295833d96e3afb6b48fda8df916d74b2',
		'Money.php' => '27fc8c3819af9829d2b2664a5f43c367',
		'ObtainTokenRequest.php' => '3e03263ccac7283363aa98dfea8b59ad',
		'ObtainTokenResponse.php' => 'cc72da3e12234937c2d82c5edab1a56b',
		'Order.php' => 'd924913bfcac51da2eee3647aa7ad581',
		'OrderCreated.php' => 'e389d7984480b1868ee3fb1f61047e85',
		'OrderCreatedObject.php' => '7eda8fd8ffad71bd146bf4db6927e493',
		'OrderEntry.php' => '64bb2dc72915a2caaa836d7b9b0ab956',
		'OrderFulfillment.php' => '2747c750c21dc54ca1052327738044c8',
		'OrderFulfillmentFulfillmentEntry.php' => '5f8724098b4e32074166e18031be6de0',
		'OrderFulfillmentFulfillmentLineItemApplication.php' => 'f360b6380d9f88e497f707748001c6a0',
		'OrderFulfillmentPickupDetails.php' => '653c4a8eb78e634957c227f09e294f0a',
		'OrderFulfillmentPickupDetailsCurbsidePickupDetails.php' => '7d909beb7a743e7a74b1fab6bb158e66',
		'OrderFulfillmentPickupDetailsScheduleType.php' => 'e85527cde86d2ec56468023ca8775dc1',
		'OrderFulfillmentRecipient.php' => '9b2e46c3a89f25cf03178c93871ab557',
		'OrderFulfillmentShipmentDetails.php' => 'f75ea79b6c604334d7f6ec0adbded6b4',
		'OrderFulfillmentState.php' => '5c4a36da872e2aa7bd42253807a297f3',
		'OrderFulfillmentType.php' => '3c4eae56cffc20821d81871d9e51e33c',
		'OrderFulfillmentUpdated.php' => '8ed329379195d0d0d4d8257f7ee2a95f',
		'OrderFulfillmentUpdatedObject.php' => '4824e4652f87c8d9e180c411e9ca4c2a',
		'OrderFulfillmentUpdatedUpdate.php' => 'b75a70fee92c514b2ebf96a2b6bd5e20',
		'OrderLineItem.php' => '9f0f5af8c54439c9248302df0e303179',
		'OrderLineItemAppliedDiscount.php' => '56b607fda33419d3bd54c6db630ed3ef',
		'OrderLineItemAppliedTax.php' => '848a93fcf943abff2bdb85c85a0fd792',
		'OrderLineItemDiscount.php' => '31ac937c1756f755408e21ea6601bcd1',
		'OrderLineItemDiscountScope.php' => '3b3f5183091bff2cc07a955e848fe503',
		'OrderLineItemDiscountType.php' => '8f96b79017bb01b4a58eb2d4c336979a',
		'OrderLineItemItemType.php' => 'd8e47ee775516348631cdbc05c13a136',
		'OrderLineItemModifier.php' => '6772c7d43e522b3b2831d69894417570',
		'OrderLineItemPricingBlocklists.php' => 'd92f4899337b418108604a2dc4680732',
		'OrderLineItemPricingBlocklistsBlockedDiscount.php' => '0219ac19e23cdf972ea5923b645519a7',
		'OrderLineItemPricingBlocklistsBlockedTax.php' => '495fb9742a49826f9eda8416fa964b6d',
		'OrderLineItemTax.php' => '0f870ea188cf9b2009580d20ec4e30af',
		'OrderLineItemTaxScope.php' => 'eda00562291dde4fd668e20bfce70189',
		'OrderLineItemTaxType.php' => '77e1ec2bb7d4e997756695bb9a583dec',
		'OrderMoneyAmounts.php' => 'd9894ac77f61e86d25230cdb71f0cb0c',
		'OrderPricingOptions.php' => '4aee059656d4d7f61ce052ea26840aaf',
		'OrderQuantityUnit.php' => '4d96c3455379c8be516231ee0811694f',
		'OrderReturn.php' => 'f62e240d7b4579a5b68dd87ecdbe32c0',
		'OrderReturnDiscount.php' => 'f3b4e3864f9766d431b7786cd5f8d2fb',
		'OrderReturnLineItem.php' => '8b5aefe32d89297d1859026da3894e49',
		'OrderReturnLineItemModifier.php' => 'bb61312e31ccddc0f7d481db80538259',
		'OrderReturnServiceCharge.php' => 'ed26ae02cfa7e867c77c5adf72bc9626',
		'OrderReturnTax.php' => 'dd4f548ac7bdc8f7782ef313e0b93782',
		'OrderReward.php' => '2e2613939e71f52923bf9e7ee3553c67',
		'OrderRoundingAdjustment.php' => '076a468af13c09e09c88650d2f1111e2',
		'OrderServiceCharge.php' => '4ba0253aa28aebf44ec56dca78e66d57',
		'OrderServiceChargeCalculationPhase.php' => 'f116e8063f6616ff426e846ff997dda1',
		'OrderServiceChargeType.php' => '31c1dd43be2b5f9fabb01790f5037bcf',
		'OrderSource.php' => 'a1c69492e4a4eede2380af740410d30a',
		'OrderState.php' => 'ebdaa6fab3b7c3cf67b66848fe609ff4',
		'OrderUpdated.php' => 'a0126754a32b36def1b78d33a8686f0f',
		'OrderUpdatedObject.php' => '904cf2484d5214b243babb2c17cef70c',
		'PauseSubscriptionRequest.php' => '103e7bef4c2cc3900cc6580f9144512a',
		'PauseSubscriptionResponse.php' => 'a1b098701c1bba09c04e47655247c507',
		'PayOrderRequest.php' => '14a9bfb11a2621babebf024bb4627496',
		'PayOrderResponse.php' => 'e4259a72094da49f559f00c55c82b922',
		'Payment.php' => '949744187ebb5179903eb534e29120a7',
		'PaymentBalanceActivityAutomaticSavingsDetail.php' => '7354e119d20c39c09904a90181bb55de',
		'PaymentBalanceActivityAutomaticSavingsReversedDetail.php' => '2aeb76135d23d9daf66779be63d345e9',
		'PaymentBalanceActivityChargeDetail.php' => '6acf3241b5db301c5a6daa4868afa3bc',
		'PaymentBalanceActivityDepositFeeDetail.php' => '9a5b3642668f2f409ecabea205f2f1e4',
		'PaymentBalanceActivityDisputeDetail.php' => '364589ba2a3397de67bca3eca114c345',
		'PaymentBalanceActivityFeeDetail.php' => '080a96feab585667f89f5ffe3c2240c2',
		'PaymentBalanceActivityFreeProcessingDetail.php' => '5bcb789461164eabb8a7c25d560c208d',
		'PaymentBalanceActivityHoldAdjustmentDetail.php' => '9fefa24bedcb188ee6906c4f63808aa6',
		'PaymentBalanceActivityOpenDisputeDetail.php' => 'ce72352f8b826602c1d21a8ea2d0dba6',
		'PaymentBalanceActivityOtherAdjustmentDetail.php' => '9b7ad3d367c3287343008aec7728860d',
		'PaymentBalanceActivityOtherDetail.php' => 'b3526957665b13b53e22866683c4464d',
		'PaymentBalanceActivityRefundDetail.php' => '8dadf13b69bd8c4f3f99156f4253a35a',
		'PaymentBalanceActivityReleaseAdjustmentDetail.php' => 'fb6756c39b0a972972ea8bc9897d0378',
		'PaymentBalanceActivityReserveHoldDetail.php' => '866008e019f7cb9b507c21dab2e73572',
		'PaymentBalanceActivityReserveReleaseDetail.php' => '6934c74eea8ee9285cf733f0da4986d5',
		'PaymentBalanceActivitySquareCapitalPaymentDetail.php' => '2f7e082e8b12195f7c34a6f45bf84835',
		'PaymentBalanceActivitySquareCapitalReversedPaymentDetail.php' => 'f04cc78bd6cf72a9b9289eb8e471c1e4',
		'PaymentBalanceActivityTaxOnFeeDetail.php' => 'af93a7f1d5e6703f834554f07d67ab45',
		'PaymentBalanceActivityThirdPartyFeeDetail.php' => '83e427d998598713835534280d106f4b',
		'PaymentBalanceActivityThirdPartyFeeRefundDetail.php' => '0a14a0cf609aeb7365da7bc3fa558c92',
		'PaymentLink.php' => '5a7a21e2b448710e2f36c1ff8fb1f054',
		'PaymentOptions.php' => '86767fda8f59342c244a989a723d2ac1',
		'PaymentRefund.php' => '6a05fe6a52b1ec9dcd8e1726d4b96d64',
		'Payout.php' => '5f0a67ee84de93fd20e53dfe03179b97',
		'PayoutEntry.php' => '2c77940705183178a39c2d170aff8334',
		'PayoutFee.php' => '6b3b02ce5338bf55ce99f48c3a8c1b64',
		'PayoutFeeType.php' => '03a923e7d52e58ebd3418bea6c29be19',
		'PayoutStatus.php' => '47f46421dca4c0021c2d8bd6be13e096',
		'PayoutType.php' => 'e32fb5a49e7f6500153101475572ed77',
		'PrePopulatedData.php' => '54b90a3aedd3b620e2443557367527c8',
		'ProcessingFee.php' => '04da1dd420716f14b486856c00d1e04a',
		'Product.php' => '6c62e485956950dcbe089708d56aa4a7',
		'ProductType.php' => '45bb3f1923af49d2952b5b27a473bb97',
		'PublishInvoiceRequest.php' => 'd2ac347fbfee547cffe7d6c02e99a89d',
		'PublishInvoiceResponse.php' => 'c80a14b15872702db021e6da1d4819f1',
		'QuantityRatio.php' => '0e755e9ff2427331710600271198f1bf',
		'QuickPay.php' => 'f40597f12752d1ba0e65f045f1e34f11',
		'Range.php' => '49a7eb110e2e75d43597f4fcf78517b5',
		'RedeemLoyaltyRewardRequest.php' => 'ffe5b154e47d7fb5b999ad78fd033bbc',
		'RedeemLoyaltyRewardResponse.php' => '7e5621ff58075a8e4328a8da25df1f7f',
		'Refund.php' => '22f89ebfe508632080efbdbf3d869162',
		'RefundPaymentRequest.php' => 'afe6f1c7bf364eba6afcb27d1f5fd51b',
		'RefundPaymentResponse.php' => '51c11f4e17a41a1dd58a0cc34a73bf0b',
		'RefundStatus.php' => '8199efac9c105281280cf484e6b4dc76',
		'RegisterDomainRequest.php' => '0f4d0c36115721c9e339cd3d66c67fc8',
		'RegisterDomainResponse.php' => '09a19bcd9fd8ef5c3a376d2142dcaafb',
		'RegisterDomainResponseStatus.php' => '78c30f0062fdbd80dd39a371fbd34f4f',
		'RemoveGroupFromCustomerResponse.php' => 'c550088229632f8480658737ba2aa9d9',
		'RenewTokenRequest.php' => 'eded8d631181fd497906b2d75c8158a7',
		'RenewTokenResponse.php' => '5caf82eb793a23ec348476c72a0f125e',
		'ResumeSubscriptionRequest.php' => '8de439dd62530969552edc2c80245a5e',
		'ResumeSubscriptionResponse.php' => '826232ec06e42dfa009fbcc3d6e96a77',
		'RetrieveBookingResponse.php' => 'a4ea88fdcfe560a428bd35049b867a91',
		'RetrieveBusinessBookingProfileResponse.php' => 'f810ec482cb95e9581991322d0e4172a',
		'RetrieveCardResponse.php' => '1d5e6e87444cc7bcbfb6a2504a558a38',
		'RetrieveCashDrawerShiftRequest.php' => 'caf220c3862429d9f4f2dac6d2dd7656',
		'RetrieveCashDrawerShiftResponse.php' => '54078f505197aa34cae3b7e29f2efc6e',
		'RetrieveCatalogObjectRequest.php' => 'f9b584273f6c51f8b8b693dd1a5033b6',
		'RetrieveCatalogObjectResponse.php' => 'b045a66fbf1dddf42576b1ae90a1a261',
		'RetrieveCustomerCustomAttributeDefinitionRequest.php' => '40f1533b882762edc8b75f70e2fd117b',
		'RetrieveCustomerCustomAttributeDefinitionResponse.php' => 'ba954fc3385af43310b009735073e5bf',
		'RetrieveCustomerCustomAttributeRequest.php' => '57d2c7e9618affc6510f88a14019f6e4',
		'RetrieveCustomerCustomAttributeResponse.php' => 'fcea42bcaf4c16e4bc02f319b7e05152',
		'RetrieveCustomerGroupResponse.php' => '22737903124f3bdaef0a00dc21e132b2',
		'RetrieveCustomerResponse.php' => 'b1bdd41315a30ec8828cebcb2cdfa2ba',
		'RetrieveCustomerSegmentResponse.php' => '5daef471f0ed681c5dd8add61be95488',
		'RetrieveDisputeEvidenceResponse.php' => 'b322a66d40e48d46a3c90d4aeee25837',
		'RetrieveDisputeResponse.php' => '30791e882e453887d6fc625e22a967ca',
		'RetrieveEmployeeResponse.php' => '6f3c85c0238abfff59be447d84ba7a0a',
		'RetrieveGiftCardFromGANRequest.php' => '3b443cb9bf8509a6629f22c58bff3c55',
		'RetrieveGiftCardFromGANResponse.php' => '72b2a3ac8c68f6360a7b86db69d468b7',
		'RetrieveGiftCardFromNonceRequest.php' => '5c6d5e9faacbe323c939185a83e97014',
		'RetrieveGiftCardFromNonceResponse.php' => 'aedd2faf7cfb89af8e9e74cd2061807a',
		'RetrieveGiftCardResponse.php' => '0562fb7e5d7785723037bff9e044c777',
		'RetrieveInventoryAdjustmentResponse.php' => '0aefcc4b3e9154f97da0ad9d8e8b618e',
		'RetrieveInventoryChangesRequest.php' => '28c38d56bf5d0a061c049ff6a440ccfb',
		'RetrieveInventoryChangesResponse.php' => 'b1f2a8640ce2fd273c675ecd106dbd26',
		'RetrieveInventoryCountRequest.php' => '7a1af67bdeef9c9ae00c6ed34ee97989',
		'RetrieveInventoryCountResponse.php' => '557d7a647e2c6d79a7130198b7f457c4',
		'RetrieveInventoryPhysicalCountResponse.php' => '6802d28309f04da5fc9bc220d4319e39',
		'RetrieveInventoryTransferResponse.php' => '58ba43588be54fd49ca2e53ce07a914b',
		'RetrieveLocationResponse.php' => '5821a4fd4c7b8d150040f3241e09dba4',
		'RetrieveLoyaltyAccountResponse.php' => '8eb0d26e01624cfe2257bc624d8c42ca',
		'RetrieveLoyaltyProgramResponse.php' => 'fa84430fefe7cc72c5a8414044b9e8c5',
		'RetrieveLoyaltyRewardResponse.php' => '257ebe7d8e03ff23e01f79507c664d46',
		'RetrieveMerchantResponse.php' => 'db391128bba6b662b2c7b8f6b9e98df8',
		'RetrieveOrderResponse.php' => '7446854171518ae5746d0261f0eb6052',
		'RetrievePaymentLinkResponse.php' => 'd31a677ddb0341e1540c4baabcd25545',
		'RetrieveSnippetResponse.php' => 'e86fda28c6df528b2f4d410e992e6300',
		'RetrieveSubscriptionRequest.php' => '2cc3b664828059aa0a6e8426f8203cf0',
		'RetrieveSubscriptionResponse.php' => '1b7e9e6bf837c7268a8fb55c5a3902a4',
		'RetrieveTeamMemberBookingProfileResponse.php' => '359b46aa49890ed618b305a205d56dd3',
		'RetrieveTeamMemberResponse.php' => 'aa343cbe8748c59a1e519d1991655341',
		'RetrieveTransactionResponse.php' => '157cea74ffd5ca27fe5c35c1eee814ae',
		'RetrieveVendorResponse.php' => '30a93bae7c55f62bc194a1973d2626ed',
		'RetrieveWageSettingResponse.php' => '145ee79323c1cf7ea7ecef43e4ff0497',
		'RevokeTokenRequest.php' => 'c5472898c3393ab685b329a350d7294c',
		'RevokeTokenResponse.php' => '2f83525bd55eb5b4f35679cb0e1a2616',
		'RiskEvaluation.php' => '706d3360832ed283e5ce0c42dd6be41a',
		'RiskEvaluationRiskLevel.php' => 'dbc6fcbb085f760817fa3552825544cd',
		'SaveCardOptions.php' => 'ca43f169d70aa43ba5645e877fa934aa',
		'SearchAvailabilityFilter.php' => 'dd36be2cb66e229b3b850b801e450835',
		'SearchAvailabilityQuery.php' => '57c772218708cf687d3efb5477f2893e',
		'SearchAvailabilityRequest.php' => '763e5969383eed934616a225dbc1c8f5',
		'SearchAvailabilityResponse.php' => '79caee6f0f265d59ebee1f8576d95b04',
		'SearchCatalogItemsRequest.php' => '55583d602ddde3572c665ab918d0cc0e',
		'SearchCatalogItemsRequestStockLevel.php' => '5e50782cae6cd6083ba4f514cbdceee0',
		'SearchCatalogItemsResponse.php' => 'e08a82245aa2ef505b3c1a0fc7e11a2e',
		'SearchCatalogObjectsRequest.php' => '038e04caa180472156f1ea3696e09d9d',
		'SearchCatalogObjectsResponse.php' => '617294737ea6e48b287c989cbe628ffb',
		'SearchCustomersRequest.php' => 'fff53ae30a043917f5cfea6cb814f3ba',
		'SearchCustomersResponse.php' => 'e23eacc9f1650930aaa323a4970cb368',
		'SearchInvoicesRequest.php' => 'a185c19db776d0a4b78831d157befbf6',
		'SearchInvoicesResponse.php' => 'e814f7f1fb8e6424f4c501b29a542648',
		'SearchLoyaltyAccountsRequest.php' => '6711c845febd62941a27c5f07530aebb',
		'SearchLoyaltyAccountsRequestLoyaltyAccountQuery.php' => 'cf036bdc8858acb295d921525b177689',
		'SearchLoyaltyAccountsResponse.php' => 'ca0425169b5ce28c2cf7a962c5a0835e',
		'SearchLoyaltyEventsRequest.php' => 'b6f66f44d9ac63fdb32d736b0f6be270',
		'SearchLoyaltyEventsResponse.php' => '4ff523bb577c6ac6a2149fa7ba16fe62',
		'SearchLoyaltyRewardsRequest.php' => '27611e1aae2186f906c5710b4d5edd09',
		'SearchLoyaltyRewardsRequestLoyaltyRewardQuery.php' => '634d0e75d5b8a0a7834351812fd5e957',
		'SearchLoyaltyRewardsResponse.php' => '12221f5c3a3eea7e4bd50dba9eaf0642',
		'SearchOrdersCustomerFilter.php' => '436c961f0bc19ee4d107e36bd3246d4b',
		'SearchOrdersDateTimeFilter.php' => '247dc0c6ae3aa6f3f8fb06e886aeacaf',
		'SearchOrdersFilter.php' => 'cc3eaacbabc1b76b2a53d6f9209a15bf',
		'SearchOrdersFulfillmentFilter.php' => '22bab5d58d78f6e71a57343f6d78ea3e',
		'SearchOrdersQuery.php' => '27777a8e5dc4f8ff3a30fe407a8d3eb4',
		'SearchOrdersRequest.php' => '0bd10f2e529f40bf5f560070ab507c2e',
		'SearchOrdersResponse.php' => '4643fff4bca5e9cdf00f3bd0d8a9fea5',
		'SearchOrdersSort.php' => 'a8964b39cee92935efa007777ef1355e',
		'SearchOrdersSortField.php' => '2806af95662f8a4e9dc3b81f39b29e0e',
		'SearchOrdersSourceFilter.php' => '557a76a699741ece16bcfc7487f9d394',
		'SearchOrdersStateFilter.php' => '51bf0627d311f415fbacae8d235e5ecb',
		'SearchShiftsRequest.php' => '3a5883ac7109b71070c6f162b47eb482',
		'SearchShiftsResponse.php' => 'c038b95f065b6d9980fc0070ac8f1251',
		'SearchSubscriptionsFilter.php' => 'e4ae7c1717b8c9d7587064f1c6175517',
		'SearchSubscriptionsQuery.php' => '3842af9a2acc7b0d77a952236d3bbe8e',
		'SearchSubscriptionsRequest.php' => '6a9f5eccc1590e14772163a45878c714',
		'SearchSubscriptionsResponse.php' => '6b32e767e260ba430a8509d6995c86a1',
		'SearchTeamMembersFilter.php' => '4a3acd208fbe2915d884f3e10dcdf1f2',
		'SearchTeamMembersQuery.php' => 'e605280e29905b12e53c33ad02b843db',
		'SearchTeamMembersRequest.php' => 'dddd4025e9820789f621a455327a0f82',
		'SearchTeamMembersResponse.php' => '892b03ace7e9c6124c12a98329bd0e8b',
		'SearchTerminalActionsRequest.php' => '2e1663fe7901348aa8a8c6635b041b24',
		'SearchTerminalActionsResponse.php' => '228e0723455fd70f6d470d3416db4141',
		'SearchTerminalCheckoutsRequest.php' => '428b71bba562e314abdcdf57c58c53a6',
		'SearchTerminalCheckoutsResponse.php' => '55104df0ff562101bb4858e64ada66d4',
		'SearchTerminalRefundsRequest.php' => '6fd7322b0416d6d8e82163015cb55f83',
		'SearchTerminalRefundsResponse.php' => 'f01ac00ecadc6d93b4b4eb012f14e5c9',
		'SearchVendorsRequest.php' => '362dd6f84f876fd4d92b5ff90c795e25',
		'SearchVendorsRequestFilter.php' => 'd7224b97869d23f1a2b512532fa45b29',
		'SearchVendorsRequestSort.php' => '1212207b3bd222c5c8e42f750e7610a1',
		'SearchVendorsRequestSortField.php' => 'a10b11f93cfa06a3522773d2840a3b37',
		'SearchVendorsResponse.php' => '397a394fa6791c1948dbde3dfcff6e1e',
		'SegmentFilter.php' => '89aa539144bdd5e8827be6696ff88256',
		'Shift.php' => '7466215c0bc51ccb79303fa46209a278',
		'ShiftFilter.php' => '577418a19abdc9638321e2e701f51f28',
		'ShiftFilterStatus.php' => '4544e0abcc4a196883ea225db9a8fd8b',
		'ShiftQuery.php' => '95bedb23ecaf8c82f6ed7a91ff7b2ee7',
		'ShiftSort.php' => '73ffed9e2b91353e52fc404cdb4c7f12',
		'ShiftSortField.php' => '87f94c957ea0fabb7c3ed33067fb17c7',
		'ShiftStatus.php' => '650b067852f83245707390e07724f467',
		'ShiftWage.php' => '59b5cfd1adf2fe83b21cfb5d64f361b0',
		'ShiftWorkday.php' => '2babc80a161c93b5da1edb4e37e6f539',
		'ShiftWorkdayMatcher.php' => '3e6174fc4720240303a9fc0fe6ad9108',
		'Site.php' => '2f08d5f985141d7a92ecedd8db382f73',
		'Snippet.php' => '473205851c1436dc75a5357ac05a8fa3',
		'SnippetResponse.php' => '9d08bc0d09a6d78a06def42e2f185bdc',
		'SortOrder.php' => 'd815398f1189995bc60b5e6fc497379f',
		'SourceApplication.php' => '48652453cbc4654c3d8efe70199c70fd',
		'StandardUnitDescription.php' => '275f268a56a0f873079da9230ffeca53',
		'StandardUnitDescriptionGroup.php' => 'ee3da36b49896205f94185bbf2d6e649',
		'SubmitEvidenceResponse.php' => '5f7a1925a30391a7d41be067fa67c843',
		'Subscription.php' => '2bd90250626d5d837956f357e9af0730',
		'SubscriptionAction.php' => 'c637faf0090cabe7b8de9485a77cccd2',
		'SubscriptionActionType.php' => '3f5ae4ad596b6a570ad38439bab0e365',
		'SubscriptionCadence.php' => '382bef84d6bb9bf86ace9af9668eb697',
		'SubscriptionEvent.php' => 'e472b9abeb90825d017c05c101e87d5c',
		'SubscriptionEventInfo.php' => 'eb42bb717353365df358569116a35738',
		'SubscriptionEventInfoCode.php' => '4b87a4c6e22f28e3940d69e0bd0a1efe',
		'SubscriptionEventSubscriptionEventType.php' => '3500b163139fbdf03392e09f7febf0de',
		'SubscriptionPhase.php' => '8741e69fb2a7808f32a92e0f52f3b1cf',
		'SubscriptionSource.php' => '95195c6ec9e377ed773e222d99cd896d',
		'SubscriptionStatus.php' => '06d894ad206e4acedfbfccc7646cee31',
		'SwapPlanRequest.php' => '46f256d920b14c14bff602b7b6923f9c',
		'SwapPlanResponse.php' => 'df8e39a1d2f520daae306271228fa036',
		'TaxCalculationPhase.php' => 'aaa15cb4ba097100b1b158e5250eeadd',
		'TaxIds.php' => '7c5fc6a4b88caafa5d189ae246096ce6',
		'TaxInclusionType.php' => '1a95836f1ce4ece724a02ee720851792',
		'TeamMember.php' => '62a29506369ab23c46d2d6a68c4ec8e6',
		'TeamMemberAssignedLocations.php' => 'f49a7579f64a0ba5ed7c28d62b356f4f',
		'TeamMemberAssignedLocationsAssignmentType.php' => 'dcfb555816686ef83a0f76208d6a68db',
		'TeamMemberBookingProfile.php' => 'f242e1d32ec258dde63195aa1be59b2c',
		'TeamMemberInvitationStatus.php' => '27dcd52c76a6120df48e685befcde988',
		'TeamMemberStatus.php' => '2e716cc15acf32f281ba28c74930e672',
		'TeamMemberWage.php' => '242024cb60ee3f0c365771d379e0a195',
		'Tender.php' => 'fb894bd85281b6c7ae58b51261fbb21b',
		'TenderCardDetails.php' => '0643cd3f6c61ec726dc2533477b38b27',
		'TenderCardDetailsEntryMethod.php' => 'bcc61ee402d8151f34676f771e800d10',
		'TenderCardDetailsStatus.php' => '44de9a2cf66860030bd610f7535d46a8',
		'TenderCashDetails.php' => '19a6d1235e4081a9c257a65ada2ff778',
		'TenderType.php' => '4cbb9cb964c1851b790dba8270e67f13',
		'TerminalAction.php' => 'c636561c55b018271a9825570612bdd5',
		'TerminalActionActionType.php' => '143e9606eafdb46308918c412c71b003',
		'TerminalActionQuery.php' => '391480e88057a08b579f788330dacafb',
		'TerminalActionQueryFilter.php' => '4ea4151112c613cc4564c7fc03348dfc',
		'TerminalActionQuerySort.php' => '38eee58613aaac96f445f02000eb32e0',
		'TerminalCheckout.php' => '334c0c36ac5d5fef4881fb2a1b7b8828',
		'TerminalCheckoutQuery.php' => 'a092939dd6776330c77074c912b15c20',
		'TerminalCheckoutQueryFilter.php' => '1a7c507022a8bfe12665b794f7a84c2f',
		'TerminalCheckoutQuerySort.php' => '12ac92fc810608787a1b54a15c8a7827',
		'TerminalRefund.php' => 'a40d6c41884d4364326e231b317e0161',
		'TerminalRefundQuery.php' => 'a454330ccdde4eecc48f2b41d0fbbf97',
		'TerminalRefundQueryFilter.php' => '4e4ddd7dc66c6b8f2380d12d97fc53a6',
		'TerminalRefundQuerySort.php' => '45253ed4332d2924bb3df6c9dc04f3a4',
		'TimeRange.php' => 'd1d06dfe71a251c58688e34300c22d42',
		'TipSettings.php' => 'df95533c1bc2f3ef6391ce7e69d8177b',
		'Transaction.php' => '3c86d0cea321465c449485cec573e214',
		'TransactionProduct.php' => '98f7d3e5289ddc11891c23801035617e',
		'TransactionType.php' => '46c99a82069c5b5b24ad3c5d51fda36b',
		'UnlinkCustomerFromGiftCardRequest.php' => 'e411b5bee45990be84bbd37e3927da0e',
		'UnlinkCustomerFromGiftCardResponse.php' => '8f9c5fc84c561b4da399f132b8024159',
		'UpdateBookingRequest.php' => '469324c237b0d93802a44f0a43f32609',
		'UpdateBookingResponse.php' => 'c9a9fbad5608ab20c5fafaa8057ba9a7',
		'UpdateBreakTypeRequest.php' => 'e57991571b58971f2a162eee8d567146',
		'UpdateBreakTypeResponse.php' => 'fdd9db41e836c634724268c0f37029fb',
		'UpdateCatalogImageRequest.php' => '3ae977028df5ab55ccf72e940d1b4c4f',
		'UpdateCatalogImageResponse.php' => '8563febabf0fe16284111cd3dd2850fe',
		'UpdateCustomerCustomAttributeDefinitionRequest.php' => '0efda07556090dc12894e66c221c3c9b',
		'UpdateCustomerCustomAttributeDefinitionResponse.php' => '696b6c2d26b633a01bbc5a13a7228404',
		'UpdateCustomerGroupRequest.php' => '5391cabbc159beef78a2816ebc9b4281',
		'UpdateCustomerGroupResponse.php' => '697f216d5091d4feda678060b1ed3d5b',
		'UpdateCustomerRequest.php' => '2cc2c8d81b2528b0a5b227c24cd1f14a',
		'UpdateCustomerResponse.php' => '171fbe38ddb68cb7c0f60fb4d3e25a59',
		'UpdateInvoiceRequest.php' => 'e42444ee744bc1fe60e7831a3a2c3710',
		'UpdateInvoiceResponse.php' => '5a75696f6c08cf94b99b9b5c1da9844a',
		'UpdateItemModifierListsRequest.php' => '72f81f773c0192bc4ff10d9f5e56b483',
		'UpdateItemModifierListsResponse.php' => '1e6c8e50312f66d28a0c56779932fc64',
		'UpdateItemTaxesRequest.php' => 'e5e0cc953a34699d56b08538837833bd',
		'UpdateItemTaxesResponse.php' => 'e088eaa6da5a0d18e86e2b678f7b9590',
		'UpdateLocationRequest.php' => 'd9e01ab41f0ba7e379be4d99bfd385c6',
		'UpdateLocationResponse.php' => '94bc87de609c910e8be2c297cd60d66a',
		'UpdateOrderRequest.php' => '0881b42a19243d90258dd15066f4c2b9',
		'UpdateOrderResponse.php' => 'ae416372d28c13f4747541dc62308f61',
		'UpdatePaymentLinkRequest.php' => '5841051d0c78210b024f550f2bd4fb8f',
		'UpdatePaymentLinkResponse.php' => 'f2f8c142b304917c697caf5b38c42747',
		'UpdatePaymentRequest.php' => 'a5be3e73a785d85b7f0f715aaf98b605',
		'UpdatePaymentResponse.php' => '9c80150bbddbb3472aa158e361ec8020',
		'UpdateShiftRequest.php' => 'a586d01056d68d1a3354921aeba8867a',
		'UpdateShiftResponse.php' => '018dfc3a2f6d231fdafe7cb20dd336d9',
		'UpdateSubscriptionRequest.php' => '1a635e73ca8659b5b06bd81169a40978',
		'UpdateSubscriptionResponse.php' => 'b6546887f08b6b824f44276494d37263',
		'UpdateTeamMemberRequest.php' => '66cc5056ef91a783f8514bf346c9386b',
		'UpdateTeamMemberResponse.php' => 'f5f351f51e27c72d7d1315421e66f7ae',
		'UpdateVendorRequest.php' => 'f16c4d1a3fd94c837578dffdbe1e484a',
		'UpdateVendorResponse.php' => '86a726eb02c0ea41c4fe37ef53880de0',
		'UpdateWageSettingRequest.php' => 'cd9e48ad125b4ea153f72e3e457320b8',
		'UpdateWageSettingResponse.php' => 'cb558e553c8278647eab5c0774249bfb',
		'UpdateWorkweekConfigRequest.php' => '0c9c53776a8f8038698f7e3013fa93c1',
		'UpdateWorkweekConfigResponse.php' => '6a34a64c635cad24a50aedd9ecec67b6',
		'UpsertCatalogObjectRequest.php' => '8e3e557abf710e39e90b1f6f22111dd3',
		'UpsertCatalogObjectResponse.php' => '0ab7a04c330eafe01a8f9c8206607801',
		'UpsertCustomerCustomAttributeRequest.php' => 'b253961545a24dea2e6d884f19abaa35',
		'UpsertCustomerCustomAttributeResponse.php' => '27f3ff542353a30d3cb91bc9c2a95032',
		'UpsertSnippetRequest.php' => '3dbfb014c9be9a0784cad49317e1ec88',
		'UpsertSnippetResponse.php' => 'b24575688cbaf8e7d2f8034bb1b02a95',
		'V1CreateRefundRequest.php' => '85bf2f0577c09dec50e47db0345d8090',
		'V1CreateRefundRequestType.php' => '52fabc7b50df003790b59677b46cb6c9',
		'V1ListOrdersRequest.php' => 'e102f85d1084d29a001bad9f55c3aed0',
		'V1ListOrdersResponse.php' => '0d7b7dfd6fe267de23936eb1e7fdbd95',
		'V1ListPaymentsRequest.php' => '87392eef382f4a97ce1b14ad9eea6768',
		'V1ListPaymentsResponse.php' => '46315b1a4e1a4e1168cfd995883bad9a',
		'V1ListRefundsRequest.php' => 'cf92bced780745abc8d512f78cf8f979',
		'V1ListRefundsResponse.php' => '8bfbdfeaab4213b33312b2b9bf1e7c6e',
		'V1ListSettlementsRequest.php' => '56b46ac2e6878d626b90cb65144ac45c',
		'V1ListSettlementsRequestStatus.php' => '47b628f0a94f1748fbb3f7e01300ce03',
		'V1ListSettlementsResponse.php' => '45fb0a5b853f586b603dda780d1fbe7d',
		'V1Money.php' => '87c5138a5d95afa7a5c4190bdbca3a8e',
		'V1Order.php' => 'b398e855df2c077a14fec45ad2680fe1',
		'V1OrderHistoryEntry.php' => '55c03dff31eed65ee5ba84b440609fa9',
		'V1OrderHistoryEntryAction.php' => '4fa0f9c2c1d75e10b4b6b45b5958f2b6',
		'V1OrderState.php' => 'd98cbd9bc3cce462f5d7314058d887e4',
		'V1Payment.php' => '6e6ce02957b0b5a70fe2f18d6ce57366',
		'V1PaymentDiscount.php' => '52fa5861b01e9f7bd3bde398d4e2e2df',
		'V1PaymentItemDetail.php' => '2c6cf7cf95a13edba2ca5aedc219b86e',
		'V1PaymentItemization.php' => '0e3cd1cacc29ad4cd81869d1ef8e0f90',
		'V1PaymentItemizationItemizationType.php' => '7bd877a080b3f44a32d2fbdd34e55abc',
		'V1PaymentModifier.php' => 'fff87b1ef01e93bef0c48871416180b2',
		'V1PaymentSurcharge.php' => '1b4cb1710583b90e9a209dbb236381e9',
		'V1PaymentSurchargeType.php' => '99692a4df669fbd511b1c7fad65db713',
		'V1PaymentTax.php' => 'cfb9659c29e396069e50a0f96724c0cb',
		'V1PaymentTaxInclusionType.php' => '7c9a4a5a04e5ea6d3b93e1b79441c465',
		'V1PhoneNumber.php' => '786f49ffbd986a90b87fd5be075b1871',
		'V1Refund.php' => 'b1c3dcbf141c79017243948ef1342fcf',
		'V1RefundType.php' => 'f3c09198c63079927f4f1fc13c5b36b5',
		'V1Settlement.php' => '7d67bcee675987f11d2ba4b171ad86ce',
		'V1SettlementEntry.php' => 'e21f5bebe21ef58db4877f04ec0bff78',
		'V1SettlementEntryType.php' => '6839b1ead883e564d541ec58de79f925',
		'V1SettlementStatus.php' => '22e32c0c068332d937bb376e5423cadf',
		'V1Tender.php' => 'a60efc2878f7d5e22dafcfdbee4ffd2b',
		'V1TenderCardBrand.php' => '1e2ee5a87d193ee8cd8972c715c56faa',
		'V1TenderEntryMethod.php' => '56e8cecf1c94b55e91a4f9980683c4ab',
		'V1TenderType.php' => '186b288fab8cb8364c9c562c22df78d7',
		'V1UpdateOrderRequest.php' => 'ab26f778ffe49b911a7506545e3f0e41',
		'V1UpdateOrderRequestAction.php' => '40916d7ef08d72ecd2f786326eb4ea64',
		'Vendor.php' => 'a5b2ef1f4f79e41a389caa56dfe71491',
		'VendorContact.php' => 'f9068ebc13cf852e672cede197787781',
		'VendorStatus.php' => '0780c513247e602b693cb06a2204772b',
		'VisibilityFilter.php' => 'b5e408ed50d72d5993e4266f2de859dc',
		'VoidTransactionResponse.php' => 'a01cfc6a31f10b9f56ea2cb79982bba7',
		'WageSetting.php' => 'bc6f3facd1f09b7ee60c1ecf86595997',
		'Weekday.php' => '8d1a4dd9bdcda02058fe65f2f11fb11c',
		'WorkweekConfig.php' => 'b2d24c00f5f931e3b67d32117063f48c',
	),
	'/core/libraries_phartemp/square/square-php-sdk/src/Utils' => array(
		'FileWrapper.php' => 'dec809b864f9ab8296bc73cbb40a0dc1',
	),
	'/core/libraries_phartemp/square/unirest-php' => array(
		'LICENSE' => '7a83288907b21923ef412c640c385858',
		'README.md' => '6f29f6dd0ba2c47115c8a964f227c847',
	),
	'/core/libraries_phartemp/square/unirest-php/src' => array(
		'Unirest.php' => 'dd4f32ba15235c2bcd181d6041fec418',
	),
	'/core/libraries_phartemp/square/unirest-php/src/Unirest' => array(
		'Exception.php' => 'e1a9a0bed884ab9cdb729e504ad4fcae',
		'Method.php' => '64452f99fa062c3e6fd8b1663bf5a6e9',
		'OverrideRetry.php' => 'ef7c0c0ad2dd279148d1bb6fa372a5a0',
		'Request.php' => '475e3d99692387c7b28408578885aa32',
		'Response.php' => '4f969fb48b81ca29f51cd01b0c31ccbb',
	),
	'/core/libraries_phartemp/square/unirest-php/src/Unirest/Request' => array(
		'Body.php' => '89ae1d3bed0ee80139e84a2ec31f4ddc',
	),
	'/core/libraries_phartemp/stripe' => array(
		'LICENSE' => '7d3ba0ac2a57368a17ff05cd5dc09a4d',
		'OPENAPI_VERSION' => '28efcb77a607bba2b6bae086f422d874',
		'README.md' => '6f16b6ebd5b656e38f1881fcfef1d53b',
		'VERSION' => '3c071c2f1cee560d91bf787d48040d1e',
		'init.php' => '1464a7ff90f7331efc1baf788b36dce2',
	),
	'/core/libraries_phartemp/stripe/data' => array(
		'ca-certificates.crt' => '6c8779e5755d9dddf677bf7a52d035ce',
	),
	'/core/libraries_phartemp/stripe/lib' => array(
		'Account.php' => 'e8233b9385dc983d0f720c25de868189',
		'AccountLink.php' => '57194027ea34f3ad0a2e69eabe48c6f7',
		'AlipayAccount.php' => '223390e92c4ba2ebed2ca15411f992f1',
		'ApiRequestor.php' => '42e45116ede8e8efcdfd529e1d5c5caa',
		'ApiResource.php' => 'ad276428c54bb3deb2638705d42e7705',
		'ApiResponse.php' => 'c87c5dbe4566009bd8f15fca5c7e5da1',
		'ApplePayDomain.php' => '79118f3027f00870217592ea4de05076',
		'ApplicationFee.php' => '506e545476851daac8bbb2917b95fbb6',
		'ApplicationFeeRefund.php' => '8b8abf75942a76a1b752471bb8188182',
		'Balance.php' => 'c6f8767d6e968a11b712f28a9fe837b0',
		'BalanceTransaction.php' => '360390c927f6dc2abdb0fd5f5dd18314',
		'BankAccount.php' => 'a64edbec478b4c597065131835cf293e',
		'BaseStripeClient.php' => 'f022eb931ce6b7337e1e6e4fee8b0b75',
		'BaseStripeClientInterface.php' => 'e11802d99548ab85164cdaffb192eb2e',
		'BitcoinReceiver.php' => '2f2874f8a1eaedc95d64d3353ce3fb6e',
		'BitcoinTransaction.php' => '36f54e9bc65a05147d780a76ea1b1cd0',
		'Capability.php' => 'd551d330803229f9e723876f5af2c5b5',
		'Card.php' => '79d0fc3ac1eb5707af3c883c17b724f6',
		'CashBalance.php' => '9764212d2dbf0bff45fa6b19b6752606',
		'Charge.php' => '588c3d69cce7bc9ee9c3a4d9ee97faf0',
		'Collection.php' => 'e8e10062ae40b1ef5563f394e6b6ccef',
		'CountrySpec.php' => 'c92f304706d21cc2af39d9fe8035e4af',
		'Coupon.php' => '13323fd15804d03967fa3b6772b70dc3',
		'CreditNote.php' => '73569c5486727789adfba3959516d4cc',
		'CreditNoteLineItem.php' => 'f0de7573f2a4a4bc8e8f518ab233ba1e',
		'Customer.php' => '25049751e3c9202cbd3efadc8607e0c2',
		'CustomerBalanceTransaction.php' => '6eb12b3712df6de5bba003bfebd363dc',
		'Discount.php' => 'e9520d98593521988b7c1c54d930eb63',
		'Dispute.php' => '0f6446c7f2fbc3ecad57db4f36279777',
		'EphemeralKey.php' => 'd859b791b23f2ad09fd0249746e44a9a',
		'ErrorObject.php' => 'e2d4a4e472a08877a75ab28a298dbb10',
		'Event.php' => '63a041c62218c498c584efa7cec8a29f',
		'ExchangeRate.php' => '80364a47b1f9f3573feb1a0d3cedc677',
		'File.php' => 'c979d141df08a41263fa0518df4c5dcf',
		'FileLink.php' => 'b44e4d02fd277eed0fc14563fe86631f',
		'FundingInstructions.php' => '16cef72604cf15d8ff1cc46bf806be6e',
		'Invoice.php' => '3bfb41368e89c15a4ef68c0b85ac149e',
		'InvoiceItem.php' => 'd5e541eaa6d82be672352345a53ee811',
		'InvoiceLineItem.php' => '2252936f3be62a19560ce371ec3de0a8',
		'LineItem.php' => 'dbe5d6404585f3db8a41821547cca08f',
		'LoginLink.php' => 'd394d8b5cea118c0c26b5590a57ccbf5',
		'Mandate.php' => '0b1bf182bca454674ded0feb389c05ef',
		'OAuth.php' => '6821f2b36eb8d677f032b7523e0a5cd1',
		'OAuthErrorObject.php' => 'eadf31c4c8c800733553821533815419',
		'Order.php' => '85a7b9dcb8a0f86097da0a7368a8f92d',
		'OrderItem.php' => 'b9c2ec9a363e622e74c86af4146f294e',
		'PaymentIntent.php' => '34e25f56c12e0e37ce5e3f4107761560',
		'PaymentLink.php' => '2fe9110cc165988268a4a47f432d4f0c',
		'PaymentMethod.php' => 'e8f3ccfef10c0f368ef898d9fbeb1c04',
		'Payout.php' => '4c6272d2565d4148dd2455e3f30533bd',
		'Person.php' => '5175babb944c4d12eff8d748c6f6242e',
		'Plan.php' => '32d2c7ed87a425ccbf6eb016fe83da95',
		'Price.php' => '93dca2ddf7608e826badcb12c23784f5',
		'Product.php' => '45e00233a68cb3a1d91d72c6c855e70a',
		'PromotionCode.php' => 'de71d4ce98d8c98056971d2d31e3ead2',
		'Quote.php' => 'a88f78ffafcd094e73b5be253691e77f',
		'Recipient.php' => 'ea3a6b2dafaf8ae94e4c4242ac10db8f',
		'RecipientTransfer.php' => '2f5ff1ca3cb39674939762c29e1e153f',
		'Refund.php' => 'f594c4acf98f5b39c00692ca05c9cf73',
		'RequestTelemetry.php' => '6d0ffed844216be045d66145014e8568',
		'Review.php' => 'f16fad08f54cc8fecf917a914963d652',
		'SKU.php' => '15a1b9c7d16c1f4d6584835c9c4bfc3a',
		'SearchResult.php' => '702b05ec6f6b8aee6c814597d2e0f6eb',
		'SetupAttempt.php' => '346df32c830510527e75e00e479bcf9a',
		'SetupIntent.php' => '5f5e82cd7f60a9a9bd48aae991952b9d',
		'ShippingRate.php' => 'ef4515935b6b9d0f97f7144faea7a45f',
		'SingletonApiResource.php' => 'a967515ef0efefe81b7e3ee027e108c1',
		'Source.php' => '4403d8d9272a03795b603aa0dd09f098',
		'SourceTransaction.php' => '4c5c984d8015cf3893dbb3eb029e46d0',
		'Stripe.php' => '3212fb17811ae056ee7d3c927584e650',
		'StripeClient.php' => '5e9106447b4ca3e6e922b6493e822918',
		'StripeClientInterface.php' => 'f98dce03c40276806b46d9dade6edaa3',
		'StripeObject.php' => '087dd483ffd45feecde5761dd773e198',
		'StripeStreamingClientInterface.php' => '492a7f6c85c7750b4c11a652a66348bd',
		'Subscription.php' => 'f2155d9cbadb90158fad75a5414a2a8e',
		'SubscriptionItem.php' => 'ea813c4b5090d3452c5fc8dfcd45ad30',
		'SubscriptionSchedule.php' => 'c0f9386be45dbc928ea9685374b74af8',
		'TaxCode.php' => 'fd5f01a414df6eb723f4b2f5265b7017',
		'TaxId.php' => '006dd714c40163213119f432cc0aca86',
		'TaxRate.php' => '2d5e224e19bf9b5f4875106904227ca7',
		'ThreeDSecure.php' => '510eea84e873fe7cdfbadbb9881e8116',
		'Token.php' => 'a3ca0738596df7670642ef9dd04cf5a3',
		'Topup.php' => 'a7b79781e52a696b276454db2e96bb2d',
		'Transfer.php' => 'f66f59dfffc9ddaea1fc9866a7385c3e',
		'TransferReversal.php' => 'bf094201bc51b252ec74e2abf2b16c36',
		'UsageRecord.php' => '32be2f398ab643ef09eb4b3403c7c811',
		'UsageRecordSummary.php' => '1a8cabfe3214aa948ccb56b89ee0e931',
		'Webhook.php' => '90f1fd85ebb213f987780d8c0ea78fba',
		'WebhookEndpoint.php' => '6c4d0c94ba6688c1851d9447b9f82197',
		'WebhookSignature.php' => '0e8c321d56fd2aa3c5f9b93ae35b45ff',
	),
	'/core/libraries_phartemp/stripe/lib/ApiOperations' => array(
		'All.php' => '52e55fa534de7d0042ab4c8779dca83f',
		'Create.php' => '5fddfb23512d8099efc4be9c2672264c',
		'Delete.php' => '6d21c1e0bf559d3c13b77504adb535d0',
		'NestedResource.php' => 'b968f5dee3d1b9e6bbca258579f47835',
		'Request.php' => 'aec619291cf0eeeb3467367a880efe55',
		'Retrieve.php' => '17f154b7c4beecdda90a58f29fcead37',
		'Search.php' => '9c0c9125e169b494284294d9f78a5f96',
		'Update.php' => '890b42a7db47862f4016be579b71035c',
	),
	'/core/libraries_phartemp/stripe/lib/Apps' => array(
		'Secret.php' => 'd0e5f7e29b036ad95f59fc07de971917',
	),
	'/core/libraries_phartemp/stripe/lib/BillingPortal' => array(
		'Configuration.php' => '15853c78a8a3602e2acda9bd2cc17ede',
		'Session.php' => '9da9466f39c1f9b1f210ff3f2520c764',
	),
	'/core/libraries_phartemp/stripe/lib/Checkout' => array(
		'Session.php' => '40b20fdc8c58a3fda4aa4341e5dd4461',
	),
	'/core/libraries_phartemp/stripe/lib/Exception' => array(
		'ApiConnectionException.php' => '3741322cee21151c3da565a0293e50d7',
		'ApiErrorException.php' => 'c250b3ff5400750172276133a1bc1f03',
		'AuthenticationException.php' => '85400ae18713f9aa4b8e0172caf296f1',
		'BadMethodCallException.php' => '11edc5fddb517b94d0f293631f62592a',
		'CardException.php' => 'dc4f6b17acf4116ce355418c60330f50',
		'ExceptionInterface.php' => '6a167cf92a95399c4d984f0f48962db3',
		'IdempotencyException.php' => '9222ed9fef53aaaac2a9bdfdf07ee2b5',
		'InvalidArgumentException.php' => 'fff3751a19d95e9c6d7239e0d20fe3ea',
		'InvalidRequestException.php' => 'cee04b4b30dc758b5fb1f02d49f6132f',
		'PermissionException.php' => '4da37a6c1e1b26b1e201dc3f17d0cd94',
		'RateLimitException.php' => 'c973c4ad3125753bd107957002844863',
		'SignatureVerificationException.php' => '639702f371e61448510953cdbc514ed6',
		'UnexpectedValueException.php' => '39fb29b7cc673553eeee41dfced44647',
		'UnknownApiErrorException.php' => 'e58ff516500a7fadc1b6d101f7677aee',
	),
	'/core/libraries_phartemp/stripe/lib/Exception/OAuth' => array(
		'ExceptionInterface.php' => 'efd38f35858ce1486bd4736cb870adb2',
		'InvalidClientException.php' => 'e4895c8bb50946d048aaac3778911f47',
		'InvalidGrantException.php' => 'b0bb9276a7627a0b58bbb1cc48e8e7e0',
		'InvalidRequestException.php' => 'ff50ca3c979d7237a28f2be760c85cf0',
		'InvalidScopeException.php' => '563505b4fb448e9a0ab8a6a4f30b6e3d',
		'OAuthErrorException.php' => '89dd00bdc9cfc9ede72b1c434d2fc85d',
		'UnknownOAuthErrorException.php' => '85f462a41b290684ad2493e8260a2a38',
		'UnsupportedGrantTypeException.php' => '58903e6537a962797025cdf44f2ee889',
		'UnsupportedResponseTypeException.php' => 'a1d9040430368addd6a6f9aa5ff98a6f',
	),
	'/core/libraries_phartemp/stripe/lib/FinancialConnections' => array(
		'Account.php' => '43f3349710aa540dca727c49cd9b5729',
		'AccountOwner.php' => '9aa964ff8cd0b5d71b080ee6bab2ec62',
		'AccountOwnership.php' => 'a65466b990a3b96dcefa73b3a50fdd73',
		'Session.php' => 'daaf7bef12f4378cd8d2adbbd5cea82c',
	),
	'/core/libraries_phartemp/stripe/lib/HttpClient' => array(
		'ClientInterface.php' => '4887c082cc95ed9ef7003c7d2ee03bb5',
		'CurlClient.php' => '0adbf1145d0ae066cac0f61e0b4b2bc0',
		'StreamingClientInterface.php' => 'db1aad3543636eacd987ab177c548477',
	),
	'/core/libraries_phartemp/stripe/lib/Identity' => array(
		'VerificationReport.php' => 'f00bd1cd8fe41cedcea90539994820ff',
		'VerificationSession.php' => 'b438840cc1a7912cb0d9017b084a883e',
	),
	'/core/libraries_phartemp/stripe/lib/Issuing' => array(
		'Authorization.php' => '1a4405459423e47cb21f9578e6bbf8df',
		'Card.php' => '2512d912070054087b2c42a422d15dfe',
		'CardDetails.php' => '5a745d0246dce3deabfe53955a054745',
		'Cardholder.php' => 'e1822914342d25fc8188acf6f5d0e204',
		'Dispute.php' => '1bc38e1e8e16d33c5a36974eeb559075',
		'Transaction.php' => 'c8d1d662ff8a443f4a2606f1d42d3c4e',
	),
	'/core/libraries_phartemp/stripe/lib/Radar' => array(
		'EarlyFraudWarning.php' => '968bb331839c68e98861dd63cf51725d',
		'ValueList.php' => 'c3bd0dbd71f18c4cde9c08aad115e528',
		'ValueListItem.php' => 'f6380021135d912fca83648141cec6e3',
	),
	'/core/libraries_phartemp/stripe/lib/Reporting' => array(
		'ReportRun.php' => 'f0d6f8efcb2d4eedfe8d442fc9bc1e52',
		'ReportType.php' => 'f45ab9c3d9eba425b87055c69e695666',
	),
	'/core/libraries_phartemp/stripe/lib/Service' => array(
		'AbstractService.php' => 'eb30706b61680d5010cb44e2c9331c46',
		'AbstractServiceFactory.php' => '7214d39971f816d4d5362cc5d9b8bbf8',
		'AccountLinkService.php' => '5e41357f58107ff1be8c29f6d9495679',
		'AccountService.php' => '037b3c4da7848e2c9862e8ac6b025174',
		'ApplePayDomainService.php' => '1e7e5d7232336cf75a0ab2c59ded68b4',
		'ApplicationFeeService.php' => '1be5608784c34d798078aaca4b7c09d4',
		'BalanceService.php' => 'd0e303d8fbb97eec520e87c1df277518',
		'BalanceTransactionService.php' => '4a57dd94301d63f087db4051f36b7172',
		'ChargeService.php' => 'db5e54a15a5f9d7228b792d78305bcaf',
		'CoreServiceFactory.php' => '9b77316eda9d1d886c3f5b3b52d814f6',
		'CountrySpecService.php' => '003b363fbccfce87ab0b9a01b77e1e98',
		'CouponService.php' => '0c941023f1e6523fe5d191dd3e584abb',
		'CreditNoteService.php' => '749c88a1bc0c4c3e0b3dd63d0409ba04',
		'CustomerService.php' => 'de3f3b6a6d6e7ab98b8b6c6eef54ce01',
		'DisputeService.php' => '7c9c8e561d1e2a6c69498608873da8c6',
		'EphemeralKeyService.php' => '568ef71d2d816f02ba5f69d3f6407a76',
		'EventService.php' => '12de4265dae14fd482071522d2c9186a',
		'ExchangeRateService.php' => '54404f5d3448bfe87c2af6ecb300ef07',
		'FileLinkService.php' => 'a6a8ce195321a9a5fc4631191d1ebac4',
		'FileService.php' => 'b5b53ab7147e79eeea841e0780b3db88',
		'InvoiceItemService.php' => 'b815339f84710206192cf57e1408d118',
		'InvoiceService.php' => '5c7119c1cfa5d84e1252a8efb524da50',
		'MandateService.php' => '1dc232386c738390206cc94e5ac3e972',
		'OAuthService.php' => '2f35560891aa910243aface6702c25fc',
		'OrderService.php' => 'bbb42fa469132375c710147bdacd8641',
		'PaymentIntentService.php' => '01a2b0a541d4166103a379cdc888533b',
		'PaymentLinkService.php' => 'b771f2b871e57d5ff770f0a402cb17aa',
		'PaymentMethodService.php' => 'c60ed80bcb2e682a78cf0a6445639183',
		'PayoutService.php' => 'ff77e4b7aa0a517e2eb42209577e74b6',
		'PlanService.php' => '785788e7d5227e75468c267429f740b1',
		'PriceService.php' => '510df0e7a23a48f9db8615703e3bfaa8',
		'ProductService.php' => 'e102cf2035080ed1748bcfb9cfdac99c',
		'PromotionCodeService.php' => '6b26860642c9eb5d296c771c1272f3b4',
		'QuoteService.php' => '1312e65a4d8bb9e57d7aee133659c2c8',
		'RefundService.php' => '304bf7f81219075146d8ad5c1a619be1',
		'ReviewService.php' => 'a7d9f5d53adbf42f7c25fb08a312bf7a',
		'SetupAttemptService.php' => 'dcfb3de56b7eb434eb1d54735d082e1c',
		'SetupIntentService.php' => '6761c99b29e11794283bc476babbbcad',
		'ShippingRateService.php' => '331d6c80f337cb56d47cd7d0560e7aeb',
		'SkuService.php' => '7ea431ebf107c86db17fbdc1e3997b44',
		'SourceService.php' => 'a6a74b811b067403d1a3cbf1865013d5',
		'SubscriptionItemService.php' => '546d3046e4cb19008d61809bc92032aa',
		'SubscriptionScheduleService.php' => 'f864515c5cd3571647bdee1c597f6cdc',
		'SubscriptionService.php' => 'db89754b18d8969077c1dcd3dedf45e3',
		'TaxCodeService.php' => '500d12ef7e79cef20170bbdd7d1af1c4',
		'TaxRateService.php' => 'c0cfd2dbbd179367413577e603265583',
		'TokenService.php' => 'e2277198d6f4e48c564c902ccc046af3',
		'TopupService.php' => '404a329dee19038bada0f9953b672dc9',
		'TransferService.php' => '45c232754813ab6a51efd02baffe39b3',
		'WebhookEndpointService.php' => '1b6c3b85c676a97dacb518b5aa5b0099',
	),
	'/core/libraries_phartemp/stripe/lib/Service/Apps' => array(
		'AppsServiceFactory.php' => 'cbda4be3794a4045ce1776c265941480',
		'SecretService.php' => 'cbc6c2c846fec0c9504f961264c68e40',
	),
	'/core/libraries_phartemp/stripe/lib/Service/BillingPortal' => array(
		'BillingPortalServiceFactory.php' => '76b5bde8e17a73e86e3262931f873515',
		'ConfigurationService.php' => 'd0179fdc2a09e1547a5c2d4a6a1fae45',
		'SessionService.php' => 'ce8f51ee8f69cebcde2ba21756b7cbed',
	),
	'/core/libraries_phartemp/stripe/lib/Service/Checkout' => array(
		'CheckoutServiceFactory.php' => 'd0e404fdc6967eff6810b0077c254d94',
		'SessionService.php' => '1c692f47ae906bbe17f3c5fc4db82493',
	),
	'/core/libraries_phartemp/stripe/lib/Service/FinancialConnections' => array(
		'AccountService.php' => '29b55a613e887cefb8eae8eaf5d0c12d',
		'FinancialConnectionsServiceFactory.php' => '1f7b818ea24014780e5ee66c087fdc32',
		'SessionService.php' => 'f3a23917004d673636d36d67a8b1413f',
	),
	'/core/libraries_phartemp/stripe/lib/Service/Identity' => array(
		'IdentityServiceFactory.php' => '692d89082f2e1614f980c5da0c9456e0',
		'VerificationReportService.php' => '98a4124a469dba2c68196a0204c75cc9',
		'VerificationSessionService.php' => 'e67543a7e867b14f09f53d875dcbb6bd',
	),
	'/core/libraries_phartemp/stripe/lib/Service/Issuing' => array(
		'AuthorizationService.php' => 'ac352c48fdbc277f8e2ced05e358b8a4',
		'CardService.php' => 'a78cbaf79ee81de0c5c89271d4083b59',
		'CardholderService.php' => 'da7123c3cb2835782de6a66eb2ff3b67',
		'DisputeService.php' => 'b5f02aed79c811d9abd989ebcb8911b6',
		'IssuingServiceFactory.php' => '1487461a5efede4d5df8a56ff5fdb4ff',
		'TransactionService.php' => 'caafd6bea5707afeab04edb418ca416d',
	),
	'/core/libraries_phartemp/stripe/lib/Service/Radar' => array(
		'EarlyFraudWarningService.php' => '0be206ec393e5c91afd77f11993cc554',
		'RadarServiceFactory.php' => '3a6747e712ac13361ff06412c0231721',
		'ValueListItemService.php' => '96600bded8575a3053d74cc6cdd748b7',
		'ValueListService.php' => '4be86a56d01a4d868b29b41ae106e083',
	),
	'/core/libraries_phartemp/stripe/lib/Service/Reporting' => array(
		'ReportRunService.php' => '24bcb926db9a1d186a15289aefc0e32e',
		'ReportTypeService.php' => '5deecf9e63d77f5e58f0af5e12d5ef5f',
		'ReportingServiceFactory.php' => '88c0c7ee87f109ea7be57f79124750eb',
	),
	'/core/libraries_phartemp/stripe/lib/Service/Sigma' => array(
		'ScheduledQueryRunService.php' => 'b92d06ac62ccc31ba0ef222c9e311cb2',
		'SigmaServiceFactory.php' => '4adf46f99cbfb06318715f03f25f2f2b',
	),
	'/core/libraries_phartemp/stripe/lib/Service/Terminal' => array(
		'ConfigurationService.php' => 'fdda9b6941259155d0597e059d5fea51',
		'ConnectionTokenService.php' => '1d263e3a3eff1312a6f509ea12ca2f2a',
		'LocationService.php' => '0eb029aaae6be41a10cf0d184f26c4f4',
		'ReaderService.php' => 'cf3cf56cf11731a142379d2751e8e6ef',
		'TerminalServiceFactory.php' => 'd7170f0336d29ab38b4402641be908ed',
	),
	'/core/libraries_phartemp/stripe/lib/Service/TestHelpers' => array(
		'CustomerService.php' => '90e2272469bc4cd72be0dc8a7ee3422d',
		'RefundService.php' => 'fc4ace28c01062c7d998e22ce1ecfca7',
		'TestClockService.php' => 'fe10f3949fb1e576c51614159cbef1f7',
		'TestHelpersServiceFactory.php' => '162586ba39c9b74e02fcf31f702d2a7c',
	),
	'/core/libraries_phartemp/stripe/lib/Service/TestHelpers/Terminal' => array(
		'ReaderService.php' => 'f3652230d7527a25badbcb2e6ed06d89',
		'TerminalServiceFactory.php' => '4e9b1e312a9d290404e313966edeb657',
	),
	'/core/libraries_phartemp/stripe/lib/Service/TestHelpers/Treasury' => array(
		'InboundTransferService.php' => 'd599296cad673fd47b5f33797f49d3df',
		'OutboundPaymentService.php' => 'cc313c6919599e49a0309eb08ee4b2e4',
		'OutboundTransferService.php' => 'b3edce3197cef4108e0876a2cd7d779e',
		'ReceivedCreditService.php' => '443e036e73ba6b60d7ab14426f9a6d5b',
		'ReceivedDebitService.php' => '85f6d35876ffce3d5b628f050bc4b096',
		'TreasuryServiceFactory.php' => 'dc099b22001253a70b9eec7f7381a78b',
	),
	'/core/libraries_phartemp/stripe/lib/Service/Treasury' => array(
		'CreditReversalService.php' => 'aaa61f65c6191b1751e22f4452462882',
		'DebitReversalService.php' => '9cf1e793248dfb8add12ce40204130ff',
		'FinancialAccountService.php' => 'b31946567363bd2ef935d02a03672dee',
		'InboundTransferService.php' => 'c57816f842a91d1a7e4d9b083a03be56',
		'OutboundPaymentService.php' => '5164e732868717b47dbe1a5858cdd0b8',
		'OutboundTransferService.php' => '8a38364c5cc15a3361ba7e9357bf116b',
		'ReceivedCreditService.php' => 'e1afda8dc8ba8060e0bd0c89415a0f46',
		'ReceivedDebitService.php' => '830a41974a84fd28c40132d609f78a85',
		'TransactionEntryService.php' => '98567272b97f526da3d2e3d9818bfbd8',
		'TransactionService.php' => 'a46c5549241d4c8e181cf2bb78a24671',
		'TreasuryServiceFactory.php' => 'b34ac0fee102c065ec4330af72343ab8',
	),
	'/core/libraries_phartemp/stripe/lib/Sigma' => array(
		'ScheduledQueryRun.php' => '6899651f25de8e548a732a0d0604d7ed',
	),
	'/core/libraries_phartemp/stripe/lib/Terminal' => array(
		'Configuration.php' => '85324facb5233f37b0410a22e2c5bbf7',
		'ConnectionToken.php' => 'dc84004455c9f719618d7728f3a676ff',
		'Location.php' => '9810a31cd15c40b5c1f90d8b49bed9f1',
		'Reader.php' => '62118e79ea4da511283a09549166b617',
	),
	'/core/libraries_phartemp/stripe/lib/TestHelpers' => array(
		'TestClock.php' => '96b3af5907e33876dc9fcc1c002a430b',
	),
	'/core/libraries_phartemp/stripe/lib/Treasury' => array(
		'CreditReversal.php' => '36f3780251a1e7b8bd50ae0a0f03caaa',
		'DebitReversal.php' => '31a12995a86995036154f3ed3163f2b1',
		'FinancialAccount.php' => '947d52c2ec4eb8743450bf4250d63884',
		'FinancialAccountFeatures.php' => 'c53650403464ddbe72f751e7ec419033',
		'InboundTransfer.php' => '09103643dc1ba9a66915369af7e751b7',
		'OutboundPayment.php' => '94c7dfca36e2e22d638f046a960cc574',
		'OutboundTransfer.php' => '08470420424e888ab2634c26128655c7',
		'ReceivedCredit.php' => 'bb4aeb2d4acf38f89707998b0a2b72cb',
		'ReceivedDebit.php' => 'a9fc65e6531a11211b240efe91254c57',
		'Transaction.php' => '623c553cc85b3a927e59f8913ab867ee',
		'TransactionEntry.php' => '4bb17f933bbd448bae3dd6345f025de2',
	),
	'/core/libraries_phartemp/stripe/lib/Util' => array(
		'CaseInsensitiveArray.php' => 'c78f00f539540c5b2ef1c779863d97ae',
		'DefaultLogger.php' => '04acddded6588613b1b27fc8664a55e1',
		'LoggerInterface.php' => '154fb2dbed7617773d1524bfdbaca764',
		'ObjectTypes.php' => '348a7c377668515681ab00924e7084c3',
		'RandomGenerator.php' => '139c0907e7ba26cf63a2d9de884955a5',
		'RequestOptions.php' => 'dd7f438dc979d6e6440167e4851beeec',
		'Set.php' => 'd14c7afcdaf07e3873c3786d5c2b0f95',
		'Util.php' => '8b6b88f8ce5ce2de51405871e45cdfc2',
	),
	'/core/libraries_phartemp/vendor' => array(
		'autoload.php' => '0a1c283faec2c55aab9baacd3ddc4e61',
	),
	'/core/libraries_phartemp/vendor/brick' => array(
	),
	'/core/libraries_phartemp/vendor/brick/math' => array(
		'LICENSE' => '755aadbc69e2680a428fe25bf567a858',
	),
	'/core/libraries_phartemp/vendor/brick/math/src' => array(
		'BigDecimal.php' => '597fd434ad5b73b46fa7240dceb18984',
		'BigInteger.php' => 'a5e5dd93a272432f509a67e9180b6e52',
		'BigNumber.php' => '1dd7bafaaef7e3f1bf9e94932f404c8b',
		'BigRational.php' => 'b379112a1ed3fbb94033966f8d6d40de',
		'RoundingMode.php' => '41e8f43814535ba00646160df4ee4b9d',
	),
	'/core/libraries_phartemp/vendor/brick/math/src/Exception' => array(
		'DivisionByZeroException.php' => '03368fd60ee7a7231e1cb38691143b01',
		'IntegerOverflowException.php' => 'c8876e78ad413445b1ae2831e9028f1f',
		'MathException.php' => 'de2c0f8ee58a05374e74abe4683a3358',
		'NegativeNumberException.php' => 'af94490ada21f498ad48a93d3f059146',
		'NumberFormatException.php' => '1a6233c8d7df9e7c60ac2e2d3acf71f9',
		'RoundingNecessaryException.php' => '35b1aa5eebc4196694a8dea1d6b510b8',
	),
	'/core/libraries_phartemp/vendor/brick/math/src/Internal' => array(
		'Calculator.php' => 'd79aa42e817c11ad33698f3d3aaa75a3',
		'CalculatorRegistry.php' => 'b51407f87c0538a23ed5d1722d28a00d',
	),
	'/core/libraries_phartemp/vendor/brick/math/src/Internal/Calculator' => array(
		'BcMathCalculator.php' => 'df8450e508bf20820d3c173dace54790',
		'GmpCalculator.php' => 'a0a8e1c10dd98c5fe15e027ccb46b4ab',
		'NativeCalculator.php' => 'b59832d0e903453715154005d2263595',
	),
	'/core/libraries_phartemp/vendor/composer' => array(
		'ClassLoader.php' => 'f7023f2c41b7ee6743c771c5c2763f3f',
		'InstalledVersions.php' => '4e13a9d6b18efb64cb0488284bdd1a1f',
		'LICENSE' => '955d5fe58c231244f6b49000f383b5e2',
		'autoload_classmap.php' => '246d25063b5e80917cbea27f64936cdd',
		'autoload_files.php' => '08e9e0ae4a4ba97b79c350790efed141',
		'autoload_namespaces.php' => '8afaf9aa450380c3bbbb6331b46cbb9b',
		'autoload_psr4.php' => '0b020b494840ebbc6b5c0ad78e4856e5',
		'autoload_real.php' => '47e6ff0c8be8dce197aa94cdeef43bba',
		'autoload_static.php' => 'bf9aac966c227e2fb906db982e3bb37f',
		'installed.json' => '02807af70cf4474b2030bb71076ccc03',
		'installed.php' => '5941da7bc164720e3770988d9e5c640c',
		'platform_check.php' => '0e50292b7432886b1fc44d671dfaf8d1',
	),
	'/core/libraries_phartemp/vendor/doctrine' => array(
	),
	'/core/libraries_phartemp/vendor/doctrine/inflector' => array(
		'LICENSE' => '6eb5e32a565f247832c2a00cf90ded7c',
		'README.md' => '229ee9aa3a2da312630c519046430f58',
	),
	'/core/libraries_phartemp/vendor/doctrine/inflector/src' => array(
		'CachedWordInflector.php' => 'c60ced48d6fd08fc471aedb062a157bd',
		'GenericLanguageInflectorFactory.php' => '8d4224ee121b9c0e0cab05d854b14c58',
		'Inflector.php' => '3bcc42719366d06ba24401f2fbf1a0cc',
		'InflectorFactory.php' => 'f4db76fcbc003807d4737da7c7bfa369',
		'Language.php' => '30fa8ba94cbcc304ab9c4a4701dcf3c1',
		'LanguageInflectorFactory.php' => '00a44957d4f1362840515680054fc6aa',
		'NoopWordInflector.php' => '485d06f87ccc37c2c381fb8410c8fb03',
		'RulesetInflector.php' => 'c2dba364b620dc28581496c3472d73cd',
		'WordInflector.php' => '78c7cd1d86abacc98f9ce34005e58f58',
	),
	'/core/libraries_phartemp/vendor/doctrine/inflector/src/Rules' => array(
		'Pattern.php' => 'b2cedd9db168fcefd444e4d32abe3b97',
		'Patterns.php' => '65c6b9863e54c1535ac4bdd0d1ef5865',
		'Ruleset.php' => '42d9e900a05b1170db5f186f99a6d0f7',
		'Substitution.php' => '9814f6c5f42d5535688e530269e2add2',
		'Substitutions.php' => 'f8c02ae6b10f7084f8394d28be06af46',
		'Transformation.php' => '5db2059dbc7179f5a85d4b561bdfe735',
		'Transformations.php' => '544fe3276fef4a0b81ad7742cd0c52cd',
		'Word.php' => '18b1a1357ce3ae1cfceff8fc6cfe4aeb',
	),
	'/core/libraries_phartemp/vendor/doctrine/inflector/src/Rules/English' => array(
		'Inflectible.php' => '72e71d3010801ce2f6cb3b281dc777d8',
		'InflectorFactory.php' => 'afa224e87998177017f2050b417abd14',
		'Rules.php' => 'f9ac593f0170a0ec2da9b7aadeba9495',
		'Uninflected.php' => 'c00a4f397cf8a4eb04d7037828912abb',
	),
	'/core/libraries_phartemp/vendor/doctrine/inflector/src/Rules/Esperanto' => array(
		'Inflectible.php' => '1c446deb9d61a8b2ac7ae1dcf689a4ed',
		'InflectorFactory.php' => 'faa0e9fea44144e4b75ec0e8e1603af1',
		'Rules.php' => 'da24fd4cf4bded850522c89af2657c76',
		'Uninflected.php' => 'd60711d84146f34d4eb52602133edc64',
	),
	'/core/libraries_phartemp/vendor/doctrine/inflector/src/Rules/French' => array(
		'Inflectible.php' => '6416c5f808c36dd083290d9d281e750b',
		'InflectorFactory.php' => 'b3dfb585201f2777745c9af93f4d0060',
		'Rules.php' => '6b7b9ccb4c656f46c9af3a07489c065b',
		'Uninflected.php' => 'd0d410f82222c105cc0a2f8cfbd804fa',
	),
	'/core/libraries_phartemp/vendor/doctrine/inflector/src/Rules/Italian' => array(
		'Inflectible.php' => '258aa76cc63602a42376b3c002ca474d',
		'InflectorFactory.php' => '3c994c231ef16e5998f374fc74cd09eb',
		'Rules.php' => '624aa5e561e814f37d29f0dbfc0ff527',
		'Uninflected.php' => '9b78588c2c67ebc16132f18f150fcceb',
	),
	'/core/libraries_phartemp/vendor/doctrine/inflector/src/Rules/NorwegianBokmal' => array(
		'Inflectible.php' => '9f9435b004af7d3e1823c2c46cdf423d',
		'InflectorFactory.php' => '00c33cd572cacb196e32fe5cfa246436',
		'Rules.php' => 'ff2f57ecaf0c1c53f4b6dc1551f95096',
		'Uninflected.php' => '1089bd006027de9615bc94914dc7c6f8',
	),
	'/core/libraries_phartemp/vendor/doctrine/inflector/src/Rules/Portuguese' => array(
		'Inflectible.php' => 'a64912c9f7cee3a3ffa36972a80f8ac1',
		'InflectorFactory.php' => '4e380829373fc9e1475aeada330c4b2f',
		'Rules.php' => 'd2b3fc8fb964cd07c7333785c07757cc',
		'Uninflected.php' => '8f6891e04d913dd29b202a482f0a364a',
	),
	'/core/libraries_phartemp/vendor/doctrine/inflector/src/Rules/Spanish' => array(
		'Inflectible.php' => '4d0252030112af9919e58eb2f3afe0c5',
		'InflectorFactory.php' => '085e248648f630e9bb67fef7dc0cda69',
		'Rules.php' => '4005d81aee53ce419908e589e3ee718d',
		'Uninflected.php' => 'dbbc8a3e6462991d9df5cbe935c87e48',
	),
	'/core/libraries_phartemp/vendor/doctrine/inflector/src/Rules/Turkish' => array(
		'Inflectible.php' => 'b40231b84047af35f7afb394d9b456ef',
		'InflectorFactory.php' => '48bf6f985ceaca823687da1c90190846',
		'Rules.php' => '1eddc08efc5e2e0b45870a80a7b2e441',
		'Uninflected.php' => '8ca269086dfd82a3da00bf15b81b91ba',
	),
	'/core/libraries_phartemp/vendor/eluceo' => array(
	),
	'/core/libraries_phartemp/vendor/eluceo/ical' => array(
		'LICENSE' => '1baaed1897c541bafb6ce66088ad8eca',
		'README.md' => '149eb739432a7c3b9c51ba68f0014605',
	),
	'/core/libraries_phartemp/vendor/eluceo/ical/src' => array(
	),
	'/core/libraries_phartemp/vendor/eluceo/ical/src/Domain' => array(
	),
	'/core/libraries_phartemp/vendor/eluceo/ical/src/Domain/Collection' => array(
		'Events.php' => '72c850b2af6e71eba0580a73d7a1d04e',
		'EventsArray.php' => '24bb449c80f2bea28a0284b18833ed25',
		'EventsGenerator.php' => '7dcbf2a6b387300514e211de5b84a4fc',
	),
	'/core/libraries_phartemp/vendor/eluceo/ical/src/Domain/Entity' => array(
		'Attendee.php' => 'c45a922d3409cce1c3b3186b11e39b42',
		'Calendar.php' => '6703dc559ebd97cd0c815a3e9fe0dd7d',
		'Event.php' => '84ff3500b6ec0667c03a56f750bb181f',
		'TimeZone.php' => '1ec4809abc39c8614fb2716ef8e2985f',
	),
	'/core/libraries_phartemp/vendor/eluceo/ical/src/Domain/Enum' => array(
		'CalendarUserType.php' => '2d0cd9c6468cdaca8e4ab950dd4a4fbb',
		'EventStatus.php' => '42928c472a77f50b6fce1c2643fdf7d3',
		'ParticipationStatus.php' => '4606a613d07ea0131cd544ac806e72fa',
		'RoleType.php' => '0ae0bad1effcb108e0388f3d462ba7f8',
		'TimeZoneTransitionType.php' => '6a69196dee70bb6012df8941bc072aae',
	),
	'/core/libraries_phartemp/vendor/eluceo/ical/src/Domain/ValueObject' => array(
		'Alarm.php' => 'af1d1259db2df97a1b58e7fb37bf903b',
		'Attachment.php' => '9fa98a6fb8040eb0923325cc282e1a88',
		'BinaryContent.php' => 'e403855a691249c99eabe83c767c8757',
		'Category.php' => '76fc24ad357aebbc8711226315b1fedc',
		'Date.php' => '7f7a559024c0f51977f0ecbf775fb7f8',
		'DateTime.php' => '1a0916a64f467f8a242108848423be0a',
		'EmailAddress.php' => 'ec507c28cf99728c90c1ccb8b0144e72',
		'GeographicPosition.php' => '8a41679be0dea35557d691ea09c09fa9',
		'Location.php' => '6ba198e650afd3778c52b7d0bb0b04af',
		'Member.php' => '06762e6a40128c8a4a993ff6fda0ac7c',
		'MultiDay.php' => '6572191cb156b34bb286f6f19f6adac9',
		'Occurrence.php' => 'd3171354919217c9183142ddba93aa92',
		'Organizer.php' => '2fa584476176d512d4e85213b44f9491',
		'PointInTime.php' => '44878e411113fe2c48228f4766dcdefa',
		'SingleDay.php' => '2d9c60bd4de0bfd34d2faf3028fcbf03',
		'TimeSpan.php' => '148cbb4898926ae412f6b165c7f036d2',
		'TimeZoneTransition.php' => 'fd0f985fe3c6330e7ebeec1ec2c11c26',
		'Timestamp.php' => '0841af8eff17adcb61e99c290c69e475',
		'UniqueIdentifier.php' => '6f1566d8b81248935a1be7cc92b213c0',
		'Uri.php' => 'ca1fb084c6a85462294a3e67a71c7d98',
	),
	'/core/libraries_phartemp/vendor/eluceo/ical/src/Domain/ValueObject/Alarm' => array(
		'AbsoluteDateTimeTrigger.php' => '49e1088ab2c79991feaa03255f7d3545',
		'Action.php' => '204911f040e847fa21e7ae5c9dc87f62',
		'AudioAction.php' => '6e961a1923a9d8ea63a3a994545d9c6c',
		'DisplayAction.php' => '41032e1e1d80a6076cd1bc0f84662f16',
		'EmailAction.php' => '0c882ae9c2133c0151e90759b28610ab',
		'RelativeTrigger.php' => '47ddb7799613680565d97ed21f77c66f',
		'Trigger.php' => '1957b588db2442fc3a41f0b724d70163',
	),
	'/core/libraries_phartemp/vendor/eluceo/ical/src/Presentation' => array(
		'Component.php' => 'ed747f9a9407033f0b17a702d9446f6e',
		'ContentLine.php' => '22b581294e868a8fc3ad975e5adea0e9',
	),
	'/core/libraries_phartemp/vendor/eluceo/ical/src/Presentation/Component' => array(
		'Property.php' => '3c9776090dfb0d3ccc8afa1cd5daa276',
	),
	'/core/libraries_phartemp/vendor/eluceo/ical/src/Presentation/Component/Property' => array(
		'Parameter.php' => '86013f48b698a39c6bc6ac564d652c9a',
		'Value.php' => '8b823ab4f998f9c97094484630edbb42',
	),
	'/core/libraries_phartemp/vendor/eluceo/ical/src/Presentation/Component/Property/Value' => array(
		'AppleLocationGeoValue.php' => '9123a607bb53be5b61dc5e8bc5ec803d',
		'BinaryValue.php' => '91d79251557d01dcc221a53034cf54bd',
		'BooleanValue.php' => '64ddad532265a99a55c5f99d8471dcac',
		'DateTimeValue.php' => '50efd989eb520bea4370def8fb3accae',
		'DateValue.php' => 'ea5ea62ab1f6c35497c0802a04195c5f',
		'DurationValue.php' => '31a1d0cb30011ead0ae97b7d604d3cf8',
		'GeoValue.php' => '9cdd446fbe9c9121537c0e0934b9c5d1',
		'IntegerValue.php' => 'da4db63b347e83d40ba9af2a6030676e',
		'ListValue.php' => '1e749763b6d2b5fe1c484c9e688ac782',
		'QuotedUriValue.php' => '5f00c94b9f9d3454adab299370cb37d0',
		'TextValue.php' => '8dd946c5d3138188aa68c88b75ee0d6c',
		'UriValue.php' => 'ca464f21cbf27d47804b642f6dd3060c',
		'UtcOffsetValue.php' => '90b8cdabe348f10b8e4cea94c7bea0ba',
	),
	'/core/libraries_phartemp/vendor/eluceo/ical/src/Presentation/Factory' => array(
		'AlarmFactory.php' => 'f816e53a4926f13e6d73e09b19a307ab',
		'AttendeeFactory.php' => '0912966555d5bd240388011603249a8c',
		'CalendarFactory.php' => '6ae9b121cdb45aae507065c91a05ff97',
		'DateTimeFactory.php' => '31b39a0923afbcd8c6d91e3b6ce5f75a',
		'EventFactory.php' => '310ab38d28e29973a6d57e8fb009dcff',
		'TimeZoneFactory.php' => 'dd64f36b8cd8d2d8115b91f0ee33ac0a',
	),
	'/core/libraries_phartemp/vendor/eluceo/ical/src/Util' => array(
		'DateTimeImmutableFactory.php' => 'dc8137d38c5c681c09b6a0797c0ed6e7',
	),
	'/core/libraries_phartemp/vendor/firebase' => array(
	),
	'/core/libraries_phartemp/vendor/firebase/php-jwt' => array(
		'LICENSE' => '896dee34dec9cdafcd250791d03131f4',
		'README.md' => 'bda4623a079952bc4cdbbad4718dc3ae',
	),
	'/core/libraries_phartemp/vendor/firebase/php-jwt/src' => array(
		'BeforeValidException.php' => '31ec8a3f128697b42496df400f7d2c4a',
		'CachedKeySet.php' => '868e64bfce8caee4f75dcd42429d6427',
		'ExpiredException.php' => 'e7636d70981e545946212b8af13d8bf3',
		'JWK.php' => '13f320d403e9270c86a940022f6248ae',
		'JWT.php' => '758b16a5a39390c28cc7c5fbcaf8cd95',
		'JWTExceptionWithPayloadInterface.php' => '20157958ff6f2e24ab93952041929038',
		'Key.php' => '08a6bb4fa747b876a122c6c886a470c8',
		'SignatureInvalidException.php' => '9352e85cd98a8ce96e246cf92b45f2a5',
	),
	'/core/libraries_phartemp/vendor/greew' => array(
	),
	'/core/libraries_phartemp/vendor/greew/oauth2-azure-provider' => array(
		'LICENSE' => '1fc7b973220111bb5c3290257803006a',
		'README.md' => 'ed72a92534ac16793d97eb97aafcea06',
	),
	'/core/libraries_phartemp/vendor/greew/oauth2-azure-provider/src' => array(
	),
	'/core/libraries_phartemp/vendor/greew/oauth2-azure-provider/src/Provider' => array(
		'Azure.php' => '6af69a0f7ce18f76f9bc3d86df317b28',
		'AzureResourceOwner.php' => '6e3db2a464d0f944a748b09c961ec443',
	),
	'/core/libraries_phartemp/vendor/guzzlehttp' => array(
	),
	'/core/libraries_phartemp/vendor/guzzlehttp/guzzle' => array(
		'LICENSE' => '9a8eefeec4fee45cb835a0f7054073fe',
		'README.md' => '66cc09f7a4ba9fa9ad5c0b0726f2b6d2',
		'UPGRADING.md' => '2419ec1208c77ff6ea91c2eccdf1550f',
	),
	'/core/libraries_phartemp/vendor/guzzlehttp/guzzle/src' => array(
		'BodySummarizer.php' => 'b0e6afe7230ca6f4d1fd29c0645374b9',
		'BodySummarizerInterface.php' => '75a377c78aa3f5aae9f1d1c737d93a0a',
		'Client.php' => '466e77afaeb8b4fbb0c7b36f213d958a',
		'ClientInterface.php' => 'fda1a0861d75585dc2596a6b7aa5de31',
		'ClientTrait.php' => '3a48e934dc3634a08931606499f9198f',
		'HandlerStack.php' => '5e00834fe2feffb22a5eec9fa6f0f7c6',
		'MessageFormatter.php' => '6815c6167b1e3fa7cafc77723d4a6468',
		'MessageFormatterInterface.php' => 'f6da54e52d60d78bca4249d7e3ce1dac',
		'Middleware.php' => '638561cbba6ebba436c2eeade96c1135',
		'Pool.php' => 'a009c04b440d1cdb9c053c9a32f53a61',
		'PrepareBodyMiddleware.php' => '0aead151a35ea236e6620c23a41bc8e4',
		'RedirectMiddleware.php' => '2b4288b8bd02427ace9fd77e05c5828d',
		'RequestOptions.php' => '3ed4804c965677eb72c74ff0e66df2e9',
		'RetryMiddleware.php' => '26674b15538cf174396ffd6afd5d3dcc',
		'TransferStats.php' => 'b8299f0d70300bb80ff20d7510f9c6d7',
		'Utils.php' => 'ad7f1a39583779fd3ec00a789ccd1cb9',
		'functions.php' => 'f635e1120715b9a0a817ccd2f83e5beb',
		'functions_include.php' => 'de95c01f5fb2c341ec04f46302f21bd8',
	),
	'/core/libraries_phartemp/vendor/guzzlehttp/guzzle/src/Cookie' => array(
		'CookieJar.php' => '82e8fe0efb264d0f50f90d5185d5256e',
		'CookieJarInterface.php' => '247762ac698031334c9b3e4cde514c98',
		'FileCookieJar.php' => '4d75a6b2d1532bd6b8a42ee77c4c62cd',
		'SessionCookieJar.php' => 'e6f5a523b8d92a3e981cfb117ad22ebb',
		'SetCookie.php' => '756ef116c905dd44da542ece0101676e',
	),
	'/core/libraries_phartemp/vendor/guzzlehttp/guzzle/src/Exception' => array(
		'BadResponseException.php' => 'd7e519a0dbfd9fa894843375202bb70f',
		'ClientException.php' => '54a375544c774f5c9be93760728c28d8',
		'ConnectException.php' => '0ec955783803b0434492f7e1078f2983',
		'GuzzleException.php' => '5df9eba87d1d37cfe45e96c03d0b7dea',
		'InvalidArgumentException.php' => '93bbd56ebd46590268bca61b44dc9976',
		'RequestException.php' => 'd0a15292d50215e36e6c677538fa663b',
		'ServerException.php' => '0e43cd4cf986728bbc6ee26ff4e5f151',
		'TooManyRedirectsException.php' => '1b9f2515ea8d951c2353c6dbebdfe888',
		'TransferException.php' => '35ade3e430b0beed278b5cf2d2fd2e19',
	),
	'/core/libraries_phartemp/vendor/guzzlehttp/guzzle/src/Handler' => array(
		'CurlFactory.php' => 'b88243f61f7bc4afbf08958e2be3cac8',
		'CurlFactoryInterface.php' => '25ce2dd5884c848145e47a3a9b0d880d',
		'CurlHandler.php' => '2785701426dc86666b930d2a3fdecf5a',
		'CurlMultiHandler.php' => 'e0e9e20a81cb25ffa4747aa1f0f1a98f',
		'EasyHandle.php' => '6af2c8e930cd417621ed7625278e2ae5',
		'HeaderProcessor.php' => 'f5cb7f1b47fa0a0beb062e765dfc6980',
		'MockHandler.php' => 'c1ccb682a328c5bbebc1f598d58514fb',
		'Proxy.php' => 'e5c582032c5907bb7377189f9ade957a',
		'StreamHandler.php' => 'f6374f26aae3985ef88ca00c2c2be479',
	),
	'/core/libraries_phartemp/vendor/guzzlehttp/promises' => array(
		'LICENSE' => '8035eaaec6b3b562c1aed15adc8b908a',
		'README.md' => '5cfc6ce9e6f363b5c619ca5ab3841d97',
	),
	'/core/libraries_phartemp/vendor/guzzlehttp/promises/src' => array(
		'AggregateException.php' => '097e27f4c6498c5b604d40539d963282',
		'CancellationException.php' => '873c8fea8e140ac1caea23a47a21642f',
		'Coroutine.php' => '843ede009b657c25b2c0ad96e40927a0',
		'Create.php' => '0d5821594aadc5c54876af8676d7e8d4',
		'Each.php' => 'a579231826762cf6168de3dc3bc425de',
		'EachPromise.php' => '0e4870b87f464a1b19b92d8871518ba3',
		'FulfilledPromise.php' => '2a69612ac0eb51e76d53937b7e613545',
		'Is.php' => 'f188ff375141ad65bf4a7fba0ea2c298',
		'Promise.php' => '29a9acd844287229b1ec1368ab3593e6',
		'PromiseInterface.php' => 'cb5a4b5cb9f8596b3d2a1139335f4dae',
		'PromisorInterface.php' => '3ce3e930638ef69e68bec4daf8a86aa8',
		'RejectedPromise.php' => '18ec76365a4b82a4cba41ae0ba099ebc',
		'RejectionException.php' => 'a35bfa27c3706ae0e2e25f5fbbababdd',
		'TaskQueue.php' => 'd02929aabe7364e2f6bc4795a460d8b4',
		'TaskQueueInterface.php' => '62de176819efe107d21043f58902c2e6',
		'Utils.php' => '0d6838c97a629da055fb729256bdc9bb',
	),
	'/core/libraries_phartemp/vendor/guzzlehttp/psr7' => array(
		'LICENSE' => 'db7096d1ec87ffcdc25c249bcf336120',
		'README.md' => 'b91d7b27a84a01a99c62a8fbef211b4b',
	),
	'/core/libraries_phartemp/vendor/guzzlehttp/psr7/src' => array(
		'AppendStream.php' => 'cb64aa97a19f23a098d4cdb6c36aea66',
		'BufferStream.php' => '31628be89b8cef4dcced82329dd828f5',
		'CachingStream.php' => '24417f6b2bd00e5e1431cd339084f496',
		'DroppingStream.php' => 'f9a2e1a2700e91bdfc15323553d76443',
		'FnStream.php' => '488dd53bcc8057c1fb9176262923cf69',
		'Header.php' => '0efcf40353f23a383ed20da88c3751e3',
		'HttpFactory.php' => '852ee761facff3015d018a03d86182d0',
		'InflateStream.php' => 'ca8b937408294b379d1fc2c7586c6887',
		'LazyOpenStream.php' => 'b78a2145a6e489add1ee03f87266a254',
		'LimitStream.php' => 'edd0d1a821a119aef9a489a5c3ee0b71',
		'Message.php' => '326cceef4962625a3fa4b6c09343eb70',
		'MessageTrait.php' => '7c942d35ddf06452a8b6299c2c18d190',
		'MimeType.php' => '291eaef7679c719871fcfb25f1988f84',
		'MultipartStream.php' => '883d88075789447a55977c709a29aa21',
		'NoSeekStream.php' => '98bfab6d3b29f20f8b55b5e1c0d648ea',
		'PumpStream.php' => 'db36cbe52ba755e5ffeab397688b3217',
		'Query.php' => '57f338d2cd9b15b5ca868e7b29a8bd7f',
		'Request.php' => 'ffb415724ded21c96a0082b81a5cfa3f',
		'Response.php' => 'f173ef88463e66d296241a892e4d29b5',
		'Rfc7230.php' => 'f8b6129f36aa16a92ac7cd49dfd5e2b5',
		'ServerRequest.php' => 'f2c86e6dc6898ee07ac4a413f7b81729',
		'Stream.php' => '8fcb5647ab9f334e0c5d195a54b8e7d6',
		'StreamDecoratorTrait.php' => '53a8c085b7a03f35a95d39c49ce452c3',
		'StreamWrapper.php' => '2d93d3223e546127fecee4b66d0a2a9f',
		'UploadedFile.php' => 'e960141dafa8c57f8a6e174b29725890',
		'Uri.php' => '2d9307b633c0d438a6c11878c921e433',
		'UriComparator.php' => '3dbdb14d00580102313cba373667ff91',
		'UriNormalizer.php' => '66fa768f9916280d9d5b3b990f664271',
		'UriResolver.php' => '55a15d42394ff2c5a415e1a36cf3994d',
		'Utils.php' => '2e9f432c5a79676dc15e8533290b4099',
	),
	'/core/libraries_phartemp/vendor/guzzlehttp/psr7/src/Exception' => array(
		'MalformedUriException.php' => 'c731d2305f30a67a1110c9eebbe6e90f',
	),
	'/core/libraries_phartemp/vendor/krombox' => array(
	),
	'/core/libraries_phartemp/vendor/krombox/oauth2-wordpress' => array(
		'LICENSE' => '2f248225b42e7fec760454128c43ac8c',
		'README.md' => 'e8734bd4265471416e41a3ddc78a13d2',
	),
	'/core/libraries_phartemp/vendor/krombox/oauth2-wordpress/src' => array(
	),
	'/core/libraries_phartemp/vendor/krombox/oauth2-wordpress/src/Provider' => array(
		'WordPress.php' => '749cedd9954aafb5caa170dfbba2a8e6',
		'WordPressResourceOwner.php' => 'c546943879efe6a4bc8d9f415d376032',
	),
	'/core/libraries_phartemp/vendor/league' => array(
	),
	'/core/libraries_phartemp/vendor/league/oauth2-client' => array(
		'LICENSE' => 'a4f0837c9d93294a47ff451e6ae38717',
		'README.md' => '299fab0a93875c9916cda33c6889d9e2',
	),
	'/core/libraries_phartemp/vendor/league/oauth2-client/src' => array(
	),
	'/core/libraries_phartemp/vendor/league/oauth2-client/src/Grant' => array(
		'AbstractGrant.php' => '6b04c17c4b9029c55d6a3f81a04ac9e8',
		'AuthorizationCode.php' => '38187a6073e90d2a23b11fffc04daf48',
		'ClientCredentials.php' => 'df78afb9a4f06b44175925e46dea1f58',
		'GrantFactory.php' => 'dd70f9443224532a53f2a9f4c755a903',
		'Password.php' => '841b19318934704b2f85a8284d433756',
		'RefreshToken.php' => 'a08504322e724f8a6e3544a72031f81e',
	),
	'/core/libraries_phartemp/vendor/league/oauth2-client/src/Grant/Exception' => array(
		'InvalidGrantException.php' => '4cf7c0c2a61e6d00dad92307660a1aec',
	),
	'/core/libraries_phartemp/vendor/league/oauth2-client/src/OptionProvider' => array(
		'HttpBasicAuthOptionProvider.php' => '2b7a77cdd8de7b8c502a48cb2ca3d25d',
		'OptionProviderInterface.php' => 'bd2ed4a7567738504b5c644383a59d60',
		'PostAuthOptionProvider.php' => 'd27534fd987201cc97d03834ebf6239b',
	),
	'/core/libraries_phartemp/vendor/league/oauth2-client/src/Provider' => array(
		'AbstractProvider.php' => 'cc0cf8d205da3bcca359776198bb7fa5',
		'GenericProvider.php' => 'd043678b171cea807050ee4b100dbc53',
		'GenericResourceOwner.php' => '3548681f48b90777d350721246c47800',
		'ResourceOwnerInterface.php' => 'f5190744547dfe4e62a84f48cd7ff4c2',
	),
	'/core/libraries_phartemp/vendor/league/oauth2-client/src/Provider/Exception' => array(
		'IdentityProviderException.php' => '20e3b1caa9047be4d849cf72649c7f68',
	),
	'/core/libraries_phartemp/vendor/league/oauth2-client/src/Token' => array(
		'AccessToken.php' => '7bc8c734949c57d208757960a3af6270',
		'AccessTokenInterface.php' => '0e80df7df0b60580aa40b18047c27458',
		'ResourceOwnerAccessTokenInterface.php' => '75bee23e05ca25ab5e12330b2210bfd9',
		'SettableRefreshTokenInterface.php' => '2c6afd229af9406d7f92412d91c6c031',
	),
	'/core/libraries_phartemp/vendor/league/oauth2-client/src/Tool' => array(
		'ArrayAccessorTrait.php' => '8c1d0afc4a982998ba17f0d8e4d242e0',
		'BearerAuthorizationTrait.php' => '93bffaed39095edd04b5d2012b3fe23d',
		'GuardedPropertyTrait.php' => '57e49a2fdfe63491ab7732ee5136d583',
		'MacAuthorizationTrait.php' => 'd2f4fa96a04e55e21f916f35846d0050',
		'ProviderRedirectTrait.php' => 'b71ce8695d0fc535a93610b31f7f0e5e',
		'QueryBuilderTrait.php' => '6966ba182313b8b700ebac801c0649cf',
		'RequestFactory.php' => 'c527b764b02ca9c0860efc47faca09fe',
		'RequiredParameterTrait.php' => '4ec4435bd438a453e1fc1839e23eaff6',
	),
	'/core/libraries_phartemp/vendor/league/oauth2-google' => array(
		'LICENSE' => 'b8748fa91e61d429304a3e58c02884c6',
		'README.md' => '207d4b5614e8197f688e7d735eed8fef',
	),
	'/core/libraries_phartemp/vendor/league/oauth2-google/src' => array(
	),
	'/core/libraries_phartemp/vendor/league/oauth2-google/src/Exception' => array(
		'HostedDomainException.php' => '8d55d940e61a193a8b92ad314e55b304',
	),
	'/core/libraries_phartemp/vendor/league/oauth2-google/src/Provider' => array(
		'Google.php' => 'f526e7d85d08ed3167e4b163d61b4750',
		'GoogleUser.php' => '517366f5fd99f709a574be9f768946f4',
	),
	'/core/libraries_phartemp/vendor/minishlink' => array(
	),
	'/core/libraries_phartemp/vendor/minishlink/web-push' => array(
		'LICENSE' => 'df312c56c29fefcbfaa0f6f3bc4c87b8',
	),
	'/core/libraries_phartemp/vendor/minishlink/web-push/src' => array(
		'ContentEncoding.php' => 'ce5e23ed6136eb47d953ed94bae8aab0',
		'Encryption.php' => '9eaeb334912e714e3a4b1276b4e1395f',
		'MessageSentReport.php' => '0e3495eba886a0d3af77d11e6c0abdc4',
		'Notification.php' => 'eec6920908b17e1b0b65c2681cfefba8',
		'Subscription.php' => '4e1f6eb0bb7cd9d8374161ca78112173',
		'SubscriptionInterface.php' => 'c5768d0b284a2f5ae8c1078a8d5f8368',
		'Utils.php' => 'a05aae4862a19eb1d3305823aafb1672',
		'VAPID.php' => '119beea19ddfa52d7f50e80e5bdbfe40',
		'WebPush.php' => '12994dc18912c085490e34ee4b8d14dc',
	),
	'/core/libraries_phartemp/vendor/phpmailer' => array(
	),
	'/core/libraries_phartemp/vendor/phpmailer/phpmailer' => array(
		'COMMITMENT' => '7ad922bcc16462a101862b1b0b15182f',
		'LICENSE' => '23c2a5e0106b99d75238986559bb5fc6',
		'README.md' => '65b4e69a397100fabe6390909d2d3d7e',
		'SECURITY.md' => '7a2ae8e920554464bb035fcdbbc69670',
		'SMTPUTF8.md' => 'fead0765bba2285f2ebf67e41027059e',
		'VBULLETIN' => '345e515523a5d17e9b104b69c763df1c',
		'VERSION' => '0c89310192bfb24730b9d0bafd0d7c61',
	),
	'/core/libraries_phartemp/vendor/phpmailer/phpmailer/language' => array(
		'phpmailer.lang-af.php' => '6b970486ebc4f95377693175c599bea0',
		'phpmailer.lang-ar.php' => '2b14746f3b0d534277cfdabc291115df',
		'phpmailer.lang-as.php' => 'af8b203d321df2ccbb2a61dc6b476229',
		'phpmailer.lang-az.php' => 'f89833f953a6c185dadf09afdafef4f7',
		'phpmailer.lang-ba.php' => '0042d0111f6fcf8646b451f8d1f07b39',
		'phpmailer.lang-be.php' => 'a59b962c6f032e04ecd21af59ac45281',
		'phpmailer.lang-bg.php' => '175314af0b8b128084dd79f72ebe46fb',
		'phpmailer.lang-bn.php' => 'c3c08b3f84c8c8bae66eae43a2eb07b7',
		'phpmailer.lang-ca.php' => '029aeda8b3974787590bf63ef43c1b8c',
		'phpmailer.lang-cs.php' => '4179060ede3ed856b1136e887005d6c0',
		'phpmailer.lang-da.php' => '5006678f727a3421372da26bf0d52df2',
		'phpmailer.lang-de.php' => 'da669e399d9603b58a34267e9e2c12e1',
		'phpmailer.lang-el.php' => '639b15de1a80b1f55f9da7eda968822a',
		'phpmailer.lang-eo.php' => 'edb2a6ed0a008d4a8270aaee618c24c5',
		'phpmailer.lang-es.php' => 'd9a8cd435cb31be09752c70b1121d9b4',
		'phpmailer.lang-et.php' => '578e46fb0cc7b93d6fe71f7464a3720a',
		'phpmailer.lang-fa.php' => '41b070f3c45930c17c2e1903f5d84222',
		'phpmailer.lang-fi.php' => '882bffa17248c866fee08c6449f55d80',
		'phpmailer.lang-fo.php' => 'ab7488aea9d8a6c97e928c254aeca8c3',
		'phpmailer.lang-fr.php' => 'a9f4bf570b77912297703e24d4b56622',
		'phpmailer.lang-gl.php' => 'ab6a5edb550b871f4818462e119e7b54',
		'phpmailer.lang-he.php' => '7633238c2eaab288d187a8c9da596043',
		'phpmailer.lang-hi.php' => '7789905be5d508028c5a0ae4066b50f6',
		'phpmailer.lang-hr.php' => '7a210c226cc0c1ac947b55c464e5b01e',
		'phpmailer.lang-hu.php' => 'b8d3f2c040c7c0a072474375bf1bd368',
		'phpmailer.lang-hy.php' => '3e8b48464e7bdeb915ce9d3bdf2dcff5',
		'phpmailer.lang-id.php' => '5e33b78cddf303afb08a37d6505fb609',
		'phpmailer.lang-it.php' => '8dfdf5a16b9d6560adaa520cdbc9b755',
		'phpmailer.lang-ja.php' => '968f59316c825ab90b3f1431f09d3008',
		'phpmailer.lang-ka.php' => 'abcbe353f7be96f34b3be82f2b5ae165',
		'phpmailer.lang-ko.php' => 'c08453d57359461a1a75ced9274b53c4',
		'phpmailer.lang-ku.php' => 'fbb1949b3d8637d0ed2c35599604ec28',
		'phpmailer.lang-lt.php' => '178755729f1beca82cdcd04dd303ee14',
		'phpmailer.lang-lv.php' => 'f4d42c46342b063daaf2fda2327fd73f',
		'phpmailer.lang-mg.php' => 'd0cb3ee747ac507b4462040182fe71b2',
		'phpmailer.lang-mn.php' => '8ef3d86ebc75205206361c3f8071da15',
		'phpmailer.lang-ms.php' => 'db962e4d772286ab5bf486519e01ba9a',
		'phpmailer.lang-nb.php' => 'd646aba7af5ea1e438bde4c5e2713015',
		'phpmailer.lang-nl.php' => '76d9ad0bd7f77dd1c288f186017948b7',
		'phpmailer.lang-pl.php' => '159bd22abdd40929c6f5600167fdd43a',
		'phpmailer.lang-pt.php' => '3bd69947535a4c9b28a696e13ff8456d',
		'phpmailer.lang-pt_br.php' => '9bb0a869840b6384c0f92656d7949b4f',
		'phpmailer.lang-ro.php' => 'ed1295ab18d3633967e8370ee53467c1',
		'phpmailer.lang-ru.php' => '7903fad2ac2c7f52daaa5492bd54c71f',
		'phpmailer.lang-si.php' => '9300e56f2a44a0c6e8252bd24b935f58',
		'phpmailer.lang-sk.php' => 'e3f8e04425cfcf0a747d7af72270acfd',
		'phpmailer.lang-sl.php' => 'd2aa32a500988d5b30f1fee51986c92d',
		'phpmailer.lang-sr.php' => '3bdd72a788a44e7dd7eb1ed187e1fffa',
		'phpmailer.lang-sr_latn.php' => '58d820608e92efc825a4c8c48c4362c1',
		'phpmailer.lang-sv.php' => '9e036505de38e87027ad5fad499b0c1a',
		'phpmailer.lang-tl.php' => 'dd64adf62086e7e6edd3fe9fd134c594',
		'phpmailer.lang-tr.php' => 'ad054e7b7c9c203f3344a10e66125684',
		'phpmailer.lang-uk.php' => '75adc9f94e9b83b3a730d2ac0d3122e0',
		'phpmailer.lang-ur.php' => '04f94ca9ae693dcedd4db606e9dcda42',
		'phpmailer.lang-vi.php' => 'a9237164bb7213a7227e6863ed55ba5c',
		'phpmailer.lang-zh.php' => '7f1201cb6c0b7565e52242e29aac78d1',
		'phpmailer.lang-zh_cn.php' => 'db9d28e659b3100af182060c642a2542',
	),
	'/core/libraries_phartemp/vendor/phpmailer/phpmailer/src' => array(
		'DSNConfigurator.php' => '5266fbb7007bf2171952658828569461',
		'Exception.php' => 'a71506f3391cfc9d02e63b2bec8eefad',
		'OAuth.php' => '5e6e04df01293a01b50a5c4eefe67482',
		'OAuthTokenProvider.php' => 'e28da9540b13e9b4c84e95d8471bfbb8',
		'PHPMailer.php' => '8eb1776dbe8a662ddc48cd30a13927c8',
		'POP3.php' => 'f1ab45178676327dac3a83dd280bf3dd',
		'SMTP.php' => 'f186604236a3fac737ba43c34941d147',
	),
	'/core/libraries_phartemp/vendor/psr' => array(
	),
	'/core/libraries_phartemp/vendor/psr/clock' => array(
		'LICENSE' => '3158bb09d112563c27a1e90264088c16',
		'README.md' => '742862a05a657d101ccfac4d86b2e1f1',
	),
	'/core/libraries_phartemp/vendor/psr/clock/src' => array(
		'ClockInterface.php' => 'e23c225e2d5b3a8407e7553b2d54c852',
	),
	'/core/libraries_phartemp/vendor/psr/http-client' => array(
		'LICENSE' => '70cd1d4d5bb26324a567dd5c3c412cca',
		'README.md' => '46767ef17931a456cf9afb21b2fd12c5',
	),
	'/core/libraries_phartemp/vendor/psr/http-client/src' => array(
		'ClientExceptionInterface.php' => 'd9f8037f3a4db6507a68f8e79510a9b2',
		'ClientInterface.php' => 'af6d87f1e98bdb47e08868fe7c92d08e',
		'NetworkExceptionInterface.php' => '0c137a9d90d4c6e268237e4581d10b5b',
		'RequestExceptionInterface.php' => '8783ad4672b5c43ee336d9ee39801938',
	),
	'/core/libraries_phartemp/vendor/psr/http-factory' => array(
		'LICENSE' => '881e228f5e6e60e07b9475850cdc2884',
		'README.md' => '3ade754262691e8d62476c98553c3822',
	),
	'/core/libraries_phartemp/vendor/psr/http-factory/src' => array(
		'RequestFactoryInterface.php' => 'bc20f23ad766937dd73eb49d88ac43a4',
		'ResponseFactoryInterface.php' => '27f52c58c45f464b51d2cab37de693cd',
		'ServerRequestFactoryInterface.php' => 'e82cf80bfe53965e095c794b4833face',
		'StreamFactoryInterface.php' => 'b0b6836009855f699d5c7261d5f6bd5f',
		'UploadedFileFactoryInterface.php' => 'da7cf0c5417129abf979b24651fb0551',
		'UriFactoryInterface.php' => '26e6d42b76f7e330bdf8caddf338d785',
	),
	'/core/libraries_phartemp/vendor/psr/http-message' => array(
		'LICENSE' => '1b0b156bcf7972a5f131e1e461e84b30',
		'README.md' => 'fb10210ca1963c9e7f1431a3e82cfe1b',
	),
	'/core/libraries_phartemp/vendor/psr/http-message/src' => array(
		'MessageInterface.php' => 'a8ba7ef892037278c508627f16c68b0f',
		'RequestInterface.php' => '421c7276ef7eef0363794469b78b3400',
		'ResponseInterface.php' => 'f33e81c3fba8a20f93adc55a2058401d',
		'ServerRequestInterface.php' => 'c9212daf1529e2d0e2be4c19040c06c2',
		'StreamInterface.php' => '9ea091df21fd7fb9ecfe4f172b698602',
		'UploadedFileInterface.php' => 'c385ad2bfbd7af09a35331717d8a8b9c',
		'UriInterface.php' => 'c7fc8bd93d8d2faf8935dd1e9e7c0dd5',
	),
	'/core/libraries_phartemp/vendor/psr/log' => array(
		'LICENSE' => '1a74629072fd794937be394ab689327e',
		'README.md' => '0073e95256311bd375ebe2ed5fbc95e8',
	),
	'/core/libraries_phartemp/vendor/psr/log/src' => array(
		'AbstractLogger.php' => 'f4f4a8e37fa277257205aaab2cf1bfdd',
		'InvalidArgumentException.php' => 'e4b3a5099730b32367ee493a2a599824',
		'LogLevel.php' => '22ae61aa9351344ddaad2408fd59a9d0',
		'LoggerAwareInterface.php' => '428b33adbaf3269b177ffa71db690782',
		'LoggerAwareTrait.php' => '9db4f2e47891bb35247a7469fa832934',
		'LoggerInterface.php' => '447e32576b77e38c19e881368450084c',
		'LoggerTrait.php' => '19b4386e4a2d0a4901abf0d3939b4a28',
		'NullLogger.php' => '6b7c99167287341581a409cdc36d3ca0',
	),
	'/core/libraries_phartemp/vendor/ralouphie' => array(
	),
	'/core/libraries_phartemp/vendor/ralouphie/getallheaders' => array(
		'LICENSE' => 'f7786f46efa7706a39adcd5b5e1ec2c3',
		'README.md' => '94653dfef8ea30f7a1e0b51684e5b565',
	),
	'/core/libraries_phartemp/vendor/ralouphie/getallheaders/src' => array(
		'getallheaders.php' => '7234669142b61b6cef90088e0139570a',
	),
	'/core/libraries_phartemp/vendor/ramsey' => array(
	),
	'/core/libraries_phartemp/vendor/ramsey/collection' => array(
		'LICENSE' => 'd8624ad739f59d4e8ae6723847007147',
		'README.md' => '246bf0f364d9b885c70da2e4dfb4ba55',
		'SECURITY.md' => '06c6a4cfb6d45cbe1abfc18a99edc0c6',
	),
	'/core/libraries_phartemp/vendor/ramsey/collection/src' => array(
		'AbstractArray.php' => '9bef0b9340a6513790e680a54fa1ab15',
		'AbstractCollection.php' => 'ed678c1ee26f775a3190f92af7d0e049',
		'AbstractSet.php' => 'a88ae7f4c019919d997f7d59d3cf668b',
		'ArrayInterface.php' => 'be49528013bfc318d514e15eb5c05a02',
		'Collection.php' => 'b3884c86add5c6ec02bbd829b34b5f40',
		'CollectionInterface.php' => '809c1ae5ce25704354afb86a96817d42',
		'DoubleEndedQueue.php' => 'e5ad5bd68e4feb856bfac262133a495b',
		'DoubleEndedQueueInterface.php' => 'f0e15e68e9f49970eb2fab0cd85398bd',
		'GenericArray.php' => '779d753c1b0b5db0bf04e60ffaefd376',
		'Queue.php' => 'c85e777354b252a8d25f73624e477885',
		'QueueInterface.php' => 'cc50b21986024cfaf4b0be5bf1761db6',
		'Set.php' => 'c6859ef111a94e7f2405e92ca37694b1',
		'Sort.php' => '0f2ce71ea990bfdf2a68618e741ddaa9',
	),
	'/core/libraries_phartemp/vendor/ramsey/collection/src/Exception' => array(
		'CollectionException.php' => '45e51c32f034cae3ca5934a464873c57',
		'CollectionMismatchException.php' => '890098b6bf8bb4a2e6deb1ab018fb5dc',
		'InvalidArgumentException.php' => '4aa4e1aadbcc9267fc755297710f8cb0',
		'InvalidPropertyOrMethod.php' => '2ae5f3f1efb8ee1bc78167dc09bd4c3f',
		'NoSuchElementException.php' => '5ef7626db54792517cddb19efe0816e1',
		'OutOfBoundsException.php' => 'df6225a9accfc33ff5451b806013484b',
		'UnsupportedOperationException.php' => '188ba96efcf11d563aa2020a53faf18c',
	),
	'/core/libraries_phartemp/vendor/ramsey/collection/src/Map' => array(
		'AbstractMap.php' => '32c041b70ec34b44545b4deb9ff06a03',
		'AbstractTypedMap.php' => 'fde8ad522df444f6d3e1cb787b49bca1',
		'AssociativeArrayMap.php' => 'dcf411a92c57a0f067a06032a032e4d5',
		'MapInterface.php' => '81167598755705ed2390ecac3edd9fcb',
		'NamedParameterMap.php' => '439accb1a1dbad54ded0dc1a73db0212',
		'TypedMap.php' => '3eb31c2863fc6e55038a6194ae595c9a',
		'TypedMapInterface.php' => 'dfeae60288ca64faed5f67284dc31d44',
	),
	'/core/libraries_phartemp/vendor/ramsey/collection/src/Tool' => array(
		'TypeTrait.php' => 'bc525a7a2baf9326a4b15f7b8af7174b',
		'ValueExtractorTrait.php' => '93a18fc954942e029846ee729445e4a3',
		'ValueToStringTrait.php' => '09e125a1d162d19c24d2edd31a814236',
	),
	'/core/libraries_phartemp/vendor/ramsey/uuid' => array(
		'LICENSE' => 'ddbf44d0e12668ad8cd392e3c1cbbc37',
		'README.md' => 'ce58d4226a7b7421a71ee51d63951508',
	),
	'/core/libraries_phartemp/vendor/ramsey/uuid/src' => array(
		'BinaryUtils.php' => '74eeed9c87d556448573601236731446',
		'DegradedUuid.php' => '13ad248f1b93d9ba937f811f2da1ca57',
		'DeprecatedUuidInterface.php' => 'bd4adaada84d9c044e634e8d5a996900',
		'DeprecatedUuidMethodsTrait.php' => 'c0bd750e87e356d421b37621b62f877a',
		'FeatureSet.php' => '79fb0ef21ccd447cb92c5d547f383984',
		'Uuid.php' => '4cce51dd49fcbdbf14024ecdaf14fa44',
		'UuidFactory.php' => 'ee95d21999fd0557ffe4c5b95eb3ad59',
		'UuidFactoryInterface.php' => '19fe97efcd197099d089c3ee7a08c5f1',
		'UuidInterface.php' => 'ea649e7031af15fbe225e6596439befc',
		'functions.php' => 'c2cf31d39b6d932f6ffbda6bb93c4a45',
	),
	'/core/libraries_phartemp/vendor/ramsey/uuid/src/Builder' => array(
		'BuilderCollection.php' => 'c4decd5e86a8160e74399248c58305b8',
		'DefaultUuidBuilder.php' => '36e55e0e371e15ba546c5d2536980b32',
		'DegradedUuidBuilder.php' => '562111c20fd174a9158132b6abb6d150',
		'FallbackBuilder.php' => 'f120c82c2216ba970f36ce68c8f3beb1',
		'UuidBuilderInterface.php' => 'dfb6b8f0f8d7a8e9ad3a4385ab70d3d4',
	),
	'/core/libraries_phartemp/vendor/ramsey/uuid/src/Codec' => array(
		'CodecInterface.php' => 'e30e9e6b64ca98d369060692a5ede7ef',
		'GuidStringCodec.php' => '34895bb89f1b9ab07641a98e9e71954e',
		'OrderedTimeCodec.php' => 'f3b4d4492c3155d27b22ed2166d751fd',
		'StringCodec.php' => '891b3418c467be3266141b410a533fe9',
		'TimestampFirstCombCodec.php' => '82961e7a8ab496c2cee635ad76dfad3f',
		'TimestampLastCombCodec.php' => '0d8491da82e2ad1c157e6c4c2d0789d0',
	),
	'/core/libraries_phartemp/vendor/ramsey/uuid/src/Converter' => array(
		'NumberConverterInterface.php' => '8c4688f44f2854a58728cc9cdce8342b',
		'TimeConverterInterface.php' => 'a9263e2132996c4716e384feddc11793',
	),
	'/core/libraries_phartemp/vendor/ramsey/uuid/src/Converter/Number' => array(
		'BigNumberConverter.php' => '6ed2ba0f63d3597931ca92fdb46871fc',
		'DegradedNumberConverter.php' => 'c7fe6bbfbc2a2a9870adbc8a47df3a61',
		'GenericNumberConverter.php' => '566675d5abdb3e91d63aa7e3c8ec7f37',
	),
	'/core/libraries_phartemp/vendor/ramsey/uuid/src/Converter/Time' => array(
		'BigNumberTimeConverter.php' => 'fbe610d1163f05cbf6247e53e62eaf90',
		'DegradedTimeConverter.php' => '17920f7c71efe01cfe14a1bfa7b6d211',
		'GenericTimeConverter.php' => 'fd7d62f08d6e0d8946effb6e2418d19a',
		'PhpTimeConverter.php' => '69c623dc2de5820476a03ff12cf4edee',
		'UnixTimeConverter.php' => 'f2ea07199ed2b029c4019c4e203a1e12',
	),
	'/core/libraries_phartemp/vendor/ramsey/uuid/src/Exception' => array(
		'BuilderNotFoundException.php' => '9565fdd37cd44420969e555c952ca346',
		'DateTimeException.php' => '8cd34f7687d5507240b0d7a87cadd935',
		'DceSecurityException.php' => '1e1d3c4eeb12304209a72c352a8b5338',
		'InvalidArgumentException.php' => 'cb7ef0c10011bd1fc5ad3ab9bdfadaa5',
		'InvalidBytesException.php' => 'e7d27af4617faff63d7a9b1f78b9f2d2',
		'InvalidUuidStringException.php' => 'e13dbbbe6f5b858fcfa93aaf3d85a05c',
		'NameException.php' => '336436a645023bdc0f7bee872c26c7a1',
		'NodeException.php' => '07c844e8a3c432cdb8ac015257486ed7',
		'RandomSourceException.php' => '5f90f5c8475459539c31ba898fd1109f',
		'TimeSourceException.php' => 'd792c861bf9c762bc6c9d431891b14bb',
		'UnableToBuildUuidException.php' => '655306b8e71eafb5ea71a14b46cba42f',
		'UnsupportedOperationException.php' => 'c40597857a3068b19d4e3b7507bf47fb',
		'UuidExceptionInterface.php' => '118887fe5d4ae5fc98182508b93dc8bc',
	),
	'/core/libraries_phartemp/vendor/ramsey/uuid/src/Fields' => array(
		'FieldsInterface.php' => '02863bf9295c9257d4f130912e4648ca',
		'SerializableFieldsTrait.php' => '24359687e7ce16da4f143644ba5d00f5',
	),
	'/core/libraries_phartemp/vendor/ramsey/uuid/src/Generator' => array(
		'CombGenerator.php' => '4442d2aa72b4279f06d9ec71a7c0636f',
		'DceSecurityGenerator.php' => '3e66ef8e5bb59fa0fed873e0003c61a7',
		'DceSecurityGeneratorInterface.php' => '8bf53f0b02675b5164ebcaee429145c0',
		'DefaultNameGenerator.php' => '46728a81c4da97d70d9bd07195720425',
		'DefaultTimeGenerator.php' => '8a26b36c08e70abac044a1bf162b0cb4',
		'NameGeneratorFactory.php' => '29ef8cade879c0b26ed02b08012da061',
		'NameGeneratorInterface.php' => '1fddd250f28697f33895d1e2c58e3e1c',
		'PeclUuidNameGenerator.php' => '56508ccc80cd0741455833f7b73a0f33',
		'PeclUuidRandomGenerator.php' => 'edb7e8ef583cae65bf883125144a65b3',
		'PeclUuidTimeGenerator.php' => '3ab28f42dd8e48719f0a84c9a810e65b',
		'RandomBytesGenerator.php' => 'b48eb143cb608ff590a97f1324822cb5',
		'RandomGeneratorFactory.php' => '105476c2d579c07ee2cb1e4ad35de22c',
		'RandomGeneratorInterface.php' => 'e6de4a578f02b8f9f3ba3a4c17c93b6a',
		'RandomLibAdapter.php' => '9e4dc5f29e616cea7187f366cb228a2b',
		'TimeGeneratorFactory.php' => 'ab2cea7ec6cdff37e71af600c5a8142a',
		'TimeGeneratorInterface.php' => 'af5c1cdaee79eb747c0f1ed14b9a5a44',
		'UnixTimeGenerator.php' => 'bf45b8495cae7ea97bc9d830c855f23d',
	),
	'/core/libraries_phartemp/vendor/ramsey/uuid/src/Guid' => array(
		'Fields.php' => '5199fe7501f2d541b2ac4ac4cf28b5d0',
		'Guid.php' => '821f288e3ff33f5ad1b6c79f7f36883c',
		'GuidBuilder.php' => '81df2404c370972dbc0d4e3a60124138',
	),
	'/core/libraries_phartemp/vendor/ramsey/uuid/src/Lazy' => array(
		'LazyUuidFromString.php' => '7e847d1024c894f764f7df96abce5bbd',
	),
	'/core/libraries_phartemp/vendor/ramsey/uuid/src/Math' => array(
		'BrickMathCalculator.php' => 'a9d74b8a60afca24415af0578cb03505',
		'CalculatorInterface.php' => 'c3f4713e1b764d7f45dad11517c84657',
		'RoundingMode.php' => '6eb2f1eb0afccd2dc53d4f6d9e31bd33',
	),
	'/core/libraries_phartemp/vendor/ramsey/uuid/src/Nonstandard' => array(
		'Fields.php' => '852617bedb60b7f22d8a0e9ad78a0434',
		'Uuid.php' => '2a3a50c7cb7e7915c4e2f0e7714c0d85',
		'UuidBuilder.php' => '10a85d04fe9f3658377f019d545882b7',
		'UuidV6.php' => '68ada3448d0635ff19486e892f97cb4f',
	),
	'/core/libraries_phartemp/vendor/ramsey/uuid/src/Provider' => array(
		'DceSecurityProviderInterface.php' => 'd79994f42140099f6937616ceefac778',
		'NodeProviderInterface.php' => '5bcd2c2724b4624bbe1505d375ce371b',
		'TimeProviderInterface.php' => '66cc5eaedd04b29904788da5ca254a08',
	),
	'/core/libraries_phartemp/vendor/ramsey/uuid/src/Provider/Dce' => array(
		'SystemDceSecurityProvider.php' => 'ed5d750e9efaf78fec98550bde378dd5',
	),
	'/core/libraries_phartemp/vendor/ramsey/uuid/src/Provider/Node' => array(
		'FallbackNodeProvider.php' => 'b5f55f2e096c00899e35e0da8f6641ea',
		'NodeProviderCollection.php' => 'f6c33ddeb8c5a6dc1523e344522a8c21',
		'RandomNodeProvider.php' => '3b814c285f70989ee91c591b29c0deda',
		'StaticNodeProvider.php' => '27e03ff74f28c0df8f423213afbad24e',
		'SystemNodeProvider.php' => '6a5b60f01127dfc5be2b935db16c9907',
	),
	'/core/libraries_phartemp/vendor/ramsey/uuid/src/Provider/Time' => array(
		'FixedTimeProvider.php' => '5dc9ae5e30ebc54d848906b61c294804',
		'SystemTimeProvider.php' => 'd2ddd092fd137a9bbc039af7cb604149',
	),
	'/core/libraries_phartemp/vendor/ramsey/uuid/src/Rfc4122' => array(
		'Fields.php' => 'a108d76575a309fc3ce2e5bfc76a04e7',
		'FieldsInterface.php' => '91ba8b7f555d01bcd39c04252782ec4f',
		'MaxTrait.php' => 'e7bd1d92e06a393441364cbbd8f130e1',
		'MaxUuid.php' => '5c77cfc1538b4aaa5f61af825d35018d',
		'NilTrait.php' => '2aae895da4c4d950c903345ffdb9a002',
		'NilUuid.php' => '137bba7d53717b9e86a2acc3a8b0674c',
		'TimeTrait.php' => '340e55fdfcadc01b14ae055ca4f51391',
		'UuidBuilder.php' => 'abd00d2959425c526950faf13e50be0d',
		'UuidInterface.php' => '474a3fbd71a56499257f545ca0d71d0e',
		'UuidV1.php' => '0b5d8a8cb8e40cb2799b30dc5202b6d5',
		'UuidV2.php' => '6ed3c00ce155133f0bfc3e0e5d1f2317',
		'UuidV3.php' => 'd321ab277e3d777ca2ff44304a311112',
		'UuidV4.php' => '81632eb7264a51d72065199bd49cca7b',
		'UuidV5.php' => '4c31dbd01f4716b1dea1a0ef20446722',
		'UuidV6.php' => 'bc89dce600ad3358830878767f3c961d',
		'UuidV7.php' => '9fc5ddc2cfc84e1bd8c250ca217d5889',
		'UuidV8.php' => 'c661dc563602084ee5f825cd724ffa5f',
		'Validator.php' => 'e42c714896c42fcc2c16c759cf98e4e5',
		'VariantTrait.php' => '82bdda3c1e1074607168238b8d80e106',
		'VersionTrait.php' => 'd0ba5a31bb946155673ccd13272bd46a',
	),
	'/core/libraries_phartemp/vendor/ramsey/uuid/src/Type' => array(
		'Decimal.php' => '2c7d819213b084219c8c6d9993d50b6a',
		'Hexadecimal.php' => '7a72be7181c2302cda18b1f779777a0f',
		'Integer.php' => 'ecd4041a65e3dd7ebb4c6a6a6528b727',
		'NumberInterface.php' => 'decc7565228bd01ccd49601a4d817f41',
		'Time.php' => '7e3a058c5f7f33dd5dbfab37bfda6621',
		'TypeInterface.php' => 'c96e1e8d948095aa511d11435317cdac',
	),
	'/core/libraries_phartemp/vendor/ramsey/uuid/src/Validator' => array(
		'GenericValidator.php' => '1ef53887608494f269b5996e4551221a',
		'ValidatorInterface.php' => '3f93de17fa4b6a600bb9594afe187edf',
	),
	'/core/libraries_phartemp/vendor/shopify' => array(
	),
	'/core/libraries_phartemp/vendor/shopify/shopify-api' => array(
		'LICENSE' => 'b57afdc3804fd2f6d4f4daf889421b90',
		'README.md' => '225135fab26d1caab28c67d4a03572ac',
		'RELEASING.md' => '7f648120d4a3d92074a2c0eab2e06610',
		'REST_RESOURCE.md' => '881afc82e00b24053411f66270006931',
		'composer-require-checker.json' => 'e4eea01a774cd35c47e9cdd8b12f7cef',
	),
	'/core/libraries_phartemp/vendor/shopify/shopify-api/src' => array(
		'ApiVersion.php' => '6441f8f59b94ebacc84b0869f1378b09',
		'Context.php' => '1ab16fe8044b28f2cb4533f62f8b4a61',
		'Utils.php' => 'fab1e978f5d6274c24669f189d275b29',
		'version.php' => '5f7b56b4006fb8260c014567e92bee54',
	),
	'/core/libraries_phartemp/vendor/shopify/shopify-api/src/Auth' => array(
		'AccessTokenOnlineResponse.php' => '937d16407499d47a6a81a3a83791f793',
		'AccessTokenOnlineUserInfo.php' => 'a4c0dc4e84c9d3fc9736128266d694d2',
		'AccessTokenResponse.php' => '402eba445f5e77ab27541a5726fd2bfc',
		'FileSessionStorage.php' => '3cf07522fe73c6d3c3e2d77167b4364a',
		'OAuth.php' => '4dbb930d66c98be3a063b3aa1d2b1233',
		'OAuthCookie.php' => '5cae238f9bfa32495518775f49090498',
		'Scopes.php' => 'a8079b265379acd8450684bc782e7b5a',
		'Session.php' => '23af29748df009654713f3dfcdbaf8a2',
		'SessionStorage.php' => 'edee02375a7f4f0805fa0096e9688a5d',
	),
	'/core/libraries_phartemp/vendor/shopify/shopify-api/src/Clients' => array(
		'Graphql.php' => '340ced595bb7f2c276a08a8a1fae573f',
		'Http.php' => '315f91efde61867048c6837a3a288314',
		'HttpClientFactory.php' => '0ec34b807e7d7ea703f3c87e120a2cae',
		'HttpHeaders.php' => 'f9ae75a5593bc858fac52e594ae5dc0c',
		'HttpResponse.php' => '5a59e28b32dc08ab52cb1b282f204782',
		'PageInfo.php' => 'c5ce7331e6dc2381becd1ca93829c93a',
		'Rest.php' => '96f7b2e8396991d08ea04850b059f702',
		'RestResponse.php' => '6fb9dc4794bb45be0860e5604bf02d4e',
		'Storefront.php' => '461975bccd68717ba7d292075d66cd1e',
	),
	'/core/libraries_phartemp/vendor/shopify/shopify-api/src/Exception' => array(
		'CookieNotFoundException.php' => '977b3937968b8c07954110d6d54aa67d',
		'CookieSetException.php' => '89df2885f107cbe95718830fbdda7307',
		'FeatureDeprecatedException.php' => 'd30438cacb24af8548a5106b24419f00',
		'HttpRequestException.php' => '28e3f4503114dbf673a5b9847dd82e2a',
		'InvalidArgumentException.php' => '04a54a4beb1d199f78ead5e07ea39495',
		'InvalidOAuthException.php' => '0eeab87e1ffe05c4b41ed3d8927de61c',
		'InvalidWebhookException.php' => '348e22cc1e25d34afa05f88a0922694a',
		'MissingArgumentException.php' => 'fe4acaa5689354fef3df5e76970ccd24',
		'MissingWebhookHandlerException.php' => '381be80c11079ae0567dd2f6acc2df60',
		'OAuthCookieNotFoundException.php' => 'e77a08f8042444b440ad4345cba8314f',
		'OAuthSessionNotFoundException.php' => '9eb7f6c428cac11305e71b9b9b02b184',
		'PrivateAppException.php' => '2adf322023d8262bb37b45e060e007d8',
		'RestResourceException.php' => 'c6647e397229fd89cca030c167831b56',
		'RestResourceRequestException.php' => 'e117594ad9d25d8734069b3d4d144d41',
		'SessionNotFoundException.php' => 'a5a045db623f68164c086765f68f2a07',
		'SessionStorageException.php' => 'cedb70d42eb1fe1ba79b42cc7e790eec',
		'ShopifyException.php' => 'fe364684081fda2b7ee94647070b0aee',
		'UninitializedContextException.php' => 'a5267457571058e7edccd46def9e08cf',
		'WebhookRegistrationException.php' => '294957e9fafc7ad6d1b1b0778895b0ed',
	),
	'/core/libraries_phartemp/vendor/shopify/shopify-api/src/Rest' => array(
		'Base.php' => '9f1fc1b9dce3d90370fa9b694500c858',
	),
	'/core/libraries_phartemp/vendor/shopify/shopify-api/src/Rest/Admin2022_04' => array(
		'AbandonedCheckout.php' => 'eecf62bbae025b0a72b47888841f250c',
		'AccessScope.php' => '4a04bf2dafa99ff7cde8fe045ea9f27a',
		'AndroidPayKey.php' => '96b33af0cb441b31ff5421c37670dd10',
		'ApplePayCertificate.php' => '554eb47a9c66a3b1c004fa4428bcce6c',
		'ApplicationCharge.php' => '387bcd057a2882470fe7f994bac2108d',
		'ApplicationCredit.php' => 'c14929c44b8d6a49e4dd54f28447251e',
		'Article.php' => '4d8fc3d5c1a72a24a616782318ce0743',
		'Asset.php' => 'c5f1feda4257f1351fa74c2f8faf2d35',
		'AssignedFulfillmentOrder.php' => '2e9d36ade6367b59f3513e1f79bb43e8',
		'Balance.php' => '5baf115eb0d81413c7363360eda28106',
		'Blog.php' => '1114f529f07ee2b9099cfac36bcf103d',
		'CancellationRequest.php' => 'd0bd697d8ea5331a57d485c76f7a18ed',
		'CarrierService.php' => '3b19122e40a94e68d607a04fab719775',
		'Checkout.php' => 'ae88a474f8a8e31cf6ed1c1687cceb96',
		'Collect.php' => '34efabf1fc60203e97e201af135392d2',
		'Collection.php' => '3ae0215f0e5418aef0ad511d36b20a8f',
		'CollectionListing.php' => '78923e4ab73f8d77ef46c7e99b3d88c0',
		'Comment.php' => '3099bd1574f32ede90c927f1870c0a67',
		'Country.php' => '247b5dbeb845dbf80817e5d2b2e047f3',
		'Currency.php' => 'eb147888291fc0617553bd7d567932ee',
		'CustomCollection.php' => '7522fdc306ef708ec9efc630660b1b06',
		'Customer.php' => '2344d0199486905d425591303f3282a4',
		'CustomerAddress.php' => '6faf074a76f5f6f63489edad411fc461',
		'CustomerSavedSearch.php' => '237b2bad6ea6bf63006ad84da20d5c96',
		'DeprecatedApiCall.php' => '4f4f5176e1f6082bfae0481d01220f12',
		'DiscountCode.php' => '6ed739f3479d6f802d75f05d2609deda',
		'Dispute.php' => '572b28bc1eb6259a3a96acc9d067b3ab',
		'DraftOrder.php' => 'eedeee65cd02daea899581f738b3ae48',
		'Event.php' => 'e8cd83346ca66a09ec30496d8e9e15ad',
		'Fulfillment.php' => '0ccc7698a6457c3c393c7a9e45fd1486',
		'FulfillmentEvent.php' => '9c2c1ae3dc072a747caa15a4a8d1dd48',
		'FulfillmentOrder.php' => 'ea2f9c22980627fb4a477fabbdb5150f',
		'FulfillmentRequest.php' => '710928922e5b97b3c1d4d4ccd9976246',
		'FulfillmentService.php' => '7a1a5ae58fdf0bf45093eb9ca28f247c',
		'GiftCard.php' => 'f34a0eb8010afc6c6aa9d99caf39e911',
		'GiftCardAdjustment.php' => 'b09d2468317729dcf40a6dbed472580d',
		'Image.php' => '6ab87b1dc97b18a8cbf2c180cc41c4c0',
		'InventoryItem.php' => '7e114e0634bcb97aeeaf170e6a73f80a',
		'InventoryLevel.php' => 'a91e15b0ca56e7a2eae5f9072b5ef3bf',
		'Location.php' => 'bb3cf4350ab77366e9d67ae9fb58e765',
		'LocationsForMove.php' => '802fbeb54ab795dbbaf2e4a952e97823',
		'MarketingEvent.php' => 'de5f43f2961ad79d04a4970f3f0c795e',
		'Metafield.php' => 'bcc3d093d1f0891d6786c9d3266ccff4',
		'MobilePlatformApplication.php' => 'ec0cd9b572b1bf2f1c7f3c8255cbcfc8',
		'Order.php' => 'c12e14b79044525c3eeb25b8e0f2b1d1',
		'OrderRisk.php' => 'd10455182510218850c6e9cea660a763',
		'Page.php' => '823666e31c0b9bb28cab7d951bc8c758',
		'Payment.php' => 'b2be0f4600f2044eb6e563e89f9d350b',
		'PaymentGateway.php' => 'f87e8163891b71b014ab779e328e0a2d',
		'PaymentTransaction.php' => 'ab4729b01a9b1a592d72466a079c18ac',
		'Payout.php' => '149939c6bdd77cad02fbd841dbdbb6ba',
		'Policy.php' => '6364e07f0dc4aba49c61314bcdf528bc',
		'PriceRule.php' => 'c10237e7350c8ee0fa9bfb4cf12099f6',
		'Product.php' => '8749eae3172bf5a40b2a9f7683d5ccc8',
		'ProductListing.php' => 'f55bae7b510d68cb6c161d3f4bcc0ea6',
		'ProductResourceFeedback.php' => '9c5e655d61c90911ad1225ae344b2a61',
		'Province.php' => 'eaef62c5006019ef28e073d0b72dbb81',
		'RecurringApplicationCharge.php' => '2f9f5e3c502b560425774f4689514e0c',
		'Redirect.php' => 'da7de98999565a6ebc0c8f418a309964',
		'Refund.php' => '05529dfaf1cc31b3e21861f4247499fa',
		'Report.php' => '8ada350f0ff37a1a28c69a2eb7e17688',
		'ResourceFeedback.php' => '4b5551e33dc05e8c4658a40521d52e5b',
		'ScriptTag.php' => '35c087312797c8f7fb7b64236dc55652',
		'ShippingZone.php' => 'd31691c8e7878934f56df25b92e27f6f',
		'Shop.php' => '344a6d85afee16050e1059161822268b',
		'SmartCollection.php' => '9f3956a61a876cdcd4c3a0f2f289a1a3',
		'StorefrontAccessToken.php' => 'a08d17297c8ec30e21a8b695f20464f4',
		'TenderTransaction.php' => '2a6474cdef3372d75e7211e7c93087f9',
		'Theme.php' => 'ff3c8ff90858d144083a1605147387dc',
		'Transaction.php' => 'c8698baf52110e4c25cca74cc00ab90b',
		'UsageCharge.php' => '3f02e176ec81d5f295b650457affa354',
		'User.php' => '678c867c313667fb39872341d8b0dbb3',
		'Variant.php' => '4fe3971f2fba3aca32f809709501a149',
		'Webhook.php' => 'cee84853e5ebba2d4985d95849fc46dc',
	),
	'/core/libraries_phartemp/vendor/shopify/shopify-api/src/Rest/Admin2022_07' => array(
		'AbandonedCheckout.php' => 'e4365a702715446e15080e7911d3dd88',
		'AccessScope.php' => '87cedf243371a12f0cd07bdbc442532f',
		'AndroidPayKey.php' => 'da46020f6490c813c6ccfaf32fdff0d0',
		'ApplePayCertificate.php' => '5f142621b09d62c9685a856b810a39d4',
		'ApplicationCharge.php' => '1f8836c4d65de95d0458749fa30e3c94',
		'ApplicationCredit.php' => '7e28c707f3528d0f9f7edf58cc9e5d8f',
		'Article.php' => '348029d5cb110917c27b5da2c3309dd9',
		'Asset.php' => '3edee1a3ad2a2998bc15d878a54773a4',
		'AssignedFulfillmentOrder.php' => 'fa02448890b812537db5bbf1dc179d91',
		'Balance.php' => 'f494c92befa964cc279d3406e71362d3',
		'Blog.php' => 'd627b3528a2fdef7dbab201484ee0c91',
		'CancellationRequest.php' => '1f916544d0e54c4e98a1ec56de31d3cf',
		'CarrierService.php' => '2e1a9ec64b96849916e13ff3cfbd7eeb',
		'Checkout.php' => '127269912fa0dac7dbf313cb12e968f4',
		'Collect.php' => '6efbd37695255911e4dbd79b5ab50f81',
		'Collection.php' => 'cd59e090522cb88c4c70a445ce98eadb',
		'CollectionListing.php' => '97c9f0525e6628aafb1c461243b5627c',
		'Comment.php' => 'e72bfc513f544c1c7db841daed499d8f',
		'Country.php' => '426738337be47a9701491ff5ae7aa495',
		'Currency.php' => '8d8902847d3e85d8fc16c05a9e88ce40',
		'CustomCollection.php' => 'b2398f74b403b5acbc304f53b2a9335f',
		'Customer.php' => 'fd30fb91ae826d4988192b115f4d894e',
		'CustomerAddress.php' => 'ae1bafcdc234f1b1d9ee442ea8f19cab',
		'DeprecatedApiCall.php' => '269343bd1505db6e03712f8a819db84d',
		'DiscountCode.php' => '9c4fcd067accbcdb8424c1919e93ec28',
		'Dispute.php' => '92f094d191a7a08c6a748e3fc40f1ef8',
		'DisputeEvidence.php' => '52f2a3c9bd5d7aa59014a7b2904e3766',
		'DisputeFileUpload.php' => 'c59f0a464a480953957d7dc5640ea02c',
		'DraftOrder.php' => '4ed3c00059d8bdff06049819d81e96b3',
		'Event.php' => 'f3447219f6bf2a7f421907dd7c1aa4d8',
		'Fulfillment.php' => '91947ffa1f9d0a429e5d217c62c4281f',
		'FulfillmentEvent.php' => '3f69386d93b63c91bee169f068dca1c8',
		'FulfillmentOrder.php' => '22ef1b41972d301aab35b16d5d62941f',
		'FulfillmentRequest.php' => '008399ea59b053b2844bfea4be03143b',
		'FulfillmentService.php' => '7af7e5cee7abfa1244dc92f256065e05',
		'GiftCard.php' => '7dff76930155a9f1c09bff0bc4434b1e',
		'GiftCardAdjustment.php' => '371022e24d393aaeb6c16e775e1ba5cb',
		'Image.php' => '39e9c3c27e8eecade2f40ea68102eaca',
		'InventoryItem.php' => 'c806de9c4800b744345e0169b23261d8',
		'InventoryLevel.php' => '015f4d6d90831f683fb79b18c05b1fc5',
		'Location.php' => '96ac9285ca26bc5fc445ce061bc8275c',
		'LocationsForMove.php' => 'e6e08e1c5fa4f125a9fcd92fb05871f4',
		'MarketingEvent.php' => 'ef5608e3e03c1ea36ccf67d8258aad1e',
		'Metafield.php' => '5777cad7148d769e807c754c657a9386',
		'MobilePlatformApplication.php' => '88ea980dbccfde766919af6fba56045d',
		'Order.php' => '216892c587bcd8d7fb17d78ef8cbefd4',
		'OrderRisk.php' => '915362ddb7bcee146b5896e34b10a6da',
		'Page.php' => '26ca60de602ddb5fb4074c2b25c1615c',
		'Payment.php' => '7e6cb6af7755b13f82a75109c5afba33',
		'PaymentGateway.php' => 'a9ce832a25c933cd17b102d10b2ddc68',
		'PaymentTransaction.php' => '377a8761140b84dc468995e791473889',
		'Payout.php' => '5c4a86cb61d6124db05fedf05dbef40e',
		'Policy.php' => '78225a3a9487625667655583f5016bf6',
		'PriceRule.php' => 'ea2e1a04aa363eadf54ffd70b1c0d37f',
		'Product.php' => '32ab0b689aa8e29fc694e475434f7b1e',
		'ProductListing.php' => '49a9a370cb9a5776da2978cf6af1789e',
		'ProductResourceFeedback.php' => 'b1ec3f582e7ea7d3e68f5607b9601d54',
		'Province.php' => '15b735d020267b174b7ca8cb209c7215',
		'RecurringApplicationCharge.php' => '9c82a2b6eecfda97567f54afef9ffd7a',
		'Redirect.php' => 'b234f32f3276ed56cff1da1a92560a62',
		'Refund.php' => 'aefbba4eba9bbfc7d142d58a01aea618',
		'Report.php' => 'a114ed75a494c58423d59f94eb476593',
		'ResourceFeedback.php' => '8d3354a741b115e20967a9e1f99c7cde',
		'ScriptTag.php' => '1a396db602130262697ed502be5b1917',
		'ShippingZone.php' => '2a20c1bec35b737ca98cf0161baf44cf',
		'Shop.php' => '782da273351b6ae859aa2a2d337f1ef0',
		'SmartCollection.php' => '9d523b032dcdc1ca1fc3caa0f04ff04d',
		'StorefrontAccessToken.php' => '689aa3659782c565de9f6be4da04150f',
		'TenderTransaction.php' => '86a0e247ddd4233aab545e701fac4e93',
		'Theme.php' => 'a16fe4a3cb6658d8f24c3c8d82dbd1de',
		'Transaction.php' => 'c2a0d87c691ccd4f00937baf14dc6e43',
		'UsageCharge.php' => '156946ac689a7963d5ec00cec2726ee2',
		'User.php' => 'ce7c087820ab5d782b5dbfe3f658cb04',
		'Variant.php' => '941d2b6aeafab27b76a0391c45b1a0ff',
		'Webhook.php' => 'f825114031ef63b514e7a6b2d18c489e',
	),
	'/core/libraries_phartemp/vendor/shopify/shopify-api/src/Rest/Admin2022_10' => array(
		'AbandonedCheckout.php' => '996b477fe48274a2bd7ba50724087b5e',
		'AccessScope.php' => '1b3b24f8bb2b9a74fab7aa7fea657d23',
		'AndroidPayKey.php' => '6bad7b5ef8637df542ba878c536d5cf1',
		'ApplePayCertificate.php' => '91747561ee6e31ef5f8546c4d093d231',
		'ApplicationCharge.php' => 'acb27920539de68b56507eb5775425c1',
		'ApplicationCredit.php' => 'b83935dad3ac13c6284452990266c8db',
		'Article.php' => '51dca357a7edd9615730878b27e935df',
		'Asset.php' => '36a034355c360085ba0e4b43a6413779',
		'AssignedFulfillmentOrder.php' => '78750a71698fefcea9dfee2c0b2751ea',
		'Balance.php' => '13174b991cf16d6a30db7ef8989c24fa',
		'Blog.php' => '415f23233f3cc0df553a6084d46f4bbd',
		'CancellationRequest.php' => 'a92c244d586501ad3d87c792837665dd',
		'CarrierService.php' => '70ac4810fffbeecdb2df0c40f601854d',
		'Checkout.php' => '0163b10ab8842b408b9b22d8abf158f9',
		'Collect.php' => '4ea646d697d5a35f4589238d797c46e1',
		'Collection.php' => '30a2388b257c03d744acd49d07ff91cc',
		'CollectionListing.php' => '22f4c189dcd9602dc37a05f4e181f71f',
		'Comment.php' => '398c1e5356627b28f3aff17ab82ccc82',
		'Country.php' => 'aa8cc1302720f4bf3697b15144741e86',
		'Currency.php' => 'aa4e8ed7f9877bee76252f4b2fb53d87',
		'CustomCollection.php' => 'c5f623f922343a2778ec889f6f7138ff',
		'Customer.php' => '03dbcafad5ad00cb47fd6c2bdde50782',
		'CustomerAddress.php' => '46faec624f9996621baed31b7cf98968',
		'DeprecatedApiCall.php' => '79df0fb6421116ac4176ee655939e079',
		'DiscountCode.php' => '1b1dfa183be4e4d793b6c86375c26c67',
		'Dispute.php' => 'b82401c6a331faf5fa2439616c572845',
		'DisputeEvidence.php' => 'c893e868b93bcded20753218a6263711',
		'DisputeFileUpload.php' => '0155b4f530bee56992f2b35d0aa75eb1',
		'DraftOrder.php' => '67effe53a2e0bc4098b516bbff395bab',
		'Event.php' => '9df2b890aa2b285407e39dc7c1c766ad',
		'Fulfillment.php' => 'c18095928d0d18f3d52d19db67e4dc0e',
		'FulfillmentEvent.php' => 'd13c4e97172c2d083ed9fefded8340ad',
		'FulfillmentOrder.php' => '143435e941ab8b4dee9bdace5677a3ee',
		'FulfillmentRequest.php' => '1b4169c9b8a7cf7f1095f790f20df5d9',
		'FulfillmentService.php' => 'c144b458a1a21045a189252e650bc32b',
		'GiftCard.php' => 'f831e2af63b90d31274cc6d04d9dd145',
		'GiftCardAdjustment.php' => '16dcfae6486e8c6c575e7bc58cf47c00',
		'Image.php' => '728549b3b41cad338c9b72a40c3b9df4',
		'InventoryItem.php' => 'da1c9bbe4fbb99f0838e0c6a38ccc1cd',
		'InventoryLevel.php' => '5420772ec9b40969b88ce73d1fc08fda',
		'Location.php' => 'a94914d750c28e05009646276671ae94',
		'LocationsForMove.php' => '6c803f68b3573f1748e412ec6036c444',
		'MarketingEvent.php' => '40d9d8be2de9bd2f48dd13ceda1a92a5',
		'Metafield.php' => 'e751c97ebcea68789e17f5a96af0ce3c',
		'MobilePlatformApplication.php' => '2ad712b58bed99f649a39661e7a0ef3f',
		'Order.php' => 'a7f5a6130cfde6ef2901ba3b32442129',
		'OrderRisk.php' => 'df60921f23618c9a056541f5050202c1',
		'Page.php' => '144f640dde047a39046eceac868c7274',
		'Payment.php' => '36a7a53fbfe66f9e628247e0a6833fc0',
		'PaymentGateway.php' => '71df02e7677b9176599db35b4f64134e',
		'PaymentTransaction.php' => '27aa19ae5c8d1bfdf43628d4958e16c1',
		'Payout.php' => '726dad76701d4e39d05c1ee20a761798',
		'Policy.php' => '216b8aebc9b5ea5e412398429409d5ae',
		'PriceRule.php' => '4a4ccedc07981090109d1b54b18b5f63',
		'Product.php' => '41ee5b3ee4d2e381e07fd27d3f9897ad',
		'ProductListing.php' => 'f5485230965d262646be8f9907034a6a',
		'ProductResourceFeedback.php' => '534e72a1db03f549a31ff4ad64e570e1',
		'Province.php' => '98e550bbbcce7a4a81cd12d5917b4331',
		'RecurringApplicationCharge.php' => 'c9ed970584cbfe8b4c41e6b38359bc8c',
		'Redirect.php' => '1d140e642b9591c1e879b8eb43ceca05',
		'Refund.php' => '6642a818c246e9548be311d1b0fce165',
		'Report.php' => 'bf23914ef7243c6d05fa4fe7e442e331',
		'ResourceFeedback.php' => '3cb0a5ffbdf56a8763f335435cee88a0',
		'ScriptTag.php' => '9a8b71cb04d48d21618450ec9c15aea2',
		'ShippingZone.php' => '8ae4d3d2dbca3dbd2f45598f2a515a7e',
		'Shop.php' => '7d101f55e6ce6dadb70523151f75872d',
		'SmartCollection.php' => '00641f2c144e0484426c5ae7f0437e4f',
		'StorefrontAccessToken.php' => '4b00cb8b97328571b3249adb39dd9194',
		'TenderTransaction.php' => '74326917d28f960db8e91cbcc33150ea',
		'Theme.php' => '08691ab5ab0219758e9a0b3b43f940bc',
		'Transaction.php' => '9a00dd0cb0408059730e883abca59440',
		'UsageCharge.php' => '09cb7eb3ccc5a234f2473e7a25d8088b',
		'User.php' => 'b653d574ce8deda5c16dadea77cb8e7b',
		'Variant.php' => '7d56140b59771d4f49e5c59102d8f7a9',
		'Webhook.php' => '47c1dc056974f233048f0062d3192fc7',
	),
	'/core/libraries_phartemp/vendor/shopify/shopify-api/src/Rest/Admin2023_01' => array(
		'AbandonedCheckout.php' => 'b6368964a1ff22f41585b4d1ca288df4',
		'AccessScope.php' => '76cbfb20fcb0a6cba15c30bfebc12b5f',
		'ApplePayCertificate.php' => 'b1d54e996d0eaf8745720bc543dd8a0a',
		'ApplicationCharge.php' => '076c7b8666d8f02bb58683d35c53da12',
		'ApplicationCredit.php' => '18ad5cd4a83dca2bb765be81d6d7b95a',
		'Article.php' => '2fcfe09dcb10fdaf92b916a9fa65e171',
		'Asset.php' => 'dc2e808fa38a18a38e8ee6aa0b5e5982',
		'AssignedFulfillmentOrder.php' => '571abc6a8165165d821f62b5f7a37e8f',
		'Balance.php' => '3a75fb90852ed53bc7f6aa3b834f4b52',
		'Blog.php' => 'ed991ccc4424306d99f5cac74a524770',
		'CancellationRequest.php' => '3e585a3dde8be95630fe86cef727bb81',
		'CarrierService.php' => '6d3d89f9a2a5c5b1d672fe392419c9ce',
		'Checkout.php' => '0f08d83b3b81f03536d62200f4222e9f',
		'Collect.php' => '1a37c79ef49489a06f1648aa3569ec14',
		'Collection.php' => '44cf783fff072e38ffc3bdace7c1eb1d',
		'CollectionListing.php' => '1ec06678dd21c1ce7a0d8449734f1d90',
		'Comment.php' => '624342b373a8bcd366a4ed732fc346c1',
		'Country.php' => '1d34c3523ab922591a769b56008d1404',
		'Currency.php' => 'fd349ee8078174d8ceaafe4de6de9243',
		'CustomCollection.php' => '690de2419c263332aeee1c716cf38514',
		'Customer.php' => '9f6f96e3bc3c4e2c369c8f141aac7654',
		'CustomerAddress.php' => '744aa3aaf7179035ebe863a8518e829f',
		'CustomerSavedSearch.php' => 'ad2d63d3703f61339aa8d33d2697f250',
		'DeprecatedApiCall.php' => '4eb9d478aa8119c6f2bc72854c7e0ea9',
		'DiscountCode.php' => 'a4b09214af913c65359912bf5b1a384e',
		'Dispute.php' => '03062a59ad6a60b2cd922338b8cae4c1',
		'DisputeEvidence.php' => '11eb2edf68aa215f64a4cd65914d6ae9',
		'DisputeFileUpload.php' => 'feb515c9f21e7fa14f7394c297c490d9',
		'DraftOrder.php' => 'acc849056c4ed98d73a2f0bdbb8a8190',
		'Event.php' => '7d8240e236c57dc8796baf35565ddf67',
		'Fulfillment.php' => 'c745dbf1438eee2e8cbb94563ca4706b',
		'FulfillmentEvent.php' => '5b992db5ea799e3fe4e4760e79c22857',
		'FulfillmentOrder.php' => 'ac6d95edc5bc738c9edff1816e811377',
		'FulfillmentRequest.php' => '5c8c9b48e569afe3321ae4c5f778487d',
		'FulfillmentService.php' => 'e053f8444c4b0ea813ba5278ce98f7ef',
		'GiftCard.php' => 'bebb1e5163266480cd109cefac9868e0',
		'GiftCardAdjustment.php' => '2b4ed7c3a4ef10308dcc293c41406669',
		'Image.php' => '8bedd80d92562e353a15a08bd9411d66',
		'InventoryItem.php' => '7ca482853ea23884a3951f35d5420b37',
		'InventoryLevel.php' => '11265403d8c2a1ef00470ac85085b65b',
		'Location.php' => '02111ebca15c60445ea20dba353dc099',
		'LocationsForMove.php' => '62fa8b69e5629d900c25c29704baeb92',
		'MarketingEvent.php' => '442874f00269c1bcc138e130e2453227',
		'Metafield.php' => '13d6be9803329f8386ffade9c098323d',
		'MobilePlatformApplication.php' => '0aad2f6e7313f75a2470f0f8cf058c79',
		'Order.php' => '44d90a049d8b97060392b96009cceb57',
		'OrderRisk.php' => 'f1831a6ec53a4826604ff0fba1a53cf0',
		'Page.php' => '58cbb9173073e1f97b5ed45a747845e2',
		'Payment.php' => '513f8854d044ac198865e4b06dcf4d89',
		'PaymentGateway.php' => '2ee8ec98b1ccdf08dba2cd6d106d36e8',
		'PaymentTransaction.php' => '3ea0a6724ffb6d4e60ce6ff424448b9a',
		'Payout.php' => '63b6f564c5c054651d19431da8ecc856',
		'Policy.php' => '9785567224e8ac86adea55e332bcd994',
		'PriceRule.php' => 'f0ff86200723a6409999e4aa88c5e93d',
		'Product.php' => '2a2c91d1d4986d33d4cd9fc65cfb3ce4',
		'ProductListing.php' => '1080beabead6c846cba4a2d0c1451d56',
		'ProductResourceFeedback.php' => 'a6224b97c632ce1d454dfc984325419e',
		'Province.php' => 'e04c3e87db3420afa1ed59d0f600155b',
		'RecurringApplicationCharge.php' => '8f87a5600c84e874a4fc595f3b9192f0',
		'Redirect.php' => '666677c91d126a3921c6ef5e54da9e7f',
		'Refund.php' => 'c1ea441a8352c9edc98754840899ad1a',
		'Report.php' => '250fa301b45d1aa5a5616efe5359f1cc',
		'ResourceFeedback.php' => 'f20482f4c38160216530ba4e61870dc2',
		'ScriptTag.php' => 'cfb1108fd17c831fc3b288aa458fc74d',
		'ShippingZone.php' => '8386b07f2169c84e16bf4b8bd7fcab8a',
		'Shop.php' => 'c079fafb0be4566f539a72688593d9b1',
		'SmartCollection.php' => 'feb1924f09035fb9f5e9f7763cc2f902',
		'StorefrontAccessToken.php' => '8957b92be2386f699fbb325ade959cad',
		'TenderTransaction.php' => '7423267339329c0907821da47fb063a4',
		'Theme.php' => '8ea722e9ed4e1342361e70be8c75590a',
		'Transaction.php' => '569fd3f8a6c0660d8b63cb1ebc642c3f',
		'UsageCharge.php' => '0c362b6ba6bf373e49e46e1f9953e238',
		'User.php' => 'b3a4c7b3b303add8545d321a4cb40d76',
		'Variant.php' => 'a318e5604711a894436c7eeb85a33d58',
		'Webhook.php' => 'a90712f29798b032a4cafd5fee2a41d0',
	),
	'/core/libraries_phartemp/vendor/shopify/shopify-api/src/Rest/Admin2023_04' => array(
		'AbandonedCheckout.php' => '0cba6bdf7a2370bab0b4dd26382b4ba9',
		'AccessScope.php' => '3ebd735a7c438d1ccb0693a4983c9e7e',
		'ApplePayCertificate.php' => '5a8af2500134d94e4429b6cd2f71bada',
		'ApplicationCharge.php' => '76f758b1e89b7ea908b31c9098c005b6',
		'ApplicationCredit.php' => '3981e1c4745fbfd74f8411678a4321b7',
		'Article.php' => 'b4c18aa32cbbf2d57354bec9c611c584',
		'Asset.php' => '41692e9b24e95960390ce4b29991e653',
		'AssignedFulfillmentOrder.php' => '8ea916dce7066e171ca2d2f29967a838',
		'Balance.php' => '9f2741127d06f5758d7d28bfa90e4e6c',
		'Blog.php' => '33b26d6d6d76f66d565c1a6bb94e8368',
		'CancellationRequest.php' => '64c634a14a712fb05d2a8d3e535bb689',
		'CarrierService.php' => '0b986abbfd57805f846a521d8ef97852',
		'Checkout.php' => 'b9bcf82f71d335ec9f4d7d124fed5adf',
		'Collect.php' => '829517e8a6a008de48f438ec31f3b00b',
		'Collection.php' => '812801b0e2eeecaa7a696ca98aa0ea57',
		'CollectionListing.php' => '86a34bd8bbd55f5d3c4a2fbcbfbb954a',
		'Comment.php' => '1105f094e00df130904c2882c291dea9',
		'Country.php' => '9ed51244d450c167d7d4d986ca264cf3',
		'Currency.php' => 'b8b9b8c38d8ad9e34cf6c95c32624e81',
		'CustomCollection.php' => '01d4f82b0eb6780a45cf2735501db557',
		'Customer.php' => 'e5f5ae462c31560bddadfcafd6a79f73',
		'CustomerAddress.php' => 'afadd9e741dd1929cc37c98a57c338b9',
		'CustomerSavedSearch.php' => '669da9a2a63cfa97103a67d9c8d6e378',
		'DeprecatedApiCall.php' => '5588cc7a471c8c5b8979feb4260d1d78',
		'DiscountCode.php' => 'b39f4f69edfdc3bf1fd700220c48fd2d',
		'Dispute.php' => '9f311c4733ad44aab24de4fe3929725e',
		'DisputeEvidence.php' => 'e2f1a82b8d921ce28e7610b7b5dd4474',
		'DisputeFileUpload.php' => 'fae65859657c3c81b8b0fc3c21665d50',
		'DraftOrder.php' => 'e8370277bc9b00a9d5bf539497bc798e',
		'Event.php' => 'e9bcbd765230e47e98d05af073c1ea80',
		'Fulfillment.php' => '708ec81c4a2509d394f947f79a62b90a',
		'FulfillmentEvent.php' => '3c2f9e3dfa8eee1c101336a077df0154',
		'FulfillmentOrder.php' => 'a752c5f065ae1838954d49f91d39fb74',
		'FulfillmentRequest.php' => 'df0d9a2acd98bd53f9b7be3c32d385b7',
		'FulfillmentService.php' => '66739f1b0ef46eb722fdbeb843ff6ce1',
		'GiftCard.php' => 'cc3ac7dac5cdc799e408189963f0845b',
		'GiftCardAdjustment.php' => '839efcf4bbdc925cd5b522003d78f141',
		'Image.php' => 'db9e6627db1c19c859314b61df440465',
		'InventoryItem.php' => 'c3372089446fee482b2d9af1c5fb5a0c',
		'InventoryLevel.php' => '6bd0cff600c057482d4b986fbaeba96d',
		'Location.php' => 'ed9bae9a93fb03a12394a867b073c735',
		'LocationsForMove.php' => '5e4918b9b3816cc2f80e93a89a8f7766',
		'MarketingEvent.php' => 'fd6c0946b0668a0743f3023da2bfc989',
		'Metafield.php' => '557752603b52883747ab02d74543e2a5',
		'MobilePlatformApplication.php' => '906f2fec5635e03934a20a974df2d66c',
		'Order.php' => '133640d7caa67676a2b9689de2ae273d',
		'OrderRisk.php' => '3f5e318e869e4d62e5611cb64ce20f2a',
		'Page.php' => '995fb2a58d19d3e1f9853c43e9f52f69',
		'Payment.php' => '96deb8fcf304dc480017d40adc5dfc02',
		'PaymentGateway.php' => 'abd0bb9d8ebfdc750cdeab6943ca35d7',
		'PaymentTransaction.php' => '9af39ec49c6047eb7a0fa3e6dc9a422d',
		'Payout.php' => '30956ef3ea728587bc7ac55caa0ce3bc',
		'Policy.php' => '6e67e4fb9f276fc3f3fc7f7ffe4ffda5',
		'PriceRule.php' => '1316954864688ef65eb6339174a9780a',
		'Product.php' => '55a4771fc3f2f9a486828eef022dc6b6',
		'ProductListing.php' => 'e857d032e991516ae43241737139cec3',
		'ProductResourceFeedback.php' => 'a4ed2f96ced8388ab0ed93c3b49167b0',
		'Province.php' => '6701dad77abade79753549cc5acd6423',
		'RecurringApplicationCharge.php' => '6de1438787865b99e4e989da13542766',
		'Redirect.php' => 'bd78bf50cd4e4a04e70e1391515d073b',
		'Refund.php' => '58bf51a7949d5952f22340793d5e1508',
		'Report.php' => 'b0e9f687ff7ae9384159bf9242c639c3',
		'ResourceFeedback.php' => 'f42ed4b0afb5ddbe9f433929aec821ee',
		'ScriptTag.php' => 'ad28097bc18d7ae4c635252c8abfe862',
		'ShippingZone.php' => '0c581144a759dce5301326c93fd0541b',
		'Shop.php' => '9bb7bbac9cf91286cab6a7f355ec047e',
		'SmartCollection.php' => 'cff27404c492dd507ca846f8643f6d68',
		'StorefrontAccessToken.php' => '7d93a1ea2fc20391aec2849fde14dd56',
		'TenderTransaction.php' => 'ab243bf990ee6b4b4d84537885edaaed',
		'Theme.php' => 'f35e29ce2f3849bac62105553b3af5dc',
		'Transaction.php' => 'e76c740277924a6c8cd91ab83a166a7a',
		'UsageCharge.php' => '07dcb803d721ca7087fc462a548e852d',
		'User.php' => 'a15308fa4d437704260403b11bbb4ba4',
		'Variant.php' => '07b170231c03210ff597b6a4c6cb7fe5',
		'Webhook.php' => '9138e9e4f472a0ab63392f50804c6090',
	),
	'/core/libraries_phartemp/vendor/shopify/shopify-api/src/Rest/Admin2023_07' => array(
		'AbandonedCheckout.php' => 'ee619d6e2f8a2cb2632293ff8da9e674',
		'AccessScope.php' => 'cc2f04539415dfee82f29857d4480db7',
		'ApplePayCertificate.php' => '1e8b296419cb842947d9250b7ac5b786',
		'ApplicationCharge.php' => '5b3ae1a9485e981e369380f9955a196a',
		'ApplicationCredit.php' => '61867028d0823310159d75df8750900c',
		'Article.php' => 'ca18267e6a0db16a602ade8507662c32',
		'Asset.php' => '24c57a78ff09595b98d78a1c5e6d2fdd',
		'AssignedFulfillmentOrder.php' => '21455e1994382bf83543136fa72a64cd',
		'Balance.php' => '458132f9ab7040d24b0f06feb173bd22',
		'Blog.php' => '489ab8cbaecb2d23f50eeffcf846ec17',
		'CancellationRequest.php' => '39278ed87e0594d7ab06e8a15db2df9f',
		'CarrierService.php' => 'a06c803c55018fad2c3d12fec67d2c42',
		'Checkout.php' => '609e28fb764800c322d38c3f9379e697',
		'Collect.php' => 'c5bd0462c77f35c0817fbef2c6122484',
		'Collection.php' => '365b39393596c2bbb58910668c494c59',
		'CollectionListing.php' => 'dd3ff66144fabd9353eeb4a19688f16d',
		'Comment.php' => 'bd0e970803f3bae15fd15ffb4b536ac9',
		'Country.php' => '37719e5b460d1c94fb7087b61a92203f',
		'Currency.php' => '9d76fa14bf4839205b8e1b5ed9f36f42',
		'CustomCollection.php' => 'e58f6125d03d50a05a7e309e5258c234',
		'Customer.php' => 'eea76bf4b0472f0b6aa9db0153f555f5',
		'CustomerAddress.php' => '1d2179bd700042ea6b7d1633bc1a4ef2',
		'CustomerSavedSearch.php' => '05516ca7f2b558a9c1c92c715923f285',
		'DeprecatedApiCall.php' => '8fd4c78e97b6db12f95b21fb598eebe4',
		'DiscountCode.php' => 'fd7412e156dce9fcfdb0f02b5d2ade32',
		'Dispute.php' => 'b672bb2e7e5e1f139c8c489bbb87f8f6',
		'DisputeEvidence.php' => '069ef77425ce55d9f6bbaf8b621da32f',
		'DisputeFileUpload.php' => 'ba34326c811e2d485be06a2e8955ca6b',
		'DraftOrder.php' => '408962083e2f7a25edb549ecf032d3d2',
		'Event.php' => '33fcc6d62c6afe35c0ebbbbdf4d5445f',
		'Fulfillment.php' => '04a199464da5154561809a82536a9b7e',
		'FulfillmentEvent.php' => '8c6b8d0c2d728668ec03f75aed507012',
		'FulfillmentOrder.php' => '159887444f532faf18960c929a8a2716',
		'FulfillmentRequest.php' => 'bce388cc7c7279e3e0f7c1e9b3bdf0a8',
		'FulfillmentService.php' => 'e6627353fcbf8329b3308cb88ecdce4d',
		'GiftCard.php' => 'e5e424ef55c3f8a8a4689255ef4b6cd9',
		'GiftCardAdjustment.php' => 'c18dbb87e0478578bbdfacb90a104944',
		'Image.php' => 'dab094b1f4c49d2e4ae124ca7ae91c58',
		'InventoryItem.php' => '0d3f36c4eff3eba13535ca165a2994ac',
		'InventoryLevel.php' => '445e0ac2731374a00bb5af485f142428',
		'Location.php' => 'c0665450ae83e7fd3abc56b4932c6a35',
		'LocationsForMove.php' => 'be22a3967484b0c601e44d2ccdcaa282',
		'MarketingEvent.php' => 'd439040843317af34086a32600917711',
		'Metafield.php' => '1f56ad2bc7aeb9187d11168bc98d3b71',
		'MobilePlatformApplication.php' => 'c4f7494a0fff04ac27042438874287cb',
		'Order.php' => '9a518bfb8edbc8043d514f25903efb28',
		'OrderRisk.php' => '66a1e15400f271b822b8ae902f463125',
		'Page.php' => 'ef5eed37f35491b165c96e44f46beda9',
		'Payment.php' => '1497f3975115608ce6fb92c96482bddc',
		'PaymentGateway.php' => '6f342ff544c5b228d582b5cb2dddc3e2',
		'PaymentTransaction.php' => '4372049d901c8e493590ee8bfd214647',
		'Payout.php' => 'e3f49078a598efcbb3096738ef39b29e',
		'Policy.php' => '72325aca34a20f6e7e03776e8663dc1e',
		'PriceRule.php' => '6ce6b862cc5ffba95c21a02976feae18',
		'Product.php' => '5553012e214f441b96e9d1bf4215c14c',
		'ProductListing.php' => '5512dede114cdc4f1206be2b2d20806e',
		'ProductResourceFeedback.php' => 'b17bf436da496c86a2850507de595478',
		'Province.php' => 'ccb2c4ed5aa1edf81fc487b0966d0e2b',
		'RecurringApplicationCharge.php' => '8f8e65a9ea59e50050763513ba4f8c0f',
		'Redirect.php' => 'c44d6887ee1ec8c076596aa6842f56a2',
		'Refund.php' => 'a5b7ebb2fd7e760482f1e5a3ec149498',
		'Report.php' => 'f320f0475f935328d28fb50357dea7cb',
		'ResourceFeedback.php' => '8e0b8b8e8388b585cd893b80a45caa71',
		'ScriptTag.php' => '1138f2d13162dac0cca33dd4682c37a7',
		'ShippingZone.php' => '97d65f830af34a12d1a5f9b4ece269d9',
		'Shop.php' => '85ae7c6ea1f725d0703a42a8f496e296',
		'SmartCollection.php' => 'bb139c90ce2e2dccdf60cfabaa04b7f9',
		'StorefrontAccessToken.php' => '8f5cfdb6c10d8f2d341b047b6576b74d',
		'TenderTransaction.php' => '6f8df4d6fd48f61955a71636325c8d81',
		'Theme.php' => 'e3b6fe99125be1a7c8b595848e4e8b0f',
		'Transaction.php' => '3d0cc1455e54dcd44f33024403e7385a',
		'UsageCharge.php' => 'c2f21f1122cdba3ced56c30e410aeacc',
		'User.php' => '6753d0b2edcb181145e35f1dfba5bf52',
		'Variant.php' => '4123ddb79fd72a65025a5d385d2c954a',
		'Webhook.php' => 'fab641b4f38b7ba4d1c909657f938052',
	),
	'/core/libraries_phartemp/vendor/shopify/shopify-api/src/Rest/Admin2023_10' => array(
		'AbandonedCheckout.php' => '7819ed57d31b9407161e8825ff3c408b',
		'AccessScope.php' => 'a6dd883de98ce83e45102123d437281f',
		'ApplePayCertificate.php' => 'df82546d02770b54b0873995dadb81c6',
		'ApplicationCharge.php' => '9820ff4a8a19554fc295b37843664d75',
		'ApplicationCredit.php' => '9333818e1b654421046c2e0adc3976ec',
		'Article.php' => '5f4b3d77049e75db0bd6ef258f1e2dee',
		'Asset.php' => '3498fe43b36b644bd4f755d2107b6f4c',
		'AssignedFulfillmentOrder.php' => '79ecb502069ea0d7214d20cc255ae065',
		'Balance.php' => 'd7e2bff2cf7146e898db875f47b505ca',
		'Blog.php' => '9905f2fa00b80d1e8a4643008fd4a5a4',
		'CancellationRequest.php' => 'ad38fa8e3198dee65f96cd147921af0f',
		'CarrierService.php' => '542d6fd6c0933f1bc6a171c9311bd429',
		'Checkout.php' => '2ac88748b94c3d4fb9d113c471b282b0',
		'Collect.php' => '542ca8af669f6d80c2144a4097be3093',
		'Collection.php' => 'f85f9f24dadbc80fb485d53665991451',
		'CollectionListing.php' => 'cd435e277669aff16d65f6747882dffe',
		'Comment.php' => 'e5682125ff73e14505461c2f212d3e43',
		'Country.php' => '8b3d8024c7593b417cb6cc266f144dee',
		'Currency.php' => 'e51f94c63d2ee4d8e3cfb1fb72369f05',
		'CustomCollection.php' => '6eb27f1c7925ba74f8a71da1aaf7b367',
		'Customer.php' => '131a70656c2635bdc64ade1debb5a31f',
		'CustomerAddress.php' => '461379a9af7e6b51a6a9632606b68beb',
		'DeprecatedApiCall.php' => 'cbfd564e87cb86ed88341c23851fc9d2',
		'DiscountCode.php' => '49f0af92efc8d0ad414fc0a9139438bc',
		'Dispute.php' => 'fd50e2ec252aa0d6f7838217ab2b5c93',
		'DisputeEvidence.php' => 'c9b240e90bf88c48e667cb24dadbbd2b',
		'DisputeFileUpload.php' => '422fd5d411ae9fbe40cbc0ab696b06ce',
		'DraftOrder.php' => '707edf40e614924cd5b4f42205608da4',
		'Event.php' => '31808142ea1062bd5519a88781d66aeb',
		'Fulfillment.php' => '728e36b24f7ffe2ed1907da350b657e4',
		'FulfillmentEvent.php' => 'd035960aba28103ad09c48f1b3149557',
		'FulfillmentOrder.php' => 'ac76672edc0020c135ca2ca4e4554b23',
		'FulfillmentRequest.php' => 'b95a14a9714ddcd6f26f4a107bd4d768',
		'FulfillmentService.php' => '57a539a1b1d907bedffa1c3ec943b5b4',
		'GiftCard.php' => '8290cbb354c15d90af589df6b14fa340',
		'GiftCardAdjustment.php' => '1a95588ae4e63f0650663421abd4d1b8',
		'Image.php' => '90d81ef6adcf84f74be95115e8944f37',
		'InventoryItem.php' => 'd3e3a58a2a882d4cf7d967d426acb060',
		'InventoryLevel.php' => 'b87cb5d0df43b4b9a3704721e39a50cb',
		'Location.php' => 'd778370b108b38be725e23be4f9b8c03',
		'LocationsForMove.php' => 'a1c767c8d1a4cc7da21cbf7e44783b86',
		'MarketingEvent.php' => '3f50d8a7be2d49565db62997f4a7c8f7',
		'Metafield.php' => '55cd00769f0a1f9a4b14892a2ae26903',
		'MobilePlatformApplication.php' => '2257aa4a2c932e4b346ae8ab2ba204dd',
		'Order.php' => 'bae4d0c09ddad90da10784649c79ce20',
		'OrderRisk.php' => 'b7199b8663a64121a44c5443d5e4782c',
		'Page.php' => '71f4851c7eb2f380c6751a82cfadab98',
		'Payment.php' => 'f7927f3294d5dd6ec4e94c210cfc9f35',
		'PaymentGateway.php' => '0dde505fdf9e6ec95ef1528c61292d8c',
		'PaymentTransaction.php' => '97597e90bfc223906147843b183cc8ce',
		'Payout.php' => '9051eef43263ee17359c39b406d55f3c',
		'Policy.php' => '3e4aa6bb6a6e4d706c280d7add75f3c6',
		'PriceRule.php' => '0796a3b84fdeb46591d5436e35c4e286',
		'Product.php' => 'ab60928e17e6ae2cd815e214881ca25f',
		'ProductListing.php' => 'd338aad4b5a3f930932cc61bc2723085',
		'ProductResourceFeedback.php' => 'bf5a0bf92af416340cd1906cb803ecec',
		'Province.php' => 'b4224c1d129a1f6256e61f782f049ab6',
		'RecurringApplicationCharge.php' => '4eec317e83ce4eb21b64b57ecc23c0e3',
		'Redirect.php' => '31a459213db8c0ed10a0a606f8ce52bb',
		'Refund.php' => '078f1f539d4c09bf071e7c5344d6ceea',
		'Report.php' => 'f75cb297350f5b5882def1949495aed1',
		'ResourceFeedback.php' => '58c2d757e63123c3d41673372715f134',
		'ScriptTag.php' => 'e007294fa7180894de9c412c52f73ed6',
		'ShippingZone.php' => '5e043bb9d34929cdfb355f8cc29a15da',
		'Shop.php' => '81e21d6f4aaeb8bd7f71b4f211cc3105',
		'SmartCollection.php' => 'b5777c9669fc2c47aa6828099ba00985',
		'StorefrontAccessToken.php' => '57be11add92d5c9b46c2a17bc19614dd',
		'TenderTransaction.php' => '9354d984a68c099d4e8f0b7816a08c26',
		'Theme.php' => 'cb155b67033bcc2cae801c8d678901ce',
		'Transaction.php' => 'c98b6c11f1e8fdf2edd9f04682ec7062',
		'UsageCharge.php' => '35824e78757beebc73f0e483271037f1',
		'User.php' => '8be45216f09ff56dc75166921eaa16fc',
		'Variant.php' => 'e238c2aff9c6be2e27c96e65b2d44384',
		'Webhook.php' => '05d833b9f9ca89b77baee0d395f3e7a4',
	),
	'/core/libraries_phartemp/vendor/shopify/shopify-api/src/Rest/Admin2024_01' => array(
		'AbandonedCheckout.php' => '9fec8f70a02bb1559067bf564947dc9f',
		'AccessScope.php' => 'a22bc79d7e668a506f1148deefa43507',
		'ApplePayCertificate.php' => '68aa4065f18db4c2a2bddce24e7180e8',
		'ApplicationCharge.php' => 'eb1c1b86085ab19500b639aa2a4679a9',
		'ApplicationCredit.php' => '9792ae83028b202174dd1336ad603df2',
		'Article.php' => '824d3cbebca6dc983432f8bd8c2bb99e',
		'Asset.php' => '52452d3a6094e5e75cb665514fd8cd4e',
		'AssignedFulfillmentOrder.php' => '750893beca13719ec849acd737be7bd5',
		'Balance.php' => 'f37de9179e9a45ed44efe205d50cbf48',
		'Blog.php' => 'bffa515bad9e63a6bef65fbdc328ab71',
		'CancellationRequest.php' => 'cb32d9c26f15d5a5304a039ce91ebd0d',
		'CarrierService.php' => '7edc90ac37be10e2e0493e0253944a1c',
		'Checkout.php' => '1c704c3e4d3abcfa747333122904a476',
		'Collect.php' => 'e76d367679100e7a5f0607d2afb79b5f',
		'Collection.php' => '9cf6f82ebe5876cad070a09f906c0bfa',
		'CollectionListing.php' => 'ff84c5d9f71e1a795f119fd6fec6fe72',
		'Comment.php' => '86dbbee3f17c0396d3b629eb119770cd',
		'Country.php' => '3249c51c187203dbbc212cd0ea6217e6',
		'Currency.php' => 'd61c57a2c2bacee2fe9ccd7af26670c4',
		'CustomCollection.php' => 'b265b6aa0b72aab700942b8c1aaa9745',
		'Customer.php' => '67ce68b1aa2cfe69360671bb4df88b1e',
		'CustomerAddress.php' => 'a446b4c126044408b6f903e8245364ca',
		'DeprecatedApiCall.php' => '7412f0fac43c7b9e7656a11293f04a7a',
		'DiscountCode.php' => 'c0c404457293b279b5aa5e931f51aaab',
		'Dispute.php' => 'c403a13d5f9ef2e8493190ec1726fdca',
		'DisputeEvidence.php' => '59c41db5934d111686c44f72c31862ad',
		'DisputeFileUpload.php' => 'c7efbb0fa1f77ba6ddb9b1b16c69e9f8',
		'DraftOrder.php' => 'cfd49d80a0888cfa8d1669e0e479cd9a',
		'Event.php' => '0e1a69e0197ade403fe9b769dd02546c',
		'Fulfillment.php' => 'd2528dc1804e1141cc18c029ad755815',
		'FulfillmentEvent.php' => 'ce38318c13b02fa8de9b114f59de01d1',
		'FulfillmentOrder.php' => 'fc6b1c30f9caf923ac160684cfa21a87',
		'FulfillmentRequest.php' => 'fadb70df29455adb89a877e320cd8897',
		'FulfillmentService.php' => 'f467790350fe3ac628bf0279d0e393fb',
		'GiftCard.php' => '825f7f6d73cb2204784c8219fe52a89d',
		'GiftCardAdjustment.php' => 'eb823930289425e0ee8ecf7cfac2f8f9',
		'Image.php' => '8c85333e392449912f9908f68cdbf26e',
		'InventoryItem.php' => 'ef51709e669399c8f89f7a4e52d283bf',
		'InventoryLevel.php' => 'fd9c5a0d51b2b90c3df6cfb8a14d6441',
		'Location.php' => '1878c610907b9c27aa234d126ecd75a5',
		'LocationsForMove.php' => '4b7bbc895fc853e9441ec8c493ab65ca',
		'MarketingEvent.php' => '8deffb48ccc9ea7016ced577acb1f60d',
		'Metafield.php' => '166726a5b580a75633e49362119921b4',
		'MobilePlatformApplication.php' => '6a6af595fef7e4a20dfb1f0fd3af7fd6',
		'Order.php' => '72974cbd2915f736f8c8d46a3bac6c6f',
		'OrderRisk.php' => '487e726fb45274a588145dbab6e274b6',
		'Page.php' => '4a616d997607ea83bb9e8cbe9c38cf8d',
		'Payment.php' => '2104049a6fc79f641d3a6a0aa55c913a',
		'PaymentGateway.php' => '7f305fef906676ffb28bce334378b859',
		'PaymentTransaction.php' => '88531808aea806f3960d4a9ae503ac7c',
		'Payout.php' => '0c071d2e08781e19601648ff836b8171',
		'Policy.php' => 'a50fa99a288606c6098a239213cfdad9',
		'PriceRule.php' => '728eb0373bd666688f73c2a7332466fb',
		'Product.php' => '49b9575264e093d36ae0ce8f482c43be',
		'ProductListing.php' => 'e3dfaa487bcbc93b5eaf3d9db5d7019d',
		'ProductResourceFeedback.php' => '7277bfb1ff95acb3c2262ab5997a7f9d',
		'Province.php' => '52c0af852b7ecc6a7c7610cd4aed7caa',
		'RecurringApplicationCharge.php' => 'df5715a6a1f2d987d77de96348c84095',
		'Redirect.php' => 'b02f28dec0b89b44d8081e0f1c9ebec0',
		'Refund.php' => '7ee10c389e987572a70d9e10705d342d',
		'Report.php' => '9cef238b647e0173f92b4d4b04389172',
		'ResourceFeedback.php' => '5701310c5d33455584430b63a0f8e9b0',
		'ScriptTag.php' => 'd9752b7d25c235306e3a533782ba6508',
		'ShippingZone.php' => '6f4ba35ece2e23e82e009e24f05a65cd',
		'Shop.php' => '1d144401ddd394b578b3058270984a89',
		'SmartCollection.php' => '679941c26a0b285ea0ae0e650a9fbfac',
		'StorefrontAccessToken.php' => '980d73863669613fac68e74772e52180',
		'TenderTransaction.php' => '9422083ac5522243d33d665d38a4e5c6',
		'Theme.php' => '7d47aa6fac00c9fbe6ff506c69700b78',
		'Transaction.php' => '6c938cc3d7033802bec60252deefa23f',
		'UsageCharge.php' => '2868bcffcd0833c313d0aafffa789f14',
		'User.php' => 'fcc57187638434aa149afd1f508bd3a0',
		'Variant.php' => '5bf0f0a56a9a2813f7fb9e36ac4a4228',
		'Webhook.php' => 'ef0c29b2e65676fe85cf1b5b48b05ffe',
	),
	'/core/libraries_phartemp/vendor/shopify/shopify-api/src/Rest/Admin2024_04' => array(
		'AbandonedCheckout.php' => '78ca82307f0dbd471953edfdd19ff8bc',
		'AccessScope.php' => '0f9b3b7e593c9d5efc7288594dbebce0',
		'ApplePayCertificate.php' => '0bd2531e74a7468fe871a48d6599933b',
		'ApplicationCharge.php' => '2908844f4fa39ae8cc0bbaf1781eb340',
		'ApplicationCredit.php' => '129e697726e91acf9fba86d436e1400e',
		'Article.php' => '3746390c21307655caf825e7780f806f',
		'Asset.php' => 'c1db5961f1092761aae1bfaf52373ba7',
		'AssignedFulfillmentOrder.php' => 'f25d37817362cd0a8048f201337ee131',
		'Balance.php' => '5ba5fe06c741406a141734b82fed2248',
		'Blog.php' => '1529c8eb03580bcceef49464c6b4a3a1',
		'CancellationRequest.php' => '7775fe6e21047224df16063a4cc68f36',
		'CarrierService.php' => '6afa34379e4601697f00bb3b544af2b7',
		'Checkout.php' => '98082fcfa2ee7c5057ef684ba2d56a4e',
		'Collect.php' => '313b64aae6ffb4085f6232bda930f85c',
		'Collection.php' => '587376d8d4527d91c6ac9270308536b9',
		'CollectionListing.php' => 'c701cb3c12bf8a031d0a02b0773a1813',
		'Comment.php' => '507605610324bbe52a101b8ea83d16b0',
		'Country.php' => '4bc85dbef3141a05a1a36339e4d6f752',
		'Currency.php' => '5deb64e46de8f988a58f93346aa49261',
		'CustomCollection.php' => '5dda156d64075e3ae697fc78ddb0e7a8',
		'Customer.php' => '15873d4f9234b8a05eb6ef942e647445',
		'CustomerAddress.php' => '41d790a738fc7aa4165f0d1a7ae88244',
		'DeprecatedApiCall.php' => '3483a5ad0082b286d08cd67d95455fc6',
		'DiscountCode.php' => 'a61ad34627ff01a27560aad49f525268',
		'Dispute.php' => '1584a4f652036c6f0199a7afc3bc6e13',
		'DisputeEvidence.php' => 'b9c3775d90d884f73910d67470e85ad1',
		'DisputeFileUpload.php' => '7782104d1d76bf625a6ebfcd7c80664f',
		'DraftOrder.php' => '3ace9c8528a87044e4ed38544be5622f',
		'Event.php' => '29e2a621775e0dccc84d7e9f6f278b87',
		'Fulfillment.php' => 'eabdab31ab325b6df7f72bc6ebf9d22e',
		'FulfillmentEvent.php' => '901b55d354929c07d14b263487314be6',
		'FulfillmentOrder.php' => '3016c50766629f2d65cba26d4050564f',
		'FulfillmentRequest.php' => '1fe56560bce2dda7416313aa219290ee',
		'FulfillmentService.php' => '87539de02d8fe0a3b4bae906c05651e0',
		'GiftCard.php' => '21825d0c3a2387eeeae7309c6e15698e',
		'GiftCardAdjustment.php' => 'a745ff07df6a52e9a04d06c5742d8746',
		'Image.php' => 'eafeae070913dd64feb40e9478136a91',
		'InventoryItem.php' => '1642bf4b0107cfacbb72f3c8492e5903',
		'InventoryLevel.php' => '6789e3c341ae645cefa04f0a47b2c35c',
		'Location.php' => 'd7049cb74c9dd5e49bed31f03df91632',
		'LocationsForMove.php' => 'd26d9689d80d502b59a54cda6a94934f',
		'MarketingEvent.php' => '4d0266229d9c90bec5ce2215617689b6',
		'Metafield.php' => '0353c88befdd49e5b0be47e1bd529c45',
		'MobilePlatformApplication.php' => 'ef0d7edd116a90a8be844db926b189a7',
		'Order.php' => '5b4a0f4db4bd91df362bfd44039501bf',
		'OrderRisk.php' => 'fd267b6154e6d686a05e86530dc8124d',
		'Page.php' => '07ac1ff723013e45ed0290dee8b8db40',
		'Payment.php' => '424b24914f4429439a4d2cfaa409ee5b',
		'PaymentGateway.php' => 'd996cb39a53950b226b566800f5499b8',
		'PaymentTransaction.php' => '788b4b869d6e1e67628393118c1f56ce',
		'Payout.php' => 'a6fa94b1afbc4aba09ab14562597b6b0',
		'Policy.php' => '47a422b6dd7c0d54946c4a2a5fbd7553',
		'PriceRule.php' => 'ee95fe2361211ea7cdf0a5245362a11b',
		'Product.php' => '46b85822c9c3a940acf2a237aaadad56',
		'ProductListing.php' => 'e2fa0abc7d462dfbf5bfa41a8dbc0e15',
		'ProductResourceFeedback.php' => '7150297b555b6f981acb2efd0d5fc502',
		'Province.php' => 'cbe038a4dc13ff729e6ecf8eff12e3cb',
		'RecurringApplicationCharge.php' => '8fbeccd0817f6e9cf91857f537b529bb',
		'Redirect.php' => 'f2b75f5c40abec9754a84b91e9d891ec',
		'Refund.php' => 'e18e1dec308245dd31a42458bc205e93',
		'ResourceFeedback.php' => 'c3fdcaef88b0ae050c3d58a5ba0b7017',
		'ScriptTag.php' => 'e62225a62fed4585381e6a446c7782cb',
		'ShippingZone.php' => '17173374ef94bd9ef782c48e3b8a7f2e',
		'Shop.php' => '38117878794c97067ae19221ffc53193',
		'SmartCollection.php' => '65089337a2204c023e80edbf55abbeee',
		'StorefrontAccessToken.php' => 'e7ed11984021c1dc5cbf481e031fe7d4',
		'TenderTransaction.php' => '845651e0b31eec85e478a9f311ee6e37',
		'Theme.php' => '6d8291dc89fcb3ff95e7398571b3e757',
		'Transaction.php' => 'a4b1564eefb8617b25b2a8bdae5fe2d0',
		'UsageCharge.php' => 'fc7a65cfadc37b779d1dbc4cab470e00',
		'User.php' => '5e20cece8e1a19124e8bb8e9d47f6b4f',
		'Variant.php' => 'a3ef2bc7ec62c0d8fd27941cd5d1d909',
		'Webhook.php' => 'a390a98094bbccb68bf90f7d901ac5f9',
	),
	'/core/libraries_phartemp/vendor/shopify/shopify-api/src/Rest/Admin2024_07' => array(
		'AbandonedCheckout.php' => 'c71d3349b22aa102e51d44639c3d484d',
		'AccessScope.php' => 'a25adfb5c7309c0a491ee2b7302a9725',
		'ApplePayCertificate.php' => 'd32f1ae5f63d5f0dc4ed906a27f2c6f7',
		'ApplicationCharge.php' => 'e7fb82d4f7f9556ebeacc6e8c4d04135',
		'ApplicationCredit.php' => 'f25fd1d440656fbb41972a16990c4f60',
		'Article.php' => 'e8aa674e596cb32b95fc56613dd8ff8c',
		'Asset.php' => 'e8239f0ce0593c6925c6f7075414facd',
		'AssignedFulfillmentOrder.php' => '20aff6fcd9366a0e0c2330e0c46e7bc8',
		'Balance.php' => 'c6739e74ee1f8bca0a4dd064655ecc87',
		'Blog.php' => '5f44fafd66fc2880591a1b370f0ca46f',
		'CancellationRequest.php' => '5571ae57f3dd59970e83b157d3d55e84',
		'CarrierService.php' => 'ae51a7665b68a5c4fdd68bd20847599e',
		'Checkout.php' => 'b5b4a47ce8c0ac0fd1219dbce4f83746',
		'Collect.php' => '81fbbc786994c288b5e2c65e96f8227c',
		'Collection.php' => '463fc9d4245c19dee30036d3dc7b38de',
		'CollectionListing.php' => 'd9944074a2bb86570e2b4c3e51087dad',
		'Comment.php' => '9109916f6f0d5f81e123716e1de5d7ae',
		'Country.php' => 'd33cdf301771c0a4625f3e2cf5ff1c1b',
		'Currency.php' => 'b9d0fa71c7afd56cbfc02f975ee9c522',
		'CustomCollection.php' => '2cbf5efbd9db6f5441be86e2df5a031d',
		'Customer.php' => '1f002a0b6899c9de5574b18e10736740',
		'CustomerAddress.php' => 'db6860a80c06baaf729ffcbfbf2a4171',
		'DeprecatedApiCall.php' => '9eb47375d7e2f2f765d0cb661168ef5b',
		'DiscountCode.php' => '29b236002d0c7accc7e732bede083080',
		'Dispute.php' => 'f536c52117b4de508d55469ccc5fe92b',
		'DisputeEvidence.php' => '085a99ec7af6347b394e985c2c48dc85',
		'DisputeFileUpload.php' => 'ae5354723c9a98e192e38a6357b7b500',
		'DraftOrder.php' => '3954c7d507f56ef0b2846a6da6edab11',
		'Event.php' => '7b8aa2eb6ec400d465296494eaeed19d',
		'Fulfillment.php' => '43ca53c35590f4bf0baf10b6de8c64dc',
		'FulfillmentEvent.php' => '39fb4ea11d05adcec96f84a5ea14b4ec',
		'FulfillmentOrder.php' => 'd74441b59af9250f02d1a1bbd066d379',
		'FulfillmentRequest.php' => '4edf7ecf66f4b8e5e4d495144645bf43',
		'FulfillmentService.php' => 'ed6f393ad97feebfce2242c37d123f76',
		'GiftCard.php' => 'f01afecc852d82041406b494953ddec9',
		'GiftCardAdjustment.php' => '3330ba3f1c9ac6e34e497bda15d899af',
		'Image.php' => '8947ca0810de88c9c1ed5af58a79bde4',
		'InventoryItem.php' => '29f64616d3795f2f653a72692b7ed9d9',
		'InventoryLevel.php' => '2d2590674061ca4e072b8a6b5d0b77b9',
		'Location.php' => 'cd7e34cac4464d67da2cc2cd4edb3b24',
		'LocationsForMove.php' => '5b6d7a4b5da309cf382a17f9c8675216',
		'MarketingEvent.php' => '8e509574c384793845f1c054b0fdf7ae',
		'Metafield.php' => 'd60632f90ef6de0138bd09b4a42a20d3',
		'MobilePlatformApplication.php' => 'd99bc8349b9024e1e1967df90d4e8d40',
		'Order.php' => '7eae22a1f1b42d461ff44ff60080160d',
		'OrderRisk.php' => '33f117b19ca4375c1ba77e428142140c',
		'Page.php' => 'bc5b61be8665cb8050b6fff29cb54353',
		'Payment.php' => '4ee16f702e3d2dd97c2ce142ce656c25',
		'PaymentGateway.php' => '4a51e1e5a1d02c890e10ce30976d80e9',
		'PaymentTransaction.php' => '4e5ac8568f9234f86510e828b14f64c1',
		'Payout.php' => 'db9986e30b1d59e5c062b819fc48ba9d',
		'Policy.php' => '50c1f0486d6aca0f6960b91cde0cf71b',
		'PriceRule.php' => '0c20bd07147df450aa2aaa9f38711597',
		'Product.php' => 'e4d55a12388b1b662c311f3de926ef56',
		'ProductListing.php' => '0a1832327b0b8dd3a7b8d2e3f70aa280',
		'ProductResourceFeedback.php' => 'ecdd886f9e16310e033ada6468bebddd',
		'Province.php' => 'f34a5d7aeca8fb907081b3dbb416d634',
		'RecurringApplicationCharge.php' => '69e69b0781664e9a64bff478e4e84ae2',
		'Redirect.php' => '279fa7d8f17557f567ae116e0bbd50ad',
		'Refund.php' => '043ce9b137a0c26904d2a6101afd3d37',
		'ResourceFeedback.php' => '49c09b6f6591cdc8f609872c574f0914',
		'ScriptTag.php' => '98682b786dbd8046f2f4e7a5fbcc370b',
		'ShippingZone.php' => '36545990337947ce3605562ef34a631f',
		'Shop.php' => '1ee5f05351c48f305928742dc7c91041',
		'SmartCollection.php' => 'bd89f8f61efa15df0701b9f4dda4dc18',
		'StorefrontAccessToken.php' => '01c287cd07f92b03d06612bdbbf43909',
		'TenderTransaction.php' => 'fec1a57c81b217e499173a41a1a4140c',
		'Theme.php' => '9bed55d55a47955118cb7859db471008',
		'Transaction.php' => 'fc952d50b27e178e33f1d471a4fa5a7a',
		'UsageCharge.php' => '6e0ff15feaf026ad61757c673ec7d99f',
		'User.php' => '8b4fe39c4590dc1bfa94fad46745e859',
		'Variant.php' => '318d9867f57b0a1d4275122b1052b67f',
		'Webhook.php' => '8c6b9afaea2c2189ef318ba264e0c437',
	),
	'/core/libraries_phartemp/vendor/shopify/shopify-api/src/Rest/Admin2024_10' => array(
		'AbandonedCheckout.php' => '413dbe91334bcadd974707bf980016be',
		'AccessScope.php' => 'aefea3b8cb1c2ebbe2ef62dcc9569d9f',
		'ApplePayCertificate.php' => '0266ced1afc7f7b132b2a17a53035c46',
		'ApplicationCharge.php' => 'c6d5eb4791bb70f46ee22e4d20e3c049',
		'ApplicationCredit.php' => '469a2288652c4358f6dc4cca1d0b76f1',
		'Article.php' => 'b65284359195a461ef616d7b6f86e726',
		'Asset.php' => '9580c80f826be24569f6396f21049733',
		'AssignedFulfillmentOrder.php' => '656dcffb4d316fb31c342762566cae7e',
		'Balance.php' => '4d3044db1e8b217cc6e1dfdd3b6de994',
		'Blog.php' => '2d6b53842e31a1b60af4b72f412acf75',
		'CancellationRequest.php' => 'd634d36ad24c488d52e525f67c4ad6ba',
		'CarrierService.php' => '0a7480c9033b870fe1f17969f56b87f1',
		'Checkout.php' => 'ffbbf136110fe7da054badb7cca5677b',
		'Collect.php' => '49206ed4f72ab9e9de56176e6bd5470f',
		'Collection.php' => 'a81ca2982c4a8cfa34389b8a562688e1',
		'CollectionListing.php' => '8589ec3b2b91e28d8185a246c103d6a0',
		'Comment.php' => '9c40243649dc941338d7b926f21250e9',
		'Country.php' => 'ca4b803a6bbc15fae52d3270c8262d38',
		'Currency.php' => '7cc76f3e8e702e20cc1db0a0c08b3a03',
		'CustomCollection.php' => 'f9cc9e9ad547be0bf6dc60cc1eca0995',
		'Customer.php' => 'ea667b65a1cbdb764ea3c65f37a17e69',
		'CustomerAddress.php' => 'd1e64a8a81c26054b62ea57b62472cd9',
		'DeprecatedApiCall.php' => '7fe512fed086bd67f74ccdd7a2792f4e',
		'DiscountCode.php' => '5f3a9abd5788285f4f79fe40b0771091',
		'Dispute.php' => '916ec8a9e1b0b6a9e80274b6d3100672',
		'DisputeEvidence.php' => 'a038048a54583483a917deadef7ad4a7',
		'DisputeFileUpload.php' => '973d521b1342c6490d55cbe5028ec112',
		'DraftOrder.php' => '1cd341098cb37012ee00932e1d099194',
		'Event.php' => 'aaab6408beab79d2753f6953ebb93cb5',
		'Fulfillment.php' => '928471fa5331b1509a4ac42563a7a19c',
		'FulfillmentEvent.php' => 'a598b74db1c4080cf1a02a16859344cc',
		'FulfillmentOrder.php' => 'e58f91ba442fa82f0183cf73a22a30ec',
		'FulfillmentRequest.php' => '13a2b6b237055cd507588c339c286388',
		'FulfillmentService.php' => 'fac6390c91132c43e4c6f10ac16d25eb',
		'GiftCard.php' => 'c0f4faba19b5121d36a351284b9d060a',
		'GiftCardAdjustment.php' => '17e23f3418a35d105b2e866d6693974f',
		'Image.php' => '2142eb2ece37a1e8c282858d2803cef4',
		'InventoryItem.php' => '0fc0a7e9137c56cde650010840310088',
		'InventoryLevel.php' => '5da87ea614deafea590b12a5a9f530c6',
		'Location.php' => '518cd47f56814d1860fd30224be684a2',
		'LocationsForMove.php' => 'de09065e8c4a90f30efb83f2f891a266',
		'MarketingEvent.php' => 'ac24e785c0b24a2659cc6a30088f43a9',
		'Metafield.php' => '2a8b1ad58c66b95abb9c00f8c33e169b',
		'MobilePlatformApplication.php' => 'f4210298b4e3d50e970f7b69cfe654ea',
		'Order.php' => '308a3d1fd83040e55fc50a87b09ba57f',
		'OrderRisk.php' => '9f68138896e9239d939afd0a6a9f90c0',
		'Page.php' => 'd2b4cff15497f1c422f26e77d29ab78b',
		'Payment.php' => '779bda57c044162307c462c05e18ea22',
		'PaymentGateway.php' => '49a0b31b545c3eab7626924659fc816e',
		'PaymentTransaction.php' => 'd555b43b42e5659ebb14af66d3b1fffc',
		'Payout.php' => '760780b2fdab5b494d4fe21a50e4d49e',
		'Policy.php' => '032357cb2243c2811df5ef44562f843e',
		'PriceRule.php' => '11489b7d3245b92b1bb4ec0d57c354a3',
		'Product.php' => '7b54fc0b3a4d5447f7507a630449e5f9',
		'ProductListing.php' => 'cc54de5292ae1350cf380b9cced967e7',
		'ProductResourceFeedback.php' => 'fe30425e3031908140895f7ea4d2eff2',
		'Province.php' => '64c2844cfde0536fc4c16b29bf0ad3a8',
		'RecurringApplicationCharge.php' => '31c03de38c2577b4c729458c2ce8b955',
		'Redirect.php' => '8fcb1b503be68a1875dae166065faa85',
		'Refund.php' => '55abdd5363a6e20b8b57a9a80bc81b79',
		'ResourceFeedback.php' => '172473fdffdb91da2167f093d24d139f',
		'ScriptTag.php' => 'a8f5f884cdddde85b89f82d680608fac',
		'ShippingZone.php' => 'f6cf208eb9eb32706a45c2b26e74a5f8',
		'Shop.php' => '1baf2bc59b787c4932d7083adf60f0a5',
		'SmartCollection.php' => '78468c53dbd7166ed6f44a48fe5634d3',
		'StorefrontAccessToken.php' => 'ee43427614ffd4a76f3ac9febeac4ad4',
		'TenderTransaction.php' => '33d781dbfb5e1e8d038a60aa909a9b64',
		'Theme.php' => '2cde444b285a594e3b04d475642998c8',
		'Transaction.php' => 'a3d1d10ed2f6b8923e899a905ad25fba',
		'UsageCharge.php' => '064aaed08c041eff5cf1ab4715649e2a',
		'User.php' => 'b40572821c148013933a741f2283835d',
		'Variant.php' => 'd1d83fb6844f12d7690f0a75a284059d',
		'Webhook.php' => 'e5e3c1152def1f9f9b353574e5d24bb2',
	),
	'/core/libraries_phartemp/vendor/shopify/shopify-api/src/Rest/Admin2025_01' => array(
		'AbandonedCheckout.php' => '26b577cd4587eb9951ffd5b4890203f7',
		'AccessScope.php' => '30d7421afff3d3b21dce8b3a3c880c4d',
		'ApplePayCertificate.php' => 'dbe58d7030e83edf1482d3e6e6e2001e',
		'ApplicationCharge.php' => '28f4957f350f155cca8fd860400b9dc5',
		'ApplicationCredit.php' => 'a6556e37aaee39d19600d872cd0cba35',
		'Article.php' => 'c07d96e09bcd6892234959867de0d40d',
		'Asset.php' => 'd4820903e949c0eb997f719651c1ab13',
		'AssignedFulfillmentOrder.php' => '200095d1fed9c9b5f5234f7957355e2d',
		'Balance.php' => '9ae4add9d8f7625866950944553595c0',
		'Blog.php' => '7eb0e2259719ceef19c2abbe99e68184',
		'CancellationRequest.php' => 'd08c368d1c80761f6cdeea2613285516',
		'CarrierService.php' => '445690b9e527ae437ee97d8ee9e74cc5',
		'Checkout.php' => '90f6f229d40f2260ab3324ec43c4eca2',
		'Collect.php' => 'fce4e91fe579876fb84ceafdefbdd040',
		'Collection.php' => '56874b51ca3c56bbb68ec411cb0a84ce',
		'CollectionListing.php' => 'c8893435828d768ad720503c6908b42e',
		'Comment.php' => '2b20de9f28acaa307f1b5a4a4b340581',
		'Country.php' => '37d64d03f07ab25730dde9054d4f1801',
		'Currency.php' => '52f3bfc3ced8f90272bdd25731c68617',
		'CustomCollection.php' => 'c1b18ab3c3ce5dd4d9b186bf76b7b340',
		'Customer.php' => '6fd2ebfda012212374f8589300b60c87',
		'CustomerAddress.php' => '8b62d0db72730539d84ca5e16409f5b0',
		'DeprecatedApiCall.php' => 'a95a0d89ae9b8984c71283515dbecc4a',
		'DiscountCode.php' => '2caf6a389d8183d711b4389e1dd31e5a',
		'Dispute.php' => 'd2d33ae59c3df31c6d22ddb19ef4cf07',
		'DisputeEvidence.php' => '71c1b1e4a656546be38d4cd9d4be7ea1',
		'DisputeFileUpload.php' => '4a107f8c440b19fed0628be693e03c8c',
		'DraftOrder.php' => 'd14deb557d75a8ee8e23bec415fe59f9',
		'Event.php' => '5e84a3b50a17fbb0d0724a2b90c32913',
		'Fulfillment.php' => '0fbe7c9b4aca5053f9bf7cf803f1a69c',
		'FulfillmentEvent.php' => 'c7a3bbf3ed8695e4faa0127f61584ced',
		'FulfillmentOrder.php' => 'd826bca142f3bac90c0b7a79e59a6c57',
		'FulfillmentRequest.php' => '21dcb584619fe6b696adec241a593acc',
		'FulfillmentService.php' => '176e45b606787f79c37ef54fb1025504',
		'GiftCard.php' => '37275e5fe15037b08f71bda3f63b419a',
		'GiftCardAdjustment.php' => '34f6a4e6d056699f4b08cf46b4566fca',
		'Image.php' => '23661f1762afa465483215dad212b1d7',
		'InventoryItem.php' => 'c12bfe227f0abaa21a5c4e64d7dfd24b',
		'InventoryLevel.php' => '808909173e91e753a860c2548736432f',
		'Location.php' => '217360512169ea379cc93387bd769589',
		'LocationsForMove.php' => 'c4a4d191ff9556570c2c3dac9c667d82',
		'MarketingEvent.php' => 'e29e2c222f45e2181a292396bad90d74',
		'Metafield.php' => 'ef8a57581d28d6abb9501ba17ca8769d',
		'MobilePlatformApplication.php' => 'e478e65e04bf7f30ef0931085a1aed37',
		'Order.php' => 'd1a2b41a8d9923d5b384767e9d1e698d',
		'OrderRisk.php' => 'f7bad174f98fca8a785945d127ac787c',
		'Page.php' => '451231b8f594f7ba042edffa8a92a471',
		'Payment.php' => '74505e33fde4446646ad026339ab16e2',
		'PaymentGateway.php' => '92d63cbeac1095f080670c1b59b5449e',
		'PaymentTransaction.php' => '70cc5edd6d78832ec73c950cc302619c',
		'Payout.php' => '13f422a0a4f235a9112258a907868cb1',
		'Policy.php' => '2143c82b2b170e186ce4a0d3d3728431',
		'PriceRule.php' => '7e3845acf0217af1b380173cae211180',
		'Product.php' => 'f06b71a75dc2cf9be36010e7ee2e8a47',
		'ProductListing.php' => '38f26b8484f0c10f352d4bebc6e44fa2',
		'ProductResourceFeedback.php' => 'eee8f0cdf6f9035f5d84181ef9f33ae9',
		'Province.php' => '1f6fabd819ffec21356b04a8daabdbaf',
		'RecurringApplicationCharge.php' => '3deda09cd1c56f6dba242695c302c6e0',
		'Redirect.php' => '7c276440e7832f9ed5e5b63c6149982a',
		'Refund.php' => 'f1f9db890eb2e0275f3a1ef17095397a',
		'ResourceFeedback.php' => '09d70e559691107a1e3d4976c6fe55bd',
		'ScriptTag.php' => '100d43e83f4fcceaac6d3d30c5aabf1d',
		'ShippingZone.php' => 'a23f6ac4a719db55ad96832db82bccc7',
		'Shop.php' => '22df955daddeb67f2b9ab4ef33028913',
		'SmartCollection.php' => 'ea43782d1cd84af30f0acd7a44dd139f',
		'StorefrontAccessToken.php' => 'f5d7795fac7575b471e40324e73a726f',
		'TenderTransaction.php' => 'a47befff9b498d0b956b580c9d0a785e',
		'Theme.php' => 'df701e29097d903d33bf9b906eefda1b',
		'Transaction.php' => '8766811220ca1cd2ad9444b54c518c64',
		'UsageCharge.php' => '3f43096af4f570e165bbf186d8299083',
		'User.php' => '50e90ed04a90907c196a9a1ec4f8ac38',
		'Variant.php' => '5cbcd13fd8df00def1afee96282d3479',
		'Webhook.php' => '814215502dc557005b52ede557a7a937',
	),
	'/core/libraries_phartemp/vendor/shopify/shopify-api/src/Rest/Admin2025_04' => array(
		'AbandonedCheckout.php' => '8afdb073ef1bb0d16f455c38df5cf892',
		'AccessScope.php' => '1a290256bda2384960f8a1fc01bd7ec0',
		'ApplePayCertificate.php' => '8f65b8fcb56294f62538034c23c59517',
		'ApplicationCharge.php' => 'fab4d49f596cb44789b09ab191b83186',
		'ApplicationCredit.php' => 'e005873e0a425427ddeea31edf8ba0e1',
		'Article.php' => '893b92fd2628b8d2a71e0bd1d8aeff7a',
		'Asset.php' => '28a4ac5d824019a947429c9f1a640972',
		'AssignedFulfillmentOrder.php' => '3530e743cdf562030194ae5ef9163d84',
		'Balance.php' => 'e885fdf022ae4b02b971bcf4699d7082',
		'Blog.php' => '97a8ba44cc1cea398651447682b8e5e7',
		'CancellationRequest.php' => '20148cb5ca1352927a84e3351e253231',
		'CarrierService.php' => '27e6210bab8698936d4741e76261ed56',
		'Checkout.php' => '34e0a0a77b654ca21db7de853daaf28a',
		'Collect.php' => 'd531fe33ce9ef365b84bad21ed4382c5',
		'Collection.php' => '502eb118e0ab787bdbd798f059b1b0ff',
		'CollectionListing.php' => '46c3bf5fb1a396225e4d0fdbfb6faca3',
		'Comment.php' => '5407d26165279ffe305328247884da3e',
		'Country.php' => '5b0a63d0af87e2881560351da037e08f',
		'Currency.php' => '2d10a18387e26d4652864fb165ff4d22',
		'CustomCollection.php' => 'bcb7ce122670fea5de2179f68074a752',
		'Customer.php' => '8aeefd5193781e0a75adf43c8c93ba96',
		'CustomerAddress.php' => 'd66d048bc4d46912c9580b293893af30',
		'DeprecatedApiCall.php' => 'b093b5ffbc77035dd92d0fb0d349d2bb',
		'DiscountCode.php' => 'de308c6041ea37f0a9591387e07d9cf7',
		'Dispute.php' => '00f90f4a5d0d7f3cc8fe6a13645db4db',
		'DisputeEvidence.php' => '22d917b8e102c5e6f18306e49cbb0f75',
		'DisputeFileUpload.php' => 'b0e5d97f992913efc9f19bb5456b73ea',
		'DraftOrder.php' => '191efe5994365d12c18a5652a0ac8b11',
		'Event.php' => '854727a7ef7224d31f18b106a3563e76',
		'Fulfillment.php' => '2721b62bbf04358e5074b96c1c98ba08',
		'FulfillmentEvent.php' => 'ac55c2e3743f22a2343e4bc21f8bb897',
		'FulfillmentOrder.php' => '476ff6e74ec5146b150961fa62e5edf3',
		'FulfillmentRequest.php' => '0b446491c21323fd916679509152d6e6',
		'FulfillmentService.php' => '17ea2b1f2ccebcaaf0d87752df68c274',
		'GiftCard.php' => '7c2049164495a356a2562cb8a7286117',
		'GiftCardAdjustment.php' => 'a83e01881dfea569f347e26bfd668bfd',
		'Image.php' => 'a9d70b3792393094d1c982cdbf41c0e7',
		'InventoryItem.php' => 'd61d2226095f9bfc84e543101982c6b2',
		'InventoryLevel.php' => '54018e05d977da9b2a6ae7c0e9cc0358',
		'Location.php' => 'b1f2e7da3b3667f3811cf43d79a34eab',
		'LocationsForMove.php' => 'f4264bb1d614cc8a2e34301753c21b58',
		'MarketingEvent.php' => '93bd51c3cfeb5083f7432d81b922992c',
		'Metafield.php' => '60e9e58005544c8b9d319a832049b273',
		'MobilePlatformApplication.php' => 'ecf1dfca927983ecd7e64743df993d90',
		'Order.php' => 'fc9f66bc930410d31fa634d019186879',
		'OrderRisk.php' => '9eb72ca0b0e448e9f09eed06d5a23f72',
		'Page.php' => '0a71aa8e92c0467a181429c4809843ab',
		'Payment.php' => 'eb9eb359fc2394566ca44082197cb1de',
		'PaymentGateway.php' => 'b1661ce7dc25e336cc5a0ccdb272a25e',
		'PaymentTransaction.php' => 'ea7619ff3ae75ead03c115ef002a975d',
		'Payout.php' => '43315776c9731db8a2546533dfdf8b5c',
		'Policy.php' => '66579c89e059f2e70fe3de5e328240f1',
		'PriceRule.php' => '279129ab9ec398502051a85874de4879',
		'Product.php' => '8f2f9fd8d68e203c4e2c80dd5736897d',
		'ProductListing.php' => 'bb26c8e1594fc885a037e6d412112e3b',
		'ProductResourceFeedback.php' => '41e9bae031dd92a485ed4dc994800978',
		'Province.php' => '91dc80a03043bb983bffa26e915d20ca',
		'RecurringApplicationCharge.php' => '19eef48dc0cf818d9fadda425d0dc7aa',
		'Redirect.php' => '6dcfb5648223fa4456b57df714fa7e42',
		'Refund.php' => 'b92acfef93b133a0047bb208e5c6fa70',
		'ResourceFeedback.php' => 'd680e3460875685c4b52052ec04f93ca',
		'ScriptTag.php' => '300284f9011b25faa0275bbbb6f8f8e8',
		'ShippingZone.php' => '3d1a20c9bba08e40dcbfd9e81a21a10d',
		'Shop.php' => '0ace224f0b2b66a2429e0b1c6b7ad108',
		'SmartCollection.php' => '5bb30acf06ad0d5cb3828e25ded02e75',
		'StorefrontAccessToken.php' => 'fd255a4273fea1769900318bcdd2be88',
		'TenderTransaction.php' => '7b5f5168fbb36b47499991bbf9e58d0b',
		'Theme.php' => '9f41f927cfa7568cbd4a0a21c0d2fe24',
		'Transaction.php' => 'f4600e12352c18b14497469ded3b2f69',
		'UsageCharge.php' => '799956cb8a328d44e6d7d6cedc50abad',
		'User.php' => '06ce2625dbefbefbf81cd486440fa642',
		'Variant.php' => '86ccb619634c29fe15971dfc51a52685',
		'Webhook.php' => '62bc97087a7d152cad33baa1605b510a',
	),
	'/core/libraries_phartemp/vendor/shopify/shopify-api/src/Rest/Admin2025_07' => array(
		'AbandonedCheckout.php' => '7352fdb711f44a9ff5c47c1f341f7baf',
		'AccessScope.php' => '40b8d7a03579e6d5486f299b37c030f6',
		'ApplePayCertificate.php' => '4a729372722f06ee07c9fda7739262c6',
		'ApplicationCharge.php' => '5f8a184001935bd594e2202ca2ca6906',
		'ApplicationCredit.php' => '4d13cfa1e5b5de2258424cc11fa06957',
		'Article.php' => '8b6de384281f3df45c7c56270e8e749a',
		'Asset.php' => '38dd4db4e1a42242797859969a7f4c3f',
		'AssignedFulfillmentOrder.php' => '4e6a2d8b18ce4c2b1071a47efcb417a9',
		'Balance.php' => '0309b7362ebad646e50a88b51cb01205',
		'Blog.php' => '8701d2313519581730c7fae40629208b',
		'CancellationRequest.php' => 'e17a27d9245b007d629773001b06fe11',
		'CarrierService.php' => 'ddb842dfe2577726cd53d0ed295a9e1b',
		'Checkout.php' => '1924d7c7a507c678d5d0665c1268fb8d',
		'Collect.php' => '83f601afddfb40cabc62403a4e1792e0',
		'Collection.php' => '4c596d33c5b1b4c27fbc2f5dc8730b12',
		'CollectionListing.php' => 'ef88f4c278617a3dd3a751234fb73ede',
		'Comment.php' => 'e6c7f5c941d61bd8111fead3ca605228',
		'Country.php' => '3704ffe34212a0630179652063042cf3',
		'Currency.php' => 'b04a8568f623f476d024901dbb8fdc67',
		'CustomCollection.php' => '393971a12ab9fb10718df04b9b2c49b6',
		'Customer.php' => 'b46e995f761894b6a2d454fd79572334',
		'DeprecatedApiCall.php' => 'eca563e8e5092fb1d042ca2b013c1555',
		'DiscountCode.php' => 'b47bd9364d0cd596d10fbd6e560a6c42',
		'Dispute.php' => '9c9870a87caec9a869a8232a9db1a711',
		'DisputeEvidence.php' => '5d764b0af51716b731bddc628321b64d',
		'DisputeFileUpload.php' => 'eda85529115e265e569d62e1d542c6a6',
		'DraftOrder.php' => '80f412a6b3f84437a7d367614a14b201',
		'Event.php' => '4383375f4a4585e8ea387a5779a40b9a',
		'Fulfillment.php' => 'bbe04e09957d1a3bc425970e96fa83ad',
		'FulfillmentEvent.php' => '1863e78d2277edabaa1923871fe0e6ac',
		'FulfillmentOrder.php' => '98e0dd8825e601ad9abd79d4f43fd798',
		'FulfillmentRequest.php' => '1bb650f18ffa892a7e715324c60c16d6',
		'FulfillmentService.php' => '748f4ba2474ebd7b0428667db11f5a84',
		'GiftCard.php' => 'eb212320ce57c598cc76e748c893ae4f',
		'GiftCardAdjustment.php' => 'e4ea772a85c19341f292c1d90b9bd122',
		'Image.php' => '4520c5b21b7aff8465a49ee0d4b351a3',
		'InventoryItem.php' => '7d5d639d6dcf88d72d60aa01dc061283',
		'InventoryLevel.php' => '15360871b202ddce0f7fae8c9f3b6ba8',
		'Location.php' => 'c8f18bbd38666c7d53cb692253fc81a6',
		'LocationsForMove.php' => '8c6d69c5a77022f9191fb89ed945db81',
		'MarketingEvent.php' => '60d5e7bcb557b57e1fd4818310517519',
		'Metafield.php' => '606e33449ad58c28268b63686f7edfb4',
		'MobilePlatformApplication.php' => 'ae580ae85801b5f6969488971c221b7a',
		'Order.php' => '814bd6ea3cff2c4a3783c9566f9c5caf',
		'OrderRisk.php' => '54c7bb20f745eb39ab58eb6cf23dbdbc',
		'Page.php' => 'fdb2c9b597dad57c4387278ca2ac5c64',
		'Payment.php' => '9b08953c730770c5364b76bc1dd53323',
		'PaymentGateway.php' => '04de37f06802ecadbe7c44e9ece898ce',
		'PaymentTransaction.php' => '95ead884bdeeee36731d1d55312cfe88',
		'Payout.php' => '984cd9718ae68ffeeabb030f00d1f2fd',
		'Policy.php' => '4e496eebac162bd6c73b1863700de938',
		'PriceRule.php' => 'c31633a9c0ac35d619d2419e9bfaf030',
		'Product.php' => 'd69dc7fb6ae89ca5d3265dea21477018',
		'ProductListing.php' => '7fbe9f0628b6cc2c7deb704478c3c9a3',
		'ProductResourceFeedback.php' => 'f852268b8c9948888a8b1c7d34c9e532',
		'Province.php' => '4b1f89df3bf8e6fd15560f0f5bcc4bff',
		'RecurringApplicationCharge.php' => 'ffeb91aa5dd3ca0cc72db382486f1af8',
		'Redirect.php' => 'dc18ab4acb74dd9c4331c8ebe3539aff',
		'Refund.php' => '45b201144d00113bd029c37b1b02ed6e',
		'ResourceFeedback.php' => '316b03ce785954685d18a5ff57fe33b4',
		'ScriptTag.php' => '9320d4b9051b8fa54868d29e33b6e543',
		'ShippingZone.php' => '4979ff2daa83ffd090b8ebe9b680a8b3',
		'Shop.php' => '3771dbe1651a98edfb331e9ca4d69989',
		'SmartCollection.php' => '044e9c501ffaf1fedac42343c857a0bb',
		'StorefrontAccessToken.php' => 'f7021f219a61a71d0b9f6704a7d801e2',
		'TenderTransaction.php' => '6bee6f09b7a3d2c64e1d2a7040b3eac1',
		'Theme.php' => 'bf70f891705ebb3d881021f1d6abdef1',
		'Transaction.php' => '8b0d022621cc013872dcf4632d8145c4',
		'UsageCharge.php' => '31185bc187edc1595daff44db206cbcc',
		'User.php' => '454ac2218bc08c17609d225bb06971b5',
		'Variant.php' => 'f297fd5b86a121655fd86da175d16149',
		'Webhook.php' => '5f7cb2e80e3bb6ed56017c1579818ffb',
	),
	'/core/libraries_phartemp/vendor/shopify/shopify-api/src/Rest/Admin2025_10' => array(
		'AbandonedCheckout.php' => '7a11d052d45a805e56760f60114a8a48',
		'AccessScope.php' => '4bb3fd68aaa6c5b2b8a4f6feed513f55',
		'ApplePayCertificate.php' => '199a6f4684fe062e772ce076408d0099',
		'ApplicationCharge.php' => '9ab7a14b3e9e34274ee0da09e6493eec',
		'ApplicationCredit.php' => 'db8bcd9d8ca16ab7fcbe24df84a467c8',
		'Article.php' => '5a17f85a8ab0ce24ac00de35dc5f7402',
		'Asset.php' => '1e736272951657581facc03c96490779',
		'AssignedFulfillmentOrder.php' => '2f7464f496ebe05e7257b61e3e571795',
		'Balance.php' => '6f1a8978305225c19594741ba47d6fdb',
		'Blog.php' => 'c53cb5e4ce3198a8c126f2c53b8339b5',
		'CancellationRequest.php' => 'ec938663142c55099cb1ed3f8488dbb9',
		'CarrierService.php' => '484bebbbc307a51c75a755b8df6f206b',
		'Checkout.php' => 'b5b7ea4a31dfa7028edcb20f77470b7a',
		'Collect.php' => '3bd6ed290146a1d826caa86acb73af9b',
		'Collection.php' => 'a9b5108d2707383c1cea52c4b7969c41',
		'CollectionListing.php' => 'ad63f1fa648f48b8a39dd7dc6e017d6e',
		'Comment.php' => '3c31028326a7e6fe2d3872965869ffec',
		'Country.php' => 'd1764e0be799f2c4173583032a21bf9e',
		'Currency.php' => 'bf201aeac2095da0c572971e69c5c4b5',
		'CustomCollection.php' => 'f572d58827406c3986328e54e44de342',
		'Customer.php' => '3bb3c4278a931bd4163e7a4734b54a90',
		'DeprecatedApiCall.php' => 'eb119d60b36fe04ca646e2e288e995f1',
		'DiscountCode.php' => 'c0369e074154c271c642acd094cf330a',
		'Dispute.php' => '0b412cab8bde932cafaa3e5db050ca70',
		'DisputeEvidence.php' => '936c88302e7e960a667055d843330b44',
		'DisputeFileUpload.php' => '2c5cf4f010f5cbb8f2a2648878c9db14',
		'DraftOrder.php' => 'b9538c7394f8a729179d6ba749c3e7ee',
		'Event.php' => '05b88c9379e5432c134c750ed21aa918',
		'Fulfillment.php' => '1941e40cbb553d0c9afd6560095c6fa0',
		'FulfillmentEvent.php' => 'c514a5055b2b60452e265de7caab5cd2',
		'FulfillmentOrder.php' => '6b4a8c8d474263cd29fac3fa520bf19d',
		'FulfillmentRequest.php' => 'd4e8fc56a2afb60aea28d8b5eee70d6d',
		'FulfillmentService.php' => '09fdfd8fb6920ecf6c3685f2506770d1',
		'GiftCard.php' => '62486137be149cc0f93d1e244fa2b735',
		'GiftCardAdjustment.php' => 'dc4297351e31de83e78f381bb0e5c3dc',
		'Image.php' => '934d60fe3e65607a66d2d04391956cf4',
		'InventoryItem.php' => '089cd89501d0f7e287c2ac9ecde3bd0c',
		'InventoryLevel.php' => '3c17e6840b112d4dca7d207743b6cc0a',
		'Location.php' => '4353df18396b5a0114af18debb49ac0b',
		'LocationsForMove.php' => '2a32185de35e90ba9c161b89a88f46c0',
		'MarketingEvent.php' => 'b84c62aab930d8c260da9302b22a0064',
		'Metafield.php' => '4a9b18291417eeeccced3f7222b6c471',
		'MobilePlatformApplication.php' => 'e29aa37633ec883c3d800e8a713af449',
		'Order.php' => 'fc288acb51aea6425f72859f1fb779a1',
		'OrderRisk.php' => '5a3d27bfa5741f499e8dfe09b93946b7',
		'Page.php' => '170ba388118795f475e2765fef331910',
		'Payment.php' => '0a30b84f8ade6017c7b621e39a1becd4',
		'PaymentGateway.php' => 'b527ad40266c1b10fe32774453aabc90',
		'PaymentTransaction.php' => 'abdb40de49093d5c0f46405bec92a755',
		'Payout.php' => 'd9a483464b502f1a364d7f93ad949aab',
		'Policy.php' => '901db5d69f9a3b9831b2c21d658992f3',
		'PriceRule.php' => 'c506da630511b98508406480b7d2f867',
		'Product.php' => '204adf8b82ab78be4ad047c7b325c2a1',
		'ProductListing.php' => 'd2a544c0a568099ecd0a692cf74e59f8',
		'ProductResourceFeedback.php' => 'a94ab019bbeaf66b38035ffe839718a7',
		'Province.php' => '8b5e13118d5443e7df9c28483802031b',
		'RecurringApplicationCharge.php' => '429ddb6f5d74580c0702d0527f98ea56',
		'Redirect.php' => '60913f12151b0b337352f4f158152368',
		'Refund.php' => '70094c0fa7f747a315e53d9195524ac9',
		'ResourceFeedback.php' => '5e9fc9f2f8529cfe72b85e94020209cd',
		'ScriptTag.php' => '797ffef376fee73018f9c80551791c28',
		'ShippingZone.php' => 'e733e96717c0dacd0a1d10f7bc7b9d11',
		'Shop.php' => '9eba654c3cdaf1460499bad56982e06b',
		'SmartCollection.php' => '376acbeb17b9cc7c5d8249528d0a4a1c',
		'StorefrontAccessToken.php' => '38276eeef0a25ba08afa50f7e65a7d46',
		'TenderTransaction.php' => '353524d163c45f0e2f0d415b7c7717db',
		'Theme.php' => 'd6962e5f2911e2840b8fcf82a963edda',
		'Transaction.php' => '4f9e24ddfa0f04a9634ed6bec7857978',
		'UsageCharge.php' => '1c7809e5e64f0e6197964f66ab5763a4',
		'User.php' => 'a297adafadf6c41cb2a5c41259bb153e',
		'Variant.php' => '086bbde384830020289dc5d81372e814',
		'Webhook.php' => '74981e465c1a15a647cbf1787e4e9f88',
	),
	'/core/libraries_phartemp/vendor/shopify/shopify-api/src/Webhooks' => array(
		'DeliveryMethod.php' => 'ae2c2236f68dd5a60e52f045c0016d04',
		'Handler.php' => 'f9a93450ec6df0b602a9528c5b00a8bb',
		'ProcessResponse.php' => 'c8b97216f50f2706ce817fd3a4808410',
		'RegisterResponse.php' => '8bf4d1cc6b5629ff09eaa1dcf1eb2099',
		'Registry.php' => 'd1bd3c0f17dd41c3698c23afdffea9f4',
		'Topics.php' => '7d7a4519e2d735990bcab7abb462d0bf',
	),
	'/core/libraries_phartemp/vendor/shopify/shopify-api/src/Webhooks/Delivery' => array(
		'EventBridge.php' => '3cff39611dedb3996c82bfdb5184f84b',
		'HttpDelivery.php' => '72d6b4a5833d9e436f8f6be749c1d0cd',
		'PubSub.php' => '487716cfcdbd4741fa1a8458dca157e0',
	),
	'/core/libraries_phartemp/vendor/spomky-labs' => array(
	),
	'/core/libraries_phartemp/vendor/spomky-labs/base64url' => array(
		'LICENSE' => '35aeec8c12aabce3d0d1740438aa885b',
	),
	'/core/libraries_phartemp/vendor/spomky-labs/base64url/src' => array(
		'Base64Url.php' => '5d46f7901282f6b89999629652c6c35f',
	),
	'/core/libraries_phartemp/vendor/spomky-labs/pki-framework' => array(
		'LICENSE' => 'ca4d2e84d098a5f871984c6ca9a6face',
		'README.md' => 'a6f52dafee39b760fb54349c8a28f4f8',
		'SECURITY.md' => '9a8cb084d7841945ed5d6a01febb8e66',
	),
	'/core/libraries_phartemp/vendor/spomky-labs/pki-framework/src' => array(
	),
	'/core/libraries_phartemp/vendor/spomky-labs/pki-framework/src/ASN1' => array(
		'DERData.php' => '1368316d29a21a5cbddc8d6fcc390e13',
		'Element.php' => 'ae99d4a441be7b5982fad0868bf37b8d',
	),
	'/core/libraries_phartemp/vendor/spomky-labs/pki-framework/src/ASN1/Component' => array(
		'Identifier.php' => '6aa1c666de4940ba8d58f102a9c2af53',
		'Length.php' => '8d54ca419cc01c6188e9b37dc40a66c9',
	),
	'/core/libraries_phartemp/vendor/spomky-labs/pki-framework/src/ASN1/Exception' => array(
		'DecodeException.php' => '9362cb72fb5b10bd8564c1e5d471e3dd',
	),
	'/core/libraries_phartemp/vendor/spomky-labs/pki-framework/src/ASN1/Feature' => array(
		'ElementBase.php' => '93ebb115926fdd895bbbca30963bc3df',
		'Encodable.php' => 'bb5ae7221a0bef897416cdd324f71e38',
		'Stringable.php' => '9a2a8bf0682e25d61d83d390802cdf06',
	),
	'/core/libraries_phartemp/vendor/spomky-labs/pki-framework/src/ASN1/Type' => array(
		'BaseString.php' => '620b410b36ceeb28f7eb9f73ce1ab347',
		'BaseTime.php' => 'd3eda5abdb70969e4ddeed819cfcd203',
		'PrimitiveString.php' => 'edd1e33f6352159a2efe68f21e1d45d1',
		'PrimitiveType.php' => 'abbad133d3eb7b69531840a706188ede',
		'StringType.php' => '23a8066e61dcc5139a16c194c0fe80e3',
		'Structure.php' => '4eeee18c4f3b0fc6a6a0e32a4a3f701a',
		'TaggedType.php' => 'f4ff027472cf8ff8ae8af6b15283f467',
		'TimeType.php' => '56d28e8fba0117863a182240d72ace4c',
		'UniversalClass.php' => '98ed40e4d45a8da682cdfc1f6cf83cdc',
		'UnspecifiedType.php' => '36f3743f5456853fcc35c6e8e171df20',
	),
	'/core/libraries_phartemp/vendor/spomky-labs/pki-framework/src/ASN1/Type/Constructed' => array(
		'ConstructedString.php' => '5c22d182d372144e13c79304093061d1',
		'Sequence.php' => '1960b420c1bde40bf14fccc641f4983f',
		'Set.php' => '8619f6f0c011dc062adfe5d51966b56b',
	),
	'/core/libraries_phartemp/vendor/spomky-labs/pki-framework/src/ASN1/Type/Primitive' => array(
		'BMPString.php' => '5874dcacc01d01a8f831fedaeca11c54',
		'BitString.php' => '9957196627452969ab4da0ddb0a12ae5',
		'Boolean.php' => '16054cdca8d158c3d8f48fd68d426f32',
		'CharacterString.php' => '3d8a01931ae4ab1bbc6c040010811d0d',
		'EOC.php' => 'cd0802cb493498b2eff9f1d7b4ede6f6',
		'Enumerated.php' => '394ca09f69f1d25e62cf2aba8b7f8884',
		'GeneralString.php' => 'd1e5492a385b39adea01c9bee9417289',
		'GeneralizedTime.php' => 'd742de044945050c6ac845902b4a650d',
		'GraphicString.php' => '6612801e02346b8db64dc8d7cf897a97',
		'IA5String.php' => '8a5542f0420efcbf5ee6f0438fc75e63',
		'Integer.php' => 'daf02dc1892fcce049da39111fefaf82',
		'NullType.php' => '5fa8714766dcbea92df01ee5d52358e2',
		'Number.php' => '65f187a9ecd23216c38a1caca3023a8b',
		'NumericString.php' => '11de10e0836944ba158fc3ebc739ac4b',
		'ObjectDescriptor.php' => 'f052cd190a38b41e5acbee3d47bbd944',
		'ObjectIdentifier.php' => 'f1b9dc9758c4d3fff8b17a888776633a',
		'OctetString.php' => '23cc57f72b33e93d5a12149029c845af',
		'PrintableString.php' => '40f8ecadb4d80d96ebc03108162d6cf1',
		'Real.php' => 'e442661edd36e37fb29027ca8c71f135',
		'RelativeOID.php' => '4019268acb43117c0e8c4149bd66059f',
		'T61String.php' => '07dfc342b480401f59017ca615c407c2',
		'UTCTime.php' => 'f36a8662ccc9d521a7d6e9321d669b7d',
		'UTF8String.php' => '47416ab862c0827d96d46ec466762e2e',
		'UniversalString.php' => '6048a257d44ca18dc956266dfc7137eb',
		'VideotexString.php' => '7aa9e72a655cc9c779582e410f9fbd77',
		'VisibleString.php' => '7259c72abb3743aee872703a699195b2',
	),
	'/core/libraries_phartemp/vendor/spomky-labs/pki-framework/src/ASN1/Type/Tagged' => array(
		'ApplicationType.php' => '182164fbc33022e992249fb2bdc8c341',
		'ContextSpecificType.php' => 'd3719d7100fdfb9c28e094d4c835425d',
		'DERTaggedType.php' => '7736e78cd58873131d2205a655e7ce20',
		'ExplicitTagging.php' => '38934c78266bcc9defc93e43e85e1201',
		'ExplicitlyTaggedType.php' => '7eff528c64689c9aa7e53ebd58522e5b',
		'ImplicitTagging.php' => '22800fb568c94b4e98abc4168322920e',
		'ImplicitlyTaggedType.php' => 'f8f289377d6112bfd5a6d3a0897cf482',
		'PrivateType.php' => '4996c8dc1aa8451109888d92c0dac446',
		'TaggedTypeWrap.php' => '00f47d2f035a2599a75aacaaf93078cd',
	),
	'/core/libraries_phartemp/vendor/spomky-labs/pki-framework/src/ASN1/Util' => array(
		'BigInt.php' => 'bd7b1377135db5de7cfece25ffbc6109',
		'Flags.php' => '357b1c7e882959cf0fd86024f21687f5',
	),
	'/core/libraries_phartemp/vendor/spomky-labs/pki-framework/src/CryptoBridge' => array(
		'Crypto.php' => 'dd158ba1e7999237476b290b9064ce50',
	),
	'/core/libraries_phartemp/vendor/spomky-labs/pki-framework/src/CryptoBridge/Crypto' => array(
		'OpenSSLCrypto.php' => 'ab52e5ca75b36c1d739ee1f1779492ac',
	),
	'/core/libraries_phartemp/vendor/spomky-labs/pki-framework/src/CryptoEncoding' => array(
		'PEM.php' => '98c8d493f08fd117a48702d55b4352fa',
		'PEMBundle.php' => '2011513236a804d6ec204457367152b7',
	),
	'/core/libraries_phartemp/vendor/spomky-labs/pki-framework/src/CryptoTypes' => array(
	),
	'/core/libraries_phartemp/vendor/spomky-labs/pki-framework/src/CryptoTypes/AlgorithmIdentifier' => array(
		'AlgorithmIdentifier.php' => '0ae67e1420177dfea2e56e8181060010',
		'AlgorithmIdentifierFactory.php' => 'f9789ba1d6d82a7185b070a29a74db89',
		'AlgorithmIdentifierProvider.php' => '17f22307b6b7626a5e824b30f5816eb7',
		'GenericAlgorithmIdentifier.php' => 'c324c6598b2b755153e145b78ff6f0ed',
		'SpecificAlgorithmIdentifier.php' => '96ace9662af21741d9c53dc59541eacd',
	),
	'/core/libraries_phartemp/vendor/spomky-labs/pki-framework/src/CryptoTypes/AlgorithmIdentifier/Asymmetric' => array(
		'ECPublicKeyAlgorithmIdentifier.php' => '941e5cbe5698600d490d3bf68f0baeab',
		'Ed25519AlgorithmIdentifier.php' => 'fd212a08bbfd32457276a255f356e393',
		'Ed448AlgorithmIdentifier.php' => 'ba0810a41d86a8190dbb28c938965ad1',
		'RFC8410EdAlgorithmIdentifier.php' => '40a61f942d2df1e672f38e2e9648cdb0',
		'RFC8410XAlgorithmIdentifier.php' => '22b8ae60672a48ad1889796aaf5d7236',
		'RSAEncryptionAlgorithmIdentifier.php' => '3ce71ea860b1313c23ae14c88dee85c2',
		'RSAPSSSSAEncryptionAlgorithmIdentifier.php' => '76d479f89a7e03ead9e4ae0f1317fa8d',
		'X25519AlgorithmIdentifier.php' => '9fb748db68e411b39290297951ff3c08',
		'X448AlgorithmIdentifier.php' => 'b8ddcf935bfebac0e24bbf8e049478e4',
	),
	'/core/libraries_phartemp/vendor/spomky-labs/pki-framework/src/CryptoTypes/AlgorithmIdentifier/Cipher' => array(
		'AES128CBCAlgorithmIdentifier.php' => 'ba478ee0e91d1364c10e514417cba6f8',
		'AES192CBCAlgorithmIdentifier.php' => '6afb1e6e45f8c9a5c171be0ebbd0c95c',
		'AES256CBCAlgorithmIdentifier.php' => 'e756602e47a3a311bba13b7a9b338325',
		'AESCBCAlgorithmIdentifier.php' => '9f15a356df98cf3c36c8d5ac223e3f55',
		'BlockCipherAlgorithmIdentifier.php' => '77081c6954dd8eb332abb5e8a4300e08',
		'CipherAlgorithmIdentifier.php' => '7f4623bde3a9a04f5c2cbedb6b9afcaf',
		'DESCBCAlgorithmIdentifier.php' => '71a06ddcc97203a757b2ef736f8a27c1',
		'DESEDE3CBCAlgorithmIdentifier.php' => 'b5d9f7c5d0c7eee7ab053e2211a97693',
		'RC2CBCAlgorithmIdentifier.php' => '958b7053709b6ca4baede1ffcf1bff8e',
	),
	'/core/libraries_phartemp/vendor/spomky-labs/pki-framework/src/CryptoTypes/AlgorithmIdentifier/Feature' => array(
		'AlgorithmIdentifierType.php' => '50ef3dc58c34ef4c36e83484b5b79687',
		'AsymmetricCryptoAlgorithmIdentifier.php' => 'bcaf1a23ee345534f0577c6477ed1164',
		'EncryptionAlgorithmIdentifier.php' => '972baaa0c58433cc696c3314e7d9dac8',
		'HashAlgorithmIdentifier.php' => 'c2aab3f05fe2f79c56f1c61f21980597',
		'PRFAlgorithmIdentifier.php' => 'bc96212d99d7b2d5f988cb6c6ec1e4fa',
		'SignatureAlgorithmIdentifier.php' => '6e2099629998bd7da1a25692329203b3',
	),
	'/core/libraries_phartemp/vendor/spomky-labs/pki-framework/src/CryptoTypes/AlgorithmIdentifier/Hash' => array(
		'HMACWithSHA1AlgorithmIdentifier.php' => '6e53c584eff6299826bf5e0c4037751a',
		'HMACWithSHA224AlgorithmIdentifier.php' => '4430e8ddc7000797d3437cbd115a60fd',
		'HMACWithSHA256AlgorithmIdentifier.php' => '5e01f8fb3cd15a3cfcba5dfcb1a39f0c',
		'HMACWithSHA384AlgorithmIdentifier.php' => '174a9121e0b0e6ab5b9f52f32fa0428c',
		'HMACWithSHA512AlgorithmIdentifier.php' => '67dafacc8fda58d3e504651b3de67693',
		'MD5AlgorithmIdentifier.php' => 'bea7ca3e273d3dbc9abd4b0254d9a070',
		'RFC4231HMACAlgorithmIdentifier.php' => '7ffc09a9c42c229093462366ffeccae8',
		'SHA1AlgorithmIdentifier.php' => '8a7a7cadbb178f11faf8fd4c9040dc0d',
		'SHA224AlgorithmIdentifier.php' => '4521982efa3e519b878841673f7d1e0b',
		'SHA256AlgorithmIdentifier.php' => 'c01f45df74100a5fd95a47e97db3444c',
		'SHA2AlgorithmIdentifier.php' => 'bc1c387219ced39385d4fa81bec755d0',
		'SHA384AlgorithmIdentifier.php' => '88ce3a384cae54177e15e4e7a7cf74f6',
		'SHA512AlgorithmIdentifier.php' => '135b6aa2120844c30434e9fe836dfcd3',
	),
	'/core/libraries_phartemp/vendor/spomky-labs/pki-framework/src/CryptoTypes/AlgorithmIdentifier/Signature' => array(
		'ECDSAWithSHA1AlgorithmIdentifier.php' => '67bac7034a4b381994b6b2c46f25e144',
		'ECDSAWithSHA224AlgorithmIdentifier.php' => '47b4e99c13eae255a11caea85945f241',
		'ECDSAWithSHA256AlgorithmIdentifier.php' => '313c816e91dd253e930a8bc7baa5fe01',
		'ECDSAWithSHA384AlgorithmIdentifier.php' => 'ce28f5f45bb282234cd3abcf2bc0009f',
		'ECDSAWithSHA512AlgorithmIdentifier.php' => '2e19add1d020442ded7eb0bb16432326',
		'ECSignatureAlgorithmIdentifier.php' => '4aba82c59af677dee3460657136efd34',
		'MD2WithRSAEncryptionAlgorithmIdentifier.php' => '70b6733f00a8f8017f29c95080a45069',
		'MD4WithRSAEncryptionAlgorithmIdentifier.php' => '7ab96b43b0711f6ca7ed7fbfb96d82ec',
		'MD5WithRSAEncryptionAlgorithmIdentifier.php' => '992efb3849027bf6cf259b4a4c55b0bf',
		'RFC3279RSASignatureAlgorithmIdentifier.php' => 'c39072da2d54879040c506cb30216d33',
		'RFC4055RSASignatureAlgorithmIdentifier.php' => '087ff80a577bd634b999c6eb59e144f8',
		'RSASignatureAlgorithmIdentifier.php' => '9590bb1b40dee56829dc57551bbde48b',
		'SHA1WithRSAEncryptionAlgorithmIdentifier.php' => '6287654ca9bee82f812c713438a4acb3',
		'SHA224WithRSAEncryptionAlgorithmIdentifier.php' => '23c3400db20e469d9a3f48ab9020e9a6',
		'SHA256WithRSAEncryptionAlgorithmIdentifier.php' => '3f1457777ebb7422a9e6faa004dbf53a',
		'SHA384WithRSAEncryptionAlgorithmIdentifier.php' => '558b036ad74a264916587e72372b8782',
		'SHA512WithRSAEncryptionAlgorithmIdentifier.php' => '97c377897f09e0122ff1bfe1a81d4a9f',
	),
	'/core/libraries_phartemp/vendor/spomky-labs/pki-framework/src/CryptoTypes/Asymmetric' => array(
		'OneAsymmetricKey.php' => 'c447068a78438a63c7140b2c7c86a48c',
		'PrivateKey.php' => '392e6055831e5c87a2182a53ae7b3aab',
		'PrivateKeyInfo.php' => 'bf5ae2d866378ecf1f1aef502602904b',
		'PublicKey.php' => '1285a141c44bb8527d81d692e3a7cc87',
		'PublicKeyInfo.php' => 'f02f375a9b1fff731b7537e39cb6c24d',
	),
	'/core/libraries_phartemp/vendor/spomky-labs/pki-framework/src/CryptoTypes/Asymmetric/Attribute' => array(
		'OneAsymmetricKeyAttributes.php' => 'f2fc80e9f6c8982515f0f4eb740ea8d5',
	),
	'/core/libraries_phartemp/vendor/spomky-labs/pki-framework/src/CryptoTypes/Asymmetric/EC' => array(
		'ECConversion.php' => '148b6bde6e759ac160d98ac56ec12090',
		'ECPrivateKey.php' => 'cf3256b23a47ed6567404409f16b25b7',
		'ECPublicKey.php' => '053e2463f9fac1d2537f87f0736fdc5c',
	),
	'/core/libraries_phartemp/vendor/spomky-labs/pki-framework/src/CryptoTypes/Asymmetric/RFC8410' => array(
		'RFC8410PrivateKey.php' => '6adf4178b76a29168d2591ed508ce615',
		'RFC8410PublicKey.php' => '9931af8e9892a926088444e8c174a590',
	),
	'/core/libraries_phartemp/vendor/spomky-labs/pki-framework/src/CryptoTypes/Asymmetric/RFC8410/Curve25519' => array(
		'Curve25519PrivateKey.php' => 'dcb00be56e5de95593ab143537883a28',
		'Curve25519PublicKey.php' => '260bde8104077a42e523f18630bbfaa0',
		'Ed25519PrivateKey.php' => 'be4d0201a10f3515e0adb33982e86c42',
		'Ed25519PublicKey.php' => '4dfc3df997f4aa48364e952b062766a6',
		'X25519PrivateKey.php' => 'b20a6f7197399bb8908e0ff4c9814ed8',
		'X25519PublicKey.php' => 'a548ac8e046a138c825667ebab90c348',
	),
	'/core/libraries_phartemp/vendor/spomky-labs/pki-framework/src/CryptoTypes/Asymmetric/RFC8410/Curve448' => array(
		'Ed448PrivateKey.php' => 'b96b2b7116e3cc5123f869de3e60a054',
		'Ed448PublicKey.php' => '8ced5dd5cde530f2e056aabcf2204c9a',
		'X448PrivateKey.php' => '5d8df2c6bb58db8779b541204da99def',
		'X448PublicKey.php' => 'c5eed5812178724b4f3e7cfd63383604',
	),
	'/core/libraries_phartemp/vendor/spomky-labs/pki-framework/src/CryptoTypes/Asymmetric/RSA' => array(
		'RSAPrivateKey.php' => '4fab5b009a2c71f1d44fee446b913f19',
		'RSAPublicKey.php' => '8a8657700a6da3e2d6c81904a88179c5',
		'RSASSAPSSPrivateKey.php' => '62001e53c61088239ef9ec298e3f2d32',
	),
	'/core/libraries_phartemp/vendor/spomky-labs/pki-framework/src/CryptoTypes/Signature' => array(
		'ECSignature.php' => '486ec6e36f75260b5677991b0602330c',
		'Ed25519Signature.php' => 'd303bb9e0188cb4b2138c85da1ffb56c',
		'Ed448Signature.php' => '591aa4c25c1dabdfd99ea43fea3541cb',
		'GenericSignature.php' => '3cb0403db6c7babbcf98d4db02d79ce8',
		'RSASignature.php' => '5ec830f5755cf5c04e97959fe93d449f',
		'Signature.php' => '23ef434bbf6b90ff65bc6191d333f798',
	),
	'/core/libraries_phartemp/vendor/spomky-labs/pki-framework/src/X501' => array(
	),
	'/core/libraries_phartemp/vendor/spomky-labs/pki-framework/src/X501/ASN1' => array(
		'Attribute.php' => '8a0724ce7c3aa74a85ae2c3877da2636',
		'AttributeType.php' => '4b6a5afddb3a959e4c5fec39330d35d9',
		'AttributeTypeAndValue.php' => 'b2f6d9cd117a933b9e6a52ce7684635a',
		'Name.php' => '7e281369f5bcb01136c431238110b1fe',
		'RDN.php' => 'e519905a16f41c75326289b35b511618',
	),
	'/core/libraries_phartemp/vendor/spomky-labs/pki-framework/src/X501/ASN1/AttributeValue' => array(
		'AttributeValue.php' => 'cb16d0cb755f43f79423715ed10496f9',
		'CommonNameValue.php' => '184db5676244acc718d93b72dded0d70',
		'CountryNameValue.php' => 'c3b0373af21806153776be50de77e41b',
		'DescriptionValue.php' => 'a6be1e339856f15bf22ab7d518ba8cd8',
		'GivenNameValue.php' => 'c15aa31d347681f711b479f926960ed7',
		'LocalityNameValue.php' => '58f83fb6e332f692fc90850fc51c3675',
		'NameValue.php' => '538742774c6f972854764737912afcb7',
		'OrganizationNameValue.php' => 'd9f7c5b48b5e3922150edc3ee860830e',
		'OrganizationalUnitNameValue.php' => '363037de2e7e25f7b14298683dfd966c',
		'PseudonymValue.php' => '33798fd47a6af72c2bd5237f4b95f7b4',
		'SerialNumberValue.php' => '9d5b1671644387b346a358fa9265f8ce',
		'StateOrProvinceNameValue.php' => 'f69461228c1be29fcbb3a64aa2fffc4d',
		'SurnameValue.php' => 'bec4bc917769c68190afaf33478d548c',
		'TitleValue.php' => '02a10101f88ac72c1ee0141610ccc240',
		'UnknownAttributeValue.php' => '722d728b2946441675ea959ba0ecf730',
	),
	'/core/libraries_phartemp/vendor/spomky-labs/pki-framework/src/X501/ASN1/AttributeValue/Feature' => array(
		'DirectoryString.php' => '60c28cc16706dfa724a7c371ffa8e646',
		'PrintableStringValue.php' => '1a755104e74481804ea069a9ec815f14',
	),
	'/core/libraries_phartemp/vendor/spomky-labs/pki-framework/src/X501/ASN1/Collection' => array(
		'AttributeCollection.php' => 'a415f3f309a6c930d338910cacbe72c6',
		'SequenceOfAttributes.php' => '2c411b5309e72a2347eb67810a882370',
		'SetOfAttributes.php' => '48277bd544cadcad0df0cc99207f6f17',
	),
	'/core/libraries_phartemp/vendor/spomky-labs/pki-framework/src/X501/DN' => array(
		'DNParser.php' => '50ff60591e325c82bf12d702906adcd3',
	),
	'/core/libraries_phartemp/vendor/spomky-labs/pki-framework/src/X501/MatchingRule' => array(
		'BinaryMatch.php' => '73342077e504c106cf8ec061a501fe56',
		'CaseExactMatch.php' => 'bb94ce37da04b1d7b7c128e049fed83d',
		'CaseIgnoreMatch.php' => '98da9421662a19ee806f05ba391ec8d3',
		'MatchingRule.php' => '05f11e854a9989032d1a9ffaf5ae03fa',
		'StringPrepMatchingRule.php' => '2955dc73c9cedb165bad6733e52f5ad0',
	),
	'/core/libraries_phartemp/vendor/spomky-labs/pki-framework/src/X501/StringPrep' => array(
		'CheckBidiStep.php' => '21238d7bdf76d03aa1fb64ef7e6e1d79',
		'InsignificantNonSubstringSpaceStep.php' => '85c68a588083c91342b594fccd96a32c',
		'MapStep.php' => 'eb355c3d17fa11ac2a94221f2eed877d',
		'NormalizeStep.php' => '3c7cba2c289377a2e0cf9222f9473ac8',
		'PrepareStep.php' => '453220089aabddaa3b1b848fb999bec8',
		'ProhibitStep.php' => '24342ad60c761c6daf6e3a9f8d4d514a',
		'StringPreparer.php' => '85d4502564f2c218f375f76514aa1906',
		'TranscodeStep.php' => 'bc8751b53b45ce11a2a47e33c9f9b11c',
	),
	'/core/libraries_phartemp/vendor/spomky-labs/pki-framework/src/X509' => array(
	),
	'/core/libraries_phartemp/vendor/spomky-labs/pki-framework/src/X509/AttributeCertificate' => array(
		'AttCertIssuer.php' => '27afeb22b46b8cb7540589c3260c7e2e',
		'AttCertValidityPeriod.php' => '68458422cd2abb515599f5159cbfca50',
		'AttributeCertificate.php' => '01b687b53dc14cf449e2410947ddd5a0',
		'AttributeCertificateInfo.php' => '0bf58ce8a23ce6d832016f8225650fd7',
		'Attributes.php' => '232e719194609836d9edc99ba358d0df',
		'Holder.php' => 'db3961cb2727891b4fafd16fdb4ad64c',
		'IssuerSerial.php' => '5bac29774554daed81b1180f4df51657',
		'ObjectDigestInfo.php' => '63cdea8c8a1b13049f75b8a180f5d623',
		'V2Form.php' => '72a2c11141d87a5a5e1398b249492b2c',
	),
	'/core/libraries_phartemp/vendor/spomky-labs/pki-framework/src/X509/AttributeCertificate/Attribute' => array(
		'AccessIdentityAttributeValue.php' => 'd6fe3a9ac7265272a1bf9d38d1b1d4fe',
		'AuthenticationInfoAttributeValue.php' => 'f58a9283b4c166344c8ab19cfef8cf38',
		'ChargingIdentityAttributeValue.php' => 'b79d0e9f33125a37a8dac29bb277f9f1',
		'GroupAttributeValue.php' => '518bf0ee165f79292f645b0416cd2c5b',
		'IetfAttrSyntax.php' => 'b1a391f9d251f33201bd2774d189992f',
		'IetfAttrValue.php' => 'f07d9bca48f42916a2d129e2cc3cb91f',
		'RoleAttributeValue.php' => 'cbe56e9b2391bd967cace2ec86b95681',
		'SvceAuthInfo.php' => '5da169770ca9d880300026991f368fa7',
	),
	'/core/libraries_phartemp/vendor/spomky-labs/pki-framework/src/X509/AttributeCertificate/Validation' => array(
		'ACValidationConfig.php' => 'f20772da486b1b99192c719973506964',
		'ACValidator.php' => '466dce05a50e128f02df48bbe9b44956',
	),
	'/core/libraries_phartemp/vendor/spomky-labs/pki-framework/src/X509/AttributeCertificate/Validation/Exception' => array(
		'ACValidationException.php' => '18000be1f66d0cc500eec014b5ecb9ad',
	),
	'/core/libraries_phartemp/vendor/spomky-labs/pki-framework/src/X509/Certificate' => array(
		'Certificate.php' => 'f0e6079e438f78b76e0a6fe4c89beab3',
		'CertificateBundle.php' => '2da40972e2624602221143afca3d7486',
		'CertificateChain.php' => '7f94fe3c8cd0e7549ae7a9b678697897',
		'Extensions.php' => '59ef836d19d6279523f537d4f6cd5860',
		'TBSCertificate.php' => '08131d7b71bdec575f4d19f0ae4d9d8b',
		'Time.php' => '889a626443efcee5dd8c407e81c1a345',
		'UniqueIdentifier.php' => '73bd9660bf8f0835ef7e4ea940b37f1d',
		'Validity.php' => 'a86c98f43542c0e2c64ddef326e616fb',
	),
	'/core/libraries_phartemp/vendor/spomky-labs/pki-framework/src/X509/Certificate/Extension' => array(
		'AAControlsExtension.php' => '13a52b0023e8e6b9be8cd69896cd22d7',
		'AuthorityInformationAccessExtension.php' => '803d71712669a21f23e2e8f263818c5e',
		'AuthorityKeyIdentifierExtension.php' => 'dd794d19e3a0d4a9a42b0088f0b0684a',
		'BasicConstraintsExtension.php' => '05d10679668c3d909d06a4c91bc32172',
		'CRLDistributionPointsExtension.php' => '7c3b2863b3f75e0f1c9d14c982eb2251',
		'CertificatePoliciesExtension.php' => 'e64ed1529e06a4f62ea926d83b213129',
		'ExtendedKeyUsageExtension.php' => '16f40b6fa72143d28e846f1cc96f502e',
		'Extension.php' => '5e23bb8411169d9dbb873a53631b1370',
		'FreshestCRLExtension.php' => '77071a2c59d92dad1b831b36713dd35e',
		'InhibitAnyPolicyExtension.php' => 'c1fb201f35eb23c7a9a3ba7385b0d326',
		'IssuerAlternativeNameExtension.php' => '88271bef5bbe24ea3927d030f2f4d642',
		'KeyUsageExtension.php' => '62e065a304bd474850ae642a3749e914',
		'NameConstraintsExtension.php' => 'ac1bd755b609f4b23b47e03af9c81389',
		'NoRevocationAvailableExtension.php' => 'a453b922cae5eb81d4b02bfe6ef6717e',
		'PolicyConstraintsExtension.php' => 'b3b49058c2a007345eb138e324efd3a8',
		'PolicyMappingsExtension.php' => 'a4b0065a39513ebeb47f5dc0237dd13d',
		'SubjectAlternativeNameExtension.php' => '3253ec500c1e1fa8cbe501dd05819d3f',
		'SubjectDirectoryAttributesExtension.php' => 'c8dcb6d14bfee4b74cbcae4b03813c4b',
		'SubjectInformationAccessExtension.php' => '70ea59ed3dcf4165d46063f8d90b818c',
		'SubjectKeyIdentifierExtension.php' => '8577b89ca61f60d282b7e3b45f713069',
		'TargetInformationExtension.php' => '3f157d00753ae238a276cacc57cae823',
		'UnknownExtension.php' => 'ff3c87fbe0e61d4222cf1090996895f6',
	),
	'/core/libraries_phartemp/vendor/spomky-labs/pki-framework/src/X509/Certificate/Extension/AccessDescription' => array(
		'AccessDescription.php' => '1a6ce2b177a8ecb1580594d301f92449',
		'AuthorityAccessDescription.php' => '4b53a567024ecc695cd4ce5514c954d9',
		'SubjectAccessDescription.php' => 'b512bc21ba0a915491a0dfbeb9ca8696',
	),
	'/core/libraries_phartemp/vendor/spomky-labs/pki-framework/src/X509/Certificate/Extension/CertificatePolicy' => array(
		'CPSQualifier.php' => '5e0181bb9f689c1376d6d88abe445ccf',
		'DisplayText.php' => '8a6851cdb555cf0371c2d81c9d7a66d1',
		'NoticeReference.php' => 'bdf9e476e55d3ea9f3dbf8a9b2c71259',
		'PolicyInformation.php' => '99bf18c6e070770978d1ae1075b11f74',
		'PolicyQualifierInfo.php' => '44a939da0571f2cadb81190b67d4e567',
		'UserNoticeQualifier.php' => 'aaaab1b5b344eb57694cf63538014dd7',
	),
	'/core/libraries_phartemp/vendor/spomky-labs/pki-framework/src/X509/Certificate/Extension/DistributionPoint' => array(
		'DistributionPoint.php' => '92b2c30b9488f229c2836edb566a244b',
		'DistributionPointName.php' => 'acb1c6645d79144aae3c671ef0f93a43',
		'FullName.php' => 'adcdeee736a52da15e59d8f87a485d5a',
		'ReasonFlags.php' => 'e0222c326eac3a26295ad353ab82efcb',
		'RelativeName.php' => '1b448c8fa7d447253ea0ebd05ef17e75',
	),
	'/core/libraries_phartemp/vendor/spomky-labs/pki-framework/src/X509/Certificate/Extension/NameConstraints' => array(
		'GeneralSubtree.php' => '692bcb9db9abf50ba7f7729139e36958',
		'GeneralSubtrees.php' => 'a7cfd4e46dd0e1d29a1559af508fa7f6',
	),
	'/core/libraries_phartemp/vendor/spomky-labs/pki-framework/src/X509/Certificate/Extension/PolicyMappings' => array(
		'PolicyMapping.php' => 'c5f68f470c77f30a0275ed4d46716fc8',
	),
	'/core/libraries_phartemp/vendor/spomky-labs/pki-framework/src/X509/Certificate/Extension/Target' => array(
		'Target.php' => '08794dcf322c6a0ee4740cef033f0262',
		'TargetGroup.php' => 'f625978a598098feba238963c492fc7b',
		'TargetName.php' => '2895d1a11837dcdc14f3b73265540795',
		'Targets.php' => '445d91564f80c70c2a6a23db45804284',
	),
	'/core/libraries_phartemp/vendor/spomky-labs/pki-framework/src/X509/CertificationPath' => array(
		'CertificationPath.php' => 'a5da05bd3018826d2f9681c87c250fc3',
	),
	'/core/libraries_phartemp/vendor/spomky-labs/pki-framework/src/X509/CertificationPath/Exception' => array(
		'PathBuildingException.php' => '717497723fc7f4861ff116bcd616b5d5',
		'PathValidationException.php' => 'b6c23f0dc58b48a2d4f665e759af6d3b',
	),
	'/core/libraries_phartemp/vendor/spomky-labs/pki-framework/src/X509/CertificationPath/PathBuilding' => array(
		'CertificationPathBuilder.php' => 'd6b46f7be35abe3e0686d8763333cff9',
	),
	'/core/libraries_phartemp/vendor/spomky-labs/pki-framework/src/X509/CertificationPath/PathValidation' => array(
		'PathValidationConfig.php' => 'd7457be2e059864b814e648163045c8b',
		'PathValidationResult.php' => 'c681b8a0e066b8591248ace83b9c331e',
		'PathValidator.php' => '070d729691ebf9c076c984bff04b43c2',
		'ValidatorState.php' => 'b39c08adf0084b87b5b1ba81db4bf662',
	),
	'/core/libraries_phartemp/vendor/spomky-labs/pki-framework/src/X509/CertificationPath/Policy' => array(
		'PolicyNode.php' => 'e823727481ddc311b0fb2f74ffbf774a',
		'PolicyTree.php' => '0988e9378c4fcc85027d059281883d25',
	),
	'/core/libraries_phartemp/vendor/spomky-labs/pki-framework/src/X509/CertificationRequest' => array(
		'Attributes.php' => 'cd5a1a5f77992229e60485cf0ec239b4',
		'CertificationRequest.php' => '336b373ebe71f9918ee6953711ccb827',
		'CertificationRequestInfo.php' => '6a6e3a99f20706c308246304c6289c98',
	),
	'/core/libraries_phartemp/vendor/spomky-labs/pki-framework/src/X509/CertificationRequest/Attribute' => array(
		'ExtensionRequestValue.php' => '61eb64e41474f77d8309ab7c13ea9a30',
	),
	'/core/libraries_phartemp/vendor/spomky-labs/pki-framework/src/X509/Exception' => array(
		'X509ValidationException.php' => 'd41c35e54d98155f7a7aed406f8c239e',
	),
	'/core/libraries_phartemp/vendor/spomky-labs/pki-framework/src/X509/Feature' => array(
		'DateTimeHelper.php' => '9bc785f2b25ea7e3eeba9aaf29a5865e',
	),
	'/core/libraries_phartemp/vendor/spomky-labs/pki-framework/src/X509/GeneralName' => array(
		'DNSName.php' => '523aa8fd4611b8b47d3adcbbb1e3640d',
		'DirectoryName.php' => '9f463c695de5b3fb9e25788abd2ae58a',
		'EDIPartyName.php' => '8fb50939a78e96051ab32df00315dd5a',
		'GeneralName.php' => '4a05bf039d8055645f26ca7059391753',
		'GeneralNames.php' => '752b20ac578d4883f085bc6646582a42',
		'IPAddress.php' => '57d376bc06711809adb6997e93a2abcf',
		'IPv4Address.php' => '39417aaf98aad1c91a711b973fcb1520',
		'IPv6Address.php' => '804a3a9e819beb627638edfab9c0749e',
		'OtherName.php' => 'ca17a60dfa75d54a2527ac08f66f6593',
		'RFC822Name.php' => 'f50f673be310dceb12ca13c34c12741d',
		'RegisteredID.php' => '236a10de82d047765b077c1b9b8b36e2',
		'UniformResourceIdentifier.php' => 'd1a109b32448be32d51c99dc8a71b11c',
		'X400Address.php' => '64b21e3792fbffdeccf5695c4608b112',
	),
	'/core/libraries_phartemp/vendor/symfony' => array(
	),
	'/core/libraries_phartemp/vendor/symfony/deprecation-contracts' => array(
		'LICENSE' => 'f288a4ab278f67080fb70a531307837a',
		'README.md' => '2f1b58feed61d01c682341406db41427',
		'function.php' => '4ba7d7bce9d6096b9fb5132624335e5c',
	),
	'/core/libraries_phartemp/vendor/voku' => array(
	),
	'/core/libraries_phartemp/vendor/voku/portable-ascii' => array(
		'LICENSE.txt' => '5b18f4441388fecd6c3162aaddda861f',
		'README.md' => '1e778fc5d28ce352779b35b43ddc934d',
	),
	'/core/libraries_phartemp/vendor/voku/portable-ascii/src' => array(
	),
	'/core/libraries_phartemp/vendor/voku/portable-ascii/src/voku' => array(
	),
	'/core/libraries_phartemp/vendor/voku/portable-ascii/src/voku/helper' => array(
		'ASCII.php' => 'a86114583084de00f6566bbf92986132',
	),
	'/core/libraries_phartemp/vendor/voku/portable-ascii/src/voku/helper/data' => array(
		'ascii_by_languages.php' => 'ff6c88595998e85c21e318381ec32046',
		'ascii_extras_by_languages.php' => '715bab700659151a4b1ca5fc67831d18',
		'ascii_language_max_key.php' => '4bfc2db3c1db2168bb20bf383d35e272',
		'ascii_ord.php' => '38c66d526ea6a24da9e46711dedc4b0b',
		'x000.php' => 'a71be5119aa27b4de58595ff4260ad85',
		'x001.php' => 'eaa016a0af210e218afdc0077ce47ba5',
		'x002.php' => 'e81d0b0d64018659a80dc025df0694e1',
		'x003.php' => '1bedf0d896a023d6379c938ef8c28cec',
		'x004.php' => '49ab4f3c625cf6b8c1c7f726cda73298',
		'x005.php' => '854bc45f1166bd40d06d56b487038572',
		'x006.php' => 'cc59c70079b7549a7d7e793cce3e3fa2',
		'x007.php' => 'd1e85a0e8db2cbaa7cf2e57e977f6288',
		'x009.php' => '2988a6a1a085e0e37bf7028fb9db4063',
		'x00a.php' => '13ff0549a56507ff92123fb1c0274c49',
		'x00b.php' => '15218412089f17a1322c476ad9e49c31',
		'x00c.php' => '15aa0c12d19856e7f455592feb1b7871',
		'x00d.php' => '55028ffebd7cc7726e281162d90010fa',
		'x00e.php' => 'e7d67a25fd227500b0bf964cdc4803a6',
		'x00f.php' => '30c75bb7a0cbea1675e74be363759d84',
		'x010.php' => '63fb2c2a9939d2828b954c6a7bda67c6',
		'x011.php' => '946cc26b18685d1fc409b8342ff56c0b',
		'x012.php' => '380548ef3fe33686f819510b6fc8133f',
		'x013.php' => '6c79e04eb81c9cf039f4ee41e25729cb',
		'x014.php' => '55464c928ba4931936ecadea1e07c8c3',
		'x015.php' => '0069910b1e35b33bb69c642cdf9f4d28',
		'x016.php' => '75ab21b18e3ed0726bdc9ff1c8e09106',
		'x017.php' => '1665a8e76d2a0ca5c143a7684e2cf252',
		'x018.php' => 'c797224837f6b4963428a7a9ab22e6f5',
		'x01d.php' => '2e8fc4f61f6b89bcdadbf2988dc0cd29',
		'x01e.php' => '0a71eee2330deb1a7cd0aecda4f23515',
		'x01f.php' => '3576c451512d57de22f4379439699efc',
		'x020.php' => '19dff5904a5c68b45cc68f36c217f3b1',
		'x021.php' => '0b394a16db933ae62bfe15e9c974f824',
		'x022.php' => 'cbd3dde013c6ebe192ed2951c25e2466',
		'x023.php' => '57ef905b4158f82fbb6fb79d9fbd5c34',
		'x024.php' => 'de503b0b0ba7192f63312f7d2c0c0d8a',
		'x025.php' => '95fc434ebb787dddb3a65b013264ef6e',
		'x026.php' => '53efee6e1b71913ddeea9ca5ce0b12f8',
		'x027.php' => 'fd5d6f3ec0d7e380c55edf4394d05b46',
		'x028.php' => '70497b7f52430f2c983b62b8e6af48ea',
		'x029.php' => 'a4fcbb89be05f21818012f9ad0d8395f',
		'x02a.php' => 'f887e520a1b8aa2671098f755d19de91',
		'x02c.php' => 'd4213d80e1229c5b902ec858a328fa4b',
		'x02e.php' => 'f0432132b6f8e45a3772f1aff83cf042',
		'x02f.php' => '2d874931c0b4db1d36be10a88c0c634e',
		'x030.php' => '53a48b5d9681e0563908b2ef7356e6ed',
		'x031.php' => '60e7d2a96cb410dae9c6f2cda7337973',
		'x032.php' => '647aaffb5ccb5a374f0ebed8c3de2c99',
		'x033.php' => '1b68a5c3cff653c7292d396e7ce2c3ef',
		'x04d.php' => 'ca8dcc7025a68523049a86ba01675579',
		'x04e.php' => '976b6b5fe48f969d99422a32d18f949c',
		'x04f.php' => 'aed387ed7c5ce034d7b34be3fa5bf9ca',
		'x050.php' => 'd2c4d0a3243e64e8ef90c3dbd5fb7a89',
		'x051.php' => 'e0bae0b99d6a416b2f1c3447c66004b0',
		'x052.php' => '9f34959c67cd16b6956c330df0f3d688',
		'x053.php' => '5b84ed8dacb13190105743acfae914e6',
		'x054.php' => '63b9bd3d068123cd32fee10bf000d92b',
		'x055.php' => '454ae4988ee1e778d1ff2a47f23bb81f',
		'x056.php' => 'da176c0e4c0e079692483b23a69ef4a4',
		'x057.php' => 'd718d20f474cbd58e2b89269190116c4',
		'x058.php' => '2eed12b168224f3ce8ab946a2c7d4bf4',
		'x059.php' => 'f2a1a2bc1cf2efc2fdb3babecda32eab',
		'x05a.php' => 'fd37fe04d27c8b9b6648355c8efc03b1',
		'x05b.php' => '89a2e5a347e2baace4ea5f854526cce7',
		'x05c.php' => '195663a23787a07665189c43d02814b9',
		'x05d.php' => 'c9b79f129410d9aaffce76b367fe0ed4',
		'x05e.php' => '7e98630b43867e71d1af75c5383d9b68',
		'x05f.php' => '55ab8a56880bf6a590f566f8b70c6e76',
		'x060.php' => '42e91a5b9cb2968b2c647f4076bb4c94',
		'x061.php' => 'dabdf8195546aaf4f90f2c14b8c4699a',
		'x062.php' => 'ad218ac425d8cd228ea0557fa9425deb',
		'x063.php' => '0c273ec59083f5b42491cfef74ec1f3a',
		'x064.php' => '9d823a76c8b8cef4c05683028a903c7b',
		'x065.php' => 'fa157f1937114b0d6543081d77603af2',
		'x066.php' => '39fbc4c69b4528032aa0eaccccb9b35f',
		'x067.php' => '749620bffc9f1e12ca70fbdac8d889e4',
		'x068.php' => 'e054bda678ae5e3e0990fb26419a20db',
		'x069.php' => 'e81bed57c4cc4ba17f407e77b191fbb9',
		'x06a.php' => '86beea5c338ef1cc401049ddb21a994a',
		'x06b.php' => 'ed653928a9bb96f1bd30c99f321b190e',
		'x06c.php' => 'ce64e295196db35f70457f6e71caa89b',
		'x06d.php' => '4c6ca2ddeac12b8660161575bf338c00',
		'x06e.php' => '53f98534d64221862f983caec7b9d056',
		'x06f.php' => 'dd1560b8d627c60f0a630e39078b11cc',
		'x070.php' => '18444be95ea5b3571aaa8a2426c39fe4',
		'x071.php' => 'c6b6b2b54d53f4510e8dda6c1cdb12ba',
		'x072.php' => '91574a347595bda3b231800cd0eba8d9',
		'x073.php' => '83fa1e5a6d2b56f6100bfb1ea8deffd0',
		'x074.php' => '7225d3b1d5c0d925ed5ac28d683bcee4',
		'x075.php' => '12b3b329a57778a99da9e309b8e95f55',
		'x076.php' => '747f78f78e59af531d2229b922005d36',
		'x077.php' => '057a15b1b880a2a4ab4f01674f707abb',
		'x078.php' => '26dd71d5fa8f0b600bf8be767bcb8dd4',
		'x079.php' => 'aa694d9036fe86328abc81ce5b29cc83',
		'x07a.php' => 'f9da8abb2badea55231e750ccc586091',
		'x07b.php' => '756304c99eda02b4239cbf63e23dcaa9',
		'x07c.php' => '0bd133456f754e5ac257854fb61dddf9',
		'x07d.php' => '5640afad8411bb7d4602e0ed92808b05',
		'x07e.php' => '25786db33f6d666f08a930e5ea1b22df',
		'x07f.php' => '7147f922dc9947cb51a73f4b455fb01a',
		'x080.php' => '9f2522fa858ce9ad5a666ecae8deee48',
		'x081.php' => '14e2c0e866dd964d01c97549f93bd1a8',
		'x082.php' => '41b01a86641552aa5af9355b68539b6b',
		'x083.php' => '0ecca459c93707be0205a40372e32973',
		'x084.php' => '46f53bd19c8f9b529bf513f689d10e0c',
		'x085.php' => 'ef5e18b1819bda85c5a23d401d615c89',
		'x086.php' => '33041b302ec86c63795eb8eceb4431ae',
		'x087.php' => '3e1278d113fffe19e7e03b5ab82885d6',
		'x088.php' => 'b76a264c83d7317ec83a386dcaa2773f',
		'x089.php' => 'af9c496841996a12b5de2611618352c5',
		'x08a.php' => '3d045536d4e8a320a6a19e8379d4c281',
		'x08b.php' => '673359a6453041fe8736b4a7bb600f6d',
		'x08c.php' => '02abf1e104b1e18f76b767770df9f9e3',
		'x08d.php' => '60985d373ececdf46ff461fa6dd36bde',
		'x08e.php' => '63cb860e8f16329c309971032931638d',
		'x08f.php' => '24106d3b75e1b22dbd463cd056899843',
		'x090.php' => '6df151bcae1d055637ff3917f7376ecf',
		'x091.php' => '793421dcaae2ea3b83ae16c538b4d2ff',
		'x092.php' => '19656291476418c23db42a38730d7f9e',
		'x093.php' => 'd314e41b9919e420051a349b87a5bdd0',
		'x094.php' => '4a302cdbbc5d934964b815bd6004d96f',
		'x095.php' => 'd18713deb7f798547a07079a2eb8447b',
		'x096.php' => 'c5d5672c53cd1ccd53e1194ce28bf5d1',
		'x097.php' => '96aeefc849878b6b29b2ddaf557de8d3',
		'x098.php' => '5d2ceeff4a484293aed90bc72a153bfe',
		'x099.php' => 'd05ccffaf84537baa3cd5a410e7b8710',
		'x09a.php' => 'a1c71de59a7126bddea3cd42a74e646c',
		'x09b.php' => '687742f756f481283715c69da1b68650',
		'x09c.php' => '11e2a66c4c88e304a51f14a3cd495f89',
		'x09d.php' => 'f61769f8a46c7cd0f699aef3aeb3eb9c',
		'x09e.php' => '9881ec103239faf94d497a7444c116ed',
		'x09f.php' => 'a66af1dd2b1354bc1225bbad9c8a40bd',
		'x0a0.php' => 'f5c6691fbc176b1516cf974811749204',
		'x0a1.php' => '004f49e364539e49b72ed45adb60c03e',
		'x0a2.php' => '5fdf49350de9f45b4d6a7a6af6a868f7',
		'x0a3.php' => '10cd5afec3f180765f32c349b6837c32',
		'x0a4.php' => '266412e355f6205125c09e628a980e5a',
		'x0ac.php' => '235d8c0f79cb4d17df9e6d5d8342e718',
		'x0ad.php' => '15bfca851e482ad10c3b22df59d9e77c',
		'x0ae.php' => 'e62fdc25d02be7448fa8758f7ebfd3dc',
		'x0af.php' => '2c40324fd0786fa47ebb0dca3caafaae',
		'x0b0.php' => 'd4433b32765f3481b2c375ec867fb020',
		'x0b1.php' => 'e5b0586ac7347899cebac1d27997b6b8',
		'x0b2.php' => '262631b697176fcf9991c40cdf337041',
		'x0b3.php' => '58bde501e6fe25f5749f8f56317aeba9',
		'x0b4.php' => 'fec92a6e264912c03edc31833d7c109e',
		'x0b5.php' => '20e9da3ce2e25e60e0bfdded335b0ce7',
		'x0b6.php' => '1fdc01c8aa8c689a44273718bc9c68c4',
		'x0b7.php' => '01fcb21855eddc83e26e3dd0320f52ec',
		'x0b8.php' => '22ca3d476d04829d626bd98a62cf6e0e',
		'x0b9.php' => 'cdcdc535908ec9689305d49410d80550',
		'x0ba.php' => '51469cc896f6adb1ce15b68b157a9ea5',
		'x0bb.php' => '7256b5c460d005f4e588596247b88c33',
		'x0bc.php' => 'acd9c96c1ed6c627cccf310ef333b701',
		'x0bd.php' => '6ad9b41978ea315096fc4e02ceaf4d78',
		'x0be.php' => 'd62ce7714f49f08e264e9aebc9c797a7',
		'x0bf.php' => '4313d816edb37d4a2a06540a1253e501',
		'x0c0.php' => '9907232e6acab8c7084e14b13c2d2c80',
		'x0c1.php' => 'c553bd654560d01e9a21b2bf5c8cbff9',
		'x0c2.php' => 'b8ca1c72f2960c5fd100ad58042638d0',
		'x0c3.php' => '5b5602eb82f277596b7180925069c42d',
		'x0c4.php' => '920d217334322685a28aaf0e61406ac3',
		'x0c5.php' => '88cd9e11d87e15837d2948045e17d85e',
		'x0c6.php' => '4b63d9a7533683eebda689bcfc77f630',
		'x0c7.php' => '85146bbe9e2fabd551c788bcd55f7881',
		'x0c8.php' => '9f65661898e1caf4f517fe20b5024d34',
		'x0c9.php' => '01768a3aa7bed836835e38a53ad9355b',
		'x0ca.php' => 'c9e2af2fe11cb7dec36db64ba7180d92',
		'x0cb.php' => '4887f7c1ff80f58b444eeac33fda8078',
		'x0cc.php' => '277b3dd61b9c2a1597aec5065b6df97e',
		'x0cd.php' => '0b2d7276af6d1d89dfecd9b9f785b279',
		'x0ce.php' => 'a1fc51c3bf4f1f1bac59cd5cd85ef58d',
		'x0cf.php' => 'f48c12a5d7afe47e6411daf9fbac981f',
		'x0d0.php' => '3a52382792f740cf7fcb5232d0be7615',
		'x0d1.php' => '66011d0d1c787cddb91e7f02895e7423',
		'x0d2.php' => '96a14c28c91106dc715867ee41f39a83',
		'x0d3.php' => 'df9a64038070408787c5d47b93936fc6',
		'x0d4.php' => 'c680d66e0de0259ca1f1d21686185083',
		'x0d5.php' => '36f0ada818bc249bfe4079be3f4677dc',
		'x0d6.php' => 'c71002b1f9100344f005d3d2a1da4db0',
		'x0d7.php' => 'c6dae2c611de6b269803e914f61ce8a6',
		'x0f9.php' => 'e7884d49627e5cdd16715a82b2ce5805',
		'x0fa.php' => '12363e8cf93004e437632e99c18a2fd0',
		'x0fb.php' => '5a11406a60996269045f566dfe54ad27',
		'x0fc.php' => 'ef88137684f70e73baea862453f080ee',
		'x0fd.php' => 'fcdf9a864132280c1f05b4ce146de131',
		'x0fe.php' => 'ce080e4bfcd5b2ba41cdae4cdf8e9842',
		'x0ff.php' => '7169216d12e3df5cc53d09db7fbf9df8',
		'x1d4.php' => '4b1e63f3ed432b852f9d173c143e5d82',
		'x1d5.php' => 'a9d16b9ee757b45858bed319badb8c12',
		'x1d6.php' => '4a830c97e379ea1ef1c54f25d99cd9fb',
		'x1d7.php' => '1afd0baa8750065e4ae44f1af872cea2',
		'x1f1.php' => '6cfcfd1332c7b0ee5da84020f7c7040c',
	),
	'/core/libraries_phartemp/vendor/web-token' => array(
	),
	'/core/libraries_phartemp/vendor/web-token/jwt-library' => array(
		'LICENSE' => '27038a84ac6a315f3f674a60f3d54972',
		'README.md' => 'c31e9b2670f57817bf4a748934d2e160',
	),
	'/core/libraries_phartemp/vendor/web-token/jwt-library/Checker' => array(
		'AlgorithmChecker.php' => '81ff8275d6cd95f3609c23df52328d51',
		'AudienceChecker.php' => '56e64827c9cd544b0ed2cc8d52bfb9ba',
		'CallableChecker.php' => '23122e361c52c559e9662e629fd484ca',
		'ClaimChecker.php' => 'aaeb25f23646e32f63914b436007bbe1',
		'ClaimCheckerManager.php' => '2d27911c4395c80c6c139a3b629dfc7d',
		'ClaimCheckerManagerFactory.php' => '4af746d01fa7917105f8d0342f2f1562',
		'ClaimExceptionInterface.php' => '2d7d15754d088bc58a7122606c141d4b',
		'ExpirationTimeChecker.php' => '29c1adb13604725a29dda49a63e7bf61',
		'HeaderChecker.php' => '0bc0c32a1f8a2e3c34148ef26a7deb7c',
		'HeaderCheckerManager.php' => '5a6de3a3fba0ea6ba2b665cf599db719',
		'HeaderCheckerManagerFactory.php' => 'a4b66aafb1d16a00747698904cc5594b',
		'InvalidClaimException.php' => 'cc1d8cce6d67683b60c5e07600319b9e',
		'InvalidHeaderException.php' => '52cc0e901120c90af12150cb12374c38',
		'IsEqualChecker.php' => 'dad515c6448a6174f7cca1f4d4f7df68',
		'IssuedAtChecker.php' => '385dc916d068100df97771a052f4556d',
		'IssuerChecker.php' => '570562648ba5d867d574cae913129345',
		'MissingMandatoryClaimException.php' => 'd18232ba78fe0a8fbd38ef5c82c20d12',
		'MissingMandatoryHeaderParameterException.php' => '4ce2ead1685611ff497d15ad2fb617a1',
		'NotBeforeChecker.php' => '45b3bd7167a5de91614cfe05b8a68fad',
		'TokenTypeSupport.php' => 'c6aa6651dba72cdaf058621d27254325',
		'UnencodedPayloadChecker.php' => '6b7865780091e6253e8b96017b8e7350',
	),
	'/core/libraries_phartemp/vendor/web-token/jwt-library/Console' => array(
		'AddKeyIntoKeysetCommand.php' => '695aaa9cc05b974770e573f176f17006',
		'EcKeyGeneratorCommand.php' => '4e1a17e07ad150ec41e0bbd11130cfd4',
		'EcKeysetGeneratorCommand.php' => '08ce075a849b8a59899146d57f056917',
		'GeneratorCommand.php' => 'e9cce923a19c135e23c2287b03e79106',
		'GetThumbprintCommand.php' => 'a49a6d1bf5e91263f62d88d4b4019f56',
		'JKULoaderCommand.php' => '356cfef9fc7a39e9c3cce363ad0c28b0',
		'KeyAnalyzerCommand.php' => 'cbfc87bd9f5f9ad1214353f27d4f834d',
		'KeyFileLoaderCommand.php' => 'f785533df920ecfa8f9a38a4560d5618',
		'KeysetAnalyzerCommand.php' => '514a643dcc1493615523d195f50aba70',
		'MergeKeysetCommand.php' => '838c5cb4da05a770214be1b8a21767aa',
		'NoneKeyGeneratorCommand.php' => '2501d64659709c7c346eb68f0467a201',
		'ObjectOutputCommand.php' => '30f52c89a9ef53f9e2218f87b084f71d',
		'OctKeyGeneratorCommand.php' => '1e5edeb1729f1efadd33435c4d4ec3de',
		'OctKeysetGeneratorCommand.php' => '3bb049ab517f38d221168b564897e817',
		'OkpKeyGeneratorCommand.php' => '118889820ab2129d39fe08eb2c28b875',
		'OkpKeysetGeneratorCommand.php' => '2a38a4d7a0fd2e043238dfb3caf67327',
		'OptimizeRsaKeyCommand.php' => 'fa6ad35c9e5c5871ec8e6628abd57c31',
		'P12CertificateLoaderCommand.php' => 'f13b16b141bf8209dbe174cce1170e53',
		'PemConverterCommand.php' => '75ab27baab365dc9a8a1312530603815',
		'PublicKeyCommand.php' => '698d57efd18c4f6464566e31b1dba280',
		'PublicKeysetCommand.php' => '60948eba585b6a77c754f646ea2b4e42',
		'RotateKeysetCommand.php' => '7289cefb14efa808822f150a8dada8c0',
		'RsaKeyGeneratorCommand.php' => 'bb87abd99a43cb3f18b45d1723f98834',
		'RsaKeysetGeneratorCommand.php' => '37c9b3413a4a92d4ad8b6f08d668d807',
		'SecretKeyGeneratorCommand.php' => '3604a47de7a79ad7607dc0e8bb7f485a',
		'X509CertificateLoaderCommand.php' => '981ebcc917023ef2be5ef4ce2fae1eeb',
		'X5ULoaderCommand.php' => 'ba45f8e10d293f733b2993a176e12e8f',
	),
	'/core/libraries_phartemp/vendor/web-token/jwt-library/Core' => array(
		'Algorithm.php' => '75cfe32b27623dbde5f427f1927730b4',
		'AlgorithmManager.php' => 'cf51400f5cdd112780f539483f2b38de',
		'AlgorithmManagerFactory.php' => '5f3084dc4b4a6b1092a7fbc2b1852743',
		'JWK.php' => 'e25dd7d38687371cca6faf4613136b33',
		'JWKSet.php' => '91af79e75ebb00c2cd44c14eaff056a5',
		'JWT.php' => 'b51dba123e2fb8d2e2bfc90273980ead',
	),
	'/core/libraries_phartemp/vendor/web-token/jwt-library/Core/Util' => array(
		'Base64UrlSafe.php' => 'b8dc4a287cffbc700be95219323b76a3',
		'BigInteger.php' => '91de2b06131629687daa27080e27cba1',
		'ECKey.php' => '4c047e6ed75ef6b51330279a4c4c6986',
		'ECSignature.php' => 'ee18cf0ef3554bccf4039e8f21c9fab7',
		'Hash.php' => '71b571d50f58565ce62fee9f0da44d3d',
		'JsonConverter.php' => 'b3f4c007eef75510201a2e0cc98f23e8',
		'KeyChecker.php' => '1b68d6e935508e04163805f6bd832e57',
		'RSAKey.php' => '35faf58adf32b6ff1edd6666067b681a',
	),
	'/core/libraries_phartemp/vendor/web-token/jwt-library/Core/Util/Ecc' => array(
		'Curve.php' => 'e55f1e6105aaf55e17c3b965ad8fcf36',
		'EcDH.php' => '74df15c984842fd186755c8e35a07fe7',
		'Math.php' => 'c28a096ea4d2efbd522cf442534847f8',
		'ModularArithmetic.php' => '36f41866f8e1c6155614f4860d8d14b5',
		'NistCurve.php' => '51d948677e328cefe7868821f5ac250d',
		'Point.php' => '395aefa7b689257c65542e3a25d2b9f3',
		'PrivateKey.php' => 'f509a2c6c4c8ba1ca52d63f737ae91c4',
		'PublicKey.php' => '2a1a10a504df3f9f6749ddbe2cef9118',
	),
	'/core/libraries_phartemp/vendor/web-token/jwt-library/Encryption' => array(
		'JWE.php' => '8416c99ba07295a2bdf300cccfc7db67',
		'JWEBuilder.php' => 'a5e9a14d80f3364f9413cf9d874d40bb',
		'JWEBuilderFactory.php' => '628bd16ae3041930e35ff521634dba64',
		'JWEDecrypter.php' => '59b766d813c05c995d39fffa93af1dff',
		'JWEDecrypterFactory.php' => 'd5b3e5e76f6cf047594ae287a9554ce7',
		'JWELoader.php' => '60ceac135fef61b160e924bb5de7a9bc',
		'JWELoaderFactory.php' => '2324b1cbceef051cb3e23b6a7b5414c1',
		'JWETokenSupport.php' => 'a7a9b1cd4127b07c5988c3e12028fbfb',
		'Recipient.php' => 'f4741db3ddddafa59bff71305bc3a659',
	),
	'/core/libraries_phartemp/vendor/web-token/jwt-library/Encryption/Algorithm' => array(
		'ContentEncryptionAlgorithm.php' => '4a3f0e996e5e76dfa6819c23bb8673cd',
		'KeyEncryptionAlgorithm.php' => '3013c4d3407b623d4348d719371c50d7',
	),
	'/core/libraries_phartemp/vendor/web-token/jwt-library/Encryption/Algorithm/ContentEncryption' => array(
		'A128CBCHS256.php' => 'f72b16a71ed6ed51bd12079fce38c755',
		'A128GCM.php' => 'fd92b73c32daaa87928f4ab2b03f8e62',
		'A192CBCHS384.php' => '4968f37d0ba44ead23295785abfd8ea9',
		'A192GCM.php' => 'd8e66b984a8e9755da4c3f5f5b5389a7',
		'A256CBCHS512.php' => '687d08e007578836cafd41475318aa32',
		'A256GCM.php' => 'c38cdf7c7d9e87e4b645330d1943550f',
		'AESCBCHS.php' => 'cca6db1d540dba60fda7ed6fbf017515',
		'AESGCM.php' => 'f7cbcbdc5e1bf3088895cc0073f119eb',
	),
	'/core/libraries_phartemp/vendor/web-token/jwt-library/Encryption/Algorithm/KeyEncryption' => array(
		'A128GCMKW.php' => '856b584cf91c9cef01a9389c5079e5bb',
		'A128KW.php' => '13c4258ec902f2a0ef1f57d84439644f',
		'A192GCMKW.php' => 'bc07b06b93afa6fc09b269ec77296141',
		'A192KW.php' => 'fc5485d0dd4283aec0823820c94576d9',
		'A256GCMKW.php' => '70aeef5b95ed2e67e8d3f49eb9f1775a',
		'A256KW.php' => 'e6de3086772260d268359ffc9f265684',
		'AESGCMKW.php' => 'b9cfd85ddb2c74112fec4a6f1aeabaae',
		'AESKW.php' => 'c34542d7fc8f3bbb2782c4a4b29d9aae',
		'AbstractECDH.php' => '1fb55ba24c4d0823be0a026a2fbfd6b4',
		'AbstractECDHAESKW.php' => 'e139d73d85f6a3c02b29813cf1728df0',
		'Dir.php' => '1a68e136ba3a875e47218632b659ce40',
		'DirectEncryption.php' => '9eb3e7dd90783086cdcc36b46984fac4',
		'ECDHES.php' => '3a1501bbb8c289da5292b5d703f7e284',
		'ECDHESA128KW.php' => '224e8ac0306bab07d57e56195964fa73',
		'ECDHESA192KW.php' => '72ccf1cc9946b160f5a2e1057423968a',
		'ECDHESA256KW.php' => 'f19cae414e9c77854cee31e971f4a753',
		'ECDHESAESKW.php' => 'ee074c8eb31c5d54f9925e4ba8443995',
		'ECDHSS.php' => '34740befe849343c919b6e80e6f9754d',
		'ECDHSSA128KW.php' => '35939501f589f1e4a89cdf917ba55d63',
		'ECDHSSA192KW.php' => '27f6528f1a6c9aa10c9d639b240a7f18',
		'ECDHSSA256KW.php' => '49d3412be42e07e4588ef000512e9bf3',
		'ECDHSSAESKW.php' => 'ef0761ef92e46591427a6fc0ba4ef503',
		'KeyAgreement.php' => '65730bbbb3cc6effafc559fc0965f6ac',
		'KeyAgreementWithKeyWrapping.php' => '906a3ac373720aeb4ead17d4ca2c4c5e',
		'KeyEncryption.php' => '74efe82988df1a82c2bcdd2b996435df',
		'KeyWrapping.php' => 'c4a9b26c1af1b27c9d6aabd26e1f2838',
		'PBES2AESKW.php' => 'c2018f699627c06c60a6c1c6f693cecc',
		'PBES2HS256A128KW.php' => 'c44ad20449a84a11587fdc4b72618b9e',
		'PBES2HS384A192KW.php' => '8a0c0bbbfeec4f68851f32fa01b6c719',
		'PBES2HS512A256KW.php' => 'ea9a8206995096aa9d2c781cc40361b2',
		'RSA.php' => '10f7cf47dc411c1f7684254ed4d45e5d',
		'RSA15.php' => '75511ca987c6241a61f1e97e57ab0eac',
		'RSAOAEP.php' => 'f8da701e88fb9a4c3eca39e4c2b5f49a',
		'RSAOAEP256.php' => '54a307f27dc4b07a151d915c837cd945',
	),
	'/core/libraries_phartemp/vendor/web-token/jwt-library/Encryption/Algorithm/KeyEncryption/Util' => array(
		'ConcatKDF.php' => '8a63ad038f2ae142f7257c86245a3b58',
		'RSACrypt.php' => '137cc9dfdf408109825dd446f0e33fa9',
	),
	'/core/libraries_phartemp/vendor/web-token/jwt-library/Encryption/Serializer' => array(
		'CompactSerializer.php' => '4de87b1c8354c0a3ead9a7018c44dc21',
		'JSONFlattenedSerializer.php' => '914e236ff56218e3de98da901945abf8',
		'JSONGeneralSerializer.php' => '4d935ef918586c79197a4cf4d942f64a',
		'JWESerializer.php' => '88758717e9a6b9c16fac8dba5c25e8b2',
		'JWESerializerManager.php' => '9aa7b12ae3460b4d2b1e7ceda40f0a4a',
		'JWESerializerManagerFactory.php' => '32c6e9868b06bb80b0074fe704cedba5',
	),
	'/core/libraries_phartemp/vendor/web-token/jwt-library/KeyManagement' => array(
		'JKUFactory.php' => '8e70ed7b4c0cbc7f5af4ce48659e506e',
		'JWKFactory.php' => 'a70adf115bed1fdaba711839d1772c73',
		'UrlKeySetFactory.php' => 'bbf75cd17b31be577d28492d6b1f7762',
		'X5UFactory.php' => '8cb440eeac619c2d5bed1387f96c768b',
	),
	'/core/libraries_phartemp/vendor/web-token/jwt-library/KeyManagement/Analyzer' => array(
		'AlgorithmAnalyzer.php' => '7dfeab84b20452780f295b67044970d3',
		'ES256KeyAnalyzer.php' => 'a06e9993b3987118b8bb1ef81cc2e29c',
		'ES384KeyAnalyzer.php' => '4bd9474e4b903e6c38a9c0226a71043a',
		'ES512KeyAnalyzer.php' => 'ca57c547791203e46a9951b881bfa25e',
		'ESKeyAnalyzer.php' => 'e2d50f16164ac735ccba0c251b0957b3',
		'HS256KeyAnalyzer.php' => 'da8c9eb80b8e096b60b7b899cb44edbc',
		'HS384KeyAnalyzer.php' => 'b6935e31ee7cf3665b4806dd1f9f3a29',
		'HS512KeyAnalyzer.php' => 'b98ff4001f93ab33435cbed2e13acc76',
		'HSKeyAnalyzer.php' => '053ac78b1a0e79c6f705da9d172b2882',
		'KeyAnalyzer.php' => '109e7bdfe5a7bdc8a87f45be8ca1fb49',
		'KeyAnalyzerManager.php' => 'b6ea981c5c077c0584377c5b126d5524',
		'KeyIdentifierAnalyzer.php' => 'cec7238e40eec95b0d0b797fc152bcd5',
		'KeysetAnalyzer.php' => 'c335adf0ee0447c2aaae9845c140abb6',
		'KeysetAnalyzerManager.php' => '7158b899fc77712d24c28ef163988ad7',
		'Message.php' => '9af9a76839994cf470f088635011229b',
		'MessageBag.php' => 'ffe9c28bd7dfac5c419dde52da309f99',
		'MixedKeyTypes.php' => '64ed03217e71ab2fce77214a1fb3fd96',
		'MixedPublicAndPrivateKeys.php' => '860266aaf5fd187a4dbd061ce1b65353',
		'NoneAnalyzer.php' => '37f4fdc295a22cc3259000ecb6f6d3fd',
		'OctAnalyzer.php' => '65feff6f02df758a6d9519b55aa297f5',
		'RsaAnalyzer.php' => 'a9cc782683bc8c14a45ee19600c48f5f',
		'UsageAnalyzer.php' => '031ec2d36fc9dc720b6b81b9c43823cd',
		'ZxcvbnKeyAnalyzer.php' => 'f78710defe6c13c409fe93fa7f572e9a',
	),
	'/core/libraries_phartemp/vendor/web-token/jwt-library/KeyManagement/KeyConverter' => array(
		'ECKey.php' => '3d161dc7ae5c8a939da7777ad03535e9',
		'KeyConverter.php' => 'f59299e7a468cc4082d02686d7096aa4',
		'RSAKey.php' => 'a7d2490f3dcde9e9c5030ac68e163fa7',
	),
	'/core/libraries_phartemp/vendor/web-token/jwt-library/NestedToken' => array(
		'NestedTokenBuilder.php' => '4265bb91d55526baa3f68355c5f19b14',
		'NestedTokenBuilderFactory.php' => '1f91b5d81307490c658beb7a25a95a94',
		'NestedTokenLoader.php' => '3da213b189a3f94d1b60f27034589329',
		'NestedTokenLoaderFactory.php' => '5312c2b389826826995662fafe4b3916',
	),
	'/core/libraries_phartemp/vendor/web-token/jwt-library/Signature' => array(
		'JWS.php' => '4d02307e43483148fa0693988ca8bcbb',
		'JWSBuilder.php' => '17b8de1183b55f9ba48edb5d589848fa',
		'JWSBuilderFactory.php' => '84a38f2c842508e6a64b51e0a2b19a79',
		'JWSLoader.php' => '096bc4f68b71c1e19eb0dd9169fe035e',
		'JWSLoaderFactory.php' => '2b9a05c8d92295ac72529cbf2898664d',
		'JWSTokenSupport.php' => '3d896a5cf5b1acf04d537bad9b8b66cb',
		'JWSVerifier.php' => '30d35a237c4564e3bb27b678c14f2ee3',
		'JWSVerifierFactory.php' => '66cdc36faec01a1a9c8326feedddfbef',
		'Signature.php' => 'ddd0e6cf18ba489ef1a33793a15807fb',
	),
	'/core/libraries_phartemp/vendor/web-token/jwt-library/Signature/Algorithm' => array(
		'ECDSA.php' => 'd2577ca3192e9a99667a5025b551e0b1',
		'ES256.php' => '258295cd039f0d709c9e90f0286730c3',
		'ES384.php' => '361cec9768343a9d213eeb14c807a31e',
		'ES512.php' => 'd06cc67851c90169dace33997b61edac',
		'EdDSA.php' => '2382d6710bf275d582f2d84d85338abf',
		'HMAC.php' => 'd8cfc8a27038ef3dc8ff9e164146f9ba',
		'HS256.php' => '5ee8c211f22928648dd54d010de9d378',
		'HS384.php' => '3eeb650939decc0b109470993fe951d3',
		'HS512.php' => '8a850efaeee5a49b82cfe9b0fcb3fe95',
		'MacAlgorithm.php' => '36dffdb5922343536020dfe572ae19ad',
		'None.php' => 'faeb0a209222df5dfd259111ffc8518f',
		'PS256.php' => '49c724c63ab2cc6790ca9a9f43809e69',
		'PS384.php' => 'df2d48aa314d04654066d85669ca872b',
		'PS512.php' => '07738df7ba1d91ea0986d44082c8e86e',
		'RS256.php' => '70883c43ec76861c819ceb1e06275b21',
		'RS384.php' => 'd903db75c9d465fbc206c5e1434ac54e',
		'RS512.php' => '47f3e1444d5cb8f21a27fd886d6a7dd2',
		'RSAPKCS1.php' => '14828d0030bcea9a18da50ef44958613',
		'RSAPSS.php' => 'c03d35ce16d190e6cedd362c1e9f1790',
		'SignatureAlgorithm.php' => '17f740f7ba12d9053cb9476cef179296',
	),
	'/core/libraries_phartemp/vendor/web-token/jwt-library/Signature/Algorithm/Util' => array(
		'RSA.php' => 'e34f0bf690815d3ebb8572d5f4e74a70',
	),
	'/core/libraries_phartemp/vendor/web-token/jwt-library/Signature/Serializer' => array(
		'CompactSerializer.php' => '5f0b5a8a64ab5769cfb23989dc0a54fb',
		'JSONFlattenedSerializer.php' => 'cfa7d9521716504cf6c4d0b74d59cd12',
		'JSONGeneralSerializer.php' => '2fb6938f330ac45d3e8ffd4ad2990f34',
		'JWSSerializer.php' => 'fee51262050ac5d47834855bd93e514e',
		'JWSSerializerManager.php' => '14f66eee8d11740b4dd4aa51b769ac84',
		'JWSSerializerManagerFactory.php' => '88f73d9eb4fff44dbe5e624025c567b6',
		'Serializer.php' => '2311f523aa6dd4cd8f3d0b2acb37117d',
	),
	'/core/packages' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/core/packages/googlelogin' => array(
		'hooks.php' => 'cb9bedc8dfed3479939af265491dfeb9',
		'product.php' => '76615317b6db7ff769a32ae7c39c83be',
		'readme.txt' => '99bbe966bf38d34eaca0a7cdcdcd6b23',
	),
	'/core/packages/googlelogin/api' => array(
		'externallogin.php' => '973ea4da16fd0cce5eaaa7c6dc3b1cfb',
	),
	'/core/packages/googlelogin/controller' => array(
		'auth.php' => '4057950b32149999b2086aaad7b7e59d',
	),
	'/core/packages/googlelogin/images' => array(
		'btn_google_dark_normal_ios.svg' => '76ac49cc5aea2b4f7316e4c2f1352949',
		'btn_google_light_normal_ios.svg' => 'ebaa7219cfddecd902a2ebcefcaab61e',
	),
	'/core/packages/googlelogin/js' => array(
		'auth.js' => '49071576fdb59417d186cc54ea335e94',
	),
	'/core/packages/googlelogin/library' => array(
		'externallogin.php' => 'd04fc0e8b7ae6f1825c3a6f3cd291c5f',
	),
	'/core/packages/googlelogin/xml' => array(
		'product_googlelogin.xml' => '7adc08a15e65b421a5d66f1741d17683',
	),
	'/core/packages/nativo' => array(
		'hooks.php' => '4baac5289ee7211719f6a086228b3512',
		'product.php' => '25fff6ad0f4817d3e19bc421fbd81a36',
	),
	'/core/packages/nativo/api' => array(
		'nativo.php' => '5252b0437843371b2b6c4206f416c0bf',
	),
	'/core/packages/nativo/controller' => array(
		'info.php' => '7671ddf109e481d537ad2cc1d3df5a55',
		'page.php' => '0e28a409d5e5762cacc6aa335633743e',
	),
	'/core/packages/nativo/xml' => array(
		'product_nativo.xml' => '593eb9e5e43657ce3f8ae8baedbde8ef',
	),
	'/core/packages/shopify' => array(
		'hooks.php' => '1163abb1a6822c2278853babeb059faa',
		'product.php' => 'b6b33437bf595774b3af3299489c7292',
		'readme.txt' => '77f91390fd6d29146a62feb953bf7c5f',
	),
	'/core/packages/shopify/api' => array(
		'shopify.php' => 'cdfd12efe1ff8aad3815763dbea2f282',
	),
	'/core/packages/shopify/bbcode' => array(
		'buy.php' => '2a83f53918a1e1362f366e14fdd54067',
	),
	'/core/packages/shopify/db' => array(
	),
	'/core/packages/shopify/db/mysql' => array(
		'querydefs.php' => 'f85e8c330f770a17b41241b0846e4b27',
	),
	'/core/packages/shopify/interface' => array(
		'productprovider.php' => '86a39137315dfd5773adc57b753582f3',
	),
	'/core/packages/shopify/js' => array(
		'vbshopify.js' => 'cf44f1a527e98f1e1b7f31c49e1e9c3a',
	),
	'/core/packages/shopify/library' => array(
		'sessionstorage.php' => '791b4bd2f0e2c29c121c65a6a4922de5',
		'shopify.php' => '0f22f14de348edd9e58c0c9c38ad86a9',
	),
	'/core/packages/shopify/utility' => array(
		'shopifystoreinfo.php' => '7dbf696c0bfc50bbda79bff36297f6a8',
		'shopifywrapper.php' => '1f71358aa65caf0c2ae5528b4cfb4f60',
	),
	'/core/packages/shopify/xml' => array(
		'product_shopify.xml' => '28f095340d5e2dd9340055cee5d26879',
	),
	'/core/packages/vbadmincp' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/core/packages/vbadmincp/db' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/core/packages/vbadmincp/db/mysql' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'querydefs.php' => 'f18a225c4e6fb3edd6d7d284e6afbc04',
	),
	'/core/packages/vbdbsearch' => array(
		'core.php' => 'ac4f08ea86192d0704b8468dbf05c59d',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/core/packages/vbdbsearch/db' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/core/packages/vbdbsearch/db/mysql' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'querydefs.php' => '4993597fa105a245bd00fcb5e4d2354c',
	),
	'/core/packages/vbevent' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/core/packages/vbevent/db' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/core/packages/vbevent/db/mysql' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'querydefs.php' => 'f3135b5603b57c6d581b83eff872d99d',
	),
	'/core/packages/vbfilescan' => array(
		'hooks.php' => '9adc4589d886492ab5ecd1381483abc7',
		'product.php' => 'fc64e2fdc5983d24d9872db2395debe5',
	),
	'/core/packages/vbfilescan/utility' => array(
	),
	'/core/packages/vbfilescan/utility/filescanner' => array(
		'clamav.php' => '455a68e415808c8ad9c5b39195be9b24',
	),
	'/core/packages/vbfilescan/vendor' => array(
		'clamav.php' => '639ec6b8eacd9455362138feca19cc28',
	),
	'/core/packages/vbfilescan/xml' => array(
		'product_vbfilescan.xml' => '17c28be9f36173aadc7ce1413770de2c',
	),
	'/core/packages/vbforum' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/core/packages/vbforum/bbcodehelper' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'table.php' => '5de6023717b4f6cf5ff8529132363295',
	),
	'/core/packages/vbforum/db' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/core/packages/vbforum/db/mysql' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'querydefs.php' => '640726f0200e48530b92c3531b491512',
	),
	'/core/packages/vbfulltextsearch' => array(
		'core.php' => '4371f544cf9a40228e044dfa2dd8eacc',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/core/packages/vbfulltextsearch/db' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/core/packages/vbfulltextsearch/db/mysql' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'querydefs.php' => 'be9ed84f320a136dccb4944e33dc33ac',
	),
	'/core/packages/vbinstall' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/core/packages/vbinstall/db' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/core/packages/vbinstall/db/mysql' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'querydefs.php' => 'a233baca174b99b3eaf06be32283223e',
	),
	'/core/packages/vbmapi' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/core/packages/vbmapi/db' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/core/packages/vbmapi/db/mysql' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'querydefs.php' => '387911670555335215f14826c311b805',
	),
	'/core/packages/vbrelatedtext' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/core/packages/vbrelatedtext/db' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/core/packages/vbrelatedtext/db/mysql' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'querydefs.php' => '06a25ef2a64f9d8e28911ed1ed21db54',
	),
	'/core/packages/vbsphinxsearch' => array(
		'connection.php' => '155b8de37743c87e191e305fb39d514d',
		'core.php' => 'fe77f7ed2abb4743f9719a8bce2149e2',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/core/packages/viglink' => array(
		'admincp.php' => '0ed1eef91387737558b65a8125ff2f2f',
	),
	'/core/packages/viglink/api' => array(
		'site.php' => '409b5580980ad5ec700efd5689a7e4f7',
	),
	'/core/packages/viglink/include' => array(
		'viglink_utils.class.php' => 'e7b0488c7549013b78c388057cbe5792',
	),
	'/core/packages/viglink/xml' => array(
		'cpnav_viglink.xml' => 'fc2220f570151979f55af19c23a6895c',
		'product_viglink.xml' => '3114facb3bcf6d4a03b0cf187f60b427',
	),
	'/core/packages/wordpresslogin' => array(
		'hooks.php' => '3023a62f12829f69527eff92387fa94e',
		'product.php' => 'bd6cfcabaf1c5ed03d5f857722b43945',
		'readme.txt' => 'f56c108ac521a4b0d9e433f055212641',
	),
	'/core/packages/wordpresslogin/api' => array(
		'externallogin.php' => 'ccf14c7832e70d0103623e9cade6d628',
	),
	'/core/packages/wordpresslogin/js' => array(
		'auth.js' => 'f0bbea804d3366e0f68f4d98ab82e55b',
	),
	'/core/packages/wordpresslogin/library' => array(
		'externallogin.php' => '5d8a4e805e21e46c7a954450d4dc1957',
	),
	'/core/packages/wordpresslogin/xml' => array(
		'product_wordpresslogin.xml' => '9cc6283f0d7537c2caef07a18e169770',
	),
	'/core/store_sitemap' => array(
		'.htaccess' => '56a98c3e6db19bd9a0c120919fe77b28',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/core/vb' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'vb.phar' => '3c1800c60fea3cfbad83267e16011310',
		'vb.php' => 'a354ea7de63f9d51198d7bc30cb32ab0',
	),
	'/core/vb5' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'route.php' => '9001efd02533fa3abb0e390efaf62cb7',
	),
	'/core/vb5/route' => array(
		'admincp.php' => '66e861a4498684c2758c18a0990a932f',
		'album.php' => '98a1b7caf09a83279443c5755832a81d',
		'article.php' => 'a5e433f24ab216295f5c61b6bc67db15',
		'blogadmin.php' => '980058b42a5b327a6c9dd78932c2c561',
		'channel.php' => '5cbecf8d1109afc7b9124d93aa9a8868',
		'conversation.php' => '26247808471420d5356b0cc54fbc70f0',
		'dashboard.php' => '7425ececbffb4dae9eeffc179f72b013',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'json.php' => '706029e89cab83b40120c6d5b6c02b13',
		'legacy.php' => '249639345ba1ed44f7272a98baba2436',
		'newcontent.php' => 'b7017596dbab4f3ecc51f80db0ef7dfa',
		'node.php' => '3618e7d40866bd9ba7760037b0a2527d',
		'page.php' => 'fbfd8af1d9dfe642b017da42ce03de68',
		'privatemessage.php' => '94176a994fcb17827fbb92980a58645e',
		'profile.php' => 'c9460dc70de804bafe6d46a9e7dc9c81',
		'settings.php' => '98d32acb892c13cedf0ecc0601971072',
		'sgadmin.php' => 'aaac43d7faf6c546254308554fa9edcb',
		'subscription.php' => 'd8c5452a6afb46afaf76eab38bc4498e',
		'visitormessage.php' => '4b4b157281041651eaefa7dd6b090fc7',
	),
	'/core/vb5/route/legacy' => array(
		'activity.php' => '6b11e8c9815374737ecb3803af76891f',
		'album.php' => '5c789395a8d9a9a2590bca2c44067d36',
		'announcement.php' => 'fa8a941acb59bc2f5ed116086cfd4830',
		'archive.php' => '2bf875c061a8ba0ef24d0e397f05661f',
		'blog.php' => '25a85bb5937085727a92b51820c50c8a',
		'converse.php' => 'a6fe336544a0a85058f919b4356d459f',
		'entry.php' => '758e0bd22bda7a818efe9210a4dd5b72',
		'faq.php' => 'e881fdd6d451726945e9b420895c5d3f',
		'forum.php' => '1de82953ac82f04a4184feaaff4290b0',
		'forumhome.php' => 'a6d1db053a5939a314ed8873fb7e2626',
		'group.php' => '12621823b464279799fe999d8a99be3c',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'member.php' => '4af1e61c4701b9b3340600454801f6a7',
		'misc.php' => '179e021aa5a888052cbc3d5ba8ce3641',
		'node.php' => '0c36f7026df903b817af5dcb5df79210',
		'online.php' => 'c6e9f616e8e46329c06685ad7456e160',
		'page.php' => 'e61ba3c47a08653865e8e93726b2c4f0',
		'poll.php' => '8c72fde152e9f5d32c48344480bbbb7e',
		'post.php' => '8e97aff983988bac80b8e9ed894fa1e1',
		'register.php' => '2c5e0dfb23bf1de976e0efbed290b430',
		'search.php' => '01dd3b0dfb986498bcd680a77eb3dfe7',
		'sendmessage.php' => 'd54ca72724b47cdbc53e8655aab70f04',
		'subscription.php' => 'e83eb38f6b93cdaecb698d747d9081c6',
		'tag.php' => '8aa7cdb84ba5572a119454c59bf970b2',
		'thread.php' => '322d97321d20ecfc47cb22c85ff3a18c',
		'threadprint.php' => '769396ba5ef42eff3157dd9a26b68fd0',
		'usercp.php' => 'c1447fe45527804e41c4388570379fc9',
		'vbcms.php' => '4fd26caa837d8537204253cdf564daf9',
	),
	'/core/vb5/route/privatemessage' => array(
		'deleteditems.php' => '92b40c1cf8d58b697486cbc2a62e989c',
		'forward.php' => '31a4e89185efd00b39c088795f347a72',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'index.php' => 'd716e724085ef0e2c084a0efc2e2a172',
		'infractions.php' => '3a7028e440e1bec6af88f3f40e9fd0ea',
		'list.php' => '008ce104b7a5dee7f7356af9794ed771',
		'new.php' => '67728f0360b10fe4b136da20f5c5de66',
		'notification.php' => '24ff31a16ca52984ea7b785b173b2c1c',
		'pendingposts.php' => '3ad66eab5be660b3364ca891813d0385',
		'report.php' => '6b7b86467749de5aaaa0eeea3b52a787',
		'reportview.php' => 'be2d887e930643b9367238ff296cddb1',
		'request.php' => '2e9d845e383592c555ced8caf7b2108a',
		'send.php' => '74ad70de9d36cbee564b82ee02e19f07',
		'sentitems.php' => '95b82173e35d1e0a2086ed8831dc2896',
		'subscribedposts.php' => 'd1efda664a35c03bac262b9f0251dd60',
		'subscribers.php' => '3c82b9bffae787d99affe849c37d4ed8',
		'trash.php' => '7cc69e5d50daa5dca8818d0189a7b901',
		'view.php' => '0907e8f2765d08f7b72049c9ff9b7750',
		'viewinfraction.php' => '34b1c84764619f456bc3a29827789fce',
	),
	'/core/vb_phartemp' => array(
		'akismet.php' => 'c743511b51de4a9297835ca1a926c25f',
		'api.php' => '7bb715523cc0d69e119b030e442dd855',
		'bbcode.php' => '12ba7e8e739b1ffe0abc9fe57e0e2fdb',
		'bbcodedatacache.php' => 'd93fe09e1fa3ddcc4bb138f7aa3539b7',
		'bbcodehelper.php' => '66cfc37cfb36b4f6efef09811d4e8085',
		'cache.php' => 'b31f1bcd93d3e316c494e028038da2a0',
		'channel.php' => 'd7f60cfea6acd9ddfed4ca6c2ab6d9d2',
		'channelpermission.php' => '12d3e8739b4517045239da804aa9548a',
		'cleaner.php' => '828c551569b85f3afa00efc0b3652609',
		'context.php' => '172fd0c20f4df6bbeea03cdfecdaadfd',
		'datamanager.php' => 'a07d84efc42538701802aaa2a09ff5f5',
		'datastore.php' => '87574eb0c196538fbd8a224f320567ea',
		'entity.php' => 'c86b826b48b7b978ae9715c53c4f4bfc',
		'exception.php' => '4353ff58572210a642481fa997a3db19',
		'fastds.php' => '3601d7a101f90235dfae69478e601254',
		'guid.php' => '53f6a2adcb25024fd314a94936488d21',
		'humanverify.php' => 'dd30380c5280ec2d62879e17c1e632f6',
		'image.php' => '634803e26b3fb1a485b565acb52a0e09',
		'ip.php' => '89572998f8a7b9a27ed47e60c902883e',
		'language.php' => '8b0f5f90cbe08c0e4151d7c32f6a752a',
		'library.php' => 'd036a7dc991cd0a496cefa923eaf3b77',
		'loginstate.php' => '805d5b851b429a377f26452849162b6a',
		'mail.php' => 'e9d92c4d528926018a89d5b7c938b84c',
		'memcache.php' => '422d9e94be420ccb19537229b36f347b',
		'memcached.php' => '13eeed391cbfe3e75166eb93b36eb032',
		'node.php' => '8f070eb0d90df59a040840d067842eaf',
		'notification.php' => '6f45721eab7b16b7c9a22f532f235771',
		'page.php' => '666a483d3d515e77754f676b3f009ae5',
		'pagerestore.php' => '9223d0f53f70a539a8bcb4642016e852',
		'permissioncontext.php' => 'c534f1a9fa2881acc9bc980eab9108d6',
		'phrase.php' => '8a0bd6a22f6f5a1673f925d7116021db',
		'products.php' => 'a8ccf1469c22ee196988cb9c3b12faba',
		'request.php' => 'ac57e15962f3740cb37a6b19738304cc',
		'session.php' => '904d2d85e0363d0bf22d823cd76b250b',
		'shutdown.php' => '048606749c8228ab7c18af85045312e3',
		'stopforumspam.php' => 'f831a7dfd8e7589bb41d3bb45bf99074',
		'string.php' => '6423ff49f17f435091a7dc6898b2eef7',
		'tags.php' => 'ff57fe0e1332c57ceb8c543f69bebab4',
		'timer.php' => '769a66d4e37938c9761a13a2621a3016',
		'types.php' => 'c3624aecbe198c736099ee89415648d8',
		'user.php' => 'a134fb28d523ced77cf6471ebb7901c9',
		'usercontext.php' => 'd27a22e14ac4c415f85c7c7a643e1166',
		'utilities.php' => '97bc49489468e5381d437f98003e00b2',
		'view.php' => 'faf81872310cd00f8ce47727c0eba88f',
		'wysiwyghtmlparser.php' => '2c592180f1f555e0ab4ba0e82e4be06b',
	),
	'/core/vb_phartemp/api' => array(
		'ad.php' => 'f457539370d55e2a2fec943379755ca5',
		'api.php' => '00063b2ab9500101ac0c7df411d00f4e',
		'bbcode.php' => '6a258c376fed91eb56b821656818607c',
		'blog.php' => '079ab8771acb6d16b34035fa4a719341',
		'bookmark.php' => '810b6a03d16c50715ce7ddc86761025e',
		'calendar.php' => 'a7cb000110deacb8a8b4c74c57780ca8',
		'contactus.php' => 'fb3f7ae95184e2017da303d58d462eb0',
		'content.php' => '7292f1383b27ff72fe1f0e03ee655bf1',
		'contenttype.php' => 'b2f53eaa31c40d6a7b4e1cea0e5ede09',
		'cron.php' => '8508196650cc199b1554befa935efb24',
		'editor.php' => 'e96fabaab6908c93534798e93364a9f2',
		'eventhighlight.php' => 'abba5ec69ae3d1b54d67e8c0f86d9e33',
		'extensions.php' => 'c97567bd5fbfd14701c4799ac6558acd',
		'external.php' => '3fe3495bab36f31d92f63affb60e92ec',
		'externallogin.php' => '83fc68eadfd77cd1b253da102773d0d3',
		'facebook.php' => 'bf47f6c1b2e1c0305871c4054845f26f',
		'fcmessaging.php' => '38eb8278fe87dcb514068a29b16ebd5d',
		'filedata.php' => '1043247a82edf8264dbf1082a397940a',
		'follow.php' => '01cab3b86c90e097d625c3b3239ee13e',
		'help.php' => 'e09e858c065153ac87eaba334593b790',
		'hook.php' => 'c0c35ea56402de296013a7ba428592b1',
		'hv.php' => 'b45be67201110edc4dcb4ce979159b53',
		'icon.php' => '91dc2c70e57158b9f8a33cf280386725',
		'language.php' => 'f41247c5866140ea6bf26167b547aaaa',
		'mail.php' => 'fd66e932073b40841a920f30198070e6',
		'node.php' => 'ee3842300ff0ca80d9d5eebc079112e2',
		'nodefield.php' => '1facd7eb7065a4473de054eb99a9718f',
		'nodevote.php' => 'c91cfd8c1954d6421cbe738d8db2f41b',
		'notice.php' => 'ccf70202ae2fdfb5df3a3e7099606711',
		'notification.php' => 'f4a823b67639782a442a194e4436de9e',
		'null.php' => 'dfa0c18245fdd797bc17df314ac46c81',
		'options.php' => '01de457effd24d5444780ebcf065eadb',
		'page.php' => '097cd75278832f8c40dd0c3a6925b217',
		'pagetemplate.php' => '8540f5341a6b5964c73d7e1871fd7a63',
		'paidsubscription.php' => '2c3ffae936d75878091634c3376e3b9b',
		'phrase.php' => 'f9ea43156d81521fa854e051e215c17b',
		'pmchat.php' => '7f34168eedd632b69733499e2a8c69b8',
		'posthistory.php' => '118e2ad3be5722b87a44622011e8c96f',
		'prefix.php' => '5cd463fb78795c4191dd21e70b784d36',
		'product.php' => '26b630fde3d95945daf4dd554724e68a',
		'profile.php' => '4843d562c8956ae5b0c4b8554b3049ba',
		'pushnotification.php' => '5a025f00b399001bcd7cdd3ad5dcc394',
		'reactions.php' => '30fa4655ab17d15ed26288fdfae3221f',
		'referuser.php' => '701aed6f1808aa01ed41ec2c1c7f6a4d',
		'reputation.php' => '907bbb611dac7d857a239ee134ce043b',
		'request.php' => 'b2cbd27d5d5f0c74a0e2762e07a712a8',
		'route.php' => '51b55662079c763cc4e4498804f24b5e',
		'search.php' => '8790f3fcba966361fb2c676b70aa419a',
		'session.php' => '3a3176d820106a0bdce4ba7f628445e4',
		'site.php' => '0b733ed39325a768514e8c3d8f3726a7',
		'socialgroup.php' => '6ef072d6150add6385fe7f7eda09fd48',
		'state.php' => 'e5e8d552d9628d83ffe67ad398cd7884',
		'style.php' => 'efbaa3a741225d1169651187e7ab436f',
		'styleschedule.php' => 'b229fa768ce45de8e238632cda1a79e1',
		'stylevar.php' => '323fabfe6dc895f45dd9744f7804bcd2',
		'tags.php' => '4dc8332152e55c6af3781120d7d8aef5',
		'template.php' => '07de7b531988e0288fb96264f0ab7fa1',
		'unsubscribe.php' => '7d71d52f9121613eb03340c0bb21ffee',
		'user.php' => 'b43f7617715127b710ea731457ff5c05',
		'usergroup.php' => 'a640e3be4fe084fa40e84076adc17a78',
		'userrank.php' => '266830a50893fa7773dbb0431fe2671b',
		'widget.php' => 'd7cfa4aaafe020e6c7ea104bb711b2a4',
		'wol.php' => 'eec44cdbfd929543ab8c4425e7bdbd40',
		'wrapper.php' => '801095c4239f5f76e5d226b1b606f02a',
	),
	'/core/vb_phartemp/api/content' => array(
		'attach.php' => 'babfdf7c8b79522cb1b13f546c1f1484',
		'channel.php' => '761aaf86764028ed1e3349667849cd7c',
		'event.php' => '70b254cb0ba488704957091ee724d21a',
		'gallery.php' => '5b8ada7f4f0b6617dfef0ad2cff80ee4',
		'infraction.php' => 'b517a9b0f94bae8d93f1876b62880708',
		'link.php' => 'aab8925cb152bcf8e059e8d257a75366',
		'photo.php' => '207398857900f2c062aff782946dfcb1',
		'poll.php' => 'bd05b5bd54a6024880d384b8b189f837',
		'privatemessage.php' => 'a8447f6034c60b4d4ec0cbee0aae5381',
		'redirect.php' => 'd4f86273ba3fd245a7b8438206f3b8a7',
		'report.php' => '625270088f639d576c6f3dbbe6fbfed4',
		'text.php' => '8cead343262fb9f8860fbbaa8ba0c0aa',
		'video.php' => '70171abde46b7605193c93dc7b6017f9',
	),
	'/core/vb_phartemp/api/externallogin' => array(
		'oauth2client.php' => '82ad0cd392cd246146fbad5ceecd06d7',
	),
	'/core/vb_phartemp/api/vb4' => array(
		'activity.php' => '564902ed853f1c0c9317b47f125f14d1',
		'ajax.php' => '70becd5d9b1a470586c3cb95d84d0938',
		'album.php' => '9aeca40092dceda5d40962245ba7c44b',
		'api.php' => 'a09167f415ba8093b3f247e7fe7383b6',
		'blog.php' => '602be004da7673a5362e5e56789f1b38',
		'cms.php' => 'f1ed8b5ce0c2a1e755690d44c6353dc8',
		'editpost.php' => '9757aba08942c93c6a3006998fc70852',
		'events.php' => '71e1457de2155c32fbefe44a8e2ab335',
		'facebook.php' => '41e1ca12335074e83e432096fbc3bc8c',
		'forum.php' => 'f9d52c4ddcc4d0f6f0db894f840d80e4',
		'forumdisplay.php' => '1f751abe79eb24ca04ba8a2048d7a693',
		'inlinemod.php' => 'ad7e88e2e050b29714233b3d9f7f748c',
		'login.php' => '298e57dbdf04aa1cb6c70abaa4b5124e',
		'member.php' => '4c0eb790d37f628801c748db7e487bf4',
		'misc.php' => 'a9b6aa9b8b03a1bb921f0a184920a202',
		'newattachment.php' => '7a1fe79affb38c6fa1e37c555a6baf41',
		'newreply.php' => '9ac90541943e169595ca4f9ec8df06a7',
		'newthread.php' => '54d1b31985011ddbea574c3b61f7a885',
		'notification.php' => '9bb216ff4d6171087ce749dd68e1f09d',
		'poll.php' => '9aeaea21487c11ca7e527b95a9db49d5',
		'postings.php' => '6f581ba313b06e5545ee939418b96dcd',
		'private.php' => 'b2439a0caf5fe473723f8b67eaa54d10',
		'profile.php' => '124aff05c8f6b903e49885387757ee5a',
		'register.php' => '25248aad3bc51a2355cffd34ab26f826',
		'report.php' => 'a68a0c505d33805cd31e50a677deebfe',
		'search.php' => 'bafed0a2879c643bdf3ce78ea0f24c61',
		'showthread.php' => 'a13e31abe81f82e55f16e9cb16255764',
		'subscription.php' => '572922521dcb2b95ed51072f25ef899d',
		'visitormessage.php' => '4985f1e188fc79b593852f240f6da035',
	),
	'/core/vb_phartemp/api/widgetdata' => array(
		'rssfeed.php' => 'e1a3ea9d89d71da07796e77ab7d311d7',
	),
	'/core/vb_phartemp/bbcode' => array(
		'url.php' => '571a8278997b33699742b197943d0779',
	),
	'/core/vb_phartemp/cache' => array(
		'apc.php' => 'ec99f00c04afa7fa2f26830b4e2ff54a',
		'db.php' => '8dffe17f6c44ebdc8a9c97e72c766661',
		'filesystem.php' => '969f253b52b4405166c15fca91724d34',
		'memcached.php' => '8a2828f50661df8edaef149b54def834',
		'memory.php' => 'c050a7fd039c4eaaa60168b9faf52610',
		'null.php' => '4165be3e657a00bc02cc774bc999a483',
	),
	'/core/vb_phartemp/datamanager' => array(
		'admin.php' => '1b4692d9e05009a6c5da79a61fe0b574',
		'constants.php' => 'be4f607b31c6c400ee0d159e33e147c2',
		'moderator.php' => '78faa58c34f9043fc8c0a9e1671a7944',
		'prefix.php' => 'f2b8cc0229efa96aef56cda0d348242c',
		'prefixset.php' => '5ae481e5f8501aebffd18cd1e07c44dc',
		'rssfeed.php' => '997e606c58aeeafc97a10c137235e712',
		'stylevar.php' => 'ef33522c4bfe1f8c2f48b5f49e60299e',
		'stylevarbackground.php' => '120fc64d04135a863fd6cefc08874df3',
		'stylevarboolean.php' => '8645b2b49a30124d828cb11b77808041',
		'stylevarborder.php' => 'eb28f1b8a5309103b6a425d46a0fd783',
		'stylevarcolor.php' => '1674e3a2b29a4081338184fa393a05d3',
		'stylevarcustom.php' => '65b2fe7be4848e0c20522fe372eeacf0',
		'stylevardefn.php' => 'edfe0c62447948b59625008ec8c2e675',
		'stylevardimension.php' => 'd36dfb4c6b4e8185765424c0ff0e9902',
		'stylevarfont.php' => 'ff9b174887693cdbb52cdf6226e65e09',
		'stylevarfontlist.php' => '657355e1b908b399f77044852e1ec587',
		'stylevarimage.php' => '5f2333d7642bef7ae58bfca10894840a',
		'stylevarimagedir.php' => '34602c47667306db5f718835b76f2eb2',
		'stylevarmargin.php' => '931e92a45eaa5c95e58d8a3490b43fa3',
		'stylevarnumeric.php' => '2422b5358ed6acab3837faf5babfc5af',
		'stylevarpadding.php' => '61de47f213f2bd6487eec9c92248d1d6',
		'stylevarpath.php' => '17f6d16e623a788b4eb416c57389b915',
		'stylevarsize.php' => 'fc711abb3631dd1c77c6a29ac86764ae',
		'stylevarstring.php' => '4611db3d4f7cbd8bd7493e375531eeb8',
		'stylevartextalign.php' => '509ab71eddd5da2e6785675db357db6d',
		'stylevartextdecoration.php' => 'cc926907680e5596563c7d45ec8e920f',
		'stylevartexttransform.php' => '8ce88579e7afa64163cc638f0726d8d3',
		'stylevarurl.php' => '45360d248f9ac92897cb3f43b242ec4d',
		'tag.php' => '70a9e07f542722d7b188a17cc8f7ae8a',
		'user.php' => '73e3e7a4458bca66c60dede9aac16446',
		'userpic.php' => '3557bcec6c51c920d239ef1422e1586e',
	),
	'/core/vb_phartemp/datamanager/userpic' => array(
		'avatar.php' => 'a0528aa748254344cc2367d1e117f33d',
		'filesystem.php' => '16b0f4aa2caa249aa679fb3d07ad2091',
	),
	'/core/vb_phartemp/datastore' => array(
		'apc.php' => 'd0db9ed62381b122ac1f351e1960ca67',
		'filecache.php' => 'a3d1f99c4eee4b61779327d8dcc7ac7e',
		'memcached.php' => '486a7ce2c03afed46ccb02e31cf6127d',
		'wincache.php' => 'a502c73f9d017fdcaef421f4d523a6ae',
	),
	'/core/vb_phartemp/db' => array(
		'arrayresult.php' => '67ebb8431bfa60a0ce4b79453e63a1d2',
		'assertor.php' => '35897c9518ba26687d06c912b4f8789e',
		'logger.php' => 'f2b01398eb08a8e06412cf8f6335537c',
		'query.php' => '89a37d0dc5e9e0e78070b1bbd559a444',
		'querybuilder.php' => '6795e4ee2ab439bb629bdd93c6df8369',
		'querydefs.php' => 'dfd99ded6201f116dcaf7e67ac69bbca',
		'querystate.php' => '2de1aa2dc130ebe08fcb3d6e36543574',
		'result.php' => 'd67cf843d193b420e93b6364d554be17',
		'type.php' => '7ff1f9cbea810c64c0d79f922e9e3bc5',
	),
	'/core/vb_phartemp/db/mysql' => array(
		'assertor.php' => 'f8502818309015c644127e588c3ee8fb',
		'connection.php' => '9757cd2c35c67f1311c2a581c131770e',
		'querybuilder.php' => 'b7405679b21b408c239cf02c06cef3cb',
		'querydefs.php' => '37c9617ce8d855ca3ce0b66784bf20a2',
		'result.php' => '1326925623ab61bff15d8eac0657e186',
	),
	'/core/vb_phartemp/db/mysql/query' => array(
		'delete.php' => '4189f1e1edfddb2bdd886dbb9418a65a',
		'insert.php' => '91e3b7e20d41ceb9179649000aef066c',
		'insertignore.php' => 'cb277c8ebdde8b7c9ee1af6789622710',
		'method.php' => 'f1c8e65ac9ff952390b5a2da64c3d46c',
		'multipleinsert.php' => '117136efb12b0e053f68c28f4d8a5eed',
		'replace.php' => '71e0d4fd62466816ea79c8b3742066e5',
		'select.php' => '523380518090a9e7761d6d7e509c2549',
		'stored.php' => 'd79cf59d8891a224d3ae5bd75b5aa18d',
		'summary.php' => '56fec542a905bf699a0c0a58c6935d12',
		'update.php' => '82fbf50e36d21a3ebe1bc3236071fbf7',
	),
	'/core/vb_phartemp/db/mysql/type' => array(
		'null.php' => '33075e174c791dc4a393d6945366f306',
		'uint.php' => 'df8e9b32ed59b5e05ff02c3a0d2a76fa',
	),
	'/core/vb_phartemp/db/query' => array(
		'delete.php' => 'b7877fa62bcb66b80e652b7d47c699d8',
		'insert.php' => 'a1fabd59394d4842d1a029e85b61f3cc',
		'insertignore.php' => '84e551138a48b5906107fec089651ca8',
		'method.php' => '4fbd035dba38fde5a911adaed65edaa9',
		'multipleinsert.php' => 'ebc8e139e290018e653b26f786c383c2',
		'replace.php' => '95a3b0692250c1d39e5f19dbc4279c1c',
		'select.php' => '0636f0b07d0c4d31562efc11a155405d',
		'stored.php' => '3f266cde76d9045d18ed52d1abe7030e',
		'summary.php' => '801954e7180dd8a199d0cd0dd1a5230b',
		'tablequery.php' => '959e3a363a4412f73afcbfb9510de78b',
		'update.php' => '08826722f800887b261fd474ed837b6c',
	),
	'/core/vb_phartemp/db/type' => array(
		'null.php' => 'cae9385e0fc0593674fa67eaa06761c8',
		'uint.php' => 'ce89d1bd4df36fe30ef718de93786acf',
	),
	'/core/vb_phartemp/entity' => array(
		'cachedurl.php' => '51384e7654f249d0e1e8fef173dd8fc4',
		'channeltask.php' => '8aebbfbb93006677e31d63d0c4999917',
		'datetime.php' => 'e059422ee9aaf0daade1990732405cc6',
		'paidsubscription.php' => '12c9f8840c1a11b131a25279440c94c1',
		'scheduleitem.php' => '5c8ac25bcd3249dc4defe65e4bc093bc',
		'styleschedule.php' => '7f8f5b792f87ad1e92b302832a473f5a',
		'webmanifest.php' => 'c5598c4d915dabba12f8c79568968ef6',
	),
	'/core/vb_phartemp/exception' => array(
		'404.php' => '7d40a17f0e164ca9d11c75927b66fd61',
		'adminstopmessage.php' => 'c2e7482d7916b2ae1404a67ce44a4592',
		'api.php' => '4331f5e1a95199d1cb3b39205ff46bdd',
		'assertor.php' => '4a1f8d24c532b3297b57f5f771ae0d30',
		'cache.php' => '09879e7d3799cc21e23bd5fc32d1ee50',
		'critical.php' => '305d6643d4642657fbcb829595a396c7',
		'database.php' => 'bf0876614ce5fa074cdd726d5bfdc8bc',
		'nodepermission.php' => 'd5c96fe34f9acd20702ae81901ed1f4b',
		'router.php' => 'dbff63123badc7e261093321db03d3f9',
		'warning.php' => 'aa4ddebfba038e6c8a761b6ece1fed2c',
	),
	'/core/vb_phartemp/exception/api' => array(
		'disabled.php' => 'dba67cd201516ee33c15c3173a5f0469',
	),
	'/core/vb_phartemp/external' => array(
		'export.php' => 'd295fdf26606ff73e08f19d04199bca3',
	),
	'/core/vb_phartemp/external/export' => array(
		'js.php' => '1ad8b078a5015e755334641ae9e80ffe',
		'rss.php' => '1a3413280cc131ba9bf04da253810046',
		'xml.php' => '8ba29ca8f92434ad16c95803343e0935',
	),
	'/core/vb_phartemp/external/export/rss' => array(
		'1.php' => 'e659f326f242c6ebb0329d8e9e342589',
		'2.php' => 'e2aee278721422f8b674784aeb9298b0',
		'91.php' => '626f1e6d5be82a19ecd4c206a45cc411',
	),
	'/core/vb_phartemp/fastds' => array(
		'apc.php' => '7614954e81b9972942cb74923f3f55b6',
	),
	'/core/vb_phartemp/humanverify' => array(
		'disabled.php' => 'fe2f780b9e24dbd4988cf0f1ef1527ea',
		'image.php' => '11091c2ea28aaf122b42c30eefa89128',
		'question.php' => '9e14c0a86b3f0cd0fe391f4594bd1814',
		'recaptcha2.php' => '2d8fcb5d1fcb3ec567f55c170127c817',
		'recaptcha3.php' => '13e9d562cbdf8710e61af7b1026c73a1',
		'turnstile.php' => '334b734fe2ffaac1a920a56f6e58dd0f',
	),
	'/core/vb_phartemp/image' => array(
		'gd.php' => '79e14a3d553b05c59fc2f75cf8da9e3a',
		'imagick.php' => 'd215da15da536fb6559c415d012e6a21',
	),
	'/core/vb_phartemp/interface' => array(
		'bbcode.php' => 'e2563a142a8d34b274d8f6aecaf0cd25',
		'timenow.php' => '752549752b16fba632f015dd11fa7bf7',
		'urlcache.php' => 'de018532a064b74960a6cd3abfda8d2f',
	),
	'/core/vb_phartemp/library' => array(
		'admin.php' => 'f711cbdb749524f068abc37db268ec17',
		'api.php' => '24b038270c3e8007e7f5b1f3570884d2',
		'article.php' => '816212ded76652a40e5c99dbd08f0840',
		'bbcode.php' => '9e28ddd557cfaf4e7928030b8c23af4a',
		'blog.php' => '1ea1861b7b36693d7dbc7ec30ef9709f',
		'calendar.php' => 'bf151236456113eae70ce5ef8ebe456e',
		'content.php' => '2ddf1845a2a2b796af984491e3f189cd',
		'cron.php' => '7c5cc1a87f1eb2bf2543941284393482',
		'eventhighlight.php' => '2a7d442c4183e47a8c13e603651944ab',
		'external.php' => '82457ed0ae8d5c25aa4e035d740301da',
		'externallogin.php' => '4ec29321d093865fc2cf51c4f54e03ed',
		'facebook.php' => 'ab94f8c1fc90b590960a0d1acaa62f03',
		'fcmessaging.php' => '76b3014b91e619b79acdb0243be8d205',
		'filedata.php' => '1c5734794556d2d4842e4c4238fd3626',
		'filescan.php' => 'ff33afbc54de4c348bbb0e24432b199d',
		'follow.php' => '95003273a8cbfa2c122dcca034159b8f',
		'functions.php' => '63fcd563edb70a1e0d1a0bc2701d6f1a',
		'icon.php' => 'a4c9bea636c920c5f60a200ac68d47a9',
		'language.php' => '8785497e31bfd5824996845766ce06a5',
		'login.php' => '55afe77f08cd96b718edab39443eff00',
		'node.php' => '318106ed60a99576c63699066af8d460',
		'nodefield.php' => '61320e4ca30a8ecac52c540fff2eb797',
		'nodevote.php' => '65311e2ca939e2b998fd34c84ccabfc6',
		'notice.php' => '7d092687d5d27c220e0b8c170b5fc142',
		'notification.php' => '8801e1077663595b70a24882d351f3e0',
		'options.php' => 'c9c4fe7fd6a3bb3372c185317bff3d54',
		'page.php' => 'edbca1dff52fe6069ee2aaca72a28e5b',
		'paidsubscription.php' => '7a160ba235061474f598cb2b667c5e6e',
		'phrase.php' => '6556b69f68c179837fa6eaab8be38fac',
		'prefix.php' => 'e8bda2cd3442621a6362553fc10688c1',
		'product.php' => 'd42b447eb43b3909dff0a5604a8f30b4',
		'pushnotification.php' => '28cb6102d34bb45e316152d2e6f05cdf',
		'reactions.php' => 'fef62cf084e6ce719789a9b2a89db24d',
		'referuser.php' => 'b898f7379adc27ccdad27251204efd78',
		'reputation.php' => 'e486c4e27825d3da3d492e8d47c7a81e',
		'route.php' => 'b792a3df40d3a8668c61d1e502169bd9',
		'search.php' => 'd3387444d4411e5b167660340e9aeb43',
		'site.php' => '63d83ddbd4a6cb117d510c0250c0309a',
		'style.php' => '7427d7d1973903a420a6af40eb1034d9',
		'styleschedule.php' => '8ef8d82f2bd0f24a08f4b85b8e014016',
		'tags.php' => '66d4c67cd53a3dd3c9902a5312aeb2e5',
		'template.php' => '4bb6cb3f6369e5bd09642f53889509b5',
		'unsubscribe.php' => '3440d19650253fd859029a56aba341e1',
		'urlcache.php' => 'efb25a5d472e229ac138c282638d5dde',
		'user.php' => '859c7dcf7fcf6a9f077d0f5202e80841',
		'usergroup.php' => '6b818a5ff8bb1389c0316fbd03778825',
		'userrank.php' => 'fce7b5c766a31edd1ce586261d8bbab7',
		'widget.php' => '9874eb99353bc888ef2c541f94c6bd3d',
		'worker.php' => 'e4c63411506c50ff89ac0c1ee275e9e8',
	),
	'/core/vb_phartemp/library/bbcode' => array(
		'table.php' => '621310fa2a69cfbf1a64b0bd73e39394',
	),
	'/core/vb_phartemp/library/content' => array(
		'attach.php' => 'bc57f4c249655dcf36d04cfbb6f9781b',
		'channel.php' => 'af675f79a971f7accaa5a551e3c73ac6',
		'event.php' => '1b11bfc78f80a6e4fb56d12493987cfb',
		'gallery.php' => '9c18cc7f21dcb9179f4840e894b633f0',
		'infraction.php' => '91304e64d5b6379616824f9035f38e49',
		'link.php' => 'ba1a0c50cd921f738008d808d3a6334a',
		'photo.php' => '99169c9c4e0b5dda8fcadf7a512506fc',
		'poll.php' => 'f0f3090d440c7e51c6709420354b378c',
		'privatemessage.php' => '09c6a19f2dd86430d0ee46ee8fa62ae4',
		'redirect.php' => '84677d02a367a0140398d4010a8a8925',
		'report.php' => 'fe038d98777e7b8fd301046da38a1c87',
		'text.php' => '00933493063b700ec958c48419eea032',
		'video.php' => '747761d8e5f17cf91db67361fe49e94b',
	),
	'/core/vb_phartemp/library/externallogin' => array(
		'oauth2client.php' => 'd3623fe73b5c065b4c1bb744bd3bcc0c',
	),
	'/core/vb_phartemp/library/vb4' => array(
		'functions.php' => '80d999562814c81ebd4771b6f304c213',
		'posthash.php' => '39f7fff5999d715182d562c99fe568bf',
	),
	'/core/vb_phartemp/mail' => array(
		'queue.php' => '4ffd91c55fbe26276c30ed1864fc2291',
		'transport.php' => '903c35c3d9fb8ba8001b2ca3c5a4ee66',
	),
	'/core/vb_phartemp/mail/transport' => array(
		'legacy.php' => 'd8fd7753bb9133f2776b4b0868b6000b',
		'phpmailer.php' => '1377da5fa5dabbe6487d13bd52ac77cf',
	),
	'/core/vb_phartemp/mail/transport/legacy' => array(
		'phpmail.php' => 'aafe5e7d36d10b95af02a5c441329bd4',
		'smtp.php' => '9b49c7484a1bd0dff64a9903a6205cf9',
	),
	'/core/vb_phartemp/mail/transport/phpmailer' => array(
		'cachingoauth.php' => 'c723f84dfc9d0dc73c86298d5221dcf4',
		'gmail.php' => 'd6f16a643fe39e9130886fe366cff1fd',
		'microsoft.php' => 'ff2ee2306327460ca7024dfa27b03b79',
		'phpmail.php' => 'eabee7b4ba10dda291fc4c465c717a2a',
		'smtp.php' => '13b6e7498819fd7945d445d7c9723e80',
	),
	'/core/vb_phartemp/notification' => array(
		'content.php' => 'a51005b7d7d4529edada773ab57f394d',
		'likednode.php' => 'b6b9492b595168f9554b5f60e2157321',
		'moderator.php' => '371b9979b64a2f383b55639cbf8b9789',
		'pollvote.php' => '596abd7883001a348f9570ca1868aa7b',
		'userrelation.php' => 'b82a5d47492132971708a438cdbb3243',
		'visitormessage.php' => '56a6eac5433dc882dd00226c9d4c4e3e',
	),
	'/core/vb_phartemp/notification/content' => array(
		'groupbyparentid.php' => '1f902a855450e00142bb8e9faef9a233',
		'groupbystarter.php' => 'ebb8f47ab863a9667c8c0cea25c09623',
		'quote.php' => '93baf7ecbe4b9c2b99a6a30ebc3305ba',
		'usermention.php' => 'e8372f7509c38f2a9ebb209519784fa1',
	),
	'/core/vb_phartemp/notification/content/groupbyparentid' => array(
		'comment.php' => '3ae2c3cac8c6cf0c05d6a5f72789ba5a',
		'threadcomment.php' => '523115b8e2ef435d3baae19a38ff58b6',
	),
	'/core/vb_phartemp/notification/content/groupbystarter' => array(
		'reply.php' => 'd506c71a5ba2949450f242fbc3c6ff33',
		'subscription.php' => '7df51077bc5b7f590fab6a25e407ada9',
	),
	'/core/vb_phartemp/notification/moderator' => array(
		'monitoredword.php' => '55d6b4e9804c211ca0b1eef8fb861332',
		'reportedpost.php' => 'ec0baa69868d0d0bdaa7f6d22ea45802',
		'spampost.php' => '75d473605ffb6caea92c568f1222d2e1',
		'unapprovedpost.php' => 'cd51660799b1c8229045e8fd5abc781e',
	),
	'/core/vb_phartemp/notification/userrelation' => array(
		'senderacceptedfollowrequest.php' => '37e7d64b21ff4927a47755c8e487d64d',
		'senderisfollowing.php' => '1109fdc8eb911f8414b049871dff1213',
	),
	'/core/vb_phartemp/options' => array(
		'option.php' => '9162fd2ce2c729716bf57d8e44e65f4c',
	),
	'/core/vb_phartemp/options/option' => array(
		'cmspreviewimagesize.php' => '3b81661dba9fb3749210c8b266a3c0e2',
		'currencysymbols.php' => 'fe2acd77867eb97df42d1871687dda36',
		'enabledscanner.php' => '489bcf874ab204b3253d23d7ec3bff9d',
		'globalignore.php' => 'ed3c485139cd42c8c1c237dd66d0cbbf',
		'imagickpdfthumbnail.php' => '14d4dd551fd3b96723731bb636432104',
		'logintype.php' => '2ce5689219941d60407d5aed53b68e5b',
		'sharingtwitterusername.php' => '4c2b6546b540386b253cafb60ca342a0',
		'sitemappath.php' => '8a16dbd547db47b209814926c05b25b7',
		'useemoji.php' => '5c95fecde047bf296a6cf3f5333df4c0',
	),
	'/core/vb_phartemp/relatedtext' => array(
		'data.php' => 'a67aec2b1b1b2b7819efda85404e4d9b',
		'persist.php' => '984c8ba6a720ac8c0aee0020d70b96fe',
		'tfidf.php' => '755576d0106accb452dc6bef24842d03',
		'vocabulary.php' => '47fa6930cb5cc4453445be56f76e7c04',
	),
	'/core/vb_phartemp/request' => array(
		'api.php' => '6ff779bb2a0ab41d3b6304d7040ba6e4',
		'cli.php' => '3050903a98263eaeb854072064c85a3b',
		'web.php' => 'b826437bb1ee45ff6020ebfdc26e80fd',
		'webapi.php' => '499e826d35474dc59dc251b7840a2dae',
	),
	'/core/vb_phartemp/search' => array(
		'core.php' => '74e851690ff26c373f3696328c4ac158',
		'criteria.php' => 'd704fba16aedbc29599aa9e4b1cdd5a7',
		'keywordvalidator.php' => 'a1ac469c3b3623aac318bc81a298f289',
	),
	'/core/vb_phartemp/session' => array(
		'api.php' => '937b898300d2a50eae689020fcdfd55a',
		'cli.php' => 'a8322bff5143492a8576b1f8b52070d5',
		'skip.php' => '03b25269803481b28035df9b5bb33406',
		'web.php' => '7ca1085becf27557e9e109e4bfc054b7',
		'webapi.php' => '1d137f0092278c806e9e438647fb696d',
	),
	'/core/vb_phartemp/stylevar' => array(
		'mapper.php' => '7a4565acc403a54feff4a2388d0b771b',
	),
	'/core/vb_phartemp/systemevent' => array(
		'cronscript.php' => '416a820508bef1ecc586a46438c638d5',
		'item.php' => 'e9856713e7d3cc6b97197845c7195545',
		'queue.php' => 'fae4ed98a0c253a74f3eada43982b2ba',
	),
	'/core/vb_phartemp/systemevent/cronscript' => array(
		'digest.php' => '9f025b0006e8ac822baaf0dc9f5bbd0a',
	),
	'/core/vb_phartemp/systemevent/cronscript/digest' => array(
		'daily.php' => '833d74a83c308f7717be363ed9531343',
		'weekly.php' => 'd62f9bedf83df0f1b2cf712c19304545',
	),
	'/core/vb_phartemp/systemevent/item' => array(
		'channeltask.php' => '9c53a9ebfbf3e89b0ce18e40faa1919a',
	),
	'/core/vb_phartemp/systemevent/item/channeltask' => array(
		'close.php' => '35b4cf53ec5a367dbd40a1040f789ee5',
		'delete.php' => '039f65a4f794594bcdd9693390eba63a',
	),
	'/core/vb_phartemp/systemevent/item/content' => array(
		'notification.php' => '7921f1ef4e075ae9689e3a9d15038585',
		'relatedtext.php' => '0981d27646afcd2e58a6c7e7557628cf',
	),
	'/core/vb_phartemp/systemevent/item/push' => array(
		'privatemessage.php' => '4684dcd553961be9bc40d0cdc9d5b829',
	),
	'/core/vb_phartemp/template' => array(
		'runtime.php' => '894e92d8b14054355b7852225b20fb88',
	),
	'/core/vb_phartemp/trait' => array(
		'noserialize.php' => 'bccfd479b4907d96ff060f49ce603ed3',
	),
	'/core/vb_phartemp/undo' => array(
		'item.php' => '12f35b8de0dd497d70469c1dc8ae6896',
		'log.php' => '45122947a327851f44c2b32b9ef9d5c9',
	),
	'/core/vb_phartemp/undo/item' => array(
		'unsubscribe.php' => '658d6ff67a5f10bdfd82c46009a6d597',
	),
	'/core/vb_phartemp/utility' => array(
		'date.php' => '3bfaed6ce9f06fe4bdb00b23c11ca8cc',
		'filescanner.php' => '5e61907f967680dbcf303f2dc49896e5',
		'functions.php' => '5f1eac62b8146bfaaec0695277e2d79b',
		'geoip.php' => '5a5db56262e3700264b7e113f835e3ee',
		'hashchecker.php' => 'd2cc3cec9e7622fb4b21dcf280ba407b',
		'ip.php' => '1ec3d319080eb3f629ac41d3d0431852',
		'random.php' => '8d19e87817bd8ac33090db142a98624b',
		'string.php' => '35e9372760d5a32be3a1bc2b854743f1',
		'unserialize.php' => '8420a8d5db64f2743c4d8eade4c51784',
		'url.php' => 'f7d65552d045aeba7ef437f0e1e6b13c',
		'wordlist.php' => '68218da074f9594411dc1e2c320df083',
	),
	'/core/vb_phartemp/utility/bbcode' => array(
		'parser.php' => '3060cbd3a00c3d162de0afba5b06d648',
	),
	'/core/vb_phartemp/utility/exception' => array(
		'phrase.php' => '92c0c36e24a370ee40503e6ee5e1b33c',
	),
	'/core/vb_phartemp/utility/geoip' => array(
		'ipstack.php' => '915eab6f3c8a498bb855066a2b7a4b42',
		'none.php' => '0b1db8b9e61d000c3abe347e6aa1ca87',
	),
	'/core/vb_phartemp/utility/hook' => array(
		'disabled.php' => '0ad6cae066877b36aeedce790de59249',
		'live.php' => '1251f32065c9638aae66bcab475df99f',
	),
	'/core/vb_phartemp/utility/password' => array(
		'algorithm.php' => '2e896ce2805dfc11613f677a352f527b',
		'exception.php' => '0b1d86b18f353aef14b04a2913cd6b6b',
	),
	'/core/vb_phartemp/utility/password/algorithm' => array(
		'argon2id.php' => '39b7f149c4e8c7e2a8c6ef0da067031c',
		'blowfish.php' => '378ea5d82d8b63289abfc1d2df20f6bf',
		'legacy.php' => '2cb432dc254ca091152eb034b2a98a21',
	),
	'/core/vb_phartemp/utility/password/exception' => array(
		'invalidscheme.php' => '4ef0bfd0c9cd555b7d1fe7b71f244f7a',
		'schemenotsupported.php' => '5b20f43a91054708ac956c4f3d6a208d',
	),
	'/core/vb_phartemp/utility/password/validator' => array(
		'haveibeenpwned.php' => '4f9767e03a63e281e46b13f30c1e65c7',
	),
	'/core/vb_phartemp/utility/template' => array(
		'class_xml_dom.php' => '8e84a817cd40d37c13be886535fb6a22',
		'conditionparser.php' => '3215ef4bac4b05e21e6bda0a85412901',
		'lexer.php' => 'f731191af4e2f116e0cd227a965270b5',
		'mathparser.php' => '4b9ff909d2ddd65837ead6f48390cac2',
		'parser.php' => 'f8924504a6112ddaa0926684bae38f13',
		'parsernode.php' => '9c47f3fc6b14e9f3b403253525f2cda9',
		'runtimevalidator.php' => '12f741a9b9adc40b952f60d595c78d19',
	),
	'/core/vb_phartemp/utility/template/parsernode' => array(
		'curly.php' => 'b93bb2c109411f14223642103c392485',
		'curlyruntime.php' => '7f5d23e711bf119e278e4f001a1f8028',
		'tag.php' => '97e35a38806859129e9045f26d203604',
		'text.php' => '8f2ebf477edb684bffa748b733d2afa8',
	),
	'/core/vb_phartemp/utility/template/parsernode/curly' => array(
		'action.php' => '9838dc2b922a81d0313a2e2aed77793b',
		'capnumber.php' => 'cddf8bd989551f970fb0992b056376c8',
		'compilesearch.php' => '147dcc06d39fde32161744fe23d1aedd',
		'concat.php' => '5158aa225c472faac49407f143f8fd1a',
		'cssextra.php' => 'a0ac0a9e92b706507669b06c04bada1d',
		'csspath.php' => '4abda8cf2cef0da6abc900959515f420',
		'customstylevar.php' => 'e9f8f8d7a7db5b057183e4ebd38abe9b',
		'data.php' => 'ad4386bdfdd0e3a8de08e87263fe29c0',
		'date.php' => '2039a2c24689b32056fce931b41fcf1b',
		'datetime.php' => '94207b4c5db7cf58d95269752812fddd',
		'debugexit.php' => '45bd3dba23e37e0f402c00c60a8a8288',
		'debugtimer.php' => 'bc9e20f83eb3c1b50dd37753de04d22e',
		'debugvardump.php' => 'b57bff481c7efc0230b8ea9b67484b45',
		'default.php' => '5b0078006f2136ef48ed33c3b5ef5959',
		'escapejs.php' => 'c7662391452670397074d64fcf80a431',
		'headlink.php' => '1354fdace98526acc9622105839d1fe2',
		'hook.php' => 'beaea9aef8593bf81c77ef3bfd81258d',
		'if.php' => 'f1e130833a046afe10225e600a0fe3db',
		'js.php' => 'd6f9fb3c5a20291a75bd5c71edfb064a',
		'math.php' => '9b2b54232b6371c053befed97e46e5b2',
		'null.php' => 'c0ba6abceeb5b86bb42cd5abed796fee',
		'number.php' => 'c5effe796d499d59004a4fc7b651350b',
		'php.php' => '3b7ab1f88afa4b9ebf4fdb7d94340b1a',
		'phrase.php' => 'e9b7bca1ba9812eb67383e54a1399630',
		'raw.php' => 'be4c9a6ea8b701e51cb928c241a6d699',
		'rawdata.php' => '782bd557b8e40db3ea2a65a67c73863f',
		'rawphrase.php' => 'ffa9b3aa4f43eb5df9e6763094ceb561',
		'redirect.php' => 'f8c402e2fd8c407a8834f053f5b7a32c',
		'schema.php' => '6ea89b44cbdac69c4f6b8fd5cbd78f75',
		'set.php' => 'db8751936e6cd5c1746ffb336cfe6977',
		'spritepath.php' => '7e6d1aeb334015802c6529f7ec8002a6',
		'strcat.php' => 'd5c9d6e8db40c214d5ef811d958823ea',
		'strrepeat.php' => '05e2cd8d0b27e9b3d1c1c3e6f4ddabda',
		'stylevar.php' => '2a5c5831fcfa022158384acb2d272544',
		'template.php' => '44fe383c594f2498e610bb37c1125e26',
		'time.php' => '05652ad652749db9cde7f9888ac83f90',
		'unset.php' => '658a5f4e2b931973b7fcc2cd7504a511',
		'url.php' => '31df8866882acbd9d6c6662a7bff8423',
		'urladmincptemp.php' => 'fa6c956f06ae965ecdec89e013991463',
		'urlencode.php' => '869d9d8dd295d1594aeeffa185dd5fe5',
		'var.php' => 'a10cb171cb2dc0bf3be8056dfc950e4b',
	),
	'/core/vb_phartemp/utility/template/parsernode/tag' => array(
		'comment.php' => '338004fee8e8605775522551d8f6d221',
		'each.php' => '3d5539348ccaa342b2a02f94883c6fd7',
		'else.php' => '45ee63235e4dfc9fd8edbd60da69515a',
		'elseif.php' => 'a83d15d1c1643e40e74a4eae549dc545',
		'every.php' => '6673cee0bb8392663d92971a6299e98c',
		'if.php' => 'd7a87d5ede2e236ab35b015c2291e386',
		'literal.php' => '28da428082908c0e3c68d0ea593bb75e',
		'null.php' => '0c3e1b0cb325c262f7ab53e012f56343',
		'usergroup.php' => '54c42852fc156ad75b44a73cf2e06d4c',
	),
	'/core/vb_phartemp/utility/trait' => array(
		'noserialize.php' => 'cbbb2eaeae42e89ec806f45cbbc1dbdf',
	),
	'/core/vb_phartemp/xml' => array(
		'builder.php' => '1a7db011c282d4963a1a353f2266e6a8',
		'export.php' => '873623405ed4f8eba7e99d67110116a8',
		'import.php' => '41fdb45af2e5b1c732c015b069499a42',
		'parser.php' => '97c5f1b36265bc8854c517f332c3afe0',
		'scanner.php' => '6695d541f3aed91f8cc43df9bfde6e98',
	),
	'/core/vb_phartemp/xml/builder' => array(
		'ajax.php' => '67cb7c6cea5392c2961e89ca276b9e51',
	),
	'/core/vb_phartemp/xml/export' => array(
		'channel.php' => '5565b2317104810ad5d8a12e4243771b',
		'page.php' => 'ad32be2b284c1c20105ef34ed2850052',
		'pagetemplate.php' => '68c990d8345854815c00e16387efbac6',
		'route.php' => '3c99db91bbbbafc9a379b1b18439a215',
		'widget.php' => '6536dec2f9be727250d16603a54fa371',
	),
	'/core/vb_phartemp/xml/import' => array(
		'channel.php' => 'b7391a4d4f4952bc8832046110bebe8e',
		'page.php' => '80d2bacdaa305290c278aaada2eff45c',
		'pagetemplate.php' => '478bcbf9604b708ee4f0e52a47e459a3',
		'route.php' => 'a667dbc59b0be5da05767ec41348e277',
		'screenlayout.php' => 'bd3b3e43388fa991728e1257e9c07164',
		'theme.php' => '65869b9ba9090ef2e45ed3a8458aa079',
		'widget.php' => '8fb721447b2b159a193c8edd3e31b004',
	),
	'/fonts' => array(
		'.htaccess' => '56a98c3e6db19bd9a0c120919fe77b28',
		'index.html' => 'd41d8cd98f00b204e9800998ecf8427e',
	),
	'/fonts/alice' => array(
		'OFL.txt' => 'e4a5807c9a3171eb9a2434b14aa81d8b',
		'alice-regular.woff' => 'f47d6a5c9e6ced3e8b30839354025a5f',
		'index.html' => 'd41d8cd98f00b204e9800998ecf8427e',
	),
	'/fonts/arvo' => array(
		'OFL.txt' => '9806ddf84b22de5aea9ed4f002d3b303',
		'arvo-bold.woff' => '689116deddf45a6813d1fd2b363fd43d',
		'arvo-bolditalic.woff' => '9a76befd81e190ab915e205d2c19e9f7',
		'arvo-italic.woff' => 'cb46ee10bc386485c2422cee3024b7ff',
		'arvo-regular.woff' => '9dec830484977d27d0a3ba7c7d7d7e45',
		'index.html' => 'd41d8cd98f00b204e9800998ecf8427e',
	),
	'/fonts/capriola' => array(
		'OFL.txt' => '5e22cac4f3047bf44bc44a0bbdff88d5',
		'capriola-regular.woff' => '3848cdc089beebb4b4350215f94d9dad',
		'index.html' => 'd41d8cd98f00b204e9800998ecf8427e',
	),
	'/fonts/dosis' => array(
		'OFL.txt' => '39440bd150ff2aa62d321f01ee927560',
		'dosis-bold.woff' => '44549b9101d9f33b9f0a043f9320e2b0',
		'dosis-extrabold.woff' => '2efbc95af6e50923f0a62e8bfdc6f1dd',
		'dosis-extralight.woff' => '75862163b96d8e02ba38de6cb4ae97c2',
		'dosis-light.woff' => '66d2cda9ae350d7c61df86284bdfa0cf',
		'dosis-medium.woff' => 'c6d049ee16c851d2551ab593b31d526c',
		'dosis-regular.woff' => 'f2de7c8e03e88d6d28a0df3385cf0707',
		'dosis-semibold.woff' => '581377e28f1de1ad9d1ee6b4c5fc4391',
		'index.html' => 'd41d8cd98f00b204e9800998ecf8427e',
	),
	'/fonts/fontawesome' => array(
		'LICENSE.txt' => '4186e0f8172f263065437f80932efbe1',
	),
	'/fonts/fontawesome/css' => array(
		'brands.css' => 'd94ccd9c21fa296b2170a83a70647034',
		'brands.min.css' => '6bb804ab927ec94b6740e50398f1dae7',
		'fontawesome.css' => '120a10c94943c6756a9508cce2160eb2',
		'fontawesome.min.css' => 'cea8bdd9bd17935518e256f85232ac1a',
		'regular.css' => '5453e81c3d631a531e4937a1fa870fda',
		'regular.min.css' => 'dd6d5825b134bdfc6d09655aec0e8217',
		'solid.css' => 'c6ddbe96142e0dc559d2804a7f5f0dee',
		'solid.min.css' => '5b46fdd25e4671dcee22c68e0c9b9d9a',
	),
	'/fonts/fontawesome/webfonts' => array(
		'fa-brands-400.woff2' => '8c1bcd87800a075b6d97f3f4b120731a',
		'fa-regular-400.woff2' => 'efae97d2f446081991a55fb72a8f3fbe',
		'fa-solid-900.woff2' => '9e462f01def01e744e4584ed56b9be54',
	),
	'/fonts/hind' => array(
		'OFL.txt' => '9214d6396f1c017f625cd76fe122d80c',
		'hind-bold.woff' => '9b21bd5e1e2bb61c8708cf794d266071',
		'hind-bold.woff2' => '2efac0bb7a940bc993c7091dd3cd6d52',
		'hind-light.woff' => '3c7425d3ec607c9fc5d7c7de025ade61',
		'hind-light.woff2' => '6005de292cafc79143ddf055e2a14bf7',
		'hind-medium.woff' => '7c1a4039fb6a351a4377b354242f7772',
		'hind-medium.woff2' => '65ac7aeecaa8f36082efc2e4f775401f',
		'hind-regular.woff' => '02da353484418046c3daca2a6f4d9e7d',
		'hind-regular.woff2' => 'bc7fa2e437f1e65da9b736dc1521d413',
		'hind-semibold.woff' => 'b41e1062d6c708a0e11f0b7c24356b1d',
		'hind-semibold.woff2' => '11512bbb4239b4f5c0aa9914b8b6bc0a',
		'index.html' => 'd41d8cd98f00b204e9800998ecf8427e',
	),
	'/fonts/lato' => array(
		'OFL.txt' => '4c869ebe248e6441e05878c683654ddc',
		'index.html' => 'd41d8cd98f00b204e9800998ecf8427e',
		'lato-black.woff' => '488bd4b082ebf6e3bfdd5c9ec89785cb',
		'lato-blackitalic.woff' => 'e9fdc03a68897e961479d472850de4eb',
		'lato-bold.woff' => '87e927a03740dd2771047d6fa9147a4c',
		'lato-bolditalic.woff' => 'b338ba26cd559b2a1cc18e1e91dbfbb2',
		'lato-hairline.woff' => 'a7f8414f4a3a12ef3ad73d745d965b45',
		'lato-hairlineitalic.woff' => 'a2e119a7de125be3702e012b46600a7a',
		'lato-italic.woff' => 'b5f08f78314c92ec305382ba04fe1746',
		'lato-light.woff' => '6ecfd5ff5e88c26d3052cba7e8d442fa',
		'lato-lightitalic.woff' => '977752ec6ccf2c93572adc4f2e243a33',
		'lato-regular.woff' => 'c6a9d8cb9286f4ace1b0619537db32ba',
	),
	'/fonts/nunito' => array(
		'OFL.txt' => '75cee882633054f4ae2105952aec7b00',
		'index.html' => 'd41d8cd98f00b204e9800998ecf8427e',
		'nunito-bold.woff' => '1d83d63c4a23f4cd24868f2ab49c9685',
		'nunito-bold.woff2' => '208684e07971f00988d393de8bb62ebc',
		'nunito-light.woff' => '9ec9bfd3a45cc78069bee0211e4ae781',
		'nunito-light.woff2' => '275677921ed1a9eb95dbb528a02e34c0',
		'nunito-regular.woff' => '13fcfde0e1f162f90a39b8f9a9b3d527',
		'nunito-regular.woff2' => '3a9d3d8ee8d13f92d85b526bf1c1e5aa',
	),
	'/fonts/oswald' => array(
		'OFL.txt' => 'd948b75f978acf84d0741b448c413cd3',
		'index.html' => 'd41d8cd98f00b204e9800998ecf8427e',
		'oswald-bold-webfont.woff' => 'd8651b9b201507bfc2fa3bbf2c36f37f',
		'oswald-light-webfont.woff' => '80e31fd71e6495447464bf88d050fa30',
		'oswald-regular-webfont.woff' => '335ceb8363c594617a985ae0cbd1f845',
	),
	'/fonts/playfairdisplay' => array(
		'OFL.txt' => '654bb835186c703967714c9bb1492bf2',
		'index.html' => 'd41d8cd98f00b204e9800998ecf8427e',
		'playfairdisplay-black.woff' => '85af3ed439d2532fafa473dd57749878',
		'playfairdisplay-blackitalic.woff' => '83fe0989d9baf96d66a0985515a97f75',
		'playfairdisplay-bold.woff' => '7057165f81b28a74d141ef314510b2de',
		'playfairdisplay-bolditalic.woff' => 'bd3d6a94066047cec33771f998cb10d9',
		'playfairdisplay-italic.woff' => '38d709c5558fa035b71865ed59fab7b4',
		'playfairdisplay-regular.woff' => 'eb45e86292ae1d8fba373106e393ec8a',
	),
	'/fonts/poppins' => array(
		'OFL.txt' => '481fed197dac47775fb62cefafa2555e',
		'Poppins-Bold.woff2' => '72eea25a559272c090d4f067e7ca3034',
		'Poppins-Medium.woff2' => '87f8f4c1da5feed6df9fe5a852c91910',
		'Poppins-Regular.woff2' => '4ca79fd9a4b1c35535ffed3118e5bdbe',
	),
	'/fonts/raleway' => array(
		'OFL.txt' => '192395d2fd64d6d1d8e9b3a92a5622f9',
		'index.html' => 'd41d8cd98f00b204e9800998ecf8427e',
		'raleway-bold-webfont.woff' => '62da4ce7b8fb5bf0e85c4c93fa839b58',
		'raleway-extrabold-webfont.woff' => 'cf1de5b38bb4aa7db706c459d9cafacb',
		'raleway-extralight-webfont.woff' => '8915278c74b54d4119606da8027299b5',
		'raleway-heavy-webfont.woff' => '8db9c9ad0ae4fc8eaf508560e1b9cc47',
		'raleway-light-webfont.woff' => '52d0134a23bd845b2766e3a32e071396',
		'raleway-medium-webfont.woff' => 'b0fdfbb41a1521724f783e9caf3c8c98',
		'raleway-regular-webfont.woff' => 'dc9211b1b8fd6cc214c28cc0d9fdfdff',
		'raleway-semibold-webfont.woff' => 'ea9f4a7fc9898247459603ea954abee8',
		'raleway-thin-webfont.woff' => '7f5ef371ade6c77566309d57a7d302f5',
	),
	'/fonts/robotocondensed' => array(
		'LICENSE.txt' => '3b83ef96387f14655fc854ddc3c6bd57',
		'index.html' => 'd41d8cd98f00b204e9800998ecf8427e',
		'robotocondensed-bold.woff' => '2ec3a454053413eff3acf215fe936084',
		'robotocondensed-bold.woff2' => 'c25164c6972602eaac040ebe54d77b2b',
		'robotocondensed-bolditalic.woff' => 'c0a8aa40ba7cb81f0c64a5cea51dcbd6',
		'robotocondensed-bolditalic.woff2' => '1c1258940e0098b7b236fbb3b1533d83',
		'robotocondensed-italic.woff' => '664116d64ef8b42f8bb6fbd161a8fa9b',
		'robotocondensed-italic.woff2' => 'fa26f2cf27300245517902fbc8cc7478',
		'robotocondensed-light.woff' => '7e27f8ab1dbecaa45b8c59f5028ebbfb',
		'robotocondensed-light.woff2' => '336729e0b93a1009aab80295ce8ce176',
		'robotocondensed-lightitalic.woff' => '4593992ebd8dc7887ba885268e9b033c',
		'robotocondensed-lightitalic.woff2' => 'e3c3ddd17d6cc092434d847b57f52fb3',
		'robotocondensed-regular.woff' => '8a1b502f21d61b71ca239f62d3cae8a3',
		'robotocondensed-regular.woff2' => '2905761cc6a0df975a96f646bf05bb6e',
	),
	'/fonts/robotoslab' => array(
		'LICENSE.txt' => '3b83ef96387f14655fc854ddc3c6bd57',
		'index.html' => 'd41d8cd98f00b204e9800998ecf8427e',
		'robotoslab-bold.woff' => '76663710e322754475a8a11b399b723d',
		'robotoslab-light.woff' => '8defb5ac78d2312c1cd1b9e2de3ae2fd',
		'robotoslab-regular.woff' => 'b4059e5a99678916ce567a2811fee8b2',
		'robotoslab-thin.woff' => '88f35a4759f65d0a3e6565d37d60b18e',
	),
	'/fonts/stintultraexpanded' => array(
		'OFL.txt' => 'd9c0af0f49197bc22523dc02e060a691',
		'index.html' => 'd41d8cd98f00b204e9800998ecf8427e',
		'stintultraexpanded-regular.woff' => '0da0a6e8fca997e9a2ad0c5038443222',
	),
	'/fonts/ubuntu' => array(
		'UFL.txt' => '325a1a9029112a2405e743c7f816427b',
		'index.html' => 'd41d8cd98f00b204e9800998ecf8427e',
		'ubuntu-bold-webfont.woff' => '9d06469d05a2a4746596fede395589bf',
		'ubuntu-bolditalic-webfont.woff' => '519922b0afb9bd37277af8f1da735c97',
		'ubuntu-italic-webfont.woff' => '0261236756d4710f95e2cb04174ab88d',
		'ubuntu-light-webfont.woff' => '84916f07ab9e5e73b44cc4ff28c8ef3c',
		'ubuntu-lightitalic-webfont.woff' => '3595d51770cbc0ea2eb82078c7f306bc',
		'ubuntu-medium-webfont.woff' => 'e923b2011c460823638d6f05b3feade5',
		'ubuntu-mediumitalic-webfont.woff' => 'eb63d368466d5995af482a6bccbcd7d1',
		'ubuntu-regular-webfont.woff' => '8d9144af133f814537a4a8e4acaecdf0',
	),
	'/images' => array(
		'.htaccess' => '56a98c3e6db19bd9a0c120919fe77b28',
		'1px.png' => 'b43a29e7a910f11bd1b91b3eecf182ab',
		'ajax-loader.gif' => '5208635d2996e4b7e66ac591c2cd18c7',
		'clear.gif' => '9bb191c6827273aa978cab39a3587950',
		'contentslider_default_background.png' => 'bce0c12dcc196f484f30cc20870328b4',
		'home.png' => 'ec8767adf5dfb60419922b1e029c655c',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'loader-box-blue.gif' => '6a3065d30f00ef6896143683d5d9e827',
		'loader-box-light.gif' => 'a946e0fd40218b460edef0d3ab317728',
		'topic-posted-ltr.png' => 'b430fa04081d45a98bb4e84c578540af',
		'topic-posted-rtl.png' => '16657c9da54e2dd951d3d74405ed46b4',
	),
	'/images/css' => array(
		'bckg_areaheader.png' => '374b25ec4cd2cb49d1da250db2f91b6a',
		'bckg_nonedit.png' => 'c6e8f848b52de3ccddfaf1b3b11195dc',
		'bckg_page.png' => '8980ebb135876b83ad2c73fa42b4d987',
		'bckg_stripe.png' => 'eba9b303cd999486bca674cfc17fbae9',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'pbar-ani.gif' => '2165b99c89c8431e7165530ccb5f89fb',
		'sprite_icons_ltr.png' => '25bab92a1bd33d70c8ee40804823b2d7',
		'sprite_icons_rtl.png' => '261b00df8af3ccdc97ceeeab0e9a89e2',
		'ui-icons_222222_256x240.png' => 'e3c994866d44326fedb62d6a93c3b276',
		'ui-icons_2e83ff_256x240.png' => '2957d4e6dc6bc65999e90686dc6314d1',
		'ui-icons_454545_256x240.png' => '0defd9b2b25ac6c5fd372cc949bec399',
		'ui-icons_888888_256x240.png' => '63678e4f0c2c3c6ec4633eeb534014db',
		'ui-icons_cd0a0a_256x240.png' => 'b6f9c2b54e21f509e96b4c74238467e3',
		'video_icon.png' => 'cbefb0e4349acbf35cf5c7910afeea78',
		'video_thumbnail_overlay.png' => 'f4623a21a35e47a3d180fe8721330d47',
		'video_thumbnail_overlay_hover.png' => 'efc5d4798e5136b5814ae5b960ecbd18',
	),
	'/images/css/imgareaselect' => array(
		'border-anim-h.gif' => 'd17d139fd0f988e292652eff78b955ed',
		'border-anim-v.gif' => '6e7a7abab9021c62fd1f730bb64020de',
		'border-h.gif' => 'b6599da1c0defd87f535fe0416b4bb7a',
		'border-v.gif' => '5ccef3f018b722ffbfc07391a4aeb646',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/images/misc' => array(
		'FB-f-Logo__white_29.png' => 'b50f6133b1e19e92c71176652b4bb7df',
		'facebook_logout.gif' => 'be68cc9ca2f10af791675183378ca1b5',
		'progress.gif' => 'f5839180e7e999028007d07f9c368ce3',
		'rss.png' => '1a189964231da8f8af463a0b7490acc1',
		'theme-default.png' => 'd2130852007366b13b3877a06cb99381',
		'vb_logo_darkblue.png' => '0bf7a99ae78525d68f8918ddf3196e5f',
		'vb_logo_darkblue.svg' => '2f1be2b5ea4ba515af99b55fe6a93c57',
		'vb_logo_gradientwhite.png' => 'abc4aa303795601b45ce22e88fc39c93',
		'vb_logo_lightblue.svg' => '14f09b61c4105b2640cb2756a665977e',
		'vb_logo_square_darkblue.svg' => '57de9afe76d7d9f446bb344fccd6d878',
		'vb_logo_white.png' => 'bdb7a0d238c89b81306156c628f2c6f6',
		'vbulletin5_logo.png' => '1d17053d795a92f16eed2cc8a35ad1d5',
	),
	'/images/sitebuilder' => array(
		'icon-layout-bare_full.png' => 'b946ca5edf13c9342493b1a769891276',
		'icon-layout-full.png' => 'b946ca5edf13c9342493b1a769891276',
		'icon-layout-narrow-wide.png' => '07fe6dce1a119a2d16ad0682f7cd659f',
		'icon-layout-threecol-15-15-70.png' => 'cf90c4dd104fa034cf75e1e14d288f4a',
		'icon-layout-threecol-15-70-15.png' => 'a066521cf69a63bf07e59bd3b472d826',
		'icon-layout-threecol-25-25-50.png' => '18160780205a04e9a8f401bd0c65990e',
		'icon-layout-threecol-25-50-25.png' => '7237b53987b64d4762ba6d784aa5ed7f',
		'icon-layout-threecol-33-33-33.png' => 'cb791d0ed0d72075bf5200b91cd6aece',
		'icon-layout-threecol-50-25-25.png' => 'b063be27e5e612c066413aa5d4d21190',
		'icon-layout-threecol-70-15-15.png' => '2c299c62799b06aa09d1e9644d0fc69d',
		'icon-layout-twocol-50-50.png' => 'f98c3ed3e946edb5654755b21f7019db',
		'icon-layout-wide-narrow.png' => '9af44452f30fc3e8d191faf196c2c81e',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'module-icon-aboutauthor.png' => 'bde3e7a66de1abf630ab26b8f4f1bc36',
		'module-icon-activitystream.png' => 'cf44187416d1e5266e8aa2bf061d4c02',
		'module-icon-ad.png' => '4e1f71f82983d16123db2bce01feefae',
		'module-icon-albumdetails.png' => '9b6565039940ad372fdeaab96d56037f',
		'module-icon-announcements.png' => '887a52d5f331ce8ed0a3239aa8307342',
		'module-icon-blog.png' => 'c3715594b236e2e04414f7a04a135863',
		'module-icon-calendar.png' => '9c8fbcb77768f6f0898f8d5b71737f64',
		'module-icon-channel.png' => '1f87736710b241141534c8cd8d322ac7',
		'module-icon-channelnavigation.png' => '03921b1a2613eb5f0099988ebfae2a53',
		'module-icon-cms.png' => '103627bde7aacf370aeea34223c0da59',
		'module-icon-contact.png' => '6dd15243b4f09a66957328ae3d526bf1',
		'module-icon-contentslider.png' => 'fcfb64918a869f66881b1bfcfd3cd44e',
		'module-icon-create-new.png' => '353a73c20c6fb75e594623e8a992e508',
		'module-icon-default.png' => '0e90a14b3b6d057467d0880c5d1eec9a',
		'module-icon-displaytemplate.png' => 'd8d625ce489a9102754e0660b1617343',
		'module-icon-friends.png' => 'b14af6aefd4165957a4bc15da195cd06',
		'module-icon-html.png' => 'bb9d390affbb2e6b6d945c5c65c433c4',
		'module-icon-media.png' => '120128b608ff2ea0cb4f16ad4450393c',
		'module-icon-onlineusers.png' => '632127f1e5e9b322c95ed5d396346fb6',
		'module-icon-pagetitle.png' => '47e5f885db379b46430efb8e3ea24ebb',
		'module-icon-password.png' => 'fa6e0c203b1542406a085b66446ef413',
		'module-icon-photo.png' => 'd5bc670fe632851b59a55a5862781615',
		'module-icon-privatemessage.png' => '32a07631004a157582f871c525e29c3e',
		'module-icon-profile.png' => 'db8c8e48d304e607e80d580e06f9514c',
		'module-icon-register.png' => '49190f519a8a50ab3ddcabb633f290f9',
		'module-icon-relatedtopics.png' => '5f3f1b29f51dc2de19c5283dc0cf6176',
		'module-icon-rssfeed.png' => 'e7b1ab718f8a83a092088103f5b7ee26',
		'module-icon-search.png' => '78818940f678bdb8ea4e5fd3f93c6ff5',
		'module-icon-settings.png' => '3a2ed2c1f9165f7b0b8889e5526987c0',
		'module-icon-statistics.png' => '62bd5a8ae386205d6c40b4affd744f45',
		'module-icon-subscriptions.png' => '6a1b4e04e663bd2623e4c117db132870',
		'module-icon-tabbedcontainer.png' => '7d00ac2325c72dea93725552dc6d71e6',
		'module-icon-tagcloud.png' => '022cc0387d626f0934d7d0e4b9f97216',
		'module-icon-tagnavigation.png' => '1406df4cd49aeb26a1c3259a97da16f2',
		'module-icon-todaysbirthday.png' => 'e8e00f23cf19ede7bffe4986b494b8d3',
		'module-icon-topactiveusers.png' => 'bd138823fb67270b744f6d4734876a21',
		'module-icon-trending.png' => '33752e8cda995d2ee09389eb95dffb0b',
		'module-icon-upcomingevents.png' => '9d1400f9177b16cf70a59da9ecb8fe37',
		'module-icon-video.png' => 'd358a33463003faf39c1106eec6c7b01',
		'page-thumb-4ecbdac82ef5d412817784.png' => '9c8945f3f3165176d9360b00d99948f7',
		'page-thumb-page_homeclassic_5d5f1629c20b7742318601.png' => '88b8890f54e499cb59de512db26cf080',
		'page-thumb-page_homecommunity_5d6039ff53c7b602957268.png' => '7761ebd11ef1496df357972915231ea1',
	),
	'/images/themes' => array(
		'index.html' => 'd41d8cd98f00b204e9800998ecf8427e',
	),
	'/images/themes/blackred' => array(
		'index.html' => 'd41d8cd98f00b204e9800998ecf8427e',
		'logo.png' => 'bf9f82c453a3ef519b1e076ce50e5c71',
	),
	'/images/themes/blueyellow' => array(
		'header_background.png' => 'db6f8c9648555fda58ad78b022552870',
		'index.html' => 'd41d8cd98f00b204e9800998ecf8427e',
	),
	'/images/themes/dark' => array(
		'body_background.png' => 'e3658e67e724ae5decb1309ab6730e93',
		'index.html' => 'd41d8cd98f00b204e9800998ecf8427e',
		'logo.png' => '645e3206736a48155a7382ba37d53709',
		'subtabbar_background.png' => '1c31c0de051f61d532138f0ea8809776',
	),
	'/images/themes/denim' => array(
		'body_background.png' => 'f04445c3ccf86c340712ba1d463d2da6',
		'header_background.png' => '647c852a2cb5b33d2a331e658cfe51bc',
		'index.html' => 'd41d8cd98f00b204e9800998ecf8427e',
		'logo.png' => '1f3d32b17098ba4ac1fd3d699972cd31',
	),
	'/images/themes/gradient' => array(
		'body_background.png' => '73254a5d6aea03bcb9a5137d8e1c6c0a',
		'index.html' => 'd41d8cd98f00b204e9800998ecf8427e',
		'logo.png' => '645e3206736a48155a7382ba37d53709',
	),
	'/images/themes/greystripes' => array(
		'body_background.png' => 'e9ac9eeaebb5b9a01da9587eff5c75c5',
		'index.html' => 'd41d8cd98f00b204e9800998ecf8427e',
		'logo.png' => '99866ea35aeb3e740c71e8871323cd9d',
	),
	'/images/themes/grunge' => array(
		'body_background.png' => 'a14a7983636316990f0bdc5316556492',
		'content_background.png' => '403ea7cfcfb720bd2f399b90f80addc0',
		'header_background.png' => '8d2d354e59b0d97fddda6972761c2d4a',
		'index.html' => 'd41d8cd98f00b204e9800998ecf8427e',
		'logo.png' => '9264be69f5709d5482b27bfcb1a841d3',
	),
	'/images/themes/halloween' => array(
		'vb_background_blackspeckled.png' => '52ded7b215b177e87c500f58436591ea',
		'vb_header_halloween.png' => 'fcb5d3f3ecdd549f8146fcee99a5b332',
		'vb_logo_gradienteggshell.png' => '538a4b80b86f2e3efa56e647d2d92e45',
	),
	'/images/themes/oldschool' => array(
		'header_background.png' => '1c8050670795c9cdc7350f683e3d049c',
		'index.html' => 'd41d8cd98f00b204e9800998ecf8427e',
		'logo.png' => '26d5a9708756e542b98b1ef77001578e',
	),
	'/images/themes/stripes' => array(
		'body_background.png' => '433d264dd83d4c35a3a894a6e79e92c5',
		'index.html' => 'd41d8cd98f00b204e9800998ecf8427e',
		'logo.png' => '391fd71d90def1aa8c06bac7aa8ccb2a',
		'stripes.png' => '3f80053583e0ce4741404395dfe7bce2',
	),
	'/images/themes/winter' => array(
		'body_background.png' => 'b1c58bced2e2e230c667f7511fed3dd9',
		'header_background.png' => 'c614ba180e0d3ad507cf5a521761d336',
		'index.html' => 'd41d8cd98f00b204e9800998ecf8427e',
		'logo.png' => '42dca2f4cf7ed35d9e4ea9fc4b966d8b',
	),
	'/images/themes/wood' => array(
		'body_background.png' => '4345c0481857557ddf734d94c5b8342f',
		'header_background.png' => '0ddc81266f2525ba8ae1483951efe855',
		'index.html' => 'd41d8cd98f00b204e9800998ecf8427e',
		'logo.png' => '1156f03bfacc1d18faf5ed06bbb4ef6d',
	),
	'/includes' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/includes/api' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'interfaceabstract.php' => '992d5b37d0fc2bff03f4ad0b5e6ebcd3',
	),
	'/includes/api/interface' => array(
		'collapsed.php' => '2609b276e16b9e2fde5057af507a44b8',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'light.php' => '9d409cc49b9a6a4bdf97a4292aab75e4',
	),
	'/includes/vb5' => array(
		'applicationabstract.php' => 'd43e1ef280403e0263c0936e5a52dbf9',
		'autoloader.php' => 'a758feda7423698fc5b09a6a7a9551bc',
		'config.php' => '02509cc82026889ed7e0fb3491063e86',
		'cookie.php' => 'e9d601d243376fb1156db495b4c031d5',
		'exception.php' => 'd5508fdc451dfc3c3210f14c42b70d3e',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'request.php' => 'c7abb96c0c00833ae23672637a3fd4d1',
		'string.php' => '909de1792a8f77d2a7184ace4c589ec2',
		'template.php' => 'b78b12715e59cb65062a0108133b5d81',
		'user.php' => '82f2f7343689c45878ff13ed2d2d2e45',
	),
	'/includes/vb5/exception' => array(
		'404.php' => '9706e761ae8c74b00f9ead18271c24e3',
		'api.php' => '2f5fb3c34a5f1fbd5fe0d891c9f43be0',
		'autoloader.php' => 'ddb4f49ddb508d620e0fe2237fcf4a7b',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/includes/vb5/frontend' => array(
		'application.php' => 'c62a4db3ef10744f1429f3d238cc0389',
		'applicationlight.php' => 'cefd2bc28eede1debd17301211d94140',
		'controller.php' => 'b01c566b2d7f0fca1e4fc0bb403add54',
		'explainqueries.php' => 'e17c928c54a14c05e7e3118f16a8b69a',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'routing.php' => '67f18c4fdba4accc89d1cc795f85b51d',
	),
	'/includes/vb5/frontend/controller' => array(
		'activity.php' => '83bbccb7928252860ba3b2b0b5eb6198',
		'admin.php' => '9b7627ca1f727971935498f6c2005bf3',
		'ajax.php' => 'b6ada67072654e2292b80b797fa60b6b',
		'attachment.php' => '2e9d4fc9ca62c47b948daba1e6b45e2e',
		'auth.php' => 'b5f4f2713a8b56396d1697f35a2c2ba9',
		'bbcode.php' => 'aed8cea317dc2e7af102bc0403678622',
		'chat.php' => '55f296fa58c603338b9f0fd6a8734b56',
		'createcontent.php' => '83d9ac09759bc9581f45dbe69c521b57',
		'dashboard.php' => '859489cf0bb8363380967c89ca4abf30',
		'external.php' => '8f133912b20736077fd994c9911f4d93',
		'filedata.php' => '2c3831e7ae66c661c422ef0ed0b62478',
		'hv.php' => '04e337d75f840b241440dbaa830f878a',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'infraction.php' => '8a96cb6626d9f0ec151e4126c9130c81',
		'json.php' => '445c608b1e3159e0620268cbde8baa9e',
		'oauth2.php' => '87d0d98e9c93521d7b69ce9f18100bdd',
		'page.php' => 'dc4dfc6295c009d12d6cf88e98aec505',
		'permission.php' => 'fe06056297fbf81b0bce5f098193e57a',
		'poll.php' => '0783843cdb177802015fe72e08551a75',
		'profile.php' => '0c06bfc744090d05029c439ea10513f0',
		'registration.php' => 'b963325b43957499ad8aa6742845d3f3',
		'relay.php' => 'ee03c55d6d34105f6786607e6353dd47',
		'report.php' => '2307cc1981c3f73438f8e3c9e1764389',
		'uploader.php' => 'e6d8e69b285045bac79f1e249ff34ec6',
		'worker.php' => '0f2f93f3ae5009c940dc28cb4aa84f3a',
	),
	'/includes/vb5/template' => array(
		'bbcode.php' => '8ff3b2ee90613b5d1394c4202d67b3d8',
		'cache.php' => '6ed752d0c82549a7382719b594d5a049',
		'headlink.php' => '66f7a6cb1da814ccb9a0f938ee529fea',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'javascript.php' => '96e3bdb75c719fc63812dd9c8ee30037',
		'nodetext.php' => 'f97780aa45e06a306b45a0229fecded1',
		'options.php' => '056c70e69acd970efd7f490223bcebf0',
		'phrase.php' => '2b886ac5f24bd31525d7fbfc12c4df51',
		'runtime.php' => 'e39ff2f1bfa06678ace7115b483b661c',
		'stylesheet.php' => '10aab8b088d10edeae1d8e417c55daa3',
		'stylevar.php' => '6fe509c0035090cf80e4110ca4fca4aa',
		'url.php' => 'c0da56c604adb5d22dcfe04669410f4e',
	),
	'/includes/vb5/template/bbcode' => array(
		'delayedrenderer.php' => '9849824991160fa74a477da88e3ec568',
		'delayedrenderqueue.php' => 'cb111e0aa7753724a9583e933609f590',
		'imgcheck.php' => '47858daa1150261474472db34669059a',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'table.php' => '6dfe9dae22bca34afa9b7c39271b6f63',
		'tablewysiwyg.php' => '3650708446370e4ecaaaf7fbbcc91f97',
		'wysiwyg.php' => '00617d666732bdb48a30247846766d10',
	),
	'/includes/vb5/template/cache' => array(
		'filesystem.php' => 'af95ca6c1e7294e409a7645c9658ac2e',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/js' => array(
		'.htaccess' => '56a98c3e6db19bd9a0c120919fe77b28',
		'admin-sbpanel-style.js' => '43cc2c452dac45c680107656038c4d61',
		'admin-sitebuilder-rollup.js' => 'da197ad764f7dd93f44ee8ed9f17bae2',
		'ajax.js' => 'd12f24e9bc0032cffd53f357cf60dbb7',
		'autocomplete.js' => '2d2a77ca8b074497dd8602a1c789e3e1',
		'blog-rollup.js' => '36aae3a2e6b3bc28aadbb1da2dd55f48',
		'blog_summary.js' => 'deea9beb47b1b73332c31e852bac663d',
		'channel-rollup.js' => '6995956aa31c6f5044da003bf1e4f12f',
		'channel_conversation.js' => '24a4ce164ebca206663c6ddb982edd2a',
		'ckeditor-rollup.js' => 'b24d5858922cae93bd7d9e29b2a13c87',
		'ckeditor.js' => '960cd9517ff319e264d93245f6f4fe13',
		'colorpicker.js' => '4621c8accaeb95cbf4ad955413dda0da',
		'colorpicker.min.js' => '24d9ddb35b7fe66cccfddbd976a6fb94',
		'config-site.js' => '72ef7e7e2aa0bb2697901afa3f8acd55',
		'contactus.js' => '200c9fd51aab252fd9bd0940cca9407f',
		'content-entry-rollup.js' => '0c148fa99fa1f5191dbbb4c9a54ca2ef',
		'content-slider.js' => '69f86359ba95949bcd7d88ee3c679b30',
		'content_entry_box.js' => '26cd7926a03908d4bc1079d75048b67c',
		'conversation-rollup.js' => '1d22e4fff4180549b2541b5f8e1dc31a',
		'conversation.js' => 'ef42d950cf09448237725184396878b0',
		'conversation_filter.js' => 'c71d9ffaf1e86b26824046d894750831',
		'conversationcommon.js' => '7d65ddd5dbf47259d86794df35fd3c7d',
		'css_b_comp_menu_dropdown.js' => 'd491817a65041f1b2f8b2e1c56a8d020',
		'css_b_comp_menu_horizontal.js' => '59c3cf02a36bc3c8424e5ac889eac3f5',
		'css_b_form_select_example.js' => '6cdfb4601f0103084cef30dbe5a01f09',
		'css_b_tabbed_pane.js' => '081d2e48b44dbf4d51cc8b9c009bf954',
		'deleteditems.js' => 'f92f4a8701a4e01b1c38d1f71f0f13eb',
		'dev-apiform.js' => '54a409f4a6144c7509272ed7c367af58',
		'dev-markup-library.js' => '7cd265e0065b6aa1fee94f886be744f2',
		'dialog.js' => '9ea89ec9c799112051afc1231c8e6d8b',
		'facebook.js' => 'ca5bc0ff2727457db1a8f4f799b1ca4f',
		'file-upload-rollup.js' => '4614457350c8455f995be2c056503edf',
		'fileupload.js' => '007c57b41792c511ff7c52c85fdb8661',
		'flatpickr.js' => '3897f70c18df17f59e3a4d68ab32cf54',
		'footer-rollup.js' => '21ebf020968c40fb0e5e5a913a82eedc',
		'fullcalendar-rollup.js' => '807216f350677110276d692e128e65fc',
		'global-head.js' => 'bf802034a270c1a1de5a40572a9ef5ff',
		'global.js' => '9159016c81665c17f0e7b0a0b7942c35',
		'group-home-rollup.js' => '127e0e04699cb17f134981798d3b0495',
		'group_summary.js' => '5077dae591354f6fcd97d71b9a588491',
		'groupadmin-rollup.js' => '36a31d01ac3aa36b2fc9b964ad8cf694',
		'header-rollup.js' => '1c334d119832787347d758aff122c63c',
		'help.js' => '1e3c7b1c95291cd26f5d03df0bd6b0eb',
		'history.js' => '41ce8b8d76d7667011b0facb39be8d21',
		'hv.js' => '144a160bee978ebfd39481561df58567',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'infraction.js' => 'e903c052f25c73c988c08131dde1a099',
		'inlinemod.js' => '9b16c6494271a19122ee4fc857d46067',
		'jquery-fallback.js' => '0f744af3e7af2108c23d0cc6c064f2c9',
		'login.js' => '6ca727aa412d3c7b8f88e47269067204',
		'login_md5.js' => 'a993f84f9a2c3ea120b4db730f96e30b',
		'lostpwd.js' => '06e1f4f096d4ff0e999f3ffaa4449e58',
		'media.js' => 'c3b87c67a36cf3dce76d73b486fb78fd',
		'memberchannel.js' => '522693fca7b3c532aaee7c9f28643937',
		'memberlist.js' => '85957daaabb9411f2d0d7457c907d142',
		'modernizr.min.js' => 'bf699a2fb0c110d4e5cff59b3337e877',
		'module-calendar.js' => 'b0b2ac8d39b9e1428d5b05c12b1702d0',
		'module-search2.js' => '6dc56029b81a92f5d816299d02404e36',
		'module-tabbedcontainer.js' => '3092e576cf00ef0ad5a8b9713817bae5',
		'notice-rollup.js' => '8a4e1f677d0438f80b57bb7820eb5df0',
		'notice.js' => '709ebd48592eddf96146807ce69d7a13',
		'oauth.js' => '90b93ff7a5f650ee63a2f6d474d56e8d',
		'paidsubscription.js' => '4a1dc459c1d2f84cbbf3d2b4f6c07a82',
		'password.js' => 'ddc5e5fd55091210b5fbd0f3b19c723f',
		'pmchat.js' => '9714798733632c3d625970517bccc2ad',
		'poll.js' => '6d3563b7b99359903a318ae2243dca1f',
		'privacy-consent-banner.js' => 'a8e1f84b351408c09275031fc8313379',
		'privatemessage.js' => 'd021b3069c3e2b9c80b29a6ced4d525d',
		'profile-custom-edit-rollup.js' => 'c5855012a37d814aad7d1b829b34033e',
		'profile-sidebar-rollup.js' => '135ccd7cb56f3d9de9c4d8413c9ebc3c',
		'profile.js' => '52c21ad6722a092a79b354735d91ac18',
		'profile_customization.js' => '6351209a5385e8e87904b3d2ba7e769a',
		'pushnotification.js' => '03cf1c13c6642cac013d352f36b39e71',
		'qtip.js' => 'f2692f42c810d4f80b8d1652c61bca51',
		'reactions.js' => 'a100427b8bbdefbc03e29c0ff3a9bc1f',
		'reset-password-rollup.js' => '7c555867bb50924de1926531f494d338',
		'reset-password.js' => 'c9077f238a561f381159033f9852b8d7',
		'responsive.js' => '6ccf1adea76258b5b9497700878bbeb9',
		'sb_activity.js' => 'f7622f64bf791767fdb27fbe5eaba79b',
		'sb_blogadmin.js' => '97e0e79d3e03b8a81657cc1e39fddf0b',
		'sb_blogs.js' => '7d9c2bdad2b196936a825f51363feeca',
		'sb_groupadmin.js' => '6ae4c59b0a28e5562989a88cde401b9f',
		'sb_modules.js' => 'fb87f4b6ce4627f3d8f6722a3050fb9d',
		'sb_online.js' => 'e44952e4849493764630dc8cde1aa269',
		'sb_page.js' => '5d43c405c213e5c813062c6d45021400',
		'sb_search.js' => '6f9e554bb30c8f301a85c355a0c53513',
		'sb_socialgroups.js' => '30117f6e4c2329786d1d5d06fb12a90f',
		'search-rollup.js' => '30aedd2b899384de6dca0e226fccaee3',
		'signup-rollup.js' => 'f5751480f54dc171a29014fb0069254a',
		'signup.js' => '3604dc29caeb381bc1ca78bc219ec801',
		'sitedata.js' => 'a16a8d5cabc12402e58895a0d51c377c',
		'storage.js' => 'a7aba7e586b359981830b20a61c02461',
		'subscribe.js' => 'be449e30991ffd61f4247196f7beb319',
		'subscription.js' => 'bd2a0407fcf725884e049651d3333917',
		'tabs.js' => '61522c47feeb9dd37a90758c6468b5f6',
		'tag-editor.js' => '80059d4f2b0cc2bafc20b855a4ad1339',
		'usersettings-rollup.js' => '1a5bbcaca5aa0a4fa3bb2cae4bd317fc',
		'usersettings.js' => '6d2f1a08119777f8de812c2a0c81d32c',
		'usersettings_notifications.js' => 'c0f8fc3fbe2e621f3aa628534e4709d1',
		'vbColorPicker.js' => '4d8db8fe3c343158d2319621e4b8ca84',
		'vbSlideshow.js' => '3f812c6eb485964f0e768412e9928109',
		'vb_serviceworker.js' => 'd965a0d2253922b70a010a6e4e80dbcd',
		'vbscroller.js' => 'c1e0586c59b2a9aec7c14ad8f9c5cbfc',
		'visitormessage.js' => 'bf3f1facd133da0bf3b41f2c5c7e1caf',
	),
	'/js/blueimp' => array(
		'LICENSE.txt' => '5d95a44253990b0fec137e3f4adcb635',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'jquery.fileupload.js' => 'd2c6c4b5df751de6bf85307eddb3499f',
		'jquery.fileupload.min.js' => 'd007eb0a2280b45fd36b57bed9804a0f',
	),
	'/js/ckeditor' => array(
		'LICENSE.md' => '4a6d282a3d245cff60fb34c9bb2a8f82',
		'ckeditor.js' => 'df3f05723b34010e67b35edfeeb6e0a3',
		'config.js' => 'dbc65722e8c3bae5b43b7616b7608db8',
		'contents.css' => '59c53171b672cd6a6ecf916b5aadaca1',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'styles.js' => 'edfb52d4b709aefd8b5effce24fb80fd',
	),
	'/js/ckeditor/adapters' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'jquery.js' => 'c3853d4ed30dc1d6c3c8cbba1e4ae804',
	),
	'/js/ckeditor/images' => array(
		'index.html' => 'd41d8cd98f00b204e9800998ecf8427e',
	),
	'/js/ckeditor/images/dark' => array(
		'arrow.png' => '409dfee0c57ac6ecb9c110f9f2212bc7',
		'close.png' => '13f6e6e6542679ef012c104374535322',
		'icons.png' => '65f395dc25bd924bd98766c2fa9a59c3',
		'icons_hidpi.png' => '87d33af9b31139ee98c95da5f08b330e',
		'index.html' => 'd41d8cd98f00b204e9800998ecf8427e',
		'lock-open.png' => '6e42c0e6eea83f6699229bd3270a191a',
		'lock.png' => '5e7e0916dd767e59aa2de6ce973d9875',
		'refresh.png' => '3523afe73c49bd374bb404a7c7270ccc',
	),
	'/js/ckeditor/images/dark/hidpi' => array(
		'close.png' => 'd7b6116b729feafe8eb3d219f6b06225',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'lock-open.png' => 'c675ac2f424544099556e70b3db55358',
		'lock.png' => 'b702d511343b1e156ca609c97c32a9eb',
		'refresh.png' => 'a31e58359a89632354ff9e218153aaa0',
	),
	'/js/ckeditor/images/dark/vbulletin' => array(
		'break.png' => 'cca19c2786b5fb62d1c1e470e11e0a94',
		'code.png' => '458c535bc6228b039d21c801ef636d59',
		'html.png' => 'b519fa24a93aca0caf429e223e8bf60f',
		'index.html' => 'd41d8cd98f00b204e9800998ecf8427e',
		'php.png' => '359f583ead234b00484ce96139417a79',
		'quote.png' => '1799cf6ad841760e34b27674eeda287e',
		'video.png' => '872239fbcf76c1c1711d14c22875fbe8',
	),
	'/js/ckeditor/images/default' => array(
		'anchor.png' => '690755f47a20e922ee455addc3a688b0',
		'arrow.png' => '6fb2120fd35b49c3cec315a9f813daca',
		'close.png' => 'e08e86da4ac4666521b798aab573e24b',
		'icons.png' => '364b436969c7e70827b18bfe2af75774',
		'icons_hidpi.png' => 'ce2a34128cc3c9b24f2fa0393f6c5b0a',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'lock-open.png' => '68ea16cdde795333b0ff59f1d00cdb82',
		'lock.png' => 'fe33ad9af4ae702a02bfbcb6d4ffd461',
		'mini.png' => '94486bdf738306e36bf7d144f4268f84',
		'refresh.png' => 'c0fad48121f254833d7b0c1a926b9a32',
		'spinner.gif' => '7f32b6e67f42a0ef3e1ddb0b9401f6c5',
	),
	'/js/ckeditor/images/default/hidpi' => array(
		'anchor.png' => '23c0c67fbcfa1f4cdb4cd8f58bc6a41d',
		'close.png' => 'a079fcad12f2af8bd0d451c2e237cf73',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'lock-open.png' => 'a8353b924c4518803d5fe37649adb9b9',
		'lock.png' => '1b4932332720b9a313129ffd1f4d5f74',
		'refresh.png' => 'd66f7cf6e817fa8316ec19ce5a1f11b0',
	),
	'/js/ckeditor/images/default/vbulletin' => array(
		'break.png' => 'cb89de0ac61c6d5cdb9ca6e27d5c595f',
		'code.png' => 'fe7ceea41f59c77fd86bec292aacb36e',
		'html.png' => '45635468888d92ec304cc9278a4061bd',
		'index.html' => 'd41d8cd98f00b204e9800998ecf8427e',
		'php.png' => '36ce4c35547f732de2885618bc0447f3',
		'quote.png' => '6fd75150d07b12ae2a9e67dddf50cbc4',
		'video.png' => 'd19b6ac4ce270e00414325b0ee6bab44',
	),
	'/js/ckeditor/lang' => array(
		'en.js' => '1f0d8b40cb315e5f7cf7d83eec7496db',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'vBLang.js' => '6487b3ecb1572bb8d29de244382c5bb7',
	),
	'/js/ckeditor/plugins' => array(
		'icons.png' => 'b7e68b2c54859e79985da6e0f33ff58c',
		'icons_hidpi.png' => '955003ebb47e900440b3037c924f269d',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/js/ckeditor/plugins/a11yhelp' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/js/ckeditor/plugins/a11yhelp/dialogs' => array(
		'a11yhelp.js' => 'a75a8d38d541a23ba92482ccb8c93f7e',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/js/ckeditor/plugins/a11yhelp/dialogs/lang' => array(
		'_translationstatus.txt' => '11d41d732cff6d447c4be81cd0dfe023',
		'af.js' => 'd98adf2eec9024cb59fa70828ee34b2d',
		'ar.js' => 'e75c212bb893df0f6ae613fea1347820',
		'az.js' => '11a4ea4fab30add64b386eefcf35c566',
		'bg.js' => '24dda0b7f5f5f8a7f450f1fc795d3475',
		'ca.js' => 'a106ab7a628f7c42d76cab99e376d3d1',
		'cs.js' => '670e20353ea4b3cf26fe0bcc7595cf45',
		'cy.js' => '718ec0a6fa22284268c5113780253087',
		'da.js' => '2f220665f60cf070b62bdcd2a471f325',
		'de-ch.js' => '6e1ffcac4d5a2cf2444a4c6125307cb6',
		'de.js' => '9548b64502c5b4934c3a67d8c4aecbe6',
		'el.js' => 'd083c6fcf8590d1e3651c5bc5fbeaadc',
		'en-au.js' => '0e15e48ee303aca6312a2b08e7b8e064',
		'en-gb.js' => 'fe665c5b88b367bf68aae28759cafe75',
		'en.js' => 'da9b95d9ce27aa54b91e9aeea262570a',
		'eo.js' => '4cc99cd4d5f391b99653d76bbaaea58b',
		'es-mx.js' => '811d503ed93d37ef3c6d32f9263f91f6',
		'es.js' => 'e39d2557c7cd88274a819ffadb5a8e37',
		'et.js' => '1b26ca4afc08bd26db78a5f2ad1059c0',
		'eu.js' => 'ce8274de16c8721f2f26e76d5dd4243b',
		'fa.js' => '39cfa1923df406262e09b583f7d9c287',
		'fi.js' => '794743766a265efafe18462fd45afab7',
		'fo.js' => 'ccc1d466a6e572378c34f2fe85ab1c9d',
		'fr-ca.js' => 'bd86481c86b3c0f03f18585727c6077c',
		'fr.js' => '9cf6b605580921a11a4b42dd0b79903a',
		'gl.js' => '627c8de1cc7da63b57261fe45dea9c5f',
		'gu.js' => '35f677d60c2476719b404eab916495ec',
		'he.js' => '81a22a77df7b560658641a381a6b3471',
		'hi.js' => 'c46018e936c24fb000b8f428cb57d01e',
		'hr.js' => 'c5bd5596d5352f4f26d9f45a8b603b15',
		'hu.js' => '6763ecd9eac6e1bb8ae3be6b74c8248b',
		'id.js' => 'ecc5eccdd76f5eba3ee3d2b6406a54cf',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'it.js' => '050e5a0f32b808314985ea5a7146b91a',
		'ja.js' => '89183221f860c6556b77d8333a733232',
		'km.js' => 'b8784b1f96645e85089799e2be94aa82',
		'ko.js' => '5af84b85abb5d326c753f572df076d67',
		'ku.js' => '0d7a1808b1ecdc437460b604db932236',
		'lt.js' => 'ac54d2175ddf55da9d6da4978cb3b284',
		'lv.js' => 'd0f9473dc50490818821824c5f561e2c',
		'mk.js' => '62f8d43dca121876dcc6ca1232c6d463',
		'mn.js' => 'bce862655e824a3cf0acd27364d599b6',
		'nb.js' => '57fc435fb7b4ad731c9a9f3a6eb17bed',
		'nl.js' => '8275a2bea18f9de011a05d0ff114c0db',
		'no.js' => '5903c189dbd083a797849b4c71a2c370',
		'oc.js' => 'c57cacd5ecc42c3543dbe606f9b799f6',
		'pl.js' => '6271ba2d181de42270d8c073de412c0f',
		'pt-br.js' => '2bad9bfea3367cc98772314e508a9c77',
		'pt.js' => '4fb98cb398cd62affb9c788c028df619',
		'ro.js' => 'dcdb30772077838dc703a03bec5cb0c7',
		'ru.js' => '93aea926bf9d858a98e5703de821b221',
		'si.js' => 'ded3172c132c1a3b1a281805c737a608',
		'sk.js' => '4763ac49c10f6a34069d2ab65b337029',
		'sl.js' => '37e2dc263d0ed967e7915ecb577ccbc5',
		'sq.js' => '9d1a6a5be83b2aeb350a73a9a7a36a8f',
		'sr-latn.js' => '2d104d7d9634ad8de68f587b5ad584bb',
		'sr.js' => '2ae8815deb885c2d741e84ca283b34ce',
		'sv.js' => '1f26c2b3c1a74e8899674f8680443065',
		'th.js' => 'ff8f97250d8f8d1e53f87b8df409b766',
		'tr.js' => '38881e17211eeb31e40cf2a9eb793d87',
		'tt.js' => 'f311f7977e09aa69301df3bfe8ecb113',
		'ug.js' => 'a7c2a4d90955f2a017b3c5e2de97eca5',
		'uk.js' => '7d1a9a01d552dc4189f6c7a3dfa302d6',
		'vi.js' => '7d9db5e80d31329c8a748e7a8fe0bd11',
		'zh-cn.js' => '19a5965aea3481f39b44c6677e917b02',
		'zh.js' => '5350a776af29fa6f5f71e0cc907abb93',
	),
	'/js/ckeditor/plugins/autocomplete' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/js/ckeditor/plugins/autocomplete/skins' => array(
		'default.css' => '140e8547ba3af2831f3ea40a2e579d26',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/js/ckeditor/plugins/clipboard' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/js/ckeditor/plugins/clipboard/dialogs' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'paste.js' => '88bdbc49b3c29a895590a363472068be',
	),
	'/js/ckeditor/plugins/colordialog' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/js/ckeditor/plugins/colordialog/dialogs' => array(
		'colordialog.css' => '90a720cbc322c333058e700b5117388b',
		'colordialog.js' => '25b480f9e9663981a1e843c80665b9c1',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/js/ckeditor/plugins/dialog' => array(
		'dialogDefinition.js' => '62e0c854228e1ecf239e74d5a5712e21',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/js/ckeditor/plugins/dialog/styles' => array(
		'dialog.css' => 'e9dbb811e0ccf0a582ad6159070d2fb0',
	),
	'/js/ckeditor/plugins/div' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/js/ckeditor/plugins/div/dialogs' => array(
		'div.js' => 'defb571be1e553ad8df038c2b06ba7f6',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/js/ckeditor/plugins/emoji' => array(
		'emoji.json' => '818c3a48e814a1906b5bf3e48ed46f97',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/js/ckeditor/plugins/emoji/assets' => array(
		'iconsall.png' => 'b823cf335b8b7b73b788879441e58689',
		'iconsall.svg' => 'e76bc97a1025e50a937209a591005690',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/js/ckeditor/plugins/emoji/skins' => array(
		'default.css' => '227c3336c8af445adcdb16d2c3dd135b',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/js/ckeditor/plugins/find' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/js/ckeditor/plugins/find/dialogs' => array(
		'find.js' => '776bc60c4355e92d340292264edeff71',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/js/ckeditor/plugins/flash' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/js/ckeditor/plugins/flash/dialogs' => array(
		'flash.js' => '09ac2ee662799bc159d1c6e7556fd779',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/js/ckeditor/plugins/flash/images' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'placeholder.png' => '071064aca5068553dd1941a583dac83d',
	),
	'/js/ckeditor/plugins/forms' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/js/ckeditor/plugins/forms/dialogs' => array(
		'button.js' => '042d46048eab832d2a10b8afc2a5af80',
		'checkbox.js' => 'd3b6002efd6652a1154a1b06c01941b9',
		'form.js' => 'b98417ba51ad1a45f31a272a58538012',
		'hiddenfield.js' => '929baf77f767b80882427bd652f41bf4',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'radio.js' => '52f6afae6cae4ff073c907d277f587bf',
		'select.js' => '2596975fb6d6ef2083d529eb9d3063f9',
		'textarea.js' => 'a0199b7305f63fe235c22facf658524b',
		'textfield.js' => 'ebde2e6efa245c10e47f338ce35d4915',
	),
	'/js/ckeditor/plugins/forms/images' => array(
		'hiddenfield.gif' => '6e7765b0483daffb25f2b7bf5098e0d9',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/js/ckeditor/plugins/iframe' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/js/ckeditor/plugins/iframe/dialogs' => array(
		'iframe.js' => 'eeee379ae9ede56f6299821ca7806800',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/js/ckeditor/plugins/iframe/images' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'placeholder.png' => '18ad1c9e422b76f98fa6aa7d168fea2e',
	),
	'/js/ckeditor/plugins/image' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/js/ckeditor/plugins/image/dialogs' => array(
		'image.js' => 'feb0c98d11ddbcbadb0e03591215e3bd',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/js/ckeditor/plugins/image/images' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'noimage.png' => 'fde0c632f67673badd09c7f4176cb569',
	),
	'/js/ckeditor/plugins/link' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/js/ckeditor/plugins/link/dialogs' => array(
		'anchor.js' => '82c106d7de1fa3dcb14c8ff0c73e8709',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'link.js' => 'ee13b578c160c2f08d0ef9d238a806bc',
	),
	'/js/ckeditor/plugins/link/images' => array(
		'anchor.png' => '0eb509b1585f536911602be0c9b62b52',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/js/ckeditor/plugins/link/images/hidpi' => array(
		'anchor.png' => '23a432b6ab1f387263bfebe3d367b6ea',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/js/ckeditor/plugins/magicline' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/js/ckeditor/plugins/magicline/images' => array(
		'icon-rtl.png' => 'a0e4279f76ad06576c855273e4701036',
		'icon.png' => '88073f01bceedaeb0aedec8380619f91',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/js/ckeditor/plugins/magicline/images/hidpi' => array(
		'icon-rtl.png' => '04d35f3d15b2219db05d77afd41ed94e',
		'icon.png' => '9c6598a80fc150ef9c537958a4d863fb',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/js/ckeditor/plugins/pagebreak' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/js/ckeditor/plugins/pagebreak/images' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'pagebreak.gif' => '05dcfa6e3332b3ab7ac9218bf420cb58',
	),
	'/js/ckeditor/plugins/pastefromword' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/js/ckeditor/plugins/pastefromword/filter' => array(
		'default.js' => 'fa9dbab0c5eaf9835e163c6dc3fded06',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/js/ckeditor/plugins/pastetools' => array(
	),
	'/js/ckeditor/plugins/pastetools/filter' => array(
		'common.js' => '6b1379f80f43d262279a16e048d32541',
	),
	'/js/ckeditor/plugins/preview' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'preview.html' => '0d805248106877e417257be520ded8d1',
	),
	'/js/ckeditor/plugins/showblocks' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/js/ckeditor/plugins/showblocks/images' => array(
		'block_address.png' => '78ebc6b6f2f95bbbd01c143939bd4f7c',
		'block_blockquote.png' => 'd6a7cc67a46e63b7cb815b7490d2c392',
		'block_div.png' => 'a1d045b7f8940df8745c4ab192029c1c',
		'block_h1.png' => 'a4ff3eac459405236e92da855d43456c',
		'block_h2.png' => '0539ba4d9f7e0b78f6e5b0a25f5cf59b',
		'block_h3.png' => 'fc1d537b36d533c18f2c7243ebbfbf3d',
		'block_h4.png' => '2ec42efea5bc2b8bd4aa9bd3ea9d39c8',
		'block_h5.png' => '058f0d4c31b49c010e7a75efe86659eb',
		'block_h6.png' => 'e5709f14533969981419dff149fbb1d6',
		'block_p.png' => '31fde7ff4d703c54d4b4208f71ecee56',
		'block_pre.png' => '42f726df96fdd27c701927dac6ea1975',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/js/ckeditor/plugins/specialchar' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/js/ckeditor/plugins/specialchar/dialogs' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'specialchar.js' => '94c4079f515569e7f865a2cac8d79f6f',
	),
	'/js/ckeditor/plugins/specialchar/dialogs/lang' => array(
		'_translationstatus.txt' => '7182f1c43a1c4202caf08d06e19a4027',
		'af.js' => 'f90a9a155c7ea267c95506045a855e42',
		'ar.js' => 'f4cbb29950d6b0edb6e5fc69f80afdb0',
		'az.js' => 'e34a177581e98e66e0fbd43a576c6537',
		'bg.js' => '87abd6af099fe3ffe9929f5eb236dcf1',
		'ca.js' => 'e7484a7c54e7a5b4568c33c684015b7d',
		'cs.js' => '799271a7405c90ef5ec7f04c6fed0cd1',
		'cy.js' => '60ef1d2d1b292c1ab9df58bad8a9c9ac',
		'da.js' => 'fff9ea3a552e9086006386dab07910b6',
		'de-ch.js' => '333ec318242c310e9b630320f586d72c',
		'de.js' => '037e627c5e125df7772c0d72bae0e694',
		'el.js' => 'f1a8ae461d1d6cf8c3c5dd1175336af1',
		'en-au.js' => '47eeeeb32b9b9bf963e66c6801d521fa',
		'en-ca.js' => 'd1aaceecabed5c0b29fda08f9589c7f5',
		'en-gb.js' => '5ddef310eb0e9f838f15a83940ff18c9',
		'en.js' => '7e9828049e43400534ee6e83320fc671',
		'eo.js' => '4e7ed58f85f6889131c5e5ed30efbab4',
		'es-mx.js' => '0554c04052afee6f897950104f276d40',
		'es.js' => '8a4aef268e26fcd2d6c8c0b325d53913',
		'et.js' => '8a09aae6621706fd9d7ad3e634e9c2c9',
		'eu.js' => '010d929d83c95656baa500f81a0a0a0b',
		'fa.js' => '5532e6602e2a9ca107f8e0e34b7fa991',
		'fi.js' => 'a48d2dff5aac3a931df6dad8f716972a',
		'fr-ca.js' => 'f8fefd214a4deffe639565a9516f8a9f',
		'fr.js' => 'a9c2cddfee4e35d2212889d42534b77e',
		'gl.js' => 'edfc04f4086d6eb317f19ab768b56f85',
		'he.js' => 'b0895f1d8c24db891a916961db8684cb',
		'hr.js' => '0ac2ced2b444be9a0849821c3e6f3447',
		'hu.js' => 'f5525728ff2a247c727ead7542609117',
		'id.js' => 'cdc9cc18b53938e9e66d60779e2f7775',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'it.js' => 'a97b21ed010f09e7e407a22d37d43ad8',
		'ja.js' => '1726941d18afedf99f71c62a5dac7ccb',
		'km.js' => 'eae31d9832365d118e0f8b98d9e88f20',
		'ko.js' => '1ba8365b08b9f4cac12ad9978955150b',
		'ku.js' => '6fab36cabaed7bc71881c7c0cdcd0211',
		'lt.js' => '928454c5836ba17352cdd3a1e7b20093',
		'lv.js' => 'cd3d2932faf46424c47af4c926d99227',
		'nb.js' => '88c9e67b6e76624cbc0fb519a47d19cb',
		'nl.js' => '8d155aa0ad7bd1a7e0ae821e7e16b476',
		'no.js' => 'b41915f2b192af44f297ebbf4e6f1414',
		'oc.js' => 'eb4b178148c1c183133dbdcc548fe29c',
		'pl.js' => '928195ba282767fd971e55df1b45c200',
		'pt-br.js' => 'a72a51ce20444a24f9e11e78a9591993',
		'pt.js' => '4168a41c42c3517a82ad4682c68a55fc',
		'ro.js' => 'dada5fcd70f738e19b514d78c56611c0',
		'ru.js' => 'ca2c1333ccd443779797db9a6799954a',
		'si.js' => 'e700f4ff82cee114042d0b0abf181032',
		'sk.js' => 'b3e07896e5395b4fa84332340a502e38',
		'sl.js' => '7c853d0c12767be6c641ddc310eee28c',
		'sq.js' => '8790ab8ab315559b80ec7c17792456d7',
		'sr-latn.js' => 'f56047da4bc460ed7cc75c54595968be',
		'sr.js' => 'd98c73bd1ca93a2f6eab9b027ced97fe',
		'sv.js' => 'd1d53b7dfd3ded50f5409923f302e2d8',
		'th.js' => '7e11442e0c128dd8cd6b019bbfaffdfa',
		'tr.js' => '06b017382fc778fbbe1a78e921e60197',
		'tt.js' => '01ccd88f0254570c3f75addf19b20e94',
		'ug.js' => 'a5f605648111842ad596ef8052242f9d',
		'uk.js' => 'd22fd92673aa44727b5a852434578cf5',
		'vi.js' => '2451b11645c22e4ac74b9dca736c71f1',
		'zh-cn.js' => 'aeb6f7a75413a1fb63242bc0d7839579',
		'zh.js' => 'd90d22dbd8293edd4b56e9d6ca91c0d2',
	),
	'/js/ckeditor/plugins/table' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/js/ckeditor/plugins/table/dialogs' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'table.js' => '5c0575026298250451d741f1451f4f8d',
	),
	'/js/ckeditor/plugins/tabletools' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/js/ckeditor/plugins/tabletools/dialogs' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'tableCell.js' => 'e3f40f9ceb4f47df8a1f5abcd657ff0b',
	),
	'/js/ckeditor/plugins/templates' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/js/ckeditor/plugins/templates/dialogs' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'templates.css' => 'a64face0c3217f75216318132b5f2660',
		'templates.js' => '628f5c1ee622702d470693bcaa14361d',
	),
	'/js/ckeditor/plugins/templates/templates' => array(
		'default.js' => '9e59eebc94b97c42116b20ebef9547d2',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/js/ckeditor/plugins/templates/templates/images' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'template1.gif' => '3136e5de71846b8c953b00f10eb397f0',
		'template2.gif' => '7d06d52475862c2eb024be874db07ba1',
		'template3.gif' => 'ba8efaef2def8132bac190720d34b4c9',
	),
	'/js/ckeditor/plugins/widget' => array(
	),
	'/js/ckeditor/plugins/widget/images' => array(
		'handle.png' => '9545978511afba8d836510b4b65a9f27',
	),
	'/js/ckeditor/skins' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/js/ckeditor/skins/moono-lisa' => array(
		'dialog.css' => '7316ef45b80b8fa0571d43195ce1314f',
		'dialog_ie.css' => 'cd9ee3d98ae8ee5e9394567fc4c47d8a',
		'dialog_ie8.css' => 'f686f78c885b165de094149ad123583f',
		'dialog_iequirks.css' => '7702c0f8b8d1f2b09e3dfe9dc67e187d',
		'editor.css' => '010f73afe6c089137855f870260f8469',
		'editor_gecko.css' => '508cafbd829396ae12131613831f6699',
		'editor_ie.css' => 'd44cab87e4d83eb3a858851cf260fa94',
		'editor_ie8.css' => '398b722f9fbca9bcc193d3ef09ebd163',
		'editor_iequirks.css' => '84a8bb04883857b8fcfc97b529a8a7d2',
		'readme.md' => '8f9414bfd66629bbe5aab660feef5218',
		'skin.js' => 'aa0b0255e47a7a7490e97a3937d83696',
	),
	'/js/ckeditor/skins/moono-lisa/images' => array(
		'arrow.png' => '6fb2120fd35b49c3cec315a9f813daca',
		'close.png' => '4a5029938889abe0bce69b0c2b87b9d7',
		'lock-open.png' => 'c84b2053f5dc9027bf24b388bb10d560',
		'lock.png' => '4e530ef0e6f06ab83a4ac7073a70c8ac',
		'refresh.png' => 'dc6708544629e319dd7f51acf716f080',
		'spinner.gif' => '7f32b6e67f42a0ef3e1ddb0b9401f6c5',
	),
	'/js/ckeditor/skins/moono-lisa/images/hidpi' => array(
		'close.png' => 'af3bc3cc83e7eb5872e7c891184bbd08',
		'lock-open.png' => 'ef64ecb3e423dcb93f513e425e43ab77',
		'lock.png' => 'e79eccafbdd92d68c44d08f351ef8c39',
		'refresh.png' => 'bc7e0d0a46a62a31aea5245d2fb6abaf',
	),
	'/js/ckeditor/vendor' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'promise.js' => 'e89748afc09f3afcd5ef40c04bcaf376',
	),
	'/js/ckeplugins' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/js/ckeplugins/autogrow' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'plugin.js' => 'ce9665a365c4fb35f263258b69b9690e',
	),
	'/js/ckeplugins/autosave' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'plugin.js' => 'c29cea364b9da60ef86216302ec570c5',
	),
	'/js/ckeplugins/image2' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'plugin.js' => '6cc3c39229681ae968a7d8e3dd0dd53a',
	),
	'/js/ckeplugins/image2/dialogs' => array(
		'image2.js' => 'd5240d0334096acafb0054539324072f',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/js/ckeplugins/image2/icons' => array(
		'image_dark.png' => 'aa8e08f1aa70f8996898214aa7041a2e',
		'image_default.png' => '203a997298a0629e47896aa5d6a6f88c',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/js/ckeplugins/image2/icons/hidpi' => array(
		'image_dark.png' => 'bb356a83e81e7007b5b41305143452fc',
		'image_default.png' => '5197499379c44681f541a65ebe182f8e',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/js/ckeplugins/image2/lang' => array(
		'af.js' => 'ec2e0d85ecdff828b2fbeb17cfec9128',
		'ar.js' => '66114a8a4e80cfc1dd3498de894ced73',
		'az.js' => 'c156f47a8c21ee86b325db97ccf4bc40',
		'bg.js' => '57745ac4d12576f115ee64a7fcf0712b',
		'bn.js' => '592f0a5c743dd80e69bf21cad169f851',
		'bs.js' => '890d9edb0fc9b5baa799b94b0a0122d0',
		'ca.js' => '986a4c45a109a45610bc38b65cc953bb',
		'cs.js' => '913de5a1454bf6f8e28790c49585a08f',
		'cy.js' => 'f2a8f6da6d20426b07769806d51f3e3b',
		'da.js' => '91fd59f598cb6358bc9519798b9cd8c4',
		'de-ch.js' => 'e7d118de55627ac0688ba0ae23d05014',
		'de.js' => '1112c545cf6f4704a8f038cb150d5ed0',
		'el.js' => '572e0c0bd41d7277f3d1f341ed71923d',
		'en-au.js' => 'a59de83ece8cb18a60073b6cdf5e5dae',
		'en-ca.js' => '2018fc78e96579c7459cbafab2a4d13f',
		'en-gb.js' => '67e6681a86e456319fb3916b5b190b55',
		'en.js' => 'e55a05b41f1e3e72d7189ecab922a9e7',
		'eo.js' => 'f94dc084827750686a719d5be416dc7e',
		'es-mx.js' => '5c595d0b95f732bf7488037e958f9863',
		'es.js' => 'f8299a84f548abd279c5934db2b9c087',
		'et.js' => '51bfe83407b7d99469e8abd292355c09',
		'eu.js' => 'd05ba01e496ebb137329f8cb75b2306e',
		'fa.js' => '8708f1b03c88078096c96b01d2d5ffea',
		'fi.js' => '3be18588960cf97b33398010f2001d7e',
		'fo.js' => 'fce0129e24de903446840b4251f080ee',
		'fr-ca.js' => '2b3d9a5f35f47c32d0747c1aa0a57530',
		'fr.js' => '38c164302bd1949ef085bdbb81e21821',
		'gl.js' => 'e54608c531e2dc7a51c3f819969e91d0',
		'gu.js' => '970bb9a9be24631dac145d55e3efc6ad',
		'he.js' => 'fd61d75df4939926939655c63c92b603',
		'hi.js' => '3d1780f630a35d39a973f10f2702ebb9',
		'hr.js' => '8d99673bf69eb88770a867aeae2cf40f',
		'hu.js' => '7ec6d2e457b54eae706e5c181cc0ebbb',
		'id.js' => '2c2aca00d5c542c666a694d7152557fd',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'is.js' => 'ec3b3d41f2478947e69726d1bdcdfe88',
		'it.js' => '3c9a197a9b09e3fc9a3c9b5633627c7f',
		'ja.js' => 'afdbf017058f9b972319db4c2ad6ea40',
		'ka.js' => '9dc0e424e215e0b7cc46a5b56c25dcb2',
		'km.js' => 'eee8fe036427318ef8cc4dfd990460b2',
		'ko.js' => '4b4953f0cb0830aa79d119640ede885f',
		'ku.js' => 'afda2c9977bdd385569e7d0952d4afe0',
		'lt.js' => '3560fdd1268140fedb3bed64386b63ad',
		'lv.js' => 'c30cf62cbeb2f206c61d2c77ab4c441c',
		'mk.js' => '9a5aad275696a26cb8237870716b6f1a',
		'mn.js' => 'd97839dfd8213f54dd49890e704ffcc8',
		'ms.js' => '5aec3b9e2787c856f341b9db220295fc',
		'nb.js' => '5d46ea0f8892ad74482e42da018a8def',
		'nl.js' => 'ffd43b38185371dc56c3fd61f21fa742',
		'no.js' => 'ec78e161e6bb41248f3afa18dc2410dc',
		'oc.js' => 'ebc5a33aff3ab88045a392c435e55e18',
		'pl.js' => '543ef99dd2900eeb37c97f703efc2218',
		'pt-br.js' => '32f18628ce9111e5b3ecd60e7d24aba2',
		'pt.js' => '0810a1c89278a4fe165edc467076edde',
		'ro.js' => 'a9789f0cf046b58319ad708488865544',
		'ru.js' => 'c8d91d7258370b5f4f1d9d713f0ab835',
		'si.js' => 'c6797b1d0c8ad5da6bcd51d6932cb912',
		'sk.js' => 'd3f58e394b00884bc7411f5f3c073288',
		'sl.js' => '47e8d1f2aeb5dca7a2ee594e8813250c',
		'sq.js' => 'ca80fb0a0f2046b8009d18ff0082202e',
		'sr-latn.js' => '52c2a8f14a104f61cde846b2431f2e0d',
		'sr.js' => 'e3f4d9a476e1f339f03b61310494c161',
		'sv.js' => '36b1f8f4af94f21e4360e93988d83a06',
		'th.js' => '781f4fe401baa03ac5072da57194d5b5',
		'tr.js' => 'c333724eadb3f34d203e4de2cd05883a',
		'tt.js' => '732b9a037bed8c8052ffe37c9314b171',
		'ug.js' => '17207e9cd7f21cc3ff3bafa99a35a0ff',
		'uk.js' => '852eb6506bfe71fc1b497891ce912dcb',
		'vi.js' => '18d180262e3a08cf2ae22f4a2383140b',
		'zh-cn.js' => '51d88fbf218b38dab7ea354362cee4d5',
		'zh.js' => '5109c18870e7fc663141e5ba2accaf8d',
	),
	'/js/ckeplugins/resize' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'plugin.js' => '6596a299399e799223f6cb9215331dfa',
	),
	'/js/ckeplugins/vblink' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'plugin.js' => '0b5c20707a350189f04e4cca5fb8a1b8',
	),
	'/js/ckeplugins/vblink/dialogs' => array(
		'anchor.js' => 'd27f622c996d8da17bd915f7db2356cc',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'link.js' => 'f9a8e01aafea5d67eff25c97778c12e6',
	),
	'/js/ckeplugins/vblink/icons' => array(
		'anchor-rtl.png' => '1bd28647cb8c1d1de26e22818848ea7d',
		'anchor.png' => 'f40edd04a2ffd93c85dddd760fca51e8',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'link.png' => '14f94a996c88092643b8538eb7db1f2d',
		'unlink.png' => 'b0e7c0eca32d01c5efd3971cafb7e5b4',
	),
	'/js/ckeplugins/vblink/images' => array(
		'anchor.png' => 'fbba0615b425d08fbd0e7a11296f9472',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/js/ckeplugins/vblink/lang' => array(
		'en.js' => '8e86de58e981959f2e4871d600600de5',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/js/ckeplugins/vbsmiley' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'plugin.js' => 'f3f8ae0cc263c25f94d5cffa1f12a32a',
	),
	'/js/ckeplugins/vbsmiley/dialogs' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'smiley.js' => 'f4434d15b1b14723419c789508bf7900',
	),
	'/js/ckeplugins/vbsmiley/icons' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'smiley.png' => '512c5703874fe81f975c7ab8c5a8205d',
	),
	'/js/ckeplugins/vbsmiley/lang' => array(
		'en.js' => '99189c4f77e7f1e125f07d125c6225ae',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/js/ckeplugins/vbsource' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'plugin.js' => 'd06ef074f0311f6f7f28f4c7eb4696cc',
	),
	'/js/ckeplugins/vbsource/icons' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'source-rtl.png' => 'fa7fc3a5a9dff3389c6fce5567b6e402',
		'source.png' => 'ac1362f90503ac4aa5b266a8b4275af2',
	),
	'/js/ckeplugins/vbsource/lang' => array(
		'en.js' => '31e50b56474b063bfc257f5c6b31fbad',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/js/ckeplugins/vbtable' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'plugin.js' => '76bf0de486158af06e72ad363ce1d233',
	),
	'/js/ckeplugins/vbwrapbuttons' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'plugin.js' => '65e5974495c9b3f3b440f963ca629577',
	),
	'/js/ckeplugins/videotag' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'plugin.js' => 'c2c885bada389285b366f531fbc4e4dc',
	),
	'/js/ckeplugins/videotag/dialogs' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'videotag.js' => 'b265fc5d345cec793222b00ddcf9662f',
	),
	'/js/colorpicker' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/js/colorpicker/css' => array(
		'colorpicker.css' => '6fbf033471319eaa35cc56697e3dcf9b',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/js/colorpicker/images' => array(
		'blank.gif' => '56398e76be6355ad5999b262208a17c9',
		'colorpicker_background.png' => 'e0c7f6c52b671e92a755d004f5d4a3d7',
		'colorpicker_close.png' => '35bf8b50bd74de832f7f2eb3ef06010e',
		'colorpicker_hex.png' => '1705820da9691d890c2653a62198d48b',
		'colorpicker_hsb_b.png' => 'dfda70651bf36ed8bdbdd8245360aeba',
		'colorpicker_hsb_h.png' => '3d524d4522038a033de27823b93a3505',
		'colorpicker_hsb_s.png' => '0874e126c1a791f1ce95abf961dab8ad',
		'colorpicker_indic.gif' => '62d80b015ce35864771ac16ef1a0ca23',
		'colorpicker_overlay.png' => '0e0151d726faa9ab3437758cae87fbe9',
		'colorpicker_rgb_b.png' => 'c4624a2e09ab05148182b23e728b77f2',
		'colorpicker_rgb_g.png' => '9ca24f17d3afdcd85233ce3a1bae4f4b',
		'colorpicker_rgb_r.png' => '25927e3c36fe35fbbe7634d08a1b4277',
		'colorpicker_save.png' => 'bbeb83fb356080745f82865be76189a3',
		'colorpicker_select.gif' => 'cdf55197d05f18c552dc35bdb858fa2a',
		'colorpicker_submit.png' => 'b723c88103936903ad57c006bd6c2481',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'slider.png' => '424b1d6b0040b0d552da03eb01b131e3',
		'trigger.png' => 'e21aea668b366228c37c4fd3f281576a',
	),
	'/js/flatpickr' => array(
		'LICENSE.md' => '4b3598865e8aaac0c4596f8cf3ac62d2',
		'README.md' => 'c2652c865397f093af2000be6488a982',
		'flatpickr.css' => '6635fc92a9b0bb77c49fb9614841978a',
		'flatpickr.js' => 'b27fbb9b9c14d6e70ac7daffa1a3f218',
		'flatpickr.min.css' => '4baa960681bc1716d01606b3b22a87dc',
		'flatpickr.min.js' => '2328c9b2822711de4fd5e3aeda6013aa',
		'ie.css' => '1d78fa1ab37517e4eca8bb058afb7277',
		'index.html' => 'cc7819055cde3194bb3b136bad5cf58d',
	),
	'/js/flatpickr/l10n' => array(
		'ar.js' => '00a34bc6d60b28d7d701f15374744443',
		'at.js' => 'e15fb3dfd321a04fca61629e6f6948a9',
		'be.js' => '18b60e09b11dd7da7457f9e1a639c75f',
		'bg.js' => '98fc734efec97fd4fc9c61f5c654857e',
		'bn.js' => '9fcf9cdddf27398dfe391c4107317b93',
		'cat.js' => 'ee971f97074bc8c43c87fad39d56817e',
		'cs.js' => '01eef5784fc555983f3c349774016b7e',
		'cy.js' => '22dd53e1cc6b8342a3d768906d0d81db',
		'da.js' => 'b58891adfa20270bab1776acfcd9f6af',
		'de.js' => '06435107946d0f24235439bd1591ac50',
		'default.js' => '1b6561082c739a42f6bd2ba441923dfd',
		'eo.js' => '44b1fd73501eb3a90596e004fc517de6',
		'es.js' => 'bbc74b92e1f1ed7be0e7dac67c5caf4f',
		'et.js' => '0c6127e8dab511e2f4c38b971502104d',
		'fa.js' => '84399ebc5280a696b8f2146b3fd4a933',
		'fi.js' => 'f8a1dbe0c938eec4e16bd7f62dddfc05',
		'fr.js' => '97076eb20848df1adba36b9f08be5507',
		'gr.js' => '982842a4673210b48849d16a9b0d687c',
		'he.js' => '03eba33a8a37450f634df9d07159960f',
		'hi.js' => '8dc6c442e9f99afc866e78ced0a08062',
		'hr.js' => 'e3368270e032f4ec79540356502c11e1',
		'hu.js' => '9dc1fde1db98f82261487eb93b1f7c8c',
		'id.js' => '457f60e25187037a2fadaf3e7c508f09',
		'index.html' => 'cc7819055cde3194bb3b136bad5cf58d',
		'index.js' => '3f4ed46c41dead6a5d1e03e4e1514dde',
		'it.js' => 'f3b230d77b8feda8c6e0caf1379fb472',
		'ja.js' => '313a169e2e63e4da2fd9958c0fb043bf',
		'ko.js' => '21501b86562bbb4f101e495ab7ee6d09',
		'lt.js' => '7947642fa73caa4dac55532ead06151a',
		'lv.js' => '0938743dca2e6fa3ffaa192da70c2a3b',
		'mk.js' => '8141ea964e17fa7fed5f3ac077737dbd',
		'mn.js' => '98d187f8771cb44dc00fc3935bde0d5a',
		'ms.js' => '843d922d05ffaf8aedf6448a80886a44',
		'my.js' => 'a45ad50c48507947b9ff3ebe045fcead',
		'nl.js' => '08e6e346384cbc1ed526f4a17633ba72',
		'no.js' => 'dbe91be98a35d76f1438ddb0bb6bcd6f',
		'pa.js' => 'bf5491f77f09944cde2cbfc0ff2f2e0d',
		'pl.js' => 'cce9c75ac4902f279d0746a7b798d640',
		'pt.js' => 'b4980ff4a56e9c3bceed814b39d4d4ef',
		'ro.js' => 'e5810df2191abd70e753544e4c1419e3',
		'ru.js' => 'e645e76628af54600249a736e1d9a14c',
		'si.js' => '858b0124edb22368d3c746995466c8f6',
		'sk.js' => '69583d8d23021eda7a49ce15bee1ee7b',
		'sl.js' => '85bc589db5154315129efc1c07d90fe9',
		'sq.js' => '407de211bdae2e8158ac102f9f1a985c',
		'sr.js' => '51d263d333427f446f9b164711675117',
		'sv.js' => '6287b3ffba8be7498b33f1a26d24bcb0',
		'th.js' => 'c9ec7a7172942bd17d321bc1c610535e',
		'tr.js' => 'ce7ae992296967539879c202fde527a2',
		'uk.js' => '07e486bec2ddc0b24b21f230dd1ff407',
		'vn.js' => '7abd3aaa124518c91633f96f12c0d843',
		'zh.js' => '592701450bbde96569b65d76ca95a60c',
	),
	'/js/flatpickr/plugins' => array(
		'index.html' => 'cc7819055cde3194bb3b136bad5cf58d',
		'minMaxTimePlugin.js' => '174b4eb7e08464b4784dfc3ab2957758',
		'rangePlugin.js' => 'd1de85127b17ad6e3677cd4f3f12301b',
		'scrollPlugin.js' => '3b5df722b16e47c730ea9247ea94ffe7',
	),
	'/js/flatpickr/plugins/confirmDate' => array(
		'confirmDate.css' => '04a46ca17ade2f9901cac89dceb305d1',
		'confirmDate.js' => 'be5dddd22eb4e25dbdbf0878d79bbc39',
		'index.html' => 'cc7819055cde3194bb3b136bad5cf58d',
	),
	'/js/flatpickr/plugins/labelPlugin' => array(
		'index.html' => 'cc7819055cde3194bb3b136bad5cf58d',
		'labelPlugin.js' => '09297470431623f1a819978c5ed88438',
	),
	'/js/flatpickr/plugins/weekSelect' => array(
		'index.html' => 'cc7819055cde3194bb3b136bad5cf58d',
		'weekSelect.js' => 'b870fab01513829fa14d56a708873cdf',
	),
	'/js/flatpickr/rtl' => array(
		'flatpickr.min.css' => '29be463156b32e2f0c71426da618b5ad',
		'index.html' => 'cc7819055cde3194bb3b136bad5cf58d',
	),
	'/js/flatpickr/rtl/themes' => array(
		'airbnb.rtl.css' => '764313efb11f0479cdda88f8bd058a2c',
		'base16_flat.rtl.css' => 'cda37aa390efa48e43657143aff9d883',
		'confetti.rtl.css' => 'cd9f7fc620c7c4244715753cfc7b7d5c',
		'dark.rtl.css' => '0abbf46c749f0ae56f3da61970532cc1',
		'index.html' => 'cc7819055cde3194bb3b136bad5cf58d',
		'material_blue.rtl.css' => '0a4c810a07f740dbf4d2c8df4685f3c4',
		'material_green.rtl.css' => '8ca0c6131b0480b486be2347e398da61',
		'material_orange.rtl.css' => 'e0bc39368dc9db5dc408cc62ef967a65',
		'material_red.rtl.css' => '3603b30cd14f1ae419627f9aa47b1c6c',
	),
	'/js/flatpickr/themes' => array(
		'airbnb.css' => '58ddbce1f72f38c708926730879b474f',
		'base16_flat.css' => 'c3f293c02aafa7c7d82c64d3e6d9c925',
		'confetti.css' => '5db72555cbad5d98d96f2a7fdf235d13',
		'dark.css' => '893828d6999bf71925d3d220d14efd78',
		'index.html' => 'cc7819055cde3194bb3b136bad5cf58d',
		'light.css' => '5f22b9f94426778f6a48bc1d20c5208d',
		'material_blue.css' => '38f5ab38797751d89723bc2c1dcc1140',
		'material_green.css' => 'df4ad1a1bb0336e61da3a50abeff9b58',
		'material_orange.css' => 'bf10c463668660611b5779db7966cc18',
		'material_red.css' => 'a7dc4c0605473a31617c40d8eb0b9d39',
	),
	'/js/jquery' => array(
		'history.adapter.jquery.js' => 'a2937a0378c72a7546100eef9fc825f1',
		'history.adapter.jquery.min.js' => '1e5a8177c054dd3a033e4a9526cb269b',
		'history.js' => 'd2d126e934d52b0a7caa4965625bb636',
		'history.min.js' => '42fd68e9a088c56d892c1213864951eb',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'jquery-3.7.1.js' => '12e87d2f3a4c8b347ab13a0764d420a3',
		'jquery-3.7.1.min.js' => '2c872dbe60f4ba70fb85356113d8b35e',
		'jquery-ui-1.13.2.custom.js' => '951d76c8d848f8c6f8aa3385085dec9f',
		'jquery-ui-1.13.2.custom.min.js' => 'b30c9554a032f6433be46b33979bdcbe',
		'jquery.autogrow.js' => '4cda035c6bb57146afb30e3198cc542c',
		'jquery.autogrow.min.js' => 'f6b63b4f46d5bafbef477a94badad198',
		'jquery.condense.custom.js' => '12cefc2ef51b0d70db0e974605f61a1b',
		'jquery.condense.custom.min.js' => '23b3ea0241a4bcb8d0569ed307e82c7e',
		'jquery.form.js' => '4fa896f615af66c3d7ef0f960895f14e',
		'jquery.form.min.js' => '380dba6716e3357c4e2e26b535a2b24a',
		'jquery.highlight-4.js' => '99f1e6a353e54b27678c6a5b2e1c9a8a',
		'jquery.imgareaselect.js' => '4cd6f10ffd85ab6d2fbc4951c34b3379',
		'jquery.imgareaselect.min.js' => 'ef7c1f1fdb33d8c5646320da8dcfa039',
		'jquery.jcarousel-swipe.js' => 'f5b6c059ddb7202082bb4d23c2de1c88',
		'jquery.jcarousel-swipe.min.js' => '7a915ff17097a56391b96b2d2b72571c',
		'jquery.jcarousel.custom.js' => '73ea19e1b6ca904069fdb47c9de7f0c6',
		'jquery.jcarousel.custom.min.js' => 'f3d383721a706c7ab84bda0690154be4',
		'jquery.qrcode.min.js' => '05f0b1d7d4b9b0b4975870606d650e3c',
		'jquery.qtip.js' => 'ee0c687d099e80985a427e32f071d277',
		'jquery.qtip.min.js' => '02a41f89157b5e2e54bcda8341144262',
		'jquery.selectBox.js' => 'f902fec085f41b654c05a0299d6c45c4',
		'jquery.selectBox.min.js' => '9ce8139ff0ead1e1bf0a21866daeb84f',
		'jquery.thumbnail-radio-checkbox.js' => '5a17d30f86ba4888358a257c5d8eb5b9',
		'jquery.thumbnail-radio-checkbox.min.js' => '2e47cd3ea004971b4c43fcea1fef7e7d',
		'jquery.ui.touch-punch.js' => '5eb6104c6e67bcaf9e4b62ee71dd63d5',
		'jquery.ui.touch-punch.min.js' => 'dcd71864693b28df2a5549b65f97e722',
		'js.cookie.js' => 'ab18c4cd54861554624eacf8b5e1f009',
		'js.cookie.min.js' => '2bc605e837691bbcbd0289f5821fd249',
	),
	'/js/jquery/datatables' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
	'/js/jquery/datatables/css' => array(
		'demo_page.css' => '0db45c8d6dcea46236553fab0018e1cf',
		'demo_table.css' => '8d069550cac86bdf0cacd9c123b439c5',
		'demo_table_jui.css' => '71cae1fcd55bfc60627d477486c8158a',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'jquery.dataTables.css' => 'b9b3c874609596bc0c9078ad65d15770',
		'jquery.dataTables_themeroller.css' => '198cac6dd48c78632f3124fa4539bfa6',
	),
	'/js/jquery/datatables/images' => array(
		'Sorting icons.psd' => '9c287dd51872df723c35176fdcb4893d',
		'back_disabled.png' => '968ff33455accf7bb3a6eb22d83882bf',
		'back_enabled.png' => 'c95ba87c7dce4de4e6bb0fec175b1c0d',
		'back_enabled_hover.png' => '7658d92cd4d9d81eb1a7ec6afe449e37',
		'favicon.ico' => 'c30dc560221bcc0645b55eff79b4741e',
		'forward_disabled.png' => 'd0075e12ab937b295e40c28ff4e63b80',
		'forward_enabled.png' => '176ddee8ff726d430348d2c4145eeafc',
		'forward_enabled_hover.png' => '6e01bfa03daa4f8bb682ca3f7aaf305f',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'sort_asc.png' => '56dbbefb9accbdc915adb2efb129f16e',
		'sort_asc_disabled.png' => '56dbbefb9accbdc915adb2efb129f16e',
		'sort_both.png' => '580f0db1b74579871ef9b8c99288a6dc',
		'sort_desc.png' => 'a88da5997b1992bc5167bded035a89d0',
		'sort_desc_disabled.png' => '671ea8aeee5520a417ae85e438a97d9f',
	),
	'/js/jquery/datatables/js' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'jquery.dataTables.js' => '8938e68fe6c1562870a24a084362b28a',
		'jquery.dataTables.min.js' => '2338fdebcee0226397db679413019f4e',
	),
	'/js/jquery/fullcalendar' => array(
		'CHANGELOG.txt' => '59b234b71a08d264db50a55be0d5d535',
		'LICENSE.txt' => 'de76520d2a2796a4d00123bc68a6e885',
		'fullcalendar.css' => 'e8b40e00132440ce72c5fbd0b949b5a4',
		'fullcalendar.js' => '3c63abe0121187c31742d61fefbbfc08',
		'fullcalendar.min.css' => '01cf59ecd029c0e3104294cbf80651a5',
		'fullcalendar.min.js' => 'cd2031c11947ddd078509eda45bd5b7f',
		'fullcalendar.print.css' => '5ce8189b1ea1fff4a44536ed5a05d47c',
		'fullcalendar.print.min.css' => '9c07631b91410332afd52327b3cc57f9',
		'gcal.js' => '8f4bb8aad4286d65bb1fa8d7f8778d8a',
		'gcal.min.js' => '6ac391ec8d253848dccd5cc4e9c0092e',
		'locale-all.js' => '78c23f4647948ffdf11a062fc893e82e',
	),
	'/js/jquery/fullcalendar/lib' => array(
		'moment.min.js' => '5866442d05c36bfb70a25cabc3a18bae',
	),
	'/js/jquery/fullcalendar/locale' => array(
		'af.js' => '4cc8fff4e0eae2beceb28852407d8ee1',
		'ar-dz.js' => 'bdebe3cc6c859fe19a39c4dcaeb8f46f',
		'ar-kw.js' => 'c99dc3d59530da6680fd7ab4f4a59764',
		'ar-ly.js' => '56ead35e6aacb17c5b2348bb4393346b',
		'ar-ma.js' => '38c8ca9e899398702a4c27171f90d4a3',
		'ar-sa.js' => '37b2642147cf798072f41e6db0ff9e24',
		'ar-tn.js' => '6688881ac22f904e20d475b4f7d8e502',
		'ar.js' => '318ee308a3338e650e21eef9bfec4454',
		'be.js' => 'ee704412608520b4a15461067bf10e80',
		'bg.js' => '844a0e17b21f6f108a2c2d52279a4194',
		'bs.js' => 'ccbff7000925c53198d4994d2b020920',
		'ca.js' => '9f4daf05cbd58dac565e862548362e50',
		'cs.js' => 'dc1b420fe2a146249881910ac5db32d4',
		'da.js' => 'c5e64b64407b8711626d0b341dbe6aa7',
		'de-at.js' => 'f58ebbf82fd65ff7a547e47ecffa9a87',
		'de-ch.js' => '1ff636a1d3f423fc532bf18a3ca77657',
		'de.js' => '15d5d4e179318560629fa0eea56a8510',
		'el.js' => 'e84f864007f21d6d3af779676dd9bc0a',
		'en-au.js' => '87eb7d91bfd405f2b1fa748dd944ec2e',
		'en-ca.js' => 'a21ff12d18dd973274e8d83726abfb46',
		'en-gb.js' => 'e957c4fa13bca1f4a29528b8729eff9c',
		'en-ie.js' => 'a11a68388d5d7892b86857c61944f9a6',
		'en-nz.js' => '536427f5c3395b42415533f189aba586',
		'es-do.js' => '3f973a3cc32a8dfd98ba2cc768543b41',
		'es-us.js' => '802b70cef70015513fe2abd746812b18',
		'es.js' => '16cb0e49055f2982cc512bdb8be8f83f',
		'et.js' => 'e968806ddef3a40ac8ee3beb4630b876',
		'eu.js' => 'e7a94e494c802877f4563f38d92f6d0e',
		'fa.js' => 'fd79aa5ca8ed85c9c6deeda0ad4023c1',
		'fi.js' => '8da8595594a3664a85e471e21d203a82',
		'fr-ca.js' => 'e8153da9dc2ca4ad6a0b4dd29f217f72',
		'fr-ch.js' => '10d15457f413e7e46a68cd79658f30d6',
		'fr.js' => '140a7e017212fcfcb7969f2adadc499a',
		'gl.js' => '40672764b9b4e830fa5231a8c33d6d71',
		'he.js' => 'e340e0ad6d7324a4a01b1329ff5e8e8c',
		'hi.js' => '3be62d0ccf23cdc983f81fcffebf8fad',
		'hr.js' => 'faaefb256840cbe92ebf567d445df81a',
		'hu.js' => 'c69c977c4698337ef02bc6d680f87171',
		'id.js' => '3ad379acdd2a9c87636116db9c31a374',
		'is.js' => '6756a2b553dfe63771134dd621836150',
		'it.js' => '847cc8ca9b5f4e6e9885bdd3a80006e7',
		'ja.js' => '64896b3b2898658036dc49a5b231db41',
		'ka.js' => '29936c3375ddb8464870f36fbb434de4',
		'kk.js' => 'a1a408d0934f8efee6b2e251d981aff9',
		'ko.js' => 'baa216ba89b4cd77221c2bdf4cd7a51b',
		'lb.js' => 'c383c75a5e9b54fa9d23afa1c33d81f6',
		'lt.js' => '2973703128bcb2ebada18ff239407825',
		'lv.js' => '316fba27f32475d6a2deef6c3932cba9',
		'mk.js' => 'cec11889b3e1a471aabe912c3019ccf1',
		'ms-my.js' => '9b11dd8ab04790934e73026d0be5c105',
		'ms.js' => '6775cf3c9ec6a867a01f63865ea2b02e',
		'nb.js' => 'adda2aadc37a1201ada9072e771d912e',
		'nl-be.js' => 'a290d39d6d9956e66f33592c91f03db5',
		'nl.js' => '0104eea0e4be0f98dc258ad3e2331eb4',
		'nn.js' => '8279b5dd8d8b3583bc414a4daa59edf8',
		'pl.js' => '5c5178c680aa3391867239eaa12ca85c',
		'pt-br.js' => 'd98aac0792be3dfe0d3d5d24c0ce2045',
		'pt.js' => 'd0d6e93cca316749b60f842603f624b8',
		'ro.js' => '00221148727ea0321bb6da9aa3590f4a',
		'ru.js' => 'd870d9459ac48f242fd78769a558711e',
		'sk.js' => '47ac02a362d43c11bedb68c9a26c8ca7',
		'sl.js' => 'fa1ebfff7cf78ba299c867bb61de8a0b',
		'sq.js' => '9b1c029280b5e0a71c89c5f7180386ef',
		'sr-cyrl.js' => '3dbdeb11141d10d9c9e822a82ec3c5bd',
		'sr.js' => 'e1717b43e0b03035a76803733c0502be',
		'sv.js' => 'f9635cf98c68864598a9ceb65ad4f86e',
		'th.js' => '6f333da064dee1aae8ed587329324c29',
		'tr.js' => '759160f2f78b84f51820fc3a4f866889',
		'uk.js' => '47074b1b9f70ecf27c228c02605d8164',
		'vi.js' => '28b1bf8515dcaa8eb23e09ee7423b493',
		'zh-cn.js' => 'c87e8d5e6c7bfc4572e5d90fdcac5d4e',
		'zh-hk.js' => 'b3778073a8d32571487fb30986fa1274',
		'zh-tw.js' => '0350357773cb032e369025733afc509c',
	),
	'/js/jquery/jssor' => array(
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
		'jssor.slider.mini.js' => '992d32a113957b5db26220f163a1c173',
	),
	'/js/jquery/jssor/img' => array(
		'a01.png' => 'b3a4dfeed8af5b5436b409b06ad4ec02',
		'a02.png' => '6fc44bfa2654e190ae0df4d42bd9a85b',
		'a03.png' => '423401cb15d5ce96bd7334ce11025c99',
		'a04.png' => '4c21f90aab6e78fe81209b2f08a6ad21',
		'a06.png' => '3355b89001029e78629c4f4aedd980c2',
		'a07.png' => '7ff90ee82079b366a1ec13d9b618f6f6',
		'a08.png' => 'e99d489aea32bd7e3923ec13a8950331',
		'a09.png' => '3f22db82513cf4aaab1a14db5246268d',
		'a10.png' => 'd278295b81195a221ff78a646fd00881',
		'a11.png' => 'fea6275fd2a203e049aa5032e17a834a',
		'a12.png' => 'fd7d2200d34c23ccc9071de6f5baeb60',
		'a13.png' => '93ff8e198333eec903a37768ef519357',
		'a14.png' => '1e9ef4546c7e30c0e52b42f58218c534',
		'a15.png' => 'f9dfe58727f0d1a1c0ee1ab6d1c745c4',
		'a16.png' => 'd531b16e67c4f695769f709f0be9dfa9',
		'a17.png' => 'dfb5fecf5c8ed8704bf74c23032660f0',
		'a18.png' => '3a6d32cb6baab301b6af0437cb1877ba',
		'a19.png' => 'e8ab2afb948fd6ab607123e3ccfd881c',
		'a20.png' => '3eeaa170357a1324b0627393d9f02061',
		'a21.png' => 'f7ce725a84be585ca5382b74d6febc64',
		'b02.png' => 'e09e717ec8145aa04e8f8faaa096c1bf',
		'b03.png' => 'eb9337f8ca7f70ad4b71cf9146894cf5',
		'b05.png' => 'dbe4b243194edc76f8de932786d8acab',
		'b06.png' => '6f541c4f5f5ad1893977875ee183dd38',
		'b07.png' => 'c2340b8fd6a28f522069188bfb1e68d2',
		'b10.png' => '98604e9cf055ce656b4b51ddc2ce770b',
		'b11.png' => '81cc5ab3dd6315ae6203718a1975ca42',
		'b12.png' => '0423f6879f25556456a7c86143cf3aab',
		'b13.png' => '94b537300555e65c3f05f5f33abb239b',
		'b14.png' => 'cbbb32e1cda36e068b53e6de06454995',
		'b16.png' => '011236ea6be6a9ed1ce883955f90c5ba',
		'b17.png' => '2f6bfd357bd98eb2077c17f3b588fa51',
		'b18.png' => '58c64644b7f2c6d921e672613ce204c5',
		'b20.png' => '70a5d8544f8cf7866cd94ddc621f2046',
		'b21.png' => '741242d171fbdb835ad0f7e694716d2e',
		'index.html' => '68b329da9893e34099c7d8ad5cb9c940',
	),
);
$md5_sum_softwareid = 'vb6';
$md5_sum_versions['vb6'] = '6.2.3';
$scanRoot = DIR . '/..';
?>